(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1031857,      24677]
NotebookOptionsPosition[   1030737,      24644]
NotebookOutlinePosition[   1031220,      24662]
CellTagsIndexPosition[   1031177,      24659]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Best Fit Ellipsoid with Statistics For ImageJ-v3.0\n", "Title",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["by", "Title",
  FontFamily->"Arial",
  FontSize->26,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox[" ", "Title",
  FontSize->26,
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 Cell[BoxData[
  FormBox[
   RowBox[{"Matty", " ", 
    SuperscriptBox["Mookerjee", "*"], " ", "and", " ", "Scott", " ", 
    SuperscriptBox["Nickleach", "\[Dagger]"]}], TraditionalForm]],
  FontFamily->"Arial",
  FontSize->26,
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox[" ",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["\n", "Title",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "*"], TraditionalForm]],
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["Dept. of Geology and the ", "Title",
  FontFamily->"Arial Narrow",
  FontSize->22,
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "\[Dagger]"], TraditionalForm]],
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["Dept. of Mathematics and Statistics, Sonoma State \
University,Rohnert Park, CA 94928\n\n          ", "Title",
  FontFamily->"Arial Narrow",
  FontSize->22,
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["This Mathematic notebook ", "Title",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["will determine the best fit ellipsoid for arbitrarily oriented \
sectional ellipses and determine error margins for the resulting data.  Input \
for this program includes the axial ratio and orientation of the sectional \
ellipses without needing to know specific axial lengths or ellipse areas.  \
One can either specify the mean values and standard deviations for the axial \
ratios (Rf's) and the angular orientations (\[Phi]'s) along with the number \
of ellipses measured or input the raw data (i.e., a file with several/many \
elliptical measurement) and the means and standard deviations will be \
calculated automatically.  The mean ellipses are determined by averaging \
ellipse shape tensors as described by Shimamoto & Ikeda (1976) and Wheeler \
(1984).  Additionally, one also needs to input the dip and dip direction of \
the plane from which the data were collected and an estimation of the \
precision of that measurement (i.e., the standard deviation of the \
distribution of possible orientations with respect to the angle away from the \
input plane's pole in any direction; this value will be refered to as \
\"Measurement Error\"  in the ",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["Mathematica ",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["input prompt and in the input data files).  Data can either be \
input manually during the running of the program or it can be read in from an \
existing file.  This program will read both text files (*.txt) and Excel \
files (*.xls and *.xlsx).   Examine the files, \"Sample Strain Data for Stats \
from ImageJ.txt\", \"Sample Strain Data for Stats from ImageJ.xls\", \
\[OpenCurlyDoubleQuote]Sample Strain Data for Stats from ImageJ.xlsx\
\[CloseCurlyDoubleQuote], \"Sample Strain Data with Std Dev from \
ImageJ.txt\", \[OpenCurlyDoubleQuote]Sample Strain Data with Std Dev from \
ImageJ.xls\[CloseCurlyDoubleQuote] and \"Sample Strain Data with Std Dev from \
ImageJ.xlsx\", to determine the appropriate file structure (it is easiest \
simply to modify these files and save them with different file names).   \n   \
       The sign convention that this program uses is as follows:  1) all \
sectional data need to be viewed from the perspective of looking downward, 2) \
perfectly vertical planes need to be viewed looking westward; for vertical \
planes that are striking exactly east-west, the plane needs to be view from \
the south to the north, 3) the orientation angle (",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["f",
  FontFamily->"Symbol",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox[") is measured from the long axis of the ellipse to the strike line \
of the sectional plane, 4) ",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["f",
  FontFamily->"Symbol",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox[" is always positive and is measured counter clockwise from the \
positive horizontal axis.  For example:",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 "\n",
 Cell[BoxData[
  RowBox[{" ", 
   GraphicsBox[{{}, {}, 
     {RGBColor[0, 0, 1], Thickness[Large], LineBox[CompressedData["
1:eJwt2nk0Vd/bAPB73XtUUlIhkqGRSklCGfbRgIRQiEQDZQoRCQlpIGQWytcU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       "]]}},
    Axes->True,
    AxesOrigin->{0, 0},
    ImageSize->{300, 300},
    PlotRange->{{-3.8116399780037673`, 
     3.8116399780037673`}, {-3.8116399780037673`, 3.8116399780037673`}},
    PlotRangeClipping->True,
    PlotRangePadding->{Automatic, Automatic},
    Ticks->False]}]],
  CellChangeTimes->{{3.487174247242574*^9, 3.4871742776123114`*^9}, 
    3.4871743338275266`*^9, {3.487174762772061*^9, 3.4871747985711083`*^9}, {
    3.48717490176101*^9, 3.4871749090874295`*^9}, {3.4871749554500813`*^9, 
    3.48717502361598*^9}, {3.4871862392520313`*^9, 3.487186271423872*^9}, {
    3.487186360744981*^9, 3.4871863936968656`*^9}, 3.487186428625863*^9, {
    3.4871865765023212`*^9, 3.487186577094355*^9}, {3.4871866405469847`*^9, 
    3.4871866966911955`*^9}, {3.487186901263897*^9, 3.4871869297615266`*^9}, {
    3.4871869857947316`*^9, 3.487186995583291*^9}, {3.487187104629528*^9, 
    3.487187110441861*^9}, {3.487187144660818*^9, 3.487187203680194*^9}, 
    3.4871883033280897`*^9, {3.487203071425685*^9, 3.487203090535719*^9}, 
    3.4872045032274*^9, {3.4872463495157666`*^9, 3.4872463693439007`*^9}, {
    3.487246433157551*^9, 3.487246435278672*^9}, {3.4872473815177937`*^9, 
    3.487247450426735*^9}, {3.4872474820085416`*^9, 3.4872477205581856`*^9}, {
    3.487248117408884*^9, 3.4872481184019413`*^9}, {3.487248178762394*^9, 
    3.4872482110042377`*^9}, {3.4872482608720903`*^9, 3.487248319881465*^9}, 
    3.4872483575806217`*^9, {3.487248908602138*^9, 3.487248909463187*^9}, {
    3.487249340737855*^9, 3.4872493588798923`*^9}, {3.4872496780271463`*^9, 
    3.4872497003824253`*^9}, {3.487250023118885*^9, 3.487250027655144*^9}, {
    3.487250575263466*^9, 3.487250676430252*^9}, {3.487251411085272*^9, 
    3.487251471173709*^9}, {3.487251816966487*^9, 3.487251829224188*^9}, {
    3.4872519179082603`*^9, 3.487251966365032*^9}, {3.4872520257294273`*^9, 
    3.487252033389866*^9}, {3.4872523305878644`*^9, 3.487252332862994*^9}, {
    3.4872523688660536`*^9, 3.4872523709751744`*^9}, 3.4872527765613728`*^9, {
    3.4872528923829975`*^9, 3.487252892648012*^9}, {3.487499290280834*^9, 
    3.48749930069143*^9}, {3.48749933355931*^9, 3.487499376693777*^9}, {
    3.4874994538371897`*^9, 3.48749946608889*^9}, {3.487499503736044*^9, 
    3.4874995041570673`*^9}, {3.487507728289461*^9, 3.487507734874838*^9}, {
    3.4875080286316395`*^9, 3.4875080768673983`*^9}, {3.4875082677043138`*^9, 
    3.4875083238205233`*^9}, {3.487508913094228*^9, 3.487508937050598*^9}, {
    3.4875876017805667`*^9, 3.487587603337656*^9}, {3.4875892032991686`*^9, 
    3.4875892051122723`*^9}, {3.487589275342289*^9, 3.4875892781714506`*^9}, {
    3.4875909175242167`*^9, 3.4875909362422867`*^9}, {3.487591048960734*^9, 
    3.4875911435141425`*^9}, 3.487591236332451*^9, {3.487591325170532*^9, 
    3.4875913269496346`*^9}, {3.4875913587614536`*^9, 
    3.4875913744783525`*^9}, {3.4875915221567993`*^9, 3.487591533167429*^9}, {
    3.487591630017969*^9, 3.487591630756011*^9}, {3.4875916701542645`*^9, 
    3.487591717766988*^9}, {3.487591978521902*^9, 3.4875919790189304`*^9}, {
    3.4876119442692347`*^9, 3.487611949521535*^9}, {3.4876123171505623`*^9, 
    3.4876123207197666`*^9}, {3.4876123583329177`*^9, 3.487612362155136*^9}, {
    3.487620968917506*^9, 3.4876209735663147`*^9}, {3.487621086931713*^9, 
    3.4876211069621487`*^9}, {3.4876211776146727`*^9, 3.48762118185788*^9}, {
    3.4876223429523196`*^9, 3.4876224066628313`*^9}, {3.4876226462948523`*^9, 
    3.4876226545940666`*^9}, {3.4879378505605435`*^9, 3.487937852526147*^9}, {
    3.4879389595976915`*^9, 3.4879389806109285`*^9}, 3.487954506800294*^9, 
    3.4879552059462833`*^9, {3.487955354226764*^9, 3.4879553548828015`*^9}, 
    3.4879778865925393`*^9, {3.488026762836731*^9, 3.4880267855730314`*^9}, {
    3.4880286760411596`*^9, 3.488028691873065*^9}, {3.48802875996296*^9, 
    3.4880287779629893`*^9}, {3.488029402590716*^9, 3.488029423166893*^9}, 
    3.4881035588680367`*^9, 3.4881039206262083`*^9, 3.488104120777656*^9, 
    3.488104903078401*^9, {3.4881050616464705`*^9, 3.488105078194417*^9}, {
    3.4881111465675077`*^9, 3.488111160340296*^9}, {3.488112068437236*^9, 
    3.4881120941107044`*^9}, 3.4881151584709883`*^9, {3.488131862127383*^9, 
    3.4881319519195185`*^9}, {3.4881327730814867`*^9, 3.488132802714182*^9}, {
    3.4881871755509825`*^9, 3.488187183630445*^9}, 3.4881889555927954`*^9, {
    3.488189998898469*^9, 3.488190098602172*^9}, {3.4881901543543606`*^9, 
    3.488190173469454*^9}, {3.4881903638923454`*^9, 3.488190380942321*^9}, {
    3.4882137973446627`*^9, 3.4882138365939074`*^9}, {3.4882140471889524`*^9, 
    3.488214056358477*^9}, {3.4882148881910553`*^9, 3.4882148951354523`*^9}, 
    3.4882149283413515`*^9, {3.4882302297011557`*^9, 3.4882302344904294`*^9}, 
    3.488231704599515*^9, {3.4882319839284916`*^9, 3.4882319992813697`*^9}, {
    3.488275876124522*^9, 3.488275881496829*^9}, 3.488276068637533*^9, 
    3.4882765579205184`*^9, 3.488277169769514*^9, 3.48827741201637*^9, {
    3.488277522075665*^9, 3.488277525446858*^9}, 3.488278079202531*^9, {
    3.488278397793753*^9, 3.488278425786354*^9}, {3.488278718245082*^9, 
    3.488278719804171*^9}, {3.488281865350086*^9, 3.488281871320428*^9}, {
    3.4882830136195784`*^9, 3.4882830192511883`*^9}, {3.488283407479191*^9, 
    3.48828342058294*^9}, {3.488285026388787*^9, 3.4882850392645235`*^9}, 
    3.4882907709793587`*^9, {3.488291081025092*^9, 3.4882910896975884`*^9}, {
    3.4882911289018307`*^9, 3.4882911544232903`*^9}, {3.488291200132905*^9, 
    3.4882912002289104`*^9}, {3.4882912461585374`*^9, 
    3.4882912662906885`*^9}, {3.4882912993615804`*^9, 3.488291313319379*^9}, {
    3.488292675314749*^9, 3.4882926928803797`*^9}, {3.488292814825794*^9, 
    3.4882928340762277`*^9}, 3.488293248100955*^9, {3.488293668880494*^9, 
    3.4882943519120936`*^9}, {3.488294386169754*^9, 3.4882944270418253`*^9}, 
    3.488294576739689*^9, {3.4883963963753386`*^9, 3.4883964781840177`*^9}, {
    3.4883965083107405`*^9, 3.488396598437896*^9}, {3.4883970123125677`*^9, 
    3.488397038351057*^9}, {3.4883973207822113`*^9, 3.4883973230023384`*^9}, {
    3.4884010355926867`*^9, 3.4884010418300433`*^9}, {3.4884029584056654`*^9, 
    3.4884029600077567`*^9}, {3.4884030443625813`*^9, 
    3.4884030517140017`*^9}, {3.4884559968958817`*^9, 3.4884560201222105`*^9},
     3.4884561828885202`*^9, {3.4884595324081016`*^9, 3.4884595557644377`*^9},
     3.488488413833895*^9, {3.488488614512373*^9, 3.488488650284419*^9}, 
    3.4884941868160906`*^9, 3.488494307578998*^9, 3.488494915640777*^9, {
    3.4884969399105587`*^9, 3.4884969446568303`*^9}, 3.4884970443505325`*^9, {
    3.488497121122924*^9, 3.4884971234120545`*^9}, {3.488497153530777*^9, 
    3.4884971544248285`*^9}, 3.488497216257365*^9, 3.4884982796191854`*^9, {
    3.4884985827925262`*^9, 3.4884985838495865`*^9}, 3.488548766839347*^9, {
    3.4885546595003877`*^9, 3.48855467351919*^9}, {3.488554768972649*^9, 
    3.488554780388302*^9}, {3.4885548176644344`*^9, 3.488554834780413*^9}, 
    3.4885558246670313`*^9, {3.488555877735067*^9, 3.488555885167492*^9}, {
    3.488555925882821*^9, 3.488555968589263*^9}, {3.488556183800573*^9, 
    3.4885561926470785`*^9}, {3.4885565714927473`*^9, 3.488556578579153*^9}, {
    3.488556819261919*^9, 3.488556860995306*^9}, 3.489757221378025*^9, {
    3.4897714976971006`*^9, 3.489771499584704*^9}, {3.4899235962696867`*^9, 
    3.489923596809717*^9}, {3.4900048505124407`*^9, 3.4900048575248413`*^9}, {
    3.490004927360836*^9, 3.490004927640852*^9}, {3.4900054204690404`*^9, 
    3.49000542064305*^9}, {3.4900273743567305`*^9, 3.490027413935995*^9}, 
    3.4900274660839777`*^9, {3.4900314898301225`*^9, 3.4900314904871597`*^9}, 
    3.490031551025623*^9, {3.4900342535741997`*^9, 3.4900342782086086`*^9}, {
    3.490036273490732*^9, 3.4900362852984076`*^9}, {3.4900363603587008`*^9, 
    3.490036371115316*^9}, 3.490037162197563*^9, 3.4900403448696017`*^9, 
    3.490048845135789*^9, 3.4904418396813517`*^9, {3.4904419441003237`*^9, 
    3.490441947441515*^9}, {3.490441986359741*^9, 3.4904420592999134`*^9}, 
    3.490444327068622*^9, {3.4904444014798784`*^9, 3.4904444022399216`*^9}, 
    3.4904474676582537`*^9, 3.49044858339207*^9, 3.490450905146867*^9, 
    3.490451714886181*^9, 3.490452510791704*^9, 3.490453288249172*^9, 
    3.490464459496053*^9, {3.4904681593526726`*^9, 3.4904681643289576`*^9}, {
    3.4904682052062955`*^9, 3.4904682058513327`*^9}, 3.490531867888402*^9, {
    3.4905333015014*^9, 3.4905333019644265`*^9}, 3.4907062892196035`*^9, {
    3.490708250619789*^9, 3.4907082541179895`*^9}, {3.490712025183682*^9, 
    3.4907120313920374`*^9}, {3.4907128353390207`*^9, 3.490712841327363*^9}, 
    3.490714884718238*^9, 3.4907291944635754`*^9, 3.490729713173244*^9, {
    3.490730085218524*^9, 3.490730101265442*^9}, {3.4907306694449396`*^9, 
    3.4907306727751303`*^9}, {3.490731048785637*^9, 3.49073105373092*^9}, {
    3.4907317737701035`*^9, 3.4907318297893076`*^9}, {3.49073192354667*^9, 
    3.490731949549157*^9}, 3.490732404969206*^9, {3.490732482961667*^9, 
    3.490732520929838*^9}, {3.490732560906125*^9, 3.490732566699456*^9}, {
    3.4907951817937293`*^9, 3.4907952097603292`*^9}, 3.49079688138494*^9, 
    3.4909578135058956`*^9, {3.490966426065824*^9, 3.4909664589038815`*^9}, 
    3.4909679863493643`*^9, {3.4909682970395103`*^9, 
    3.4909683252911596`*^9}, {3.490972673956398*^9, 3.4909726987292414`*^9}, 
    3.4909728202534547`*^9, {3.490972862435929*^9, 3.4909728817019625`*^9}, {
    3.490972913073618*^9, 3.4909729566132946`*^9}, {3.490973518869482*^9, 
    3.4909735657475643`*^9}, {3.4909736125476465`*^9, 3.490973619021658*^9}, {
    3.490973703355406*^9, 3.4909737369578648`*^9}, {3.490973801963179*^9, 
    3.4909738048959846`*^9}, 3.490974014136751*^9, 3.4911489290724*^9, 
    3.491152414014719*^9, {3.4911532777726364`*^9, 3.491153287179453*^9}, {
    3.4911533826048203`*^9, 3.4911533843676233`*^9}, 3.4911608269218388`*^9, 
    3.4911610198473773`*^9, {3.4912215420326176`*^9, 3.4912215503786325`*^9}, 
    3.4912215809234858`*^9, {3.491221615103146*^9, 3.4912217052401047`*^9}, 
    3.4912220487527075`*^9, {3.4912290845968103`*^9, 
    3.4912290884968166`*^9}, {3.4912385323231597`*^9, 3.491238550410194*^9}, 
    3.491238719776881*^9, {3.4912389233205233`*^9, 3.4912389754925075`*^9}, 
    3.491241094984701*^9, 3.4912414098657107`*^9, {3.491385847243327*^9, 
    3.4913859619878902`*^9}, 3.4913859937217054`*^9, {3.491386060978552*^9, 
    3.4913860866870227`*^9}, 3.491386146561447*^9, {3.491386424457342*^9, 
    3.4913864460755787`*^9}, {3.4913864766593275`*^9, 3.49138647687934*^9}, 
    3.491397677026628*^9, 3.4913977115026884`*^9, 3.4913978076456575`*^9, 
    3.4913980532212887`*^9, {3.491398197490342*^9, 3.491398204603955*^9}, {
    3.491398273540476*^9, 3.4913983694494443`*^9}, {3.4913984869332504`*^9, 
    3.491398496948468*^9}, 3.4914136297351246`*^9, 3.4914140468859844`*^9, {
    3.491416748060483*^9, 3.4914167482264924`*^9}, 3.4914168077348957`*^9, {
    3.4916705003527727`*^9, 3.491670503035977*^9}, {3.491670536529236*^9, 
    3.4916706071469603`*^9}, {3.4916706472234306`*^9, 
    3.4916706812470903`*^9}, {3.4916708342053595`*^9, 3.491670835266161*^9}, {
    3.4916709879504294`*^9, 3.491670997248046*^9}, 3.4916710720657773`*^9, {
    3.4917362307280855`*^9, 3.491736236375295*^9}, {3.491736287652585*^9, 
    3.49173648371373*^9}, {3.4917372333262467`*^9, 3.4917372347458496`*^9}, 
    3.4917372742763186`*^9, {3.491757814102442*^9, 3.491757843992094*^9}, 
    3.491761526294041*^9}],
 StyleBox[" ",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain"],
 StyleBox[" \[Phi] = 120\[Degree]. ",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 StyleBox[" \n  ",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain"],
 Cell[BoxData[
  GraphicsBox[{{}, {}, 
    {RGBColor[0, 0, 1], Thickness[Large], LineBox[CompressedData["
1:eJwt2nk0lN//AHBmxsyEZI1shbKrkCXiXrsspVCEFpVkK5IWabWUItkSKtFi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      "]]}},
   Axes->True,
   AxesOrigin->{0, 0},
   ImageSize->{300, 300},
   PlotRange->{{-3.8116399780037673`, 
    3.8116399780037673`}, {-3.8116399780037673`, 3.8116399780037673`}},
   PlotRangeClipping->True,
   PlotRangePadding->{Automatic, Automatic},
   Ticks->False]],
  CellChangeTimes->{{3.487174247242574*^9, 3.4871742776123114`*^9}, 
    3.4871743338275266`*^9, {3.487174762772061*^9, 3.4871747985711083`*^9}, {
    3.48717490176101*^9, 3.4871749090874295`*^9}, {3.4871749554500813`*^9, 
    3.48717502361598*^9}, {3.4871862392520313`*^9, 3.487186271423872*^9}, {
    3.487186360744981*^9, 3.4871863936968656`*^9}, 3.487186428625863*^9, {
    3.4871865765023212`*^9, 3.487186577094355*^9}, {3.4871866405469847`*^9, 
    3.4871866966911955`*^9}, {3.487186901263897*^9, 3.4871869297615266`*^9}, {
    3.4871869857947316`*^9, 3.487186995583291*^9}, {3.487187104629528*^9, 
    3.487187110441861*^9}, {3.487187144660818*^9, 3.487187203680194*^9}, 
    3.4871883033280897`*^9, {3.487203071425685*^9, 3.487203090535719*^9}, 
    3.4872045032274*^9, {3.4872463495157666`*^9, 3.4872463693439007`*^9}, {
    3.487246433157551*^9, 3.487246435278672*^9}, {3.4872473815177937`*^9, 
    3.487247450426735*^9}, {3.4872474820085416`*^9, 3.4872477205581856`*^9}, {
    3.487248117408884*^9, 3.4872481184019413`*^9}, {3.487248178762394*^9, 
    3.4872482110042377`*^9}, {3.4872482608720903`*^9, 3.487248319881465*^9}, 
    3.4872483575806217`*^9, {3.487248908602138*^9, 3.487248909463187*^9}, {
    3.487249340737855*^9, 3.4872493588798923`*^9}, {3.4872496780271463`*^9, 
    3.4872497003824253`*^9}, {3.487250023118885*^9, 3.487250027655144*^9}, {
    3.487250575263466*^9, 3.487250676430252*^9}, {3.487251411085272*^9, 
    3.487251471173709*^9}, {3.487251816966487*^9, 3.487251829224188*^9}, {
    3.4872519179082603`*^9, 3.487251966365032*^9}, {3.4872520257294273`*^9, 
    3.487252033389866*^9}, {3.4872523305878644`*^9, 3.487252332862994*^9}, {
    3.4872523688660536`*^9, 3.4872523709751744`*^9}, 3.4872527765613728`*^9, {
    3.4872528923829975`*^9, 3.487252892648012*^9}, {3.487499290280834*^9, 
    3.48749930069143*^9}, {3.48749933355931*^9, 3.487499376693777*^9}, {
    3.4874994538371897`*^9, 3.48749946608889*^9}, {3.487499503736044*^9, 
    3.4874995041570673`*^9}, {3.487507728289461*^9, 3.487507734874838*^9}, {
    3.4875080286316395`*^9, 3.4875080768673983`*^9}, {3.4875082677043138`*^9, 
    3.4875083238205233`*^9}, {3.487508913094228*^9, 3.487508937050598*^9}, {
    3.4875876017805667`*^9, 3.487587603337656*^9}, {3.4875892032991686`*^9, 
    3.4875892051122723`*^9}, {3.487589275342289*^9, 3.4875892781714506`*^9}, {
    3.4875909175242167`*^9, 3.4875909362422867`*^9}, {3.487591048960734*^9, 
    3.4875911435141425`*^9}, 3.487591236332451*^9, {3.487591325170532*^9, 
    3.4875913269496346`*^9}, {3.4875913587614536`*^9, 
    3.4875913744783525`*^9}, {3.4875915221567993`*^9, 3.487591533167429*^9}, {
    3.487591630017969*^9, 3.487591630756011*^9}, {3.4875916701542645`*^9, 
    3.487591717766988*^9}, {3.487591978521902*^9, 3.4875919790189304`*^9}, {
    3.4876119442692347`*^9, 3.487611949521535*^9}, {3.4876123171505623`*^9, 
    3.4876123207197666`*^9}, {3.4876123583329177`*^9, 3.487612362155136*^9}, {
    3.487620968917506*^9, 3.4876209735663147`*^9}, {3.487621086931713*^9, 
    3.4876211069621487`*^9}, {3.4876211776146727`*^9, 3.48762118185788*^9}, {
    3.4876223429523196`*^9, 3.4876224066628313`*^9}, {3.4876226462948523`*^9, 
    3.4876226545940666`*^9}, {3.4879378505605435`*^9, 3.487937852526147*^9}, {
    3.4879389595976915`*^9, 3.4879389806109285`*^9}, 3.487954506800294*^9, 
    3.4879552059462833`*^9, {3.487955354226764*^9, 3.4879553548828015`*^9}, 
    3.4879778865925393`*^9, {3.488026762836731*^9, 3.4880267855730314`*^9}, {
    3.4880286760411596`*^9, 3.488028691873065*^9}, {3.48802875996296*^9, 
    3.4880287779629893`*^9}, {3.488029402590716*^9, 3.488029423166893*^9}, 
    3.4881035588680367`*^9, 3.4881039206262083`*^9, 3.488104120777656*^9, 
    3.488104903078401*^9, {3.4881050616464705`*^9, 3.488105078194417*^9}, {
    3.4881111465675077`*^9, 3.488111160340296*^9}, {3.488112068437236*^9, 
    3.4881120941107044`*^9}, 3.4881151584709883`*^9, {3.488131862127383*^9, 
    3.4881319519195185`*^9}, {3.4881327730814867`*^9, 3.488132802714182*^9}, {
    3.4881871755509825`*^9, 3.488187183630445*^9}, 3.4881889555927954`*^9, {
    3.488189998898469*^9, 3.488190098602172*^9}, {3.4881901543543606`*^9, 
    3.488190173469454*^9}, {3.4881903638923454`*^9, 3.488190380942321*^9}, {
    3.4882137973446627`*^9, 3.4882138365939074`*^9}, {3.4882140471889524`*^9, 
    3.488214056358477*^9}, {3.4882148881910553`*^9, 3.4882148951354523`*^9}, 
    3.4882149283413515`*^9, {3.4882302297011557`*^9, 3.4882302344904294`*^9}, 
    3.488231704599515*^9, {3.4882319839284916`*^9, 3.4882319992813697`*^9}, {
    3.488275876124522*^9, 3.488275881496829*^9}, 3.488276068637533*^9, 
    3.4882765579205184`*^9, 3.488277169769514*^9, 3.48827741201637*^9, {
    3.488277522075665*^9, 3.488277525446858*^9}, 3.488278079202531*^9, {
    3.488278397793753*^9, 3.488278425786354*^9}, {3.488278718245082*^9, 
    3.488278719804171*^9}, {3.488281865350086*^9, 3.488281871320428*^9}, {
    3.4882830136195784`*^9, 3.4882830192511883`*^9}, {3.488283407479191*^9, 
    3.48828342058294*^9}, {3.488285026388787*^9, 3.4882850392645235`*^9}, 
    3.4882907709793587`*^9, {3.488291081025092*^9, 3.4882910896975884`*^9}, {
    3.4882911289018307`*^9, 3.4882911544232903`*^9}, {3.488291200132905*^9, 
    3.4882912002289104`*^9}, {3.4882912461585374`*^9, 
    3.4882912662906885`*^9}, {3.4882912993615804`*^9, 3.488291313319379*^9}, {
    3.488292675314749*^9, 3.4882926928803797`*^9}, {3.488292814825794*^9, 
    3.4882928340762277`*^9}, 3.488293248100955*^9, {3.488293668880494*^9, 
    3.4882943519120936`*^9}, {3.488294386169754*^9, 3.4882944270418253`*^9}, 
    3.488294576739689*^9, {3.4883963963753386`*^9, 3.4883964781840177`*^9}, {
    3.4883965083107405`*^9, 3.488396598437896*^9}, {3.4883970123125677`*^9, 
    3.488397038351057*^9}, {3.4883973207822113`*^9, 3.4883973230023384`*^9}, {
    3.4884010355926867`*^9, 3.4884010418300433`*^9}, {3.4884029584056654`*^9, 
    3.4884029600077567`*^9}, {3.4884030443625813`*^9, 
    3.4884030517140017`*^9}, {3.4884559968958817`*^9, 3.4884560201222105`*^9},
     3.4884561828885202`*^9, {3.4884595324081016`*^9, 3.4884595557644377`*^9},
     3.488488413833895*^9, {3.488488614512373*^9, 3.488488650284419*^9}, 
    3.4884941868160906`*^9, 3.488494307578998*^9, 3.488494915640777*^9, {
    3.4884969399105587`*^9, 3.4884969446568303`*^9}, 3.4884970443505325`*^9, {
    3.488497121122924*^9, 3.4884971234120545`*^9}, {3.488497153530777*^9, 
    3.4884971544248285`*^9}, 3.488497216257365*^9, 3.4884982796191854`*^9, {
    3.4884985827925262`*^9, 3.4884985838495865`*^9}, 3.488548766839347*^9, {
    3.4885546595003877`*^9, 3.48855467351919*^9}, {3.488554768972649*^9, 
    3.488554780388302*^9}, {3.4885548176644344`*^9, 3.488554834780413*^9}, 
    3.4885558246670313`*^9, {3.488555877735067*^9, 3.488555885167492*^9}, {
    3.488555925882821*^9, 3.488555968589263*^9}, {3.488556183800573*^9, 
    3.4885561926470785`*^9}, {3.4885565714927473`*^9, 3.488556578579153*^9}, {
    3.488556819261919*^9, 3.488556860995306*^9}, 3.489757221378025*^9, {
    3.4897714976971006`*^9, 3.489771499584704*^9}, {3.4899235962696867`*^9, 
    3.489923596809717*^9}, {3.4900048505124407`*^9, 3.4900048575248413`*^9}, {
    3.490004927360836*^9, 3.490004927640852*^9}, {3.4900054204690404`*^9, 
    3.49000542064305*^9}, {3.4900273743567305`*^9, 3.490027413935995*^9}, 
    3.4900274660839777`*^9, {3.4900314898301225`*^9, 3.4900314904871597`*^9}, 
    3.490031551025623*^9, {3.4900342535741997`*^9, 3.4900342782086086`*^9}, {
    3.490036273490732*^9, 3.4900362852984076`*^9}, {3.4900363603587008`*^9, 
    3.490036371115316*^9}, 3.490037162197563*^9, 3.4900403448696017`*^9, 
    3.490048845135789*^9, 3.4904418396813517`*^9, {3.4904419441003237`*^9, 
    3.490441947441515*^9}, {3.490441986359741*^9, 3.4904420592999134`*^9}, 
    3.490444327068622*^9, {3.4904444014798784`*^9, 3.4904444022399216`*^9}, 
    3.4904474676582537`*^9, 3.49044858339207*^9, 3.490450905146867*^9, 
    3.490451714886181*^9, 3.490452510791704*^9, 3.490453288249172*^9, 
    3.490464459496053*^9, {3.4904681593526726`*^9, 3.4904681643289576`*^9}, {
    3.4904682052062955`*^9, 3.4904682058513327`*^9}, 3.490531867888402*^9, {
    3.4905333015014*^9, 3.4905333019644265`*^9}, 3.4907062892196035`*^9, {
    3.490708250619789*^9, 3.4907082541179895`*^9}, {3.490712025183682*^9, 
    3.4907120313920374`*^9}, {3.4907128353390207`*^9, 3.490712841327363*^9}, 
    3.490714884718238*^9, 3.4907291944635754`*^9, 3.490729713173244*^9, {
    3.490730085218524*^9, 3.490730101265442*^9}, {3.4907306694449396`*^9, 
    3.4907306727751303`*^9}, {3.490731048785637*^9, 3.49073105373092*^9}, {
    3.4907317737701035`*^9, 3.4907318297893076`*^9}, {3.49073192354667*^9, 
    3.490731949549157*^9}, 3.490732404969206*^9, {3.490732482961667*^9, 
    3.490732520929838*^9}, {3.490732560906125*^9, 3.490732566699456*^9}, {
    3.4907951817937293`*^9, 3.4907952097603292`*^9}, 3.49079688138494*^9, 
    3.4909578135058956`*^9, {3.490966426065824*^9, 3.4909664589038815`*^9}, 
    3.4909679863493643`*^9, {3.4909682970395103`*^9, 
    3.4909683252911596`*^9}, {3.490972673956398*^9, 3.4909726987292414`*^9}, 
    3.4909728202534547`*^9, {3.490972862435929*^9, 3.4909728817019625`*^9}, {
    3.490972913073618*^9, 3.4909729566132946`*^9}, {3.490973518869482*^9, 
    3.4909735657475643`*^9}, {3.4909736125476465`*^9, 3.490973619021658*^9}, {
    3.490973703355406*^9, 3.4909737369578648`*^9}, {3.490973801963179*^9, 
    3.4909738048959846`*^9}, 3.490974014136751*^9, 3.4911489290724*^9, 
    3.491152414014719*^9, {3.4911532777726364`*^9, 3.491153287179453*^9}, {
    3.4911533826048203`*^9, 3.4911533843676233`*^9}, 3.4911608269218388`*^9, 
    3.4911610198473773`*^9, {3.4912215420326176`*^9, 3.4912215503786325`*^9}, 
    3.4912215809234858`*^9, {3.491221615103146*^9, 3.4912217052401047`*^9}, 
    3.4912220487527075`*^9, {3.4912290845968103`*^9, 
    3.4912290884968166`*^9}, {3.4912385323231597`*^9, 3.491238550410194*^9}, 
    3.491238719776881*^9, {3.4912389233205233`*^9, 3.4912389754925075`*^9}, 
    3.491241094984701*^9, 3.4912414098657107`*^9, {3.491385847243327*^9, 
    3.4913859619878902`*^9}, 3.4913859937217054`*^9, {3.491386060978552*^9, 
    3.4913860866870227`*^9}, 3.491386146561447*^9, {3.491386424457342*^9, 
    3.4913864460755787`*^9}, {3.4913864766593275`*^9, 3.49138647687934*^9}, 
    3.491397677026628*^9, 3.4913977115026884`*^9, 3.4913978076456575`*^9, 
    3.4913980532212887`*^9, {3.491398197490342*^9, 3.491398204603955*^9}, {
    3.491398273540476*^9, 3.4913983694494443`*^9}, {3.4913984869332504`*^9, 
    3.491398496948468*^9}, 3.4914136297351246`*^9, 3.4914140468859844`*^9, {
    3.491416748060483*^9, 3.4914167482264924`*^9}, 3.4914168077348957`*^9, {
    3.4916705003527727`*^9, 3.491670503035977*^9}, {3.491670536529236*^9, 
    3.4916706071469603`*^9}, {3.4916706472234306`*^9, 
    3.4916706812470903`*^9}, {3.4916708342053595`*^9, 3.491670835266161*^9}, {
    3.4916709879504294`*^9, 3.491670997248046*^9}, 3.4916710720657773`*^9, {
    3.4917362307280855`*^9, 3.491736236375295*^9}, {3.491736287652585*^9, 
    3.49173648371373*^9}, {3.4917372333262467`*^9, 3.4917372347458496`*^9}, 
    3.4917372742763186`*^9, {3.491757814102442*^9, 3.491757843992094*^9}, 
    3.491761526294041*^9}],
 StyleBox["  ",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain"],
 StyleBox["\[Phi] = 60\[Degree].",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 StyleBox["\n",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain"],
 StyleBox["\n", "Subtitle"],
 StyleBox["and 5) for perfectly horizontal planes, \[Phi] is measured from \
the east-west line such that the NE quadrant is positive and the SE quadrant \
is negative.", "Subtitle",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["\n", "Subtitle",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain"],
 "\n",
 StyleBox["     \tYou can read the \"readme.txt\" file for more information \
about this program. To start the program (as with all Mathematica notebooks), \
place the cursor anywhere in the cell below and either press \"Shift + \
Enter\" or simply press the \"Enter\" key adjacent to the number pad.\n     \n\
          This notebook includes some code for plotting equal area and equal \
angel projections that was modified from code written by Joshua R. Davis. \n  \
        \n           \[OpenCurlyDoubleQuote]Geological Programs for ",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["Mathematica\[CloseCurlyDoubleQuote]",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox[" is licensed under the MIT Licence, Copyright (C) 2010--2014 Matty \
Mookerjee.",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]]
}], "Title",
 CellChangeTimes->{
  3.4917614716499157`*^9, {3.4917615574568233`*^9, 3.4917615853424187`*^9}, {
   3.4917616314800577`*^9, 3.4917617411333294`*^9}, {3.4917617914002047`*^9, 
   3.491761819106789*^9}, {3.4917618524476957`*^9, 3.4917619213336363`*^9}, {
   3.4917620172371216`*^9, 3.491762028839785*^9}, {3.4917621011239195`*^9, 
   3.4917622244359727`*^9}, {3.491762641874849*^9, 3.491762662914052*^9}, {
   3.4917627301618986`*^9, 3.4917627370082903`*^9}, {3.491762842899347*^9, 
   3.491762940447926*^9}, {3.4917630387615495`*^9, 3.4917630447968946`*^9}, {
   3.4917630789628487`*^9, 3.491763276090124*^9}, {3.4917633460441246`*^9, 
   3.4917633932208233`*^9}, {3.4917634758815513`*^9, 3.491763569314895*^9}, {
   3.4917636143754725`*^9, 3.491763621594886*^9}, {3.491763696945195*^9, 
   3.4917638106997013`*^9}, {3.496273066387349*^9, 3.4962730700685596`*^9}, 
   3.4965751470772*^9, {3.4965897584788036`*^9, 3.4965898182322216`*^9}, {
   3.496589859949608*^9, 3.4965899082923727`*^9}, {3.4965899703479223`*^9, 
   3.496590039466875*^9}, {3.496590116442278*^9, 3.496590204748329*^9}, {
   3.4966078234209867`*^9, 3.4966078319614754`*^9}, {3.496607962894964*^9, 
   3.496607990430539*^9}, 3.496608321495475*^9, {3.4966085919609447`*^9, 
   3.4966086007164454`*^9}, {3.496608681365058*^9, 3.496608695300855*^9}, {
   3.4966087359201784`*^9, 3.496608862116397*^9}, {3.496608903985791*^9, 
   3.4966089553447285`*^9}, {3.4966090112649274`*^9, 3.496609125722474*^9}, {
   3.49660919820362*^9, 3.496609200408746*^9}, {3.496609328095049*^9, 
   3.496609341975843*^9}, {3.496609398300064*^9, 3.4966093992441187`*^9}, 
   3.496609435008164*^9, 3.496609482951906*^9, {3.496609568459797*^9, 
   3.4966095701598945`*^9}, 3.4966096162915325`*^9, {3.4968307194487405`*^9, 
   3.4968307820042915`*^9}, {3.4968325326709795`*^9, 3.496832539280351*^9}, {
   3.4968326815674334`*^9, 3.4968327197956204`*^9}, {3.496832749995345*^9, 
   3.496832777318908*^9}, {3.4968328130169497`*^9, 3.4968328230395217`*^9}, {
   3.4968328978147683`*^9, 3.496832935579914*^9}, 3.4968329666366825`*^9, {
   3.4968330077840357`*^9, 3.4968330328574605`*^9}, {3.4968330663233747`*^9, 
   3.4968333775300426`*^9}, {3.496938603911016*^9, 3.4969386055211077`*^9}, {
   3.4969386786712923`*^9, 3.4969386836955795`*^9}, {3.496939311156468*^9, 
   3.496939314469658*^9}, {3.496939346905513*^9, 3.4969393474845457`*^9}, {
   3.496939427847142*^9, 3.4969394284751787`*^9}, {3.4969394867675123`*^9, 
   3.496939488839631*^9}, {3.496939537498414*^9, 3.4969395926565685`*^9}, {
   3.4969439820792327`*^9, 3.4969439838753357`*^9}, {3.4969622568382835`*^9, 
   3.496962263098625*^9}, 3.4969626831104527`*^9, {3.497133308786896*^9, 
   3.497133310059969*^9}, {3.4971333481381474`*^9, 3.497133421855363*^9}, {
   3.4971356634775767`*^9, 3.4971356959124317`*^9}, {3.499476441441551*^9, 
   3.4994764668850064`*^9}, {3.5002184572803693`*^9, 3.500218458278771*^9}, {
   3.5028243533764515`*^9, 3.502824358696061*^9}, {3.502824402157737*^9, 
   3.5028244121729546`*^9}, {3.5028244642146463`*^9, 
   3.5028244645110464`*^9}, {3.5028246827841167`*^9, 3.5028247137189713`*^9}, 
   3.503330913317746*^9, {3.503762494540354*^9, 3.50376249833701*^9}, {
   3.503762848473091*^9, 3.50376288051812*^9}, 3.503777389697968*^9, {
   3.504265496131397*^9, 3.504265502063736*^9}, {3.5042656219725943`*^9, 
   3.5042656317761555`*^9}, {3.505427435831833*^9, 3.505427442476213*^9}, {
   3.5054274909739866`*^9, 3.5054275144163275`*^9}, 3.505919133943254*^9, {
   3.517670485603842*^9, 3.5176704858378425`*^9}, 3.5220148959176626`*^9, {
   3.5472275629997625`*^9, 3.5472275673521705`*^9}, {3.5479355193310432`*^9, 
   3.5479355204710445`*^9}, 3.5479384847885537`*^9, 3.547977441563924*^9, 
   3.5479877780619435`*^9, {3.611348998086944*^9, 3.6113490006100883`*^9}, 
   3.611357680098527*^9, {3.6114791757912693`*^9, 3.611479178651433*^9}, {
   3.6114797355992885`*^9, 3.611479755590432*^9}, {3.611481872099489*^9, 
   3.6114818997730722`*^9}, {3.6114819989217434`*^9, 
   3.6114820093963423`*^9}, {3.6114820954522643`*^9, 3.611482097138361*^9}, {
   3.6114829933106194`*^9, 3.6114829933106194`*^9}, 3.6114840002422123`*^9, {
   3.6458055961233444`*^9, 3.6458055961233444`*^9}},
 TextAlignment->Left],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<Precise\>\"", " ", "is", " ", "the", " ", "working", " ", 
     "precision", " ", "used", " ", "by", " ", "Mathematica", " ", "in", " ", 
     "its", " ", "FindMinimum", " ", 
     RowBox[{"function", ".", "  ", "To"}], " ", "use", " ", "the", " ", 
     "default", " ", "value", " ", "of", " ", "working", " ", "precision", 
     " ", 
     RowBox[{"(", "recommended", ")"}], " ", "keep", " ", "\"\<Precise\>\"", 
     " ", "equal", " ", "to", " ", 
     RowBox[{"zero", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Precise", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<ptsize\>\"", " ", "is", " ", "the", " ", "point", " ", "size", " ", 
     "for", " ", "the", " ", "equal", " ", "area", " ", "plots", " ", 
     "points"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ptsize", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<FitSizePercent\>\"", " ", "is", " ", "the", " ", "percentage", " ", 
     "of", " ", "\"\<ptsize\>\"", " ", "for", " ", "the", " ", "best", " ", 
     "fit", " ", "ellipsoid", " ", "axis", " ", "orienatation", " ", "for", 
     " ", "the", " ", "equal", " ", "area", " ", "plot"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FitSizePercent", "=", "3"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<MeanSizePercent\>\"", " ", "is", " ", "the", " ", "percentage", " ", 
     "of", " ", "\"\<ptsize\>\"", " ", "for", " ", "the", " ", "mean", " ", 
     "equal", " ", "area", " ", "plot", " ", "point"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MeanSizePercent", "=", "2"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<desiredpercentage\>\"", " ", "is", " ", "the", " ", "desired", " ", 
     "error", " ", "bounds", " ", "percentage", " ", "for", " ", "both", " ", 
     "the", " ", "strain", " ", "parameters", " ", "as", " ", "well", " ", 
     "as", " ", "the", " ", "error", " ", "angle", " ", "for", " ", "the", 
     " ", "principal", " ", "axes", " ", "orientations"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"desiredpercentage", "=", ".95"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<PlanarFitThreshold\>\"", " ", "is", " ", "used", " ", "to", " ", 
     "determine", " ", "whether", " ", "to", " ", "fit", " ", "a", " ", 
     "plane", " ", "to", " ", "your", " ", "distribution", " ", "of", " ", 
     "ellipsoid", " ", "axes", " ", 
     RowBox[{"orientations", ".", "  ", "If"}], " ", "the", " ", "error", " ",
      "angle", " ", "for", " ", "a", " ", "given", " ", "axes", " ", "is", 
     " ", "greater", " ", "than", " ", "\"\<PlanarFitThreshold,\>\"", " ", 
     "then", " ", "the", " ", "program", " ", "will", " ", "attempt", " ", 
     "fitting", " ", "a", " ", "plane", " ", "to", " ", "the", " ", 
     RowBox[{"data", ".", "  ", "\"\<PlanarFitThreshold\>\""}], " ", "is", 
     " ", "in", " ", 
     RowBox[{"degrees", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PlanarFitThreshold", "=", "5"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "If", " ", "the", " ", "error", " ", "angle", " ", "is", " ", "greater", 
     " ", "than", " ", "\"\<PlanarFitThreshold,\>\"", " ", "then", " ", "the",
      " ", "program", " ", "will", " ", "fit", " ", "a", " ", "plane", " ", 
     "to", " ", "the", " ", "axes", " ", 
     RowBox[{"orientations", ".", "  ", "If"}], " ", "the", " ", "mean", " ", 
     "angle", " ", "between", " ", "the", " ", "axes", " ", "and", " ", "the",
      " ", "fit", " ", "plane", " ", "is", " ", "less", " ", "than", " ", 
     "\"\<MeanDiffThreshold,\>\"", " ", "then", " ", "the", " ", "program", 
     " ", "will", " ", "output", " ", "the", " ", "orientation", " ", "of", 
     " ", "this", " ", "plane", " ", "and", " ", "plot", " ", "the", " ", 
     "great", " ", "circle", " ", "on", " ", "the", " ", "equal", " ", "area",
      " ", 
     RowBox[{"projection", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MeanDiffThreshold", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<curveresolution\>\"", " ", "determines", " ", "the", " ", 
     "smoothness", " ", "of", " ", "the", " ", "great", " ", "circle", " ", 
     RowBox[{"projections", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"curveresolution", "=", "50"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<greatcolor\>\"", " ", "is", " ", "the", " ", "color", " ", "of", " ",
      "the", " ", "great", " ", "circle", " ", 
     RowBox[{"projections", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"greatcolor", "=", 
     RowBox[{"CMYKColor", "[", 
      RowBox[{"0", ",", "1", ",", "1", ",", ".25"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<greatthickness\>\"", " ", "is", " ", "the", " ", "thickness", " ", 
     "of", " ", "the", " ", "line", " ", "for", " ", "the", " ", "great", " ",
      "circle", " ", 
     RowBox[{"projections", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"greatthickness", "=", "0.005"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<AlphaOn\>\"", " ", "will", " ", "determine", " ", "if", " ", "alpha",
      " ", "percentage", " ", "is", " ", "calculated", " ", "and", " ", 
     "output", " ", "for", " ", "your", " ", 
     RowBox[{"data", ".", "  ", "Change"}], " ", "AlphaOn", " ", "to", " ", 
     "1", " ", "if", " ", "you", " ", "want", " ", "it", " ", 
     RowBox[{"calculated", "."}]}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"AlphaOn", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<alphapercent\>\"", " ", "is", " ", "the", " ", "desired", " ", 
     "radius", " ", "for", " ", "the", " ", "error", " ", "bounds", " ", 
     "for", " ", "the", " ", "ellipsoid", " ", "axes", " ", 
     RowBox[{"orientations", ".", "  ", "\[Alpha]95"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"i", ".", "e", "."}], ",", " ", 
       RowBox[{"alphapercent", "=", ".95"}]}], ")"}], " ", "is", " ", 
     "fairly", " ", "standard", " ", "for", " ", "paleomagnetic", " ", 
     RowBox[{"data", "."}]}], "  ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"alphapercent", "=", ".95"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<ApproxNumbSqrs\>\"", " ", "is", " ", "the", " ", "approximate", " ", 
     "number", " ", "of", " ", "grid", " ", "squares", " ", "used", " ", "to",
      " ", "determine", " ", "the", " ", "error", " ", "bounds", " ", 
     "percentage", " ", "under", " ", "the", " ", "kernel", " ", "density", 
     " ", "estimator", " ", "function"}], "  ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApproxNumbSqrs", "=", "2000"}], ";"}], "  ", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<SigmaBuffer\>\"", " ", "is", " ", "the", " ", "amount", " ", "of", 
     " ", "space", " ", "around", " ", "the", " ", "data", " ", "set", " ", 
     "to", " ", "be", " ", "used", " ", "to", " ", "determine", " ", "the", 
     " ", "error", " ", "bounds", " ", "percentage", " ", "under", " ", "the",
      " ", "kernel", " ", "density", " ", "estimator", " ", "function"}], " ",
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SigmaBuffer", "=", "2"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<SetPrec\>\"", " ", "is", " ", "the", " ", "amount", " ", "of", " ", 
     "precision", " ", "used", " ", "to", " ", "determine", " ", "the", " ", 
     "elevation", " ", "under", " ", "the", " ", "kernel", " ", "density", 
     " ", "estimator", " ", "function", " ", "with", " ", "the", " ", 
     "desired", " ", 
     RowBox[{"volume", "/", "error"}], " ", "bounds"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SetPrec", "=", "0.0001"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "NumberOfContours", " ", "is", " ", "the", " ", "number", " ", "of", " ", 
     "contours", " ", "used", " ", "in", " ", "the", " ", "equal", " ", 
     "area", " ", "projection", " ", "of", " ", "the", " ", "principal", " ", 
     "axes", " ", "orientation", " ", "plots"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NumberOfContours", "=", "7"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "ContouringPercent", " ", "is", " ", "the", " ", "size", " ", "of", " ", 
     "the", " ", "counting", " ", "circle", " ", "in", " ", "terms", " ", 
     "of", " ", "the", " ", "percent", " ", "of", " ", "the", " ", "total", 
     " ", "area", " ", "of", " ", "the", " ", "equal", " ", "area", " ", 
     "plot"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ContouringPercent", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "One", " ", "can", " ", "decrease", " ", "GridDenisty", " ", "if", " ", 
      RowBox[{"he", "/", "she"}], " ", "would", " ", "like", " ", "to", " ", 
      "decrease", " ", "the", " ", "spacing", " ", "between", " ", "the", " ",
       "lines", " ", "of", " ", "the", " ", "counting", " ", "grid", " ", 
      "for", " ", "the", " ", "equal", " ", "area", " ", "projections"}], ",",
      " ", 
     RowBox[{"which", " ", "increases", " ", "the", " ", 
      RowBox[{"grid", "'"}], "s", " ", "density"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"GridDensity", "=", ".5"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<Flinncontinterval\>\"", " ", "is", " ", "the", " ", "octahedral", 
     " ", "shear", " ", "strain", " ", "contour", " ", "interval", " ", "for",
      " ", "the", " ", "Flinn", " ", "diagram"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Flinncontinterval", "=", ".25"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<Flinncolor\>\"", " ", "is", " ", "the", " ", "color", " ", "of", " ",
      "the", " ", "point", " ", "for", " ", "the", " ", "Flinn", " ", 
     "diagram"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Flinncolor", "=", 
     RowBox[{"CMYKColor", "[", 
      RowBox[{"0", ",", "1", ",", "1", ",", ".25"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<FlinnPtSize\>\"", " ", "is", " ", "the", " ", "size", " ", "of", " ",
      "the", " ", "point", " ", "for", " ", "the", " ", "Flinn", " ", 
     "diagram"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FlinnPtSize", "=", "0.02"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<PercentFlinnPtsSize\>\"", " ", "is", " ", "the", " ", "percentage", 
     " ", "of", " ", "\"\<FlinnPtSize\>\"", " ", "point", " ", "size", " ", 
     "for", " ", "the", " ", "statistical", "  ", "points", " ", "for", " ", 
     "the", " ", "Flinn", " ", "diagram"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PercentFlinnPtsSize", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<ErrorShapePercent\>\"", " ", "is", " ", "a", " ", "parameter", " ", 
     "which", " ", "helps", " ", "decide", " ", "whether", " ", "to", " ", 
     "graph", " ", "a", " ", "rectangular", " ", "error", " ", "area", " ", 
     "or", " ", "an", " ", "area", " ", "of", " ", "constant", " ", 
     RowBox[{"\[Epsilon]s", "'"}], "s", " ", "and", " ", 
     RowBox[{"k", "'"}], "s", " ", "for", " ", "the", " ", "Flinn", " ", 
     RowBox[{"plot", ".", "  ", "The"}], " ", "lower", " ", "this", " ", 
     "value", " ", "the", " ", "more", " ", "likely", " ", "the", " ", 
     "program", " ", "will", " ", "yield", " ", "a", " ", "rectangular", " ", 
     "error", " ", 
     RowBox[{"area", "."}]}], "  ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ErrorShapePercent", "=", "1.5"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<continterval\>\"", " ", "is", " ", "the", " ", "octahedral", " ", 
     "shear", " ", "strain", " ", "contour", " ", "interval", " ", "for", " ",
      "the", " ", "Hsu", " ", "diagram"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"continterval", "=", "0.1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<PtSize\>\"", " ", "is", " ", "the", " ", "size", " ", "of", " ", 
     "the", " ", "point", " ", "for", " ", "the", " ", "Hsu", " ", 
     "diagram"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PtSize", "=", "0.02"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<color\>\"", " ", "is", " ", "the", " ", "color", " ", "of", " ", 
     "the", " ", "point", " ", "for", " ", "the", " ", "Hsu", " ", 
     "diagram"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"color", "=", 
     RowBox[{"CMYKColor", "[", 
      RowBox[{"0", ",", "1", ",", "1", ",", ".25"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<PercentHsuPtSize\>\"", " ", "is", " ", "the", " ", "percentage", " ",
      "of", " ", "\"\<PtSize\>\"", " ", "point", " ", "size", " ", "for", " ",
      "the", " ", "statistical", "  ", "points", " ", "for", " ", "the", " ", 
     "Hsu", " ", "diagram"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"PercentHsuPtSize", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
      "\"\<ComplexPolyOrRegularPoly\>\"", " ", "determines", " ", "whether", 
       " ", "the", " ", "program", " ", "will", " ", "plot", " ", "an", " ", 
       "irregular", " ", "polygon", " ", "error", " ", "region", " ", "or", 
       " ", "a", " ", "more", " ", "simplified", " ", "but", " ", "less", " ",
        "precise", " ", "error", " ", 
       RowBox[{"region", ".", " ", "ComplexPolyOrRegularPoly"}], " ", "equal",
        " ", "to", " ", "one", " ", "will", " ", "yield", " ", "an", " ", 
       "irregular", " ", "polygon", " ", "error", " ", "region", " ", "and", 
       " ", "if", " ", "it", " ", "is", " ", "equal", " ", "to", " ", "zero", 
       " ", "then", " ", "the", " ", "program", " ", "will", " ", "produce", 
       " ", "a", " ", "simplified", " ", "error", " ", "region", " ", 
       "defined", " ", "by", " ", "the", " ", "plus"}], "-", " ", 
      RowBox[{"or", " ", "minus"}], "-", 
      RowBox[{"values", " ", "of", " ", "\[Epsilon]s"}]}], ",", " ", "\[Nu]", 
     ",", " ", 
     RowBox[{
      RowBox[{"and", " ", 
       RowBox[{"Flinn", "'"}], "s", " ", "k"}], "-", 
      RowBox[{"value", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ComplexPolyOrRegularPoly", "=", "1"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "\"\<ReduceRes\>\"", " ", "reduces", " ", "the", " ", "number", " ", 
      "of", " ", "points", " ", "that", " ", "define", " ", "the", " ", 
      "error", " ", "region", " ", "in", " ", "both", " ", "the", " ", "Hsu", 
      " ", "and", " ", "Flinn", " ", 
      RowBox[{"diagrams", ".", "  ", "ReduceRes"}], " ", "equal", " ", "to", 
      " ", "one", " ", "is", " ", "no", " ", "reduction"}], ";", " ", 
     RowBox[{
     "ReduceRes", " ", "equal", " ", "to", " ", "2", " ", "will", " ", 
      "reduce", " ", "the", " ", "number", " ", "of", " ", "point", " ", "by",
       " ", "a", " ", "half"}], ";", " ", 
     RowBox[{
     "ReduceRes", " ", "equal", " ", "to", " ", "4", " ", "will", " ", 
      "reduce", " ", "the", " ", "number", " ", "of", " ", "points", " ", 
      "by", " ", "a", " ", "quarter"}], ";", " ", 
     RowBox[{"etc", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ReduceRes", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "\"\<kcont[x]\>\"", " ", "specifies", " ", "the", " ", "values", " ", 
      "for", " ", "the", " ", "Flinn", " ", "k", " ", 
      RowBox[{"contours", ".", "  ", "You"}], " ", "can", " ", "add", " ", 
      "additional", " ", "contours", " ", "by", " ", "typing", " ", "in", " ",
       "addtional", " ", "values"}], ",", " ", 
     RowBox[{"e", ".", "g", "."}], ",", " ", 
     RowBox[{"\"\<kcont[9]=1000;\>\"", "."}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"kcont", "[", "1", "]"}], "=", "10"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"kcont", "[", "2", "]"}], "=", "5"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"kcont", "[", "3", "]"}], "=", "2"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"kcont", "[", "4", "]"}], "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"kcont", "[", "5", "]"}], "=", "0.75"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"kcont", "[", "6", "]"}], "=", "0.5"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"kcont", "[", "7", "]"}], "=", "0.25"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"kcont", "[", "8", "]"}], "=", "0.1"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   StyleBox[
    RowBox[{
     RowBox[{"Off", "[", 
      RowBox[{"General", "::", "obspkg"}], "]"}], ";"}], "MessageName"], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Off", "[", 
     RowBox[{"Power", "::", "infy"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Off", "[", 
     StyleBox[
      RowBox[{"Solve", "::", "ratnz"}], "MessageName"], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Off", "[", 
     StyleBox[
      RowBox[{"FindRoot", "::", "jsing"}], "MessageName"], 
     StyleBox["]", "MessageName"]}], 
    StyleBox[";", "MessageName"]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Breaknumb", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FileorManual", "=", 
     RowBox[{
     "Input", "[", 
      "\"\<Do you want to enter your data manually (m) or do you want to \
import a file (f)?  Enter 'm' or 'f' accordingly.\>\"", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"FileorManual", "\[Equal]", "f"}], ",", 
      RowBox[{"FOM", "=", "1"}]}], "]"}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"FileorManual", "\[Equal]", "m"}], ",", 
      RowBox[{"FOM", "=", "0"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"FOM", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"FN", "=", 
        RowBox[{
        "Input", "[", 
         "\"\<Enter the name of the data file to be opened. Enclose the \
entire file name (include the file extension) in quotations marks.\>\"", 
         "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"FF", "=", 
        RowBox[{"FileFormat", "[", "FN", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"FF", "\[Equal]", "\"\<XLS\>\""}], "||", 
          RowBox[{"FF", "==", "\"\<XLSX\>\""}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"things", "=", 
           RowBox[{"Import", "[", "FN", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"things", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "4", ",", "3"}], "]"}], "]"}], "==", 
             "\"\<Std Dev of Axial Ratio\>\""}], ",", 
            RowBox[{
             RowBox[{"PoS", "=", "0"}], ";"}], ",", 
            RowBox[{
             RowBox[{"PoS", "=", "1"}], ";"}]}], "]"}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"FF", "\[Equal]", "\"\<Text\>\""}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"SandT", "=", 
           RowBox[{"OpenRead", "[", "FN", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"Skip", "[", 
           RowBox[{"SandT", ",", "Word", ",", "16"}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Read", "[", 
              RowBox[{"SandT", ",", "Word"}], "]"}], "\[Equal]", 
             "\"\<Std\>\""}], ",", 
            RowBox[{
             RowBox[{"PoS", "=", "0"}], ";"}], ",", 
            RowBox[{
             RowBox[{"PoS", "=", "1"}], ";"}]}], "]"}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"FF", "\[Equal]", "\"\<XLS\>\""}], "&&", 
           RowBox[{"PoS", "\[Equal]", "0"}]}], "||", 
          RowBox[{
           RowBox[{"FF", "==", "\"\<XLSX\>\""}], "&&", 
           RowBox[{"PoS", "\[Equal]", "0"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"things", "=", 
           RowBox[{"Import", "[", "FN", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"numbplanes", "=", 
           RowBox[{"Round", "[", 
            RowBox[{"things", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1", ",", "3"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"ct", "=", "1"}], ";", "\n", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", "\n", 
            RowBox[{
             RowBox[{
              RowBox[{"Dip", "[", "ct", "]"}], "=", 
              RowBox[{"things", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", 
                 RowBox[{"(", 
                  RowBox[{"3", "+", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"ct", "-", "1"}], ")"}], "*", "5"}], ")"}]}], 
                  ")"}], ",", "1"}], "]"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"DipDir", "[", "ct", "]"}], "=", 
              RowBox[{"things", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", 
                 RowBox[{"(", 
                  RowBox[{"3", "+", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"ct", "-", "1"}], ")"}], "*", "5"}], ")"}]}], 
                  ")"}], ",", "2"}], "]"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"AngularPlaneError", "[", "ct", "]"}], "=", 
              RowBox[{"things", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", 
                 RowBox[{"(", 
                  RowBox[{"3", "+", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"ct", "-", "1"}], ")"}], "*", "5"}], ")"}]}], 
                  ")"}], ",", "3"}], "]"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Major", "[", "ct", "]"}], "=", 
              RowBox[{"things", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", 
                 RowBox[{"ct", "*", "5"}], ",", "1"}], "]"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Minor", "[", "ct", "]"}], "=", 
              RowBox[{"things", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", 
                 RowBox[{"ct", "*", "5"}], ",", "2"}], "]"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"\[CapitalPi]", "[", "ct", "]"}], "=", 
              FractionBox[
               RowBox[{"Major", "[", "ct", "]"}], 
               RowBox[{"Minor", "[", "ct", "]"}]]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"SigmaRatio", "[", "ct", "]"}], "=", 
              RowBox[{"things", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", 
                 RowBox[{"ct", "*", "5"}], ",", "3"}], "]"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"TempFee", "[", "ct", "]"}], "=", 
              RowBox[{"things", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", 
                 RowBox[{"ct", "*", "5"}], ",", "4"}], "]"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Fee", "[", "ct", "]"}], "=", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"TempFee", "[", "ct", "]"}], ">", "90"}], ",", 
                RowBox[{
                 RowBox[{"TempFee", "[", "ct", "]"}], "-", "180"}], ",", 
                RowBox[{"TempFee", "[", "ct", "]"}]}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"\[CapitalPsi]", "[", "ct", "]"}], "=", 
              RowBox[{
               RowBox[{"Fee", "[", "ct", "]"}], "*", 
               FractionBox["\[Pi]", "180"]}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"SigmaFee", "[", "ct", "]"}], "=", 
              RowBox[{"things", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", 
                 RowBox[{"ct", "*", "5"}], ",", "5"}], "]"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"numbdata", "[", "ct", "]"}], "=", 
              RowBox[{"things", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", 
                 RowBox[{"ct", "*", "5"}], ",", "6"}], "]"}], "]"}]}], ";", 
             "\n", 
             RowBox[{"ct", "=", 
              RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}]}], "]"}], ";",
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"FF", "\[Equal]", "\"\<XLS\>\""}], "&&", 
           RowBox[{"PoS", "\[Equal]", "1"}]}], "||", 
          RowBox[{
           RowBox[{"FF", "==", "\"\<XLSX\>\""}], "&&", 
           RowBox[{"PoS", "\[Equal]", "1"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"things", "=", 
           RowBox[{"Import", "[", "FN", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"numbplanes", "=", 
           RowBox[{"Round", "[", 
            RowBox[{"things", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1", ",", "3"}], "]"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Tot", "=", 
           RowBox[{
            RowBox[{"Dimensions", "[", "things", "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"count", "=", "1"}], ";", "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"count", "\[LessEqual]", "Tot"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"things", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "count", ",", "1"}], "]"}], "]"}], 
                "\[Equal]", "\"\<\>\""}], ",", 
               RowBox[{
                RowBox[{"Break", "[", "]"}], ";"}]}], "]"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"count", "=", 
              RowBox[{"count", "+", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Tot", "=", 
           RowBox[{"count", "-", "1"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"sectposition", "[", "1", "]"}], "=", "1"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"ct", "<", "numbplanes"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"sectposition", "[", 
               RowBox[{"ct", "+", "1"}], "]"}], "=", 
              RowBox[{
               RowBox[{"Position", "[", 
                RowBox[{"things", ",", 
                 RowBox[{"\"\<Section #\>\"", "<>", 
                  RowBox[{"ToString", "[", 
                   RowBox[{"ct", "+", "1"}], "]"}]}]}], "]"}], "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"ct", "=", 
              RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"Dip", "[", "ct", "]"}], "=", 
              RowBox[{"things", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", 
                 RowBox[{
                  RowBox[{"sectposition", "[", "ct", "]"}], "+", "2"}], ",", 
                 "1"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"DipDir", "[", "ct", "]"}], "=", 
              RowBox[{"things", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", 
                 RowBox[{
                  RowBox[{"sectposition", "[", "ct", "]"}], "+", "2"}], ",", 
                 "2"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"AngularPlaneError", "[", "ct", "]"}], "=", 
              RowBox[{"things", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", 
                 RowBox[{
                  RowBox[{"sectposition", "[", "ct", "]"}], "+", "2"}], ",", 
                 "3"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"ct", "=", 
              RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"numbdata", "[", "ct", "]"}], "=", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"ct", "<", "numbplanes"}], ",", 
                RowBox[{
                 RowBox[{"sectposition", "[", 
                  RowBox[{"ct", "+", "1"}], "]"}], "-", 
                 RowBox[{"sectposition", "[", "ct", "]"}], "-", "4"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"Tot", "-", 
                 RowBox[{"sectposition", "[", "ct", "]"}], "-", "3"}]}], 
               "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"ct", "=", 
              RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"ct2", "=", "1"}], ";", "\[IndentingNewLine]", 
             RowBox[{"While", "[", 
              RowBox[{
               RowBox[{"ct2", "\[LessEqual]", 
                RowBox[{"numbdata", "[", "ct", "]"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{
                 RowBox[{"Major", "[", 
                  RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                 RowBox[{"things", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", 
                    RowBox[{
                    RowBox[{"sectposition", "[", "ct", "]"}], "+", "3", "+", 
                    "ct2"}], ",", "1"}], "]"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Minor", "[", 
                  RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                 RowBox[{"things", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", 
                    RowBox[{
                    RowBox[{"sectposition", "[", "ct", "]"}], "+", "3", "+", 
                    "ct2"}], ",", "2"}], "]"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Rf", "[", 
                  RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                 FractionBox[
                  RowBox[{"Major", "[", 
                   RowBox[{"ct", ",", "ct2"}], "]"}], 
                  RowBox[{"Minor", "[", 
                   RowBox[{"ct", ",", "ct2"}], "]"}]]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"TempPhiAngle", "[", 
                  RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                 RowBox[{"things", "[", 
                  RowBox[{"[", 
                   RowBox[{"1", ",", 
                    RowBox[{
                    RowBox[{"sectposition", "[", "ct", "]"}], "+", "3", "+", 
                    "ct2"}], ",", "3"}], "]"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"PhiAngle", "[", 
                  RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"TempPhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], ">", "90"}], ",", 
                   RowBox[{
                    RowBox[{"TempPhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], "-", "180"}], ",", 
                   RowBox[{"TempPhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}]}], "]"}]}], ";", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"PhiVect", "[", 
                  RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"PhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], "*", 
                    RowBox[{"Pi", "/", "180"}]}], "]"}], ",", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"PhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], "*", 
                    RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"PhiVectSeed", "[", "ct", "]"}], "=", 
                 RowBox[{"PhiVect", "[", 
                  RowBox[{"ct", ",", "1"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"NewPhiAngle", "[", 
                  RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"ct2", "\[Equal]", "1"}], ",", 
                   RowBox[{"PhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], ",", 
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"ArcCos", "[", 
                    RowBox[{"Dot", "[", 
                    RowBox[{
                    RowBox[{"PhiVect", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], ",", 
                    RowBox[{"PhiVectSeed", "[", "ct", "]"}]}], "]"}], "]"}], 
                    ">", 
                    RowBox[{"Pi", "/", "2"}]}], ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"PhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], "-", "180"}], ")"}], 
                    "-", 
                    RowBox[{"PhiAngle", "[", 
                    RowBox[{"ct", ",", "1"}], "]"}]}], "]"}], "<", "90"}], 
                    ",", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"PhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], "-", "180"}], ")"}], 
                    ",", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"PhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], "+", "180"}], ")"}]}], 
                    "]"}], ",", 
                    RowBox[{"PhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}]}], "]"}]}], "]"}]}], 
                ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", 
                RowBox[{"ct2", "=", 
                 RowBox[{"ct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"SigmaRatio", "[", "ct", "]"}], "=", 
              RowBox[{"StandardDeviation", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Rf", "[", 
                  RowBox[{"ct", ",", "x"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"x", ",", "1", ",", 
                   RowBox[{"numbdata", "[", "ct", "]"}]}], "}"}]}], "]"}], 
               "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"SigmaFee", "[", "ct", "]"}], "=", 
              RowBox[{"StandardDeviation", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"NewPhiAngle", "[", 
                  RowBox[{"ct", ",", "x"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"x", ",", "1", ",", 
                   RowBox[{"numbdata", "[", "ct", "]"}]}], "}"}]}], "]"}], 
               "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"ct", "=", 
              RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", "\n", 
          "\[IndentingNewLine]", 
          RowBox[{"ct1", "=", "1"}], ";", "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"ct1", "\[LessEqual]", "numbplanes"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"ct2", "=", "1"}], ";", "\[IndentingNewLine]", 
             RowBox[{"While", "[", 
              RowBox[{
               RowBox[{"ct2", "\[LessEqual]", 
                RowBox[{"numbdata", "[", "ct1", "]"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"phi", "=", 
                 RowBox[{
                  FractionBox["1", "180"], " ", 
                  RowBox[{"PhiAngle", "[", 
                   RowBox[{"ct1", ",", "ct2"}], "]"}], " ", "\[Pi]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"Elle1", "=", 
                 SqrtBox[
                  RowBox[{"Rf", "[", 
                   RowBox[{"ct1", ",", "ct2"}], "]"}]]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"Elle2", "=", 
                 FractionBox["1", 
                  SqrtBox[
                   RowBox[{"Rf", "[", 
                    RowBox[{"ct1", ",", "ct2"}], "]"}]]]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"PrinMat", "=", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"Elle1", ",", "0"}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"0", ",", "Elle2"}], "}"}]}], "}"}]}], ";", 
                RowBox[{"RotMat", "=", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Cos", "[", "phi", "]"}], ",", 
                    RowBox[{"Sin", "[", "phi", "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "phi", "]"}]}], ",", 
                    RowBox[{"Cos", "[", "phi", "]"}]}], "}"}]}], "}"}]}], ";", 
                RowBox[{
                 RowBox[{"EllipMat", "[", 
                  RowBox[{"ct1", ",", "ct2"}], "]"}], "=", 
                 RowBox[{
                  RowBox[{"Transpose", "[", "RotMat", "]"}], ".", "PrinMat", 
                  ".", "RotMat"}]}], ";", 
                RowBox[{"ct2", "=", 
                 RowBox[{"ct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
             "\[IndentingNewLine]", "\[IndentingNewLine]", 
             RowBox[{"AvgMat", "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                    RowBox[{"x", "=", "1"}], 
                    RowBox[{"numbdata", "[", "ct1", "]"}]], 
                    RowBox[{
                    RowBox[{"EllipMat", "[", 
                    RowBox[{"ct1", ",", "x"}], "]"}], "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], 
                    ")"}], "/", 
                   RowBox[{"numbdata", "[", "ct1", "]"}]}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                    RowBox[{"x", "=", "1"}], 
                    RowBox[{"numbdata", "[", "ct1", "]"}]], 
                    RowBox[{
                    RowBox[{"EllipMat", "[", 
                    RowBox[{"ct1", ",", "x"}], "]"}], "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                    ")"}], "/", 
                   RowBox[{"numbdata", "[", "ct1", "]"}]}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                    RowBox[{"x", "=", "1"}], 
                    RowBox[{"numbdata", "[", "ct1", "]"}]], 
                    RowBox[{
                    RowBox[{"EllipMat", "[", 
                    RowBox[{"ct1", ",", "x"}], "]"}], "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], 
                    ")"}], "/", 
                   RowBox[{"numbdata", "[", "ct1", "]"}]}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                    RowBox[{"x", "=", "1"}], 
                    RowBox[{"numbdata", "[", "ct1", "]"}]], 
                    RowBox[{
                    RowBox[{"EllipMat", "[", 
                    RowBox[{"ct1", ",", "x"}], "]"}], "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                    ")"}], "/", 
                   RowBox[{"numbdata", "[", "ct1", "]"}]}]}], "}"}]}], 
               "}"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
             RowBox[{"Eigval", "=", 
              RowBox[{"Eigenvalues", "[", "AvgMat", "]"}]}], ";", 
             RowBox[{"Eigvect", "=", 
              RowBox[{"Eigenvectors", "[", "AvgMat", "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"T", "=", 
              RowBox[{"Eigensystem", "[", "AvgMat", "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"Tevl", "=", 
              RowBox[{"Sort", "[", 
               RowBox[{"Eigval", ",", "Greater"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                "Tevl", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], "\[Equal]", 
                RowBox[{
                "Eigval", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}]}], ",", 
               RowBox[{"Tevect", "=", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"T", "\[LeftDoubleBracket]", 
                   RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                  RowBox[{"T", "\[LeftDoubleBracket]", 
                   RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                 "}"}]}], ",", 
               RowBox[{"Tevect", "=", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"T", "\[LeftDoubleBracket]", 
                   RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
                  RowBox[{"T", "\[LeftDoubleBracket]", 
                   RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], 
                 "}"}]}]}], "]"}], ";", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Tevect", "\[LeftDoubleBracket]", 
                 RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], 
                "\[Equal]", "0"}], ",", 
               RowBox[{
                RowBox[{"\[CapitalTheta]", "=", 
                 FractionBox["\[Pi]", "2"]}], ";"}], ",", 
               RowBox[{
                RowBox[{"\[CapitalTheta]", "=", 
                 RowBox[{"ArcTan", "[", 
                  FractionBox[
                   RowBox[{"Tevect", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], 
                   RowBox[{"Tevect", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]], 
                  "]"}]}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"\[CapitalPi]", "[", "ct1", "]"}], "=", 
              FractionBox[
               RowBox[{
               "Tevl", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
               RowBox[{
               "Tevl", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}]]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"\[CapitalPsi]", "[", "ct1", "]"}], "=", 
              "\[CapitalTheta]"}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Fee", "[", "ct1", "]"}], "=", 
              RowBox[{
               FractionBox["180", "\[Pi]"], "*", 
               RowBox[{"\[CapitalPsi]", "[", "ct1", "]"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"ct1", "=", 
              RowBox[{"ct1", "+", "1"}]}], ";"}]}], "]"}], ";"}]}], "]"}], 
       ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"FF", "\[Equal]", "\"\<Text\>\""}], "&&", 
          RowBox[{"PoS", "\[Equal]", "1"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"things", "=", 
           RowBox[{"OpenRead", "[", "FN", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"Skip", "[", 
           RowBox[{"things", ",", "Word", ",", "3"}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"numbplanes", "=", 
           RowBox[{"Read", "[", 
            RowBox[{"things", ",", "Number"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Tabby2", "=", 
           RowBox[{"ReadList", "[", 
            RowBox[{"FN", ",", "Word"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"Tot", "=", 
           RowBox[{
            RowBox[{"Dimensions", "[", "Tabby2", "]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"sectposition", "[", "1", "]"}], "=", "4"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"ct", "<", "numbplanes"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"sectposition", "[", 
               RowBox[{"ct", "+", "1"}], "]"}], "=", 
              RowBox[{
               RowBox[{
                RowBox[{"Position", "[", 
                 RowBox[{"Tabby2", ",", 
                  RowBox[{"\"\<#\>\"", "<>", 
                   RowBox[{"ToString", "[", 
                    RowBox[{"ct", "+", "1"}], "]"}]}]}], "]"}], 
                "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
               "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"ct", "=", 
              RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", 
          RowBox[{
           RowBox[{"sectposition", "[", 
            RowBox[{"ct", "+", "1"}], "]"}], "=", 
           RowBox[{"Tot", "+", "2"}]}], ";", "\n", "\[IndentingNewLine]", 
          RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"stuff", "=", 
              RowBox[{"OpenRead", "[", "FN", "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"Skip", "[", 
              RowBox[{"stuff", ",", "Word", ",", 
               RowBox[{
                RowBox[{"sectposition", "[", "ct", "]"}], "+", "5"}]}], "]"}],
              ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Dip", "[", "ct", "]"}], "=", 
              RowBox[{"Read", "[", 
               RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"DipDir", "[", "ct", "]"}], "=", 
              RowBox[{"Read", "[", 
               RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"AngularPlaneError", "[", "ct", "]"}], "=", 
              RowBox[{"Read", "[", 
               RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"ct", "=", 
              RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\n", 
          RowBox[{
           RowBox[{"numbsub", "[", "0", "]"}], "=", "19"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"numbdata", "[", "0", "]"}], "=", "0"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"ct", "=", "1"}], ";", "\n", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"numbdata", "[", "ct", "]"}], "=", 
              RowBox[{
               FractionBox["1", "3"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"sectposition", "[", 
                  RowBox[{"ct", "+", "1"}], "]"}], "-", 
                 RowBox[{"numbsub", "[", 
                  RowBox[{"ct", "-", "1"}], "]"}], "-", 
                 RowBox[{"3", " ", 
                  RowBox[{"numbdata", "[", 
                   RowBox[{"ct", "-", "1"}], "]"}]}]}], ")"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"numbsub", "[", "ct", "]"}], "=", 
              RowBox[{
               RowBox[{"sectposition", "[", 
                RowBox[{"ct", "+", "1"}], "]"}], "+", "15", "-", 
               RowBox[{"3", " ", 
                RowBox[{"numbdata", "[", "ct", "]"}]}]}]}], ";", "\n", 
             RowBox[{"ct", "=", 
              RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", "\n", 
          "\[IndentingNewLine]", 
          RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"stuff", "=", 
              RowBox[{"OpenRead", "[", "FN", "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"Skip", "[", 
              RowBox[{"stuff", ",", "Word", ",", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"ct", "\[Equal]", "1"}], ",", "17", ",", 
                 RowBox[{
                  RowBox[{"sectposition", "[", "ct", "]"}], "+", "13"}]}], 
                "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{"ct2", "=", "1"}], ";", "\[IndentingNewLine]", 
             RowBox[{"While", "[", 
              RowBox[{
               RowBox[{"ct2", "\[LessEqual]", 
                RowBox[{"numbdata", "[", "ct", "]"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{
                 RowBox[{"Major", "[", 
                  RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                 RowBox[{"Read", "[", 
                  RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Minor", "[", 
                  RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                 RowBox[{"Read", "[", 
                  RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Rf", "[", 
                  RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                 FractionBox[
                  RowBox[{"Major", "[", 
                   RowBox[{"ct", ",", "ct2"}], "]"}], 
                  RowBox[{"Minor", "[", 
                   RowBox[{"ct", ",", "ct2"}], "]"}]]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"TempPhiAngle", "[", 
                  RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                 RowBox[{"Read", "[", 
                  RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"PhiAngle", "[", 
                  RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"TempPhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], ">", "90"}], ",", 
                   RowBox[{
                    RowBox[{"TempPhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], "-", "180"}], ",", 
                   RowBox[{"TempPhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}]}], "]"}]}], ";", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"PhiVect", "[", 
                  RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"PhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], "*", 
                    RowBox[{"Pi", "/", "180"}]}], "]"}], ",", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"PhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], "*", 
                    RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"PhiVectSeed", "[", "ct", "]"}], "=", 
                 RowBox[{"PhiVect", "[", 
                  RowBox[{"ct", ",", "1"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"NewPhiAngle", "[", 
                  RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"ct2", "\[Equal]", "1"}], ",", 
                   RowBox[{"PhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], ",", 
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"ArcCos", "[", 
                    RowBox[{"Dot", "[", 
                    RowBox[{
                    RowBox[{"PhiVect", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], ",", 
                    RowBox[{"PhiVectSeed", "[", "ct", "]"}]}], "]"}], "]"}], 
                    ">", 
                    RowBox[{"Pi", "/", "2"}]}], ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"PhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], "-", "180"}], ")"}], 
                    "-", 
                    RowBox[{"PhiAngle", "[", 
                    RowBox[{"ct", ",", "1"}], "]"}]}], "]"}], "<", "90"}], 
                    ",", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"PhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], "-", "180"}], ")"}], 
                    ",", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"PhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], "+", "180"}], ")"}]}], 
                    "]"}], ",", 
                    RowBox[{"PhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}]}], "]"}]}], "]"}]}], 
                ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", 
                RowBox[{"ct2", "=", 
                 RowBox[{"ct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"SigmaRatio", "[", "ct", "]"}], "=", 
              RowBox[{"StandardDeviation", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Rf", "[", 
                  RowBox[{"ct", ",", "x"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"x", ",", "1", ",", 
                   RowBox[{"numbdata", "[", "ct", "]"}]}], "}"}]}], "]"}], 
               "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"SigmaFee", "[", "ct", "]"}], "=", 
              RowBox[{"StandardDeviation", "[", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"NewPhiAngle", "[", 
                  RowBox[{"ct", ",", "x"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"x", ",", "1", ",", 
                   RowBox[{"numbdata", "[", "ct", "]"}]}], "}"}]}], "]"}], 
               "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"ct", "=", 
              RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\n", 
          RowBox[{"ct1", "=", "1"}], ";", "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"ct1", "\[LessEqual]", "numbplanes"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"ct2", "=", "1"}], ";", "\[IndentingNewLine]", 
             RowBox[{"While", "[", 
              RowBox[{
               RowBox[{"ct2", "\[LessEqual]", 
                RowBox[{"numbdata", "[", "ct1", "]"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"phi", "=", 
                 RowBox[{
                  FractionBox["1", "180"], " ", 
                  RowBox[{"PhiAngle", "[", 
                   RowBox[{"ct1", ",", "ct2"}], "]"}], " ", "\[Pi]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"Elle1", "=", 
                 SqrtBox[
                  RowBox[{"Rf", "[", 
                   RowBox[{"ct1", ",", "ct2"}], "]"}]]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"Elle2", "=", 
                 FractionBox["1", 
                  SqrtBox[
                   RowBox[{"Rf", "[", 
                    RowBox[{"ct1", ",", "ct2"}], "]"}]]]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"PrinMat", "=", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"Elle1", ",", "0"}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"0", ",", "Elle2"}], "}"}]}], "}"}]}], ";", 
                RowBox[{"RotMat", "=", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Cos", "[", "phi", "]"}], ",", 
                    RowBox[{"Sin", "[", "phi", "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "phi", "]"}]}], ",", 
                    RowBox[{"Cos", "[", "phi", "]"}]}], "}"}]}], "}"}]}], ";", 
                RowBox[{
                 RowBox[{"EllipMat", "[", 
                  RowBox[{"ct1", ",", "ct2"}], "]"}], "=", 
                 RowBox[{
                  RowBox[{"Transpose", "[", "RotMat", "]"}], ".", "PrinMat", 
                  ".", "RotMat"}]}], ";", 
                RowBox[{"ct2", "=", 
                 RowBox[{"ct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
             "\[IndentingNewLine]", "\[IndentingNewLine]", 
             RowBox[{"AvgMat", "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                    RowBox[{"x", "=", "1"}], 
                    RowBox[{"numbdata", "[", "ct1", "]"}]], 
                    RowBox[{
                    RowBox[{"EllipMat", "[", 
                    RowBox[{"ct1", ",", "x"}], "]"}], "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], 
                    ")"}], "/", 
                   RowBox[{"numbdata", "[", "ct1", "]"}]}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                    RowBox[{"x", "=", "1"}], 
                    RowBox[{"numbdata", "[", "ct1", "]"}]], 
                    RowBox[{
                    RowBox[{"EllipMat", "[", 
                    RowBox[{"ct1", ",", "x"}], "]"}], "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                    ")"}], "/", 
                   RowBox[{"numbdata", "[", "ct1", "]"}]}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                    RowBox[{"x", "=", "1"}], 
                    RowBox[{"numbdata", "[", "ct1", "]"}]], 
                    RowBox[{
                    RowBox[{"EllipMat", "[", 
                    RowBox[{"ct1", ",", "x"}], "]"}], "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], 
                    ")"}], "/", 
                   RowBox[{"numbdata", "[", "ct1", "]"}]}], ",", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    UnderoverscriptBox["\[Sum]", 
                    RowBox[{"x", "=", "1"}], 
                    RowBox[{"numbdata", "[", "ct1", "]"}]], 
                    RowBox[{
                    RowBox[{"EllipMat", "[", 
                    RowBox[{"ct1", ",", "x"}], "]"}], "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                    ")"}], "/", 
                   RowBox[{"numbdata", "[", "ct1", "]"}]}]}], "}"}]}], 
               "}"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
             RowBox[{"Eigval", "=", 
              RowBox[{"Eigenvalues", "[", "AvgMat", "]"}]}], ";", 
             RowBox[{"Eigvect", "=", 
              RowBox[{"Eigenvectors", "[", "AvgMat", "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"T", "=", 
              RowBox[{"Eigensystem", "[", "AvgMat", "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"Tevl", "=", 
              RowBox[{"Sort", "[", 
               RowBox[{"Eigval", ",", "Greater"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                "Tevl", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], "\[Equal]", 
                RowBox[{
                "Eigval", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}]}], ",", 
               RowBox[{"Tevect", "=", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"T", "\[LeftDoubleBracket]", 
                   RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                  RowBox[{"T", "\[LeftDoubleBracket]", 
                   RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                 "}"}]}], ",", 
               RowBox[{"Tevect", "=", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"T", "\[LeftDoubleBracket]", 
                   RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
                  RowBox[{"T", "\[LeftDoubleBracket]", 
                   RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], 
                 "}"}]}]}], "]"}], ";", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Tevect", "\[LeftDoubleBracket]", 
                 RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], 
                "\[Equal]", "0"}], ",", 
               RowBox[{
                RowBox[{"\[CapitalTheta]", "=", 
                 FractionBox["\[Pi]", "2"]}], ";"}], ",", 
               RowBox[{
                RowBox[{"\[CapitalTheta]", "=", 
                 RowBox[{"ArcTan", "[", 
                  FractionBox[
                   RowBox[{"Tevect", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], 
                   RowBox[{"Tevect", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]], 
                  "]"}]}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"\[CapitalPi]", "[", "ct1", "]"}], "=", 
              FractionBox[
               RowBox[{
               "Tevl", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
               RowBox[{
               "Tevl", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}]]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"\[CapitalPsi]", "[", "ct1", "]"}], "=", 
              "\[CapitalTheta]"}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Fee", "[", "ct1", "]"}], "=", 
              RowBox[{
               FractionBox["180", "\[Pi]"], "*", 
               RowBox[{"\[CapitalPsi]", "[", "ct1", "]"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"ct1", "=", 
              RowBox[{"ct1", "+", "1"}]}], ";"}]}], "]"}], ";"}]}], "]"}], 
       ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"FF", "\[Equal]", "\"\<Text\>\""}], "&&", 
          RowBox[{"PoS", "\[Equal]", "0"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"things", "=", 
           RowBox[{"OpenRead", "[", "FN", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"Skip", "[", 
           RowBox[{"things", ",", "Word", ",", "3"}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"numbplanes", "=", 
           RowBox[{"Read", "[", 
            RowBox[{"things", ",", "Number"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"stuff", "=", 
           RowBox[{"OpenRead", "[", "FN", "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Skip", "[", 
              RowBox[{"stuff", ",", "Word", ",", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"ct", "\[Equal]", "1"}], ",", "9", ",", "7"}], 
                "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Dip", "[", "ct", "]"}], "=", 
              RowBox[{"Read", "[", 
               RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"DipDir", "[", "ct", "]"}], "=", 
              RowBox[{"Read", "[", 
               RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"AngularPlaneError", "[", "ct", "]"}], "=", 
              RowBox[{"Read", "[", 
               RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"Skip", "[", 
              RowBox[{"stuff", ",", "Word", ",", "19"}], "]"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Major", "[", "ct", "]"}], "=", 
              RowBox[{"Read", "[", 
               RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Minor", "[", "ct", "]"}], "=", 
              RowBox[{"Read", "[", 
               RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"\[CapitalPi]", "[", "ct", "]"}], "=", 
              FractionBox[
               RowBox[{"Major", "[", "ct", "]"}], 
               RowBox[{"Minor", "[", "ct", "]"}]]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"SigmaRatio", "[", "ct", "]"}], "=", 
              RowBox[{"Read", "[", 
               RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"TempFee", "[", "ct", "]"}], "=", 
              RowBox[{"Read", "[", 
               RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Fee", "[", "ct", "]"}], "=", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"TempFee", "[", "ct", "]"}], ">", "90"}], ",", 
                RowBox[{
                 RowBox[{"TempFee", "[", "ct", "]"}], "-", "180"}], ",", 
                RowBox[{"TempFee", "[", "ct", "]"}]}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"\[CapitalPsi]", "[", "ct", "]"}], "=", 
              RowBox[{
               RowBox[{"Fee", "[", "ct", "]"}], "*", 
               FractionBox["\[Pi]", "180"]}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"SigmaFee", "[", "ct", "]"}], "=", 
              RowBox[{"Read", "[", 
               RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"numbdata", "[", "ct", "]"}], "=", 
              RowBox[{"Read", "[", 
               RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"ct", "=", 
              RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}]}], "]"}], 
       ";"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"PoS", "=", "0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"numbplanes", "=", 
        RowBox[{
        "Input", "[", 
         "\"\<Enter the number of planes from which you have elliptical data.\
\>\"", "]"}]}], ";", 
       RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Dip", "[", "ct", "]"}], "=", 
           RowBox[{"Input", "[", 
            RowBox[{"\"\<\>\"", " ", 
             RowBox[{"N", "[", "ct", "]"}], " ", 
             "\"\<Enter the Dip of plane.\>\""}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"DipDir", "[", "ct", "]"}], "=", 
           RowBox[{"Input", "[", 
            RowBox[{"\"\<\>\"", " ", 
             RowBox[{"N", "[", "ct", "]"}], " ", 
             "\"\<Enter the Dip Direction of plane.\>\""}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"AngularPlaneError", "[", "ct", "]"}], "=", 
           RowBox[{"Input", "[", 
            RowBox[{"\"\<\>\"", 
             RowBox[{"N", "[", "ct", "]"}], 
             "\"\<Enter the estimated Measurment Error associated with the \
orientation of this plane (in degrees).\>\""}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"\[CapitalPi]", "[", "ct", "]"}], "=", 
           RowBox[{"Input", "[", 
            RowBox[{"\"\<\>\"", " ", 
             RowBox[{"N", "[", "ct", "]"}], " ", 
             "\"\<Enter the Axial Ratio (Rf).\>\""}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"SigmaRatio", "[", "ct", "]"}], "=", 
           RowBox[{"Input", "[", 
            RowBox[{"\"\<\>\"", 
             RowBox[{"N", "[", "ct", "]"}], 
             "\"\<Enter the standard deviation for the axial ratios (Rf's).\>\
\""}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"numbdata", "[", "ct", "]"}], "=", 
           RowBox[{"Input", "[", 
            RowBox[{"\"\<\>\"", 
             RowBox[{"N", "[", "ct", "]"}], 
             "\"\<How many ellipses were measured to determine this standard \
deviation?\>\""}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"TempFee", "[", "ct", "]"}], "=", 
           RowBox[{"Input", "[", 
            RowBox[{"\"\<\>\"", " ", 
             RowBox[{"N", "[", "ct", "]"}], " ", 
             "\"\<Enter the Angular Orientation, (\[Phi]).\>\""}], "]"}]}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Fee", "[", "ct", "]"}], "=", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"TempFee", "[", "ct", "]"}], ">", "90"}], ",", 
             RowBox[{
              RowBox[{"TempFee", "[", "ct", "]"}], "-", "180"}], ",", 
             RowBox[{"TempFee", "[", "ct", "]"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"\[CapitalPsi]", "[", "ct", "]"}], "=", 
           RowBox[{
            FractionBox["1", "180"], " ", 
            RowBox[{"Fee", "[", "ct", "]"}], " ", "\[Pi]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"SigmaFee", "[", "ct", "]"}], "=", 
           RowBox[{"Input", "[", 
            RowBox[{"\"\<\>\"", 
             RowBox[{"N", "[", "ct", "]"}], 
             "\"\<Enter the standard deviation for the angular orientations (\
\[Phi]'s)\>\""}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"ct", "=", 
           RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"GeneralEllipsoid", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Lambda]1", ",", "\[Gamma]3", ",", "\[Gamma]2"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"\[Gamma]3", ",", "\[Lambda]2", ",", "\[Gamma]1"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"\[Gamma]2", ",", "\[Gamma]1", ",", "\[Lambda]3"}], "}"}]}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"dummy", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"ErrorIndex", "[", "0", "]"}], "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"dummy", "\[LessEqual]", "numbplanes"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"OriginalDipDir", "[", "dummy", "]"}], "=", 
        RowBox[{"DipDir", "[", "dummy", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"DipDir", "[", "dummy", "]"}], "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Dip", "[", "dummy", "]"}], "\[Equal]", "90"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"DipDir", "[", "dummy", "]"}], "\[Equal]", "0"}], ",", 
            "180", ",", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"DipDir", "[", "dummy", "]"}], ">", "180"}], ",", 
              RowBox[{
               RowBox[{"DipDir", "[", "dummy", "]"}], "-", "180"}], ",", 
              RowBox[{"DipDir", "[", "dummy", "]"}]}], "]"}]}], "]"}], ",", 
          RowBox[{"DipDir", "[", "dummy", "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"f", "=", 
        RowBox[{
         RowBox[{"DipDir", "[", "dummy", "]"}], "-", "90"}]}], ";", 
       RowBox[{"j", "=", 
        RowBox[{"90", "-", 
         RowBox[{"Dip", "[", "dummy", "]"}]}]}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Dip", "[", "dummy", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{"f", "=", "90"}]}], "]"}], ";", 
       RowBox[{"\[Mu]", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             FractionBox[
              RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}], ",", 
            RowBox[{"Sin", "[", 
             FractionBox[
              RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}], ",", "0"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              FractionBox[
               RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}]}], ",", 
            RowBox[{"Cos", "[", 
             FractionBox[
              RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}], ",", "0"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
       RowBox[{"H", "=", 
        RowBox[{
         RowBox[{"Transpose", "[", "\[Mu]", "]"}], ".", "GeneralEllipsoid", 
         ".", "\[Mu]"}]}], ";", 
       RowBox[{"\[Eta]", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"Cos", "[", 
             FractionBox[
              RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}], ",", 
            RowBox[{"Sin", "[", 
             FractionBox[
              RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              FractionBox[
               RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}]}], ",", 
            RowBox[{"Cos", "[", 
             FractionBox[
              RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}]}], "}"}]}], "}"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Q", "=", 
        RowBox[{
         RowBox[{"Transpose", "[", "\[Eta]", "]"}], ".", "H", ".", 
         "\[Eta]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"TempMatEll", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Q", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
            RowBox[{"Q", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Q", "\[LeftDoubleBracket]", 
             RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
            RowBox[{"Q", "\[LeftDoubleBracket]", 
             RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], "}"}]}], 
         "}"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"SectionEllipse", "[", "dummy", "]"}], "=", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
              RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
             RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
              RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], "}"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
              RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
             RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
              RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], "}"}]}], 
          "}"}], "/", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
                RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], " ", 
               RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
                RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], "-", 
              RowBox[{
               RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
                RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], " ", 
               RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
                RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}]}], ")"}],
             "^", "2"}], ")"}], "^", 
          RowBox[{"(", 
           RowBox[{"1", "/", "4"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"PrinMat", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"N", "[", 
             SqrtBox[
              FractionBox["1", 
               SuperscriptBox[
                RowBox[{"\[CapitalPi]", "[", "dummy", "]"}], "2"]]], "]"}], 
            ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"N", "[", 
             FractionBox["1", 
              SqrtBox[
               FractionBox["1", 
                SuperscriptBox[
                 RowBox[{"\[CapitalPi]", "[", "dummy", "]"}], "2"]]]], 
             "]"}]}], "}"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"RotMat", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"N", "[", 
              RowBox[{"\[CapitalPsi]", "[", "dummy", "]"}], "]"}], "]"}], ",", 
            RowBox[{"Sin", "[", 
             RowBox[{"N", "[", 
              RowBox[{"\[CapitalPsi]", "[", "dummy", "]"}], "]"}], "]"}]}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              RowBox[{"N", "[", 
               RowBox[{"\[CapitalPsi]", "[", "dummy", "]"}], "]"}], "]"}]}], 
            ",", 
            RowBox[{"Cos", "[", 
             RowBox[{"N", "[", 
              RowBox[{"\[CapitalPsi]", "[", "dummy", "]"}], "]"}], "]"}]}], 
           "}"}]}], "}"}]}], ";", 
       RowBox[{"TempEllipMat", "=", 
        RowBox[{
         RowBox[{"Transpose", "[", "RotMat", "]"}], ".", "PrinMat", ".", 
         "RotMat"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"EllipMat", "[", "dummy", "]"}], "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"TempEllipMat", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
            RowBox[{"TempEllipMat", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"TempEllipMat", "\[LeftDoubleBracket]", 
             RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
            RowBox[{"TempEllipMat", "\[LeftDoubleBracket]", 
             RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], "}"}]}], 
         "}"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"ErrorIndex", "[", "dummy", "]"}], "=", 
        RowBox[{
         RowBox[{"ErrorIndex", "[", 
          RowBox[{"dummy", "-", "1"}], "]"}], "+", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"EllipMat", "[", "dummy", "]"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "-", 
              RowBox[{
               RowBox[{"SectionEllipse", "[", "dummy", "]"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ")"}], 
            "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"EllipMat", "[", "dummy", "]"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
              RowBox[{
               RowBox[{"SectionEllipse", "[", "dummy", "]"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], ")"}], 
            "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"EllipMat", "[", "dummy", "]"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
              RowBox[{
               RowBox[{"SectionEllipse", "[", "dummy", "]"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], ")"}], 
            "2"]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"MD", "[", "dummy", "]"}], "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"EllipMat", "[", "dummy", "]"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "-", 
              RowBox[{
               RowBox[{"SectionEllipse", "[", "dummy", "]"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ")"}], 
            "]"}], "+", 
           RowBox[{"Abs", "[", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"EllipMat", "[", "dummy", "]"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
              RowBox[{
               RowBox[{"SectionEllipse", "[", "dummy", "]"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], ")"}], 
            "]"}], "+", 
           RowBox[{"Abs", "[", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"EllipMat", "[", "dummy", "]"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
              RowBox[{
               RowBox[{"SectionEllipse", "[", "dummy", "]"}], 
               "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], ")"}], 
            "]"}]}], ")"}], "/", "3"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"dummy", "=", 
        RowBox[{"dummy", "+", "1"}]}], ";"}]}], "]"}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"\[Lambda]2", "=", "1"}], ";"}], "\n", 
   RowBox[{"Off", "[", 
    RowBox[{"FindMinimum", "::", "precw"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mycons", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "-", "\[Lambda]1", "-", "\[Lambda]3"}], ")"}], 
        "\[LessEqual]", "0"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"\[Gamma]1", "^", "2"}]}], "-", 
          RowBox[{"\[Gamma]2", "^", "2"}], "-", 
          RowBox[{"\[Gamma]3", "^", "2"}], "+", "\[Lambda]1", "+", 
          "\[Lambda]3", "+", 
          RowBox[{"\[Lambda]1", " ", "\[Lambda]3"}]}], ")"}], 
        "\[GreaterEqual]", "0"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Gamma]2", "^", "2"}], "-", 
         RowBox[{"2", " ", "\[Gamma]1", " ", "\[Gamma]2", " ", "\[Gamma]3"}], 
         "+", 
         RowBox[{
          RowBox[{"\[Gamma]1", "^", "2"}], " ", "\[Lambda]1"}], "+", 
         RowBox[{
          RowBox[{"\[Gamma]3", "^", "2"}], " ", "\[Lambda]3"}], "-", 
         RowBox[{"\[Lambda]1", " ", "\[Lambda]3"}]}], "\[LessEqual]", "0"}]}],
       "}"}]}], ";"}], "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "g"}], "]"}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"stepsize", "=", ".1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Lamda1max", "=", "10"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Lamda3max", "=", "10"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"init\[Lambda]1", "=", ".01"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"counter", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"init\[Lambda]1", "\[LessEqual]", "Lamda1max"}], ",", "\n", 
      RowBox[{
       RowBox[{"init\[Lambda]3", "=", ".01"}], ";", "\n", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"init\[Lambda]3", "\[LessEqual]", "Lamda3max"}], ",", "\n", 
         RowBox[{
          RowBox[{"Quiet", "[", 
           RowBox[{
            RowBox[{"FindMinimum", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], ",", 
                "mycons"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
              RowBox[{"Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}]}], 
             "]"}], ";", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Length", "[", "$MessageList", "]"}], "\[Equal]", 
               "0"}], ",", 
              RowBox[{"Break", "[", "]"}]}], "]"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"init\[Lambda]3", "=", 
           RowBox[{"init\[Lambda]3", "+", "stepsize"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"counter", "=", 
           RowBox[{"counter", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Quiet", "[", 
        RowBox[{
         RowBox[{"FindMinimum", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], ",", "mycons"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
           RowBox[{"Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}]}], 
          "]"}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "$MessageList", "]"}], "\[Equal]", "0"}], 
           ",", 
           RowBox[{"Break", "[", "]"}]}], "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"init\[Lambda]1", "=", 
        RowBox[{"init\[Lambda]1", "+", "stepsize"}]}], ";"}]}], "]"}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"reducedprecision", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"Precise", "\[Equal]", "0"}], ",", "\n", 
      RowBox[{
       RowBox[{"hmmm", "=", 
        RowBox[{"FindMinimum", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], ",", "mycons"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
          RowBox[{"Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}]}], 
         "]"}]}], ";"}], ",", 
      RowBox[{
       RowBox[{"Quiet", "[", 
        RowBox[{
         RowBox[{"FindMinimum", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], ",", "mycons"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
           RowBox[{"Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}], ",", 
           RowBox[{"WorkingPrecision", "\[Rule]", "Precise"}]}], "]"}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "$MessageList", "]"}], "\[Equal]", "0"}], 
           ",", 
           RowBox[{
            RowBox[{"hmmm", "=", 
             RowBox[{"FindMinimum", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], ",", 
                 "mycons"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
               RowBox[{"Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}], 
               ",", 
               RowBox[{"WorkingPrecision", "\[Rule]", "Precise"}]}], "]"}]}], 
            ";"}], ",", 
           RowBox[{
            RowBox[{"reducedprecision", "=", "1"}], ";", 
            RowBox[{"hmmm", "=", 
             RowBox[{"FindMinimum", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], ",", 
                 "mycons"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
               RowBox[{"Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}]}], 
              "]"}]}], ";"}]}], "]"}], ";"}], "]"}], ";"}]}], "]"}], ";"}], 
   "\n", "\n", "\n", 
   RowBox[{
    RowBox[{"\[Lambda]1", "=", 
     RowBox[{"hmmm", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "1", ",", "2"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Lambda]3", "=", 
     RowBox[{"hmmm", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "2", ",", "2"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Gamma]1", "=", 
     RowBox[{"hmmm", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "3", ",", "2"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Gamma]2", "=", 
     RowBox[{"hmmm", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "4", ",", "2"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Gamma]3", "=", 
     RowBox[{"hmmm", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "5", ",", "2"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Gerror", "=", 
     FractionBox[
      RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], "numbplanes"]}], ";"}], 
   "\n", "\n", 
   RowBox[{
    RowBox[{"FitEllipsoid", "=", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\[Lambda]1", ",", "\[Gamma]3", ",", "\[Gamma]2"}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"\[Gamma]3", ",", "\[Lambda]2", ",", "\[Gamma]1"}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"\[Gamma]2", ",", "\[Gamma]1", ",", "\[Lambda]3"}], "}"}]}],
         "}"}], ",", "6"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"S", "=", 
     RowBox[{"Eigensystem", "[", "FitEllipsoid", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"M", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"Eigenvectors", "[", "FitEllipsoid", "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"L", "=", 
     RowBox[{"Eigenvalues", "[", "FitEllipsoid", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"test", "=", 
     RowBox[{"Sort", "[", 
      RowBox[{
       RowBox[{"Abs", "[", "L", "]"}], ",", "Greater"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"rat", "=", 
     RowBox[{
      SqrtBox[
       RowBox[{
       "test", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], "/", 
      SqrtBox[
       RowBox[{
       "test", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]]}]}], 
    ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"rat", ">", "10"}], ",", 
      RowBox[{
       RowBox[{"Quiet", "[", 
        RowBox[{
         RowBox[{"FindMinimum", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], ",", "mycons"}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
           RowBox[{"Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}], ",", 
           RowBox[{"WorkingPrecision", "\[Rule]", "40"}]}], "]"}], ";", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "$MessageList", "]"}], "\[Equal]", "0"}], 
           ",", 
           RowBox[{
            RowBox[{"hmmm", "=", 
             RowBox[{"FindMinimum", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], ",", 
                 "mycons"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
               RowBox[{"Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}], 
               ",", 
               RowBox[{"WorkingPrecision", "\[Rule]", "40"}]}], "]"}]}], 
            ";"}], ",", 
           RowBox[{
            RowBox[{"hmmm", "=", 
             RowBox[{"FindMinimum", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], ",", 
                 "mycons"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
               RowBox[{"Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}]}], 
              "]"}]}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"\[Lambda]1", "=", 
          RowBox[{"hmmm", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"\[Lambda]3", "=", 
          RowBox[{"hmmm", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "2", ",", "2"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"\[Gamma]1", "=", 
          RowBox[{"hmmm", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "3", ",", "2"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"\[Gamma]2", "=", 
          RowBox[{"hmmm", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "4", ",", "2"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"\[Gamma]3", "=", 
          RowBox[{"hmmm", "[", 
           RowBox[{"[", 
            RowBox[{"2", ",", "5", ",", "2"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Gerror", "=", 
          FractionBox[
           RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], "numbplanes"]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"FitEllipsoid", "=", 
          RowBox[{"N", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"\[Lambda]1", ",", "\[Gamma]3", ",", "\[Gamma]2"}], 
               "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Gamma]3", ",", "\[Lambda]2", ",", "\[Gamma]1"}], 
               "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Gamma]2", ",", "\[Gamma]1", ",", "\[Lambda]3"}], 
               "}"}]}], "}"}], ",", "6"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"S", "=", 
          RowBox[{"Eigensystem", "[", "FitEllipsoid", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"M", "=", 
          RowBox[{"Transpose", "[", 
           RowBox[{"Eigenvectors", "[", "FitEllipsoid", "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"L", "=", 
          RowBox[{"Eigenvalues", "[", "FitEllipsoid", "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"test", "=", 
          RowBox[{"Sort", "[", 
           RowBox[{
            RowBox[{"Abs", "[", "L", "]"}], ",", "Greater"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"rat", "=", 
          RowBox[{
           SqrtBox[
            RowBox[{
            "test", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
           "/", 
           SqrtBox[
            RowBox[{
            "test", "\[LeftDoubleBracket]", "3", 
             "\[RightDoubleBracket]"}]]}]}], ";"}], "]"}], ";"}]}], "]"}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MeanDiffError", "=", 
     RowBox[{"Mean", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"MD", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", "numbplanes"}], "}"}]}], "]"}], "]"}]}], 
    ";"}], "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Problem", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"L", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "<", "0"}], "||", 
       RowBox[{
        RowBox[{"L", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "<", "0"}], "||", 
       RowBox[{
        RowBox[{"L", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "<", "0"}], "||", 
       RowBox[{"rat", ">", "1000"}]}], ",", 
      RowBox[{
       RowBox[{"Problem", "=", "1"}], ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"L", "=", 
     RowBox[{"Sort", "[", 
      RowBox[{
       RowBox[{"Abs", "[", "L", "]"}], ",", "Greater"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Lval", "=", 
     RowBox[{"N", "[", 
      RowBox[{"{", 
       RowBox[{
        FractionBox["1", 
         SqrtBox[
          RowBox[{
          "L", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]]], ",", 
        FractionBox["1", 
         SqrtBox[
          RowBox[{
          "L", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]], ",", 
        FractionBox["1", 
         SqrtBox[
          RowBox[{
          "L", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]]}], 
       "}"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"FitLengths", "=", "Lval"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Min", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], "]"}], "\[Equal]", 
       RowBox[{"S", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Longnumb", "=", "1"}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Min", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], "]"}], "\[Equal]", 
       RowBox[{"S", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Longnumb", "=", "2"}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Min", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], "]"}], "\[Equal]", 
       RowBox[{"S", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Longnumb", "=", "3"}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Max", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], "]"}], "\[Equal]", 
       RowBox[{"S", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Shortnumb", "=", "1"}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Max", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], "]"}], "\[Equal]", 
       RowBox[{"S", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Shortnumb", "=", "2"}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Max", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
          RowBox[{"S", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], "]"}], "\[Equal]", 
       RowBox[{"S", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Shortnumb", "=", "3"}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Intermnumb", "=", 
     RowBox[{"6", "-", "Longnumb", "-", "Shortnumb"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ShortAxis", "=", 
     RowBox[{
      RowBox[{"S", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "Shortnumb"}], "]"}], "]"}], "/", 
      RowBox[{"Norm", "[", 
       RowBox[{"S", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "Shortnumb"}], "]"}], "]"}], "]"}]}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"IntermAxis", "=", 
     RowBox[{
      RowBox[{"S", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "Intermnumb"}], "]"}], "]"}], "/", 
      RowBox[{"Norm", "[", 
       RowBox[{"S", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "Intermnumb"}], "]"}], "]"}], "]"}]}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"LongAxis", "=", 
     RowBox[{
      RowBox[{"S", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "Longnumb"}], "]"}], "]"}], "/", 
      RowBox[{"Norm", "[", 
       RowBox[{"S", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "Longnumb"}], "]"}], "]"}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ShortAxisFit", "=", "ShortAxis"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IntermAxisFit", "=", "IntermAxis"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"LongAxisFit", "=", "LongAxis"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ForPlotRange", "=", 
     RowBox[{"Lval", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Ellipsoids", "=", 
     RowBox[{"ParametricPlot3D", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
           "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
            " ", 
           RowBox[{
           "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
           " ", 
           RowBox[{"Cos", "[", "t", "]"}], " ", 
           RowBox[{"Cos", "[", "u", "]"}]}], "+", 
          RowBox[{
           RowBox[{
           "IntermAxis", "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}], " ", 
           RowBox[{
           "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
           " ", 
           RowBox[{"Sin", "[", "t", "]"}], " ", 
           RowBox[{"Cos", "[", "u", "]"}]}], "+", 
          RowBox[{
           RowBox[{
           "ShortAxis", "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}], " ", 
           RowBox[{
           "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
           " ", 
           RowBox[{"Sin", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{
           "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
            " ", 
           RowBox[{
           "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
           " ", 
           RowBox[{"Cos", "[", "t", "]"}], " ", 
           RowBox[{"Cos", "[", "u", "]"}]}], "+", 
          RowBox[{
           RowBox[{
           "IntermAxis", "\[LeftDoubleBracket]", "2", 
            "\[RightDoubleBracket]"}], " ", 
           RowBox[{
           "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
           " ", 
           RowBox[{"Sin", "[", "t", "]"}], " ", 
           RowBox[{"Cos", "[", "u", "]"}]}], "+", 
          RowBox[{
           RowBox[{
           "ShortAxis", "\[LeftDoubleBracket]", "2", 
            "\[RightDoubleBracket]"}], " ", 
           RowBox[{
           "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
           " ", 
           RowBox[{"Sin", "[", "u", "]"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{
           "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}],
            " ", 
           RowBox[{
           "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
           " ", 
           RowBox[{"Cos", "[", "t", "]"}], " ", 
           RowBox[{"Cos", "[", "u", "]"}]}], "+", 
          RowBox[{
           RowBox[{
           "IntermAxis", "\[LeftDoubleBracket]", "3", 
            "\[RightDoubleBracket]"}], " ", 
           RowBox[{
           "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
           " ", 
           RowBox[{"Sin", "[", "t", "]"}], " ", 
           RowBox[{"Cos", "[", "u", "]"}]}], "+", 
          RowBox[{
           RowBox[{
           "ShortAxis", "\[LeftDoubleBracket]", "3", 
            "\[RightDoubleBracket]"}], " ", 
           RowBox[{
           "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
           " ", 
           RowBox[{"Sin", "[", "u", "]"}]}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", 
         RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"u", ",", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], ",", 
         FractionBox["\[Pi]", "2"]}], "}"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"400", ",", "400"}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"m1", "=", 
     RowBox[{"Graphics3D", "[", 
      RowBox[{"Cylinder", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "1.2"}], " ", 
           RowBox[{
           "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
           " ", "LongAxis"}], ",", 
          RowBox[{"1.2", " ", 
           RowBox[{
           "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
           " ", "LongAxis"}]}], "}"}], ",", 
        RowBox[{".075", "*", 
         RowBox[{"Lval", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}]}], "]"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"m2", "=", 
     RowBox[{"Graphics3D", "[", 
      RowBox[{"Cylinder", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "1.2"}], " ", 
           RowBox[{
           "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
           " ", "IntermAxis"}], ",", 
          RowBox[{"1.2", " ", 
           RowBox[{
           "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
           " ", "IntermAxis"}]}], "}"}], ",", 
        RowBox[{".075", "*", 
         RowBox[{"Lval", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}]}], "]"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"m3", "=", 
     RowBox[{"Graphics3D", "[", 
      RowBox[{"Cylinder", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "1.2"}], " ", 
           RowBox[{
           "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
           " ", "ShortAxis"}], ",", 
          RowBox[{"1.2", " ", 
           RowBox[{
           "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
           " ", "ShortAxis"}]}], "}"}], ",", 
        RowBox[{".075", "*", 
         RowBox[{"Lval", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}]}], "]"}], "]"}]}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"vectors", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"m1", ",", "m2", ",", "m3"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Vellipsoid", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"Ellipsoids", ",", "vectors", ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"400", ",", "400"}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"dummy", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"dummy", "\[LessEqual]", "numbplanes"}], ",", 
      RowBox[{
       RowBox[{"f", "=", 
        RowBox[{
         RowBox[{"DipDir", "[", "dummy", "]"}], "-", "90"}]}], ";", 
       RowBox[{"j", "=", 
        RowBox[{"90", "-", 
         RowBox[{"Dip", "[", "dummy", "]"}]}]}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Dip", "[", "dummy", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{"f", "=", "90"}]}], "]"}], ";", 
       RowBox[{"\[Mu]", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             FractionBox[
              RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}], ",", 
            RowBox[{"Sin", "[", 
             FractionBox[
              RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}], ",", "0"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              FractionBox[
               RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}]}], ",", 
            RowBox[{"Cos", "[", 
             FractionBox[
              RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}], ",", "0"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
       RowBox[{"H", "=", 
        RowBox[{
         RowBox[{"Transpose", "[", "\[Mu]", "]"}], ".", "FitEllipsoid", ".", 
         "\[Mu]"}]}], ";", 
       RowBox[{"\[Eta]", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"Cos", "[", 
             FractionBox[
              RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}], ",", 
            RowBox[{"Sin", "[", 
             FractionBox[
              RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              FractionBox[
               RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}]}], ",", 
            RowBox[{"Cos", "[", 
             FractionBox[
              RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}]}], "}"}]}], "}"}]}], 
       ";", 
       RowBox[{"Q", "=", 
        RowBox[{
         RowBox[{"Transpose", "[", "\[Eta]", "]"}], ".", "H", ".", 
         "\[Eta]"}]}], ";", 
       RowBox[{"Ellipse", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Q", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
            RowBox[{"Q", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Q", "\[LeftDoubleBracket]", 
             RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
            RowBox[{"Q", "\[LeftDoubleBracket]", 
             RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], "}"}]}], 
         "}"}]}], ";", 
       RowBox[{"Se", "=", 
        RowBox[{"Eigensystem", "[", "Ellipse", "]"}]}], ";", 
       RowBox[{"Me", "=", 
        RowBox[{"Transpose", "[", 
         RowBox[{"Eigenvectors", "[", "Ellipse", "]"}], "]"}]}], ";", 
       RowBox[{
        RowBox[{"Le", "[", "dummy", "]"}], "=", 
        RowBox[{"Eigenvalues", "[", "Ellipse", "]"}]}], ";", 
       RowBox[{
        RowBox[{"Le", "[", "dummy", "]"}], "=", 
        RowBox[{"Sort", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Le", "[", "dummy", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], "//", "N"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Le", "[", "dummy", "]"}], "[", 
              RowBox[{"[", "2", "]"}], "]"}], "//", "N"}]}], "}"}], ",", 
          "Greater"}], "]"}]}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Le", "[", "dummy", "]"}], "\[NotEqual]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Se", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
            RowBox[{"Se", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], "}"}]}], 
         ",", 
         RowBox[{
          RowBox[{"Me", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Me", "\[LeftDoubleBracket]", 
                RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
               RowBox[{"Me", "\[LeftDoubleBracket]", 
                RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "}"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Me", "\[LeftDoubleBracket]", 
                RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
               RowBox[{"Me", "\[LeftDoubleBracket]", 
                RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], "}"}]}],
             "}"}]}], ";"}]}], "]"}], ";", 
       RowBox[{
        RowBox[{"Le", "[", "dummy", "]"}], "=", 
        RowBox[{"{", 
         RowBox[{
          FractionBox["1", 
           SqrtBox[
            RowBox[{
             RowBox[{"Le", "[", "dummy", "]"}], "\[LeftDoubleBracket]", "2", 
             "\[RightDoubleBracket]"}]]], ",", 
          FractionBox["1", 
           SqrtBox[
            RowBox[{
             RowBox[{"Le", "[", "dummy", "]"}], "\[LeftDoubleBracket]", "1", 
             "\[RightDoubleBracket]"}]]]}], "}"}]}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Me", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], "\[Equal]", 
          "0"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"AngularOrientation", "[", "dummy", "]"}], "=", 
           FractionBox["\[Pi]", "2"]}], ";"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"AngularOrientation", "[", "dummy", "]"}], "=", 
           RowBox[{"ArcTan", "[", 
            FractionBox[
             RowBox[{"Me", "\[LeftDoubleBracket]", 
              RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], 
             RowBox[{"Me", "\[LeftDoubleBracket]", 
              RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]], "]"}]}], 
          ";"}]}], "]"}], ";", 
       RowBox[{
        RowBox[{"FitAxialRatio", "[", "dummy", "]"}], "=", 
        FractionBox[
         RowBox[{
          RowBox[{"Le", "[", "dummy", "]"}], "\[LeftDoubleBracket]", "1", 
          "\[RightDoubleBracket]"}], 
         RowBox[{
          RowBox[{"Le", "[", "dummy", "]"}], "\[LeftDoubleBracket]", "2", 
          "\[RightDoubleBracket]"}]]}], ";", 
       RowBox[{"dummy", "=", 
        RowBox[{"dummy", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"num", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"num", "\[LessEqual]", "numbplanes"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"AreaFit", "[", "num", "]"}], "=", 
        RowBox[{"\[Pi]", " ", 
         RowBox[{
          RowBox[{"Le", "[", "num", "]"}], "\[LeftDoubleBracket]", "1", 
          "\[RightDoubleBracket]"}], " ", 
         RowBox[{
          RowBox[{"Le", "[", "num", "]"}], "\[LeftDoubleBracket]", "2", 
          "\[RightDoubleBracket]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"r", "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"AreaFit", "[", "num", "]"}], " ", 
              RowBox[{"\[CapitalPi]", "[", "num", "]"}]}], "\[Pi]"]], ">", 
           RowBox[{
            RowBox[{"Le", "[", "num", "]"}], "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}]}], ",", 
          RowBox[{
           SqrtBox[
            FractionBox[
             RowBox[{
              RowBox[{"AreaFit", "[", "num", "]"}], " ", 
              RowBox[{"\[CapitalPi]", "[", "num", "]"}]}], "\[Pi]"]], "*", 
           "1.1"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Le", "[", "num", "]"}], "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}], " ", "1.1"}]}], "]"}]}], ";", 
       RowBox[{
        RowBox[{"Initgraph", "[", "num", "]"}], "=", 
        RowBox[{"ParametricPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              SqrtBox[
               FractionBox[
                RowBox[{
                 RowBox[{"AreaFit", "[", "num", "]"}], " ", 
                 RowBox[{"\[CapitalPi]", "[", "num", "]"}]}], "\[Pi]"]], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"\[CapitalPsi]", "[", "num", "]"}], "]"}], " ", 
              RowBox[{"Sin", "[", "t", "]"}]}], "-", 
             RowBox[{
              SqrtBox[
               FractionBox[
                RowBox[{"AreaFit", "[", "num", "]"}], 
                RowBox[{
                 RowBox[{"\[CapitalPi]", "[", "num", "]"}], " ", "\[Pi]"}]]], 
              " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"\[CapitalPsi]", "[", "num", "]"}], "]"}], " ", 
              RowBox[{"Cos", "[", "t", "]"}]}]}], ",", 
            RowBox[{
             RowBox[{
              SqrtBox[
               FractionBox[
                RowBox[{
                 RowBox[{"AreaFit", "[", "num", "]"}], " ", 
                 RowBox[{"\[CapitalPi]", "[", "num", "]"}]}], "\[Pi]"]], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"\[CapitalPsi]", "[", "num", "]"}], "]"}], " ", 
              RowBox[{"Sin", "[", "t", "]"}]}], "+", 
             RowBox[{
              SqrtBox[
               FractionBox[
                RowBox[{"AreaFit", "[", "num", "]"}], 
                RowBox[{
                 RowBox[{"\[CapitalPi]", "[", "num", "]"}], " ", "\[Pi]"}]]], 
              " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"\[CapitalPsi]", "[", "num", "]"}], "]"}], " ", 
              RowBox[{"Cos", "[", "t", "]"}]}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", 
            RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "r"}], ",", "r"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "r"}], ",", "r"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"300", ",", "300"}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Thick", ",", "Blue"}], "}"}]}], ",", 
          RowBox[{
          "PlotLabel", "\[Rule]", "\"\<initial input data (input)\>\""}]}], 
         "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Fitgraph", "[", "num", "]"}], "=", 
        RowBox[{"ParametricPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Le", "[", "num", "]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"AngularOrientation", "[", "num", "]"}], "]"}], " ", 
              RowBox[{"Sin", "[", "t", "]"}]}], "-", 
             RowBox[{
              RowBox[{
               RowBox[{"Le", "[", "num", "]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"AngularOrientation", "[", "num", "]"}], "]"}], " ", 
              RowBox[{"Cos", "[", "t", "]"}]}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Le", "[", "num", "]"}], "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"AngularOrientation", "[", "num", "]"}], "]"}], " ", 
              RowBox[{"Sin", "[", "t", "]"}]}], "+", 
             RowBox[{
              RowBox[{
               RowBox[{"Le", "[", "num", "]"}], "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"AngularOrientation", "[", "num", "]"}], "]"}], " ", 
              RowBox[{"Cos", "[", "t", "]"}]}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", 
            RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "r"}], ",", "r"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "r"}], ",", "r"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Thick", ",", "Red"}], "}"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"300", ",", "300"}], "}"}]}], ",", 
          RowBox[{
          "PlotLabel", "\[Rule]", 
           "\"\<Section through best fit ellipsoid (fit)\>\""}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"sections", "[", "num", "]"}], "=", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"Initgraph", "[", "num", "]"}], ",", 
          RowBox[{"Fitgraph", "[", "num", "]"}], ",", 
          RowBox[{"PlotLabel", "\[Rule]", 
           RowBox[{"Row", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<Red = Fit.   Blue = Input.  Dip:DipDir = \>\"", ",", 
              RowBox[{"N", "[", 
               RowBox[{"Dip", "[", "num", "]"}], "]"}], ",", "\"\<:\>\"", ",", 
              RowBox[{"N", "[", 
               RowBox[{"OriginalDipDir", "[", "num", "]"}], "]"}]}], "}"}], 
            "]"}]}], ",", 
          RowBox[{"PlotRange", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "r"}], ",", "r"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "r"}], ",", "r"}], "}"}]}], "}"}]}], ",", 
          RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
          RowBox[{"ImageSize", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"300", ",", "300"}], "}"}]}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"num", "=", 
        RowBox[{"num", "+", "1"}]}], ";"}]}], "]"}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"sections", "[", "ct", "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Initial Axial Ratio (Blue) = \>\"", ",", 
         RowBox[{"N", "[", 
          RowBox[{"\[CapitalPi]", "[", "ct", "]"}], "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Final Fit Axial Ratio (Red) = \>\"", ",", 
         RowBox[{"N", "[", 
          FractionBox[
           RowBox[{
            RowBox[{"Le", "[", "ct", "]"}], "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}], 
           RowBox[{
            RowBox[{"Le", "[", "ct", "]"}], "\[LeftDoubleBracket]", "2", 
            "\[RightDoubleBracket]"}]], "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Initial Angle (Blue) = \>\"", ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"N", "[", 
             FractionBox[
              RowBox[{
               RowBox[{"\[CapitalPsi]", "[", "ct", "]"}], " ", "180"}], 
              "\[Pi]"], "]"}], "\[GreaterEqual]", "0"}], ",", 
           RowBox[{"N", "[", 
            FractionBox[
             RowBox[{
              RowBox[{"\[CapitalPsi]", "[", "ct", "]"}], " ", "180"}], 
             "\[Pi]"], "]"}], ",", 
           RowBox[{"180", "+", 
            RowBox[{"N", "[", 
             FractionBox[
              RowBox[{
               RowBox[{"\[CapitalPsi]", "[", "ct", "]"}], " ", "180"}], 
              "\[Pi]"], "]"}]}]}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Final Fit Angle (Red)= \>\"", ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"N", "[", 
             FractionBox[
              RowBox[{
               RowBox[{"AngularOrientation", "[", "ct", "]"}], " ", "180"}], 
              "\[Pi]"], "]"}], "\[GreaterEqual]", "0"}], ",", 
           RowBox[{"N", "[", 
            FractionBox[
             RowBox[{
              RowBox[{"AngularOrientation", "[", "ct", "]"}], " ", "180"}], 
             "\[Pi]"], "]"}], ",", 
           RowBox[{"180", "+", 
            RowBox[{"N", "[", 
             FractionBox[
              RowBox[{
               RowBox[{"AngularOrientation", "[", "ct", "]"}], " ", "180"}], 
              "\[Pi]"], "]"}]}]}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"ct", "=", 
        RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{"Clear", "[", 
    RowBox[{"a", ",", "b", ",", "c"}], "]"}], "\n", 
   RowBox[{
    RowBox[{"dummy3", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"dummy3", "\[LessEqual]", "numbplanes"}], ",", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"DipDir", "[", "dummy3", "]"}], "\[GreaterEqual]", "0"}], "&&", 
          RowBox[{
           RowBox[{"DipDir", "[", "dummy3", "]"}], "\[LessEqual]", "90"}]}], 
         ",", 
         RowBox[{
          RowBox[{"\[Theta]", "=", 
           RowBox[{"DipDir", "[", "dummy3", "]"}]}], ";"}]}], "]"}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"DipDir", "[", "dummy3", "]"}], ">", "90"}], "&&", 
          RowBox[{
           RowBox[{"DipDir", "[", "dummy3", "]"}], "\[LessEqual]", "180"}]}], 
         ",", 
         RowBox[{
          RowBox[{"\[Theta]", "=", 
           RowBox[{"180", "-", 
            RowBox[{"DipDir", "[", "dummy3", "]"}]}]}], ";"}]}], "]"}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"DipDir", "[", "dummy3", "]"}], ">", "180"}], "&&", 
          RowBox[{
           RowBox[{"DipDir", "[", "dummy3", "]"}], "\[LessEqual]", "270"}]}], 
         ",", 
         RowBox[{
          RowBox[{"\[Theta]", "=", 
           RowBox[{
            RowBox[{"DipDir", "[", "dummy3", "]"}], "-", "180"}]}], ";"}]}], 
        "]"}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"DipDir", "[", "dummy3", "]"}], ">", "270"}], "&&", 
          RowBox[{
           RowBox[{"DipDir", "[", "dummy3", "]"}], "\[LessEqual]", "360"}]}], 
         ",", 
         RowBox[{
          RowBox[{"\[Theta]", "=", 
           RowBox[{"360", "-", 
            RowBox[{"DipDir", "[", "dummy3", "]"}]}]}], ";"}]}], "]"}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Theta]", "\[Equal]", "90"}], "||", 
          RowBox[{"\[Theta]", "\[Equal]", "270"}]}], ",", 
         RowBox[{
          RowBox[{"a", "=", "0"}], ";"}], ",", 
         RowBox[{
          RowBox[{"a", "=", 
           SqrtBox[
            FractionBox["1", 
             RowBox[{"1", "+", 
              SuperscriptBox[
               RowBox[{"Tan", "[", 
                FractionBox[
                 RowBox[{"\[Theta]", " ", "\[Pi]"}], "180"], "]"}], 
               "2"]}]]]}], ";"}]}], "]"}], ";", 
       RowBox[{"b", "=", 
        SqrtBox[
         RowBox[{"1", "-", 
          SuperscriptBox["a", "2"]}]]}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Dip", "[", "dummy3", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"a", "=", "0"}], ";", 
          RowBox[{"b", "=", "0"}], ";", 
          RowBox[{"c", "=", "1"}], ";"}], ",", 
         RowBox[{
          RowBox[{"c", "=", 
           RowBox[{"Tan", "[", 
            RowBox[{
             FractionBox["1", "180"], " ", 
             RowBox[{"(", 
              RowBox[{"90", "-", 
               RowBox[{"Dip", "[", "dummy3", "]"}]}], ")"}], " ", "\[Pi]"}], 
            "]"}]}], ";"}]}], "]"}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"DipDir", "[", "dummy3", "]"}], "\[GreaterEqual]", "0"}], "&&", 
          RowBox[{
           RowBox[{"DipDir", "[", "dummy3", "]"}], "\[LessEqual]", "90"}]}], 
         ",", 
         RowBox[{
          RowBox[{"a", "=", "a"}], ";", 
          RowBox[{"b", "=", 
           RowBox[{"-", "b"}]}], ";"}]}], "]"}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"DipDir", "[", "dummy3", "]"}], ">", "90"}], "&&", 
          RowBox[{
           RowBox[{"DipDir", "[", "dummy3", "]"}], "\[LessEqual]", "180"}]}], 
         ",", 
         RowBox[{
          RowBox[{"a", "=", 
           RowBox[{"-", "a"}]}], ";", 
          RowBox[{"b", "=", 
           RowBox[{"-", "b"}]}], ";"}]}], "]"}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"DipDir", "[", "dummy3", "]"}], ">", "180"}], "&&", 
          RowBox[{
           RowBox[{"DipDir", "[", "dummy3", "]"}], "\[LessEqual]", "270"}]}], 
         ",", 
         RowBox[{
          RowBox[{"a", "=", 
           RowBox[{"-", "a"}]}], ";", 
          RowBox[{"b", "=", "b"}], ";"}]}], "]"}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"DipDir", "[", "dummy3", "]"}], ">", "270"}], "&&", 
          RowBox[{
           RowBox[{"DipDir", "[", "dummy3", "]"}], "\[LessEqual]", "360"}]}], 
         ",", 
         RowBox[{
          RowBox[{"a", "=", "a"}], ";", 
          RowBox[{"b", "=", "b"}], ";"}]}], "]"}], ";", 
       RowBox[{"scale", "=", 
        FractionBox["1", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"]}]]]}], ";", 
       RowBox[{"aprime", "=", 
        RowBox[{"scale", " ", "a"}]}], ";", 
       RowBox[{"bprime", "=", 
        RowBox[{"scale", " ", "b"}]}], ";", 
       RowBox[{"cprime", "=", 
        RowBox[{"scale", " ", "c"}]}], ";", 
       RowBox[{
        RowBox[{"normvect", "[", "dummy3", "]"}], "=", 
        RowBox[{"N", "[", 
         RowBox[{"{", 
          RowBox[{"aprime", ",", "bprime", ",", "cprime"}], "}"}], "]"}]}], 
       ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"normvect", "[", "dummy3", "]"}], "\[LeftDoubleBracket]", 
           "3", "\[RightDoubleBracket]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"DipDir", "[", "dummy3", "]"}], "\[Equal]", "90"}], "||", 
             RowBox[{
              RowBox[{"DipDir", "[", "dummy3", "]"}], "\[Equal]", "270"}]}], 
            ",", 
            RowBox[{
             RowBox[{
              RowBox[{"const1", "[", "dummy3", "]"}], "=", "1"}], ";", 
             RowBox[{
              RowBox[{"const2", "[", "dummy3", "]"}], "=", "0"}], ";"}], ",", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"DipDir", "[", "dummy3", "]"}], ">", "45"}], "&&", 
                  RowBox[{
                   RowBox[{"DipDir", "[", "dummy3", "]"}], "<", "135"}]}], 
                 ")"}], "||", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"DipDir", "[", "dummy3", "]"}], "<", "315"}], "&&", 
                  RowBox[{
                   RowBox[{"DipDir", "[", "dummy3", "]"}], ">", "225"}]}], 
                 ")"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"const1", "[", "dummy3", "]"}], "=", 
                 RowBox[{"Tan", "[", 
                  RowBox[{
                   FractionBox["1", "180"], " ", 
                   RowBox[{"DipDir", "[", "dummy3", "]"}], " ", "\[Pi]"}], 
                  "]"}]}], ";", 
                RowBox[{
                 RowBox[{"const2", "[", "dummy3", "]"}], "=", "1"}], ";"}], 
               ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"const1", "[", "dummy3", "]"}], "=", 
                 RowBox[{"Tan", "[", 
                  RowBox[{
                   FractionBox["1", "180"], " ", 
                   RowBox[{"DipDir", "[", "dummy3", "]"}], " ", "\[Pi]"}], 
                  "]"}]}], ";", 
                RowBox[{
                 RowBox[{"const2", "[", "dummy3", "]"}], "=", "1"}], ";"}]}], 
              "]"}], ";"}]}], "]"}], ";", 
          RowBox[{
           RowBox[{"PlaneSect", "[", "dummy3", "]"}], "=", 
           RowBox[{"ParametricPlot3D", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"const1", "[", "dummy3", "]"}], " ", "x"}], ",", 
               RowBox[{
                RowBox[{"const2", "[", "dummy3", "]"}], " ", "x"}], ",", 
               "z"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{
                 "Lval", "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}]}], " ", "1.1"}], ",", 
               RowBox[{
                RowBox[{
                "Lval", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], " ", "1.1"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"z", ",", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{
                 "Lval", "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}]}], " ", "1.1"}], ",", 
               RowBox[{
                RowBox[{
                "Lval", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], " ", "1.1"}]}], "}"}], ",", 
             RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}], 
          ";"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"PlaneSect", "[", "dummy3", "]"}], "=", 
           RowBox[{"Plot3D", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "x"}], " ", 
                 RowBox[{
                  RowBox[{"normvect", "[", "dummy3", "]"}], 
                  "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
                "-", 
                RowBox[{"y", " ", 
                 RowBox[{
                  RowBox[{"normvect", "[", "dummy3", "]"}], 
                  "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}]}], 
               ")"}], "/", 
              RowBox[{
               RowBox[{"normvect", "[", "dummy3", "]"}], 
               "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{
                 "Lval", "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}]}], " ", "1.1"}], ",", 
               RowBox[{
                RowBox[{
                "Lval", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], " ", "1.1"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"y", ",", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{
                 "Lval", "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}]}], " ", "1.1"}], ",", 
               RowBox[{
                RowBox[{
                "Lval", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], " ", "1.1"}]}], "}"}], ",", 
             RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}], 
          ";"}]}], "]"}], ";", 
       RowBox[{"dummy3", "=", 
        RowBox[{"dummy3", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"AxesInit", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ct", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", 
      RowBox[{
       RowBox[{"RotPhi", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"AngularOrientation", "[", "ct", "]"}], "]"}], ",", 
            RowBox[{"Sin", "[", 
             RowBox[{"AngularOrientation", "[", "ct", "]"}], "]"}], ",", 
            "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              RowBox[{"AngularOrientation", "[", "ct", "]"}], "]"}]}], ",", 
            RowBox[{"Cos", "[", 
             RowBox[{"AngularOrientation", "[", "ct", "]"}], "]"}], ",", 
            "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
       RowBox[{"first", "=", 
        RowBox[{"AxesInit", ".", "RotPhi"}]}], ";", 
       RowBox[{"RotDip", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"Cos", "[", 
             RowBox[{
              FractionBox["1", "180"], " ", 
              RowBox[{"Dip", "[", "ct", "]"}], " ", "\[Pi]"}], "]"}], ",", 
            RowBox[{"Sin", "[", 
             RowBox[{
              FractionBox["1", "180"], " ", 
              RowBox[{"Dip", "[", "ct", "]"}], " ", "\[Pi]"}], "]"}]}], "}"}],
           ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              RowBox[{
               FractionBox["1", "180"], " ", 
               RowBox[{"Dip", "[", "ct", "]"}], " ", "\[Pi]"}], "]"}]}], ",", 
            RowBox[{"Cos", "[", 
             RowBox[{
              FractionBox["1", "180"], " ", 
              RowBox[{"Dip", "[", "ct", "]"}], " ", "\[Pi]"}], "]"}]}], 
           "}"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"second", "=", 
        RowBox[{"first", ".", "RotDip"}]}], ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Dip", "[", "ct", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"DD", "=", "0"}], ";"}], ",", 
         RowBox[{
          RowBox[{"DD", "=", 
           RowBox[{"DipDir", "[", "ct", "]"}]}], ";"}]}], "]"}], ";", 
       RowBox[{"RotDipDir", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{
              FractionBox["1", "180"], " ", 
              RowBox[{"(", 
               RowBox[{"90", "-", "DD"}], ")"}], " ", "\[Pi]"}], "]"}], ",", 
            RowBox[{"Sin", "[", 
             RowBox[{
              FractionBox["1", "180"], " ", 
              RowBox[{"(", 
               RowBox[{"90", "-", "DD"}], ")"}], " ", "\[Pi]"}], "]"}], ",", 
            "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              RowBox[{
               FractionBox["1", "180"], " ", 
               RowBox[{"(", 
                RowBox[{"90", "-", "DD"}], ")"}], " ", "\[Pi]"}], "]"}]}], 
            ",", 
            RowBox[{"Cos", "[", 
             RowBox[{
              FractionBox["1", "180"], " ", 
              RowBox[{"(", 
               RowBox[{"90", "-", "DD"}], ")"}], " ", "\[Pi]"}], "]"}], ",", 
            "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"third", "=", 
        RowBox[{"second", ".", "RotDipDir"}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"x", "[", "t_", "]"}], "=", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Le", "[", "ct", "]"}], "\[LeftDoubleBracket]", "1", 
           "\[RightDoubleBracket]"}], " ", 
          RowBox[{"Cos", "[", "t", "]"}], " ", 
          RowBox[{"third", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"Le", "[", "ct", "]"}], "\[LeftDoubleBracket]", "2", 
           "\[RightDoubleBracket]"}], " ", 
          RowBox[{"Sin", "[", "t", "]"}], " ", 
          RowBox[{"third", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}]}]}], ";", 
       RowBox[{
        RowBox[{"y", "[", "t_", "]"}], "=", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Le", "[", "ct", "]"}], "\[LeftDoubleBracket]", "1", 
           "\[RightDoubleBracket]"}], " ", 
          RowBox[{"Cos", "[", "t", "]"}], " ", 
          RowBox[{"third", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"Le", "[", "ct", "]"}], "\[LeftDoubleBracket]", "2", 
           "\[RightDoubleBracket]"}], " ", 
          RowBox[{"Sin", "[", "t", "]"}], " ", 
          RowBox[{"third", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}]}]}], ";", 
       RowBox[{
        RowBox[{"z", "[", "t_", "]"}], "=", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Le", "[", "ct", "]"}], "\[LeftDoubleBracket]", "1", 
           "\[RightDoubleBracket]"}], " ", 
          RowBox[{"Cos", "[", "t", "]"}], " ", 
          RowBox[{"third", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"Le", "[", "ct", "]"}], "\[LeftDoubleBracket]", "2", 
           "\[RightDoubleBracket]"}], " ", 
          RowBox[{"Sin", "[", "t", "]"}], " ", 
          RowBox[{"third", "\[LeftDoubleBracket]", 
           RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}]}]}]}], ";", 
       RowBox[{
        RowBox[{"PlaneEllipse", "[", "ct", "]"}], "=", 
        RowBox[{"ParametricPlot3D", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"x", "[", "t", "]"}], ",", 
            RowBox[{"y", "[", "t", "]"}], ",", 
            RowBox[{"z", "[", "t", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "0", ",", 
            RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"Red", ",", "Thick"}], "}"}]}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ct", "=", 
        RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TempPlaneSection", "=", 
     RowBox[{"PlaneSect", "[", "1", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct", "<", "numbplanes"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"TempPlaneSection", "=", 
        RowBox[{"Show", "[", 
         RowBox[{"TempPlaneSection", ",", 
          RowBox[{"PlaneSect", "[", 
           RowBox[{"ct", "+", "1"}], "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ct", "=", 
        RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"qt", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TempPlaneEllipse", "=", 
     RowBox[{"PlaneEllipse", "[", "1", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"qt", "<", "numbplanes"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"TempPlaneEllipse", "=", 
        RowBox[{"Show", "[", 
         RowBox[{"TempPlaneEllipse", ",", 
          RowBox[{"PlaneEllipse", "[", 
           RowBox[{"qt", "+", "1"}], "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"qt", "=", 
        RowBox[{"qt", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"EllipsoidPlanes", "=", 
    RowBox[{"Show", "[", 
     RowBox[{
     "TempPlaneSection", ",", "Vellipsoid", ",", "TempPlaneEllipse", ",", 
      RowBox[{"BoxRatios", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<North \[UpArrow] \>\"", ",", "\"\<East \[Rule] \>\"", ",", 
         "\"\<Up \[UpArrow] \>\""}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
             "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}],
             " ", "1.1"}], ",", 
           RowBox[{
            RowBox[{
            "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            " ", "1.1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
             "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}],
             " ", "1.1"}], ",", 
           RowBox[{
            RowBox[{
            "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            " ", "1.1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{
             "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}],
             " ", "1.1"}], ",", 
           RowBox[{
            RowBox[{
            "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            " ", "1.1"}]}], "}"}]}], "}"}]}], ",", 
      RowBox[{"ViewPoint", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", "0", ",", "3"}], "}"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", "False"}]}], "]"}]}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"K", "=", 
     FractionBox[
      RowBox[{
       FractionBox[
        RowBox[{
        "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        RowBox[{
        "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], "-", 
       "1"}], 
      RowBox[{
       FractionBox[
        RowBox[{
        "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        RowBox[{
        "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], "-", 
       "1"}]]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"\[Nu]", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          RowBox[{
          "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
          "]"}]}], "-", 
        RowBox[{"Log", "[", 
         RowBox[{
         "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
         "]"}], "-", 
        RowBox[{"Log", "[", 
         RowBox[{
         "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
         "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Log", "[", 
         RowBox[{
         "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
         "]"}], "-", 
        RowBox[{"Log", "[", 
         RowBox[{
         "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
         "]"}]}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"lnot", "=", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
        "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], " ", 
        RowBox[{
        "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], " ", 
        RowBox[{
        "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
       ")"}], 
      RowBox[{"1", "/", "3"}]]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"\[Epsilon]s", "=", 
     RowBox[{
      FractionBox["1", "3"], " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Log", "[", 
             FractionBox[
              RowBox[{
              "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
              "lnot"], "]"}], "-", 
            RowBox[{"Log", "[", 
             FractionBox[
              RowBox[{
              "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
              "lnot"], "]"}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Log", "[", 
             FractionBox[
              RowBox[{
              "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
              "lnot"], "]"}], "-", 
            RowBox[{"Log", "[", 
             FractionBox[
              RowBox[{
              "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
              "lnot"], "]"}]}], ")"}], "2"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Log", "[", 
             FractionBox[
              RowBox[{
              "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
              "lnot"], "]"}], "-", 
            RowBox[{"Log", "[", 
             FractionBox[
              RowBox[{
              "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
              "lnot"], "]"}]}], ")"}], "2"]}], ")"}], ".5"]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"NormLong", "=", 
     FractionBox[
      RowBox[{"Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      RowBox[{
      "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NormShort", "=", 
     FractionBox[
      RowBox[{"Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      RowBox[{
      "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}]}], ",", 
      RowBox[{
       RowBox[{"LPlunge", "=", "90"}], ";"}], ",", 
      RowBox[{
       RowBox[{"LPlunge", "=", 
        FractionBox[
         RowBox[{
          RowBox[{"ArcTan", "[", 
           FractionBox[
            RowBox[{"Abs", "[", 
             RowBox[{
             "LongAxis", "\[LeftDoubleBracket]", "3", 
              "\[RightDoubleBracket]"}], "]"}], 
            SqrtBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{
               "LongAxis", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
               "LongAxis", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], "2"]}]]], "]"}], " ", "180"}], 
         "\[Pi]"]}], ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
       "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"Tl", "=", "90"}], ";"}], ",", 
      RowBox[{
       RowBox[{"Tl", "=", 
        RowBox[{"Abs", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"ArcTan", "[", 
            FractionBox[
             RowBox[{
             "LongAxis", "\[LeftDoubleBracket]", "2", 
              "\[RightDoubleBracket]"}], 
             RowBox[{
             "LongAxis", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}]], "]"}], " ", "180"}], "\[Pi]"], 
         "]"}]}], ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"LTrend", "=", 
       RowBox[{"180", "-", "Tl"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"LTrend", "=", "Tl"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"LTrend", "=", 
       RowBox[{"360", "-", "Tl"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"LTrend", "=", 
       RowBox[{"180", "+", "Tl"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"LTrend", "=", 
       RowBox[{"360", "-", "Tl"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"LTrend", "=", 
       RowBox[{"180", "+", "Tl"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"LTrend", "=", 
       RowBox[{"180", "-", "Tl"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"LTrend", "=", "Tl"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[LessEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[LessEqual]", "0"}]}], ",", 
      RowBox[{"LTrend", "=", "90"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"LTrend", "=", "90"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        ">", "0"}]}], ",", 
      RowBox[{"LTrend", "=", "270"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"LTrend", "=", "270"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}]}], ",", 
      RowBox[{
       RowBox[{"LPlunge", "=", "90"}], ";", 
       RowBox[{"LTrend", "=", "\"\<NA\>\""}]}]}], "]"}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}]}], ",", 
      RowBox[{
       RowBox[{"IPlunge", "=", "90"}], ";"}], ",", 
      RowBox[{
       RowBox[{"IPlunge", "=", 
        RowBox[{
         FractionBox["1", "\[Pi]"], 
         RowBox[{"ArcTan", "[", 
          FractionBox[
           RowBox[{"Abs", "[", 
            RowBox[{
            "IntermAxis", "\[LeftDoubleBracket]", "3", 
             "\[RightDoubleBracket]"}], "]"}], 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "2"]}]]], "]"}], " ", "180"}]}], 
       ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
       "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       "\[Equal]", "0"}], ",", 
      RowBox[{"\[CapitalTau]i", "=", "90"}], ",", 
      RowBox[{
       RowBox[{"\[CapitalTau]i", "=", 
        RowBox[{"Abs", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"ArcTan", "[", 
            FractionBox[
             RowBox[{
             "IntermAxis", "\[LeftDoubleBracket]", "2", 
              "\[RightDoubleBracket]"}], 
             RowBox[{
             "IntermAxis", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}]], "]"}], " ", "180"}], "\[Pi]"], 
         "]"}]}], ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"ITrend", "=", 
       RowBox[{"180", "-", "\[CapitalTau]i"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"ITrend", "=", "\[CapitalTau]i"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"ITrend", "=", 
       RowBox[{"360", "-", "\[CapitalTau]i"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"ITrend", "=", 
       RowBox[{"180", "+", "\[CapitalTau]i"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"ITrend", "=", 
       RowBox[{"360", "-", "\[CapitalTau]i"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"ITrend", "=", 
       RowBox[{"180", "+", "\[CapitalTau]i"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"ITrend", "=", 
       RowBox[{"180", "-", "\[CapitalTau]i"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"ITrend", "=", "\[CapitalTau]i"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[LessEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[LessEqual]", "0"}]}], ",", 
      RowBox[{"ITrend", "=", "90"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"ITrend", "=", "90"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        ">", "0"}]}], ",", 
      RowBox[{"ITrend", "=", "270"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"ITrend", "=", "270"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}]}], ",", 
      RowBox[{
       RowBox[{"IPlunge", "=", "90"}], ";", 
       RowBox[{"ITrend", "=", "\"\<NA\>\""}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}]}], ",", 
      RowBox[{
       RowBox[{"SPlunge", "=", "90"}], ";"}], ",", 
      RowBox[{
       RowBox[{"SPlunge", "=", 
        RowBox[{
         FractionBox["1", "\[Pi]"], 
         RowBox[{"ArcTan", "[", 
          FractionBox[
           RowBox[{"Abs", "[", 
            RowBox[{
            "ShortAxis", "\[LeftDoubleBracket]", "3", 
             "\[RightDoubleBracket]"}], "]"}], 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "2"]}]]], "]"}], " ", "180"}]}], 
       ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
       "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       "\[Equal]", "0"}], ",", 
      RowBox[{"\[CapitalTau]s", "=", "90"}], ",", 
      RowBox[{
       RowBox[{"\[CapitalTau]s", "=", 
        RowBox[{"Abs", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"ArcTan", "[", 
            FractionBox[
             RowBox[{
             "ShortAxis", "\[LeftDoubleBracket]", "2", 
              "\[RightDoubleBracket]"}], 
             RowBox[{
             "ShortAxis", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}]], "]"}], " ", "180"}], "\[Pi]"], 
         "]"}]}], ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"STrend", "=", 
       RowBox[{"180", "-", "\[CapitalTau]s"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"STrend", "=", "\[CapitalTau]s"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"STrend", "=", 
       RowBox[{"360", "-", "\[CapitalTau]s"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"STrend", "=", 
       RowBox[{"180", "+", "\[CapitalTau]s"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"STrend", "=", 
       RowBox[{"360", "-", "\[CapitalTau]s"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"STrend", "=", 
       RowBox[{"180", "+", "\[CapitalTau]s"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"STrend", "=", 
       RowBox[{"180", "-", "\[CapitalTau]s"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"STrend", "=", "\[CapitalTau]s"}]}], "]"}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[LessEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[LessEqual]", "0"}]}], ",", 
      RowBox[{"STrend", "=", "90"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"STrend", "=", "90"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        ">", "0"}]}], ",", 
      RowBox[{"STrend", "=", "270"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"STrend", "=", "270"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}]}], ",", 
      RowBox[{
       RowBox[{"SPlunge", "=", "90"}], ";", 
       RowBox[{"STrend", "=", "\"\<NA\>\""}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FitTrendLong", "=", "LTrend"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FitPlungeLong", "=", "LPlunge"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FitTrendInterm", "=", "ITrend"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FitPlungeInterm", "=", "IPlunge"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FitTrendShort", "=", "STrend"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FitPlungeShort", "=", "SPlunge"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"statnumb", "=", 
     RowBox[{
     "Input", "[", 
      "\"\<How many iterations do you want the simulation to run?\>\"", 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ctstat", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ctstat", "\[LessEqual]", "statnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"ctstat", "\[LessEqual]", "statnumb"}], ",", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"z1", "=", 
           RowBox[{"RandomReal", "[", 
            RowBox[{
             RowBox[{"NormalDistribution", "[", 
              RowBox[{"0", ",", "1"}], "]"}], ",", "statnumb"}], "]"}]}], ";",
           "\[IndentingNewLine]", 
          RowBox[{"z2", "=", 
           RowBox[{"RandomReal", "[", 
            RowBox[{
             RowBox[{"NormalDistribution", "[", 
              RowBox[{"0", ",", "1"}], "]"}], ",", "statnumb"}], "]"}]}], ";",
           "\n", "\[IndentingNewLine]", 
          RowBox[{"Clear", "[", 
           RowBox[{
           "\[Lambda]1", ",", "\[Lambda]3", ",", "\[Gamma]1", ",", 
            "\[Gamma]2", ",", "\[Gamma]3"}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"GeneralEllipsoid", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"\[Lambda]1", ",", "\[Gamma]3", ",", "\[Gamma]2"}], 
              "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Gamma]3", ",", "\[Lambda]2", ",", "\[Gamma]1"}], 
              "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Gamma]2", ",", "\[Gamma]1", ",", "\[Lambda]3"}], 
              "}"}]}], "}"}]}], ";", "\n", "\[IndentingNewLine]", 
          RowBox[{"dummy", "=", "1"}], ";", "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"dummy", "\[LessEqual]", "numbplanes"}], ",", "\n", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"DipDir", "[", "dummy", "]"}], "\[GreaterEqual]", 
                 "0"}], "&&", 
                RowBox[{
                 RowBox[{"DipDir", "[", "dummy", "]"}], "\[LessEqual]", 
                 "90"}]}], ",", 
               RowBox[{
                RowBox[{"\[Theta]", "=", 
                 RowBox[{"DipDir", "[", "dummy", "]"}]}], ";"}]}], "]"}], ";", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"DipDir", "[", "dummy", "]"}], ">", "90"}], "&&", 
                RowBox[{
                 RowBox[{"DipDir", "[", "dummy", "]"}], "\[LessEqual]", 
                 "180"}]}], ",", 
               RowBox[{
                RowBox[{"\[Theta]", "=", 
                 RowBox[{"180", "-", 
                  RowBox[{"DipDir", "[", "dummy", "]"}]}]}], ";"}]}], "]"}], 
             ";", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"DipDir", "[", "dummy", "]"}], ">", "180"}], "&&", 
                RowBox[{
                 RowBox[{"DipDir", "[", "dummy", "]"}], "\[LessEqual]", 
                 "270"}]}], ",", 
               RowBox[{
                RowBox[{"\[Theta]", "=", 
                 RowBox[{
                  RowBox[{"DipDir", "[", "dummy", "]"}], "-", "180"}]}], 
                ";"}]}], "]"}], ";", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"DipDir", "[", "dummy", "]"}], ">", "270"}], "&&", 
                RowBox[{
                 RowBox[{"DipDir", "[", "dummy", "]"}], "\[LessEqual]", 
                 "360"}]}], ",", 
               RowBox[{
                RowBox[{"\[Theta]", "=", 
                 RowBox[{"360", "-", 
                  RowBox[{"DipDir", "[", "dummy", "]"}]}]}], ";"}]}], "]"}], 
             ";", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Theta]", "\[Equal]", "90"}], "||", 
                RowBox[{"\[Theta]", "\[Equal]", "270"}]}], ",", 
               RowBox[{
                RowBox[{"a", "=", "0"}], ";"}], ",", 
               RowBox[{
                RowBox[{"a", "=", 
                 SqrtBox[
                  FractionBox["1", 
                   RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    FractionBox[
                    RowBox[{"\[Theta]", " ", "\[Pi]"}], "180"], "]"}], 
                    "2"]}]]]}], ";"}]}], "]"}], ";", 
             RowBox[{"b", "=", 
              SqrtBox[
               RowBox[{"1", "-", 
                SuperscriptBox["a", "2"]}]]}], ";", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Dip", "[", "dummy", "]"}], "\[Equal]", "0"}], ",", 
               RowBox[{
                RowBox[{"a", "=", "0"}], ";", 
                RowBox[{"b", "=", "0"}], ";", 
                RowBox[{"c", "=", "1"}], ";"}], ",", 
               RowBox[{
                RowBox[{"c", "=", 
                 RowBox[{"Tan", "[", 
                  RowBox[{
                   FractionBox["1", "180"], " ", 
                   RowBox[{"(", 
                    RowBox[{"90", "-", 
                    RowBox[{"Dip", "[", "dummy", "]"}]}], ")"}], " ", 
                   "\[Pi]"}], "]"}]}], ";"}]}], "]"}], ";", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"DipDir", "[", "dummy", "]"}], "\[GreaterEqual]", 
                 "0"}], "&&", 
                RowBox[{
                 RowBox[{"DipDir", "[", "dummy", "]"}], "\[LessEqual]", 
                 "90"}]}], ",", 
               RowBox[{
                RowBox[{"a", "=", "a"}], ";", 
                RowBox[{"b", "=", 
                 RowBox[{"-", "b"}]}], ";"}]}], "]"}], ";", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"DipDir", "[", "dummy", "]"}], ">", "90"}], "&&", 
                RowBox[{
                 RowBox[{"DipDir", "[", "dummy", "]"}], "\[LessEqual]", 
                 "180"}]}], ",", 
               RowBox[{
                RowBox[{"a", "=", 
                 RowBox[{"-", "a"}]}], ";", 
                RowBox[{"b", "=", 
                 RowBox[{"-", "b"}]}], ";"}]}], "]"}], ";", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"DipDir", "[", "dummy", "]"}], ">", "180"}], "&&", 
                RowBox[{
                 RowBox[{"DipDir", "[", "dummy", "]"}], "\[LessEqual]", 
                 "270"}]}], ",", 
               RowBox[{
                RowBox[{"a", "=", 
                 RowBox[{"-", "a"}]}], ";", 
                RowBox[{"b", "=", "b"}], ";"}]}], "]"}], ";", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"DipDir", "[", "dummy", "]"}], ">", "270"}], "&&", 
                RowBox[{
                 RowBox[{"DipDir", "[", "dummy", "]"}], "\[LessEqual]", 
                 "360"}]}], ",", 
               RowBox[{
                RowBox[{"a", "=", "a"}], ";", 
                RowBox[{"b", "=", "b"}], ";"}]}], "]"}], ";", 
             RowBox[{"scale", "=", 
              FractionBox["1", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox["a", "2"], "+", 
                 SuperscriptBox["b", "2"], "+", 
                 SuperscriptBox["c", "2"]}]]]}], ";", 
             RowBox[{"aprime", "=", 
              RowBox[{"scale", " ", "a"}]}], ";", 
             RowBox[{"bprime", "=", 
              RowBox[{"scale", " ", "b"}]}], ";", 
             RowBox[{"cprime", "=", 
              RowBox[{"scale", " ", "c"}]}], ";", 
             RowBox[{
              RowBox[{"normvect", "[", "dummy", "]"}], "=", 
              RowBox[{"N", "[", 
               RowBox[{"{", 
                RowBox[{"aprime", ",", "bprime", ",", "cprime"}], "}"}], 
               "]"}]}], ";", 
             RowBox[{"Theta", "=", 
              RowBox[{"Abs", "[", 
               RowBox[{"RandomReal", "[", 
                RowBox[{"NormalDistribution", "[", 
                 RowBox[{"0", ",", 
                  RowBox[{"AngularPlaneError", "[", "dummy", "]"}]}], "]"}], 
                "]"}], "]"}]}], ";", "\n", "\[IndentingNewLine]", 
             RowBox[{"tempnorm", "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Sin", "[", 
                 RowBox[{"Theta", "*", 
                  RowBox[{"Pi", "/", "180"}]}], "]"}], ",", "0", ",", 
                RowBox[{"Cos", "[", 
                 RowBox[{"Theta", "*", 
                  RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"RandRot", "=", 
              RowBox[{"RandomReal", "[", 
               RowBox[{"{", 
                RowBox[{"0", ",", 
                 RowBox[{"2", "Pi"}]}], "}"}], "]"}]}], ";", 
             "\[IndentingNewLine]", "\[IndentingNewLine]", 
             RowBox[{"RandRotMat", "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Cos", "[", "RandRot", "]"}], ",", 
                  RowBox[{"Sin", "[", "RandRot", "]"}], ",", "0"}], "}"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"Sin", "[", "RandRot", "]"}]}], ",", 
                  RowBox[{"Cos", "[", "RandRot", "]"}], ",", "0"}], "}"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"temprot", "=", 
              RowBox[{"RandRotMat", ".", "tempnorm"}]}], ";", "\n", 
             "\[IndentingNewLine]", 
             RowBox[{"Strike", "=", 
              RowBox[{
               RowBox[{"DipDir", "[", "dummy", "]"}], "+", "90"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"270", "\[LessEqual]", 
                RowBox[{"DipDir", "[", "dummy", "]"}], "\[LessEqual]", 
                "360"}], ",", 
               RowBox[{
                RowBox[{"Tsk", "=", 
                 RowBox[{
                  RowBox[{"(", "Strike", ")"}], "*", 
                  RowBox[{"Pi", "/", "180"}]}]}], ";", 
                RowBox[{"s1", "=", 
                 RowBox[{"(", 
                  RowBox[{"Cos", "[", "Tsk", "]"}], ")"}]}], ";", 
                RowBox[{"s2", "=", 
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{"Sin", "[", "Tsk", "]"}], ")"}]}]}], ";"}]}], 
              "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"0", "\[LessEqual]", 
                RowBox[{"DipDir", "[", "dummy", "]"}], "<", "90"}], ",", 
               RowBox[{
                RowBox[{"Tsk", "=", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"180", "-", "Strike"}], ")"}], "*", 
                  RowBox[{"Pi", "/", "180"}]}]}], ";", 
                RowBox[{"s1", "=", 
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{"Cos", "[", "Tsk", "]"}], ")"}]}]}], ";", 
                RowBox[{"s2", "=", 
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{"Sin", "[", "Tsk", "]"}], ")"}]}]}], ";"}]}], 
              "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"90", "\[LessEqual]", 
                RowBox[{"DipDir", "[", "dummy", "]"}], "<", "180"}], ",", 
               RowBox[{
                RowBox[{"Tsk", "=", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"Strike", "-", "180"}], ")"}], "*", 
                  RowBox[{"Pi", "/", "180"}]}]}], ";", 
                RowBox[{"s1", "=", 
                 RowBox[{"-", 
                  RowBox[{"(", 
                   RowBox[{"Cos", "[", "Tsk", "]"}], ")"}]}]}], ";", 
                RowBox[{"s2", "=", 
                 RowBox[{"(", 
                  RowBox[{"Sin", "[", "Tsk", "]"}], ")"}]}], ";"}]}], "]"}], 
             ";", "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"180", "\[LessEqual]", 
                RowBox[{"DipDir", "[", "dummy", "]"}], "<", "270"}], ",", 
               RowBox[{
                RowBox[{"Tsk", "=", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"360", "-", "Strike"}], ")"}], "*", 
                  RowBox[{"Pi", "/", "180"}]}]}], ";", 
                RowBox[{"s1", "=", 
                 RowBox[{"(", 
                  RowBox[{"Cos", "[", "Tsk", "]"}], ")"}]}], ";", 
                RowBox[{"s2", "=", 
                 RowBox[{"(", 
                  RowBox[{"Sin", "[", "Tsk", "]"}], ")"}]}], ";"}]}], "]"}], 
             ";", 
             RowBox[{"strikevect", "=", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"s1", ",", "s2", ",", "0"}], "}"}], "//", "N"}]}], 
             ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
             RowBox[{"perpaxis", "=", 
              RowBox[{
               RowBox[{"Cross", "[", 
                RowBox[{
                 RowBox[{"normvect", "[", "dummy", "]"}], ",", "strikevect"}],
                 "]"}], "//", "N"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"RotAxisMat", "=", 
              RowBox[{"Transpose", "[", 
               RowBox[{"{", 
                RowBox[{"strikevect", ",", "perpaxis", ",", 
                 RowBox[{"normvect", "[", "dummy", "]"}]}], "}"}], "]"}]}], 
             ";", "\[IndentingNewLine]", 
             RowBox[{"RotedNorm", "=", 
              RowBox[{"RotAxisMat", ".", "temprot"}]}], ";", "\n", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"NewDip", "[", 
               RowBox[{"ctstat", ",", "dummy"}], "]"}], "=", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"RotedNorm", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0"}], "&&", 
                 RowBox[{
                  RowBox[{"RotedNorm", "[", 
                   RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}]}], ",", 
                "0", ",", 
                RowBox[{"90", "-", 
                 RowBox[{"Abs", "[", 
                  RowBox[{
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"RotedNorm", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], "/", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"RotedNorm", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ")"}], "2"], "+", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{"RotedNorm", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ")"}], "2"]}], "]"}]}], 
                    "]"}], "*", 
                   RowBox[{"180", "/", "Pi"}]}], "]"}]}]}], "]"}]}], ";", 
             "\[IndentingNewLine]", "\[IndentingNewLine]", 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"RotedNorm", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], "<", "0"}], ",", 
               RowBox[{
                RowBox[{"RotedNorm", "=", 
                 RowBox[{"-", "RotedNorm"}]}], ";"}]}], "]"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"RotedNorm", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "<", "0"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"NewDipDir", "[", 
                  RowBox[{"ctstat", ",", "dummy"}], "]"}], "=", 
                 RowBox[{"90", "+", 
                  RowBox[{
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"RotedNorm", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "/", 
                    RowBox[{"RotedNorm", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "*", 
                   RowBox[{"180", "/", "Pi"}]}]}]}], ";"}]}], "]"}], ";", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"RotedNorm", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], ">", "0"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"NewDipDir", "[", 
                  RowBox[{"ctstat", ",", "dummy"}], "]"}], "=", 
                 RowBox[{"270", "+", 
                  RowBox[{
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"RotedNorm", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "/", 
                    RowBox[{"RotedNorm", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "*", 
                   RowBox[{"180", "/", "Pi"}]}]}]}], ";"}]}], "]"}], ";", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"RotedNorm", "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "\[Equal]", "0"}], ",", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"RotedNorm", "[", 
                   RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0"}], ",", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "=", 
                   "\"\<NA\>\""}], ";"}], ",", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"RotedNorm", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ">", "0"}], ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "=", "0"}], 
                    ";"}], ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "=", "180"}], 
                    ";"}]}], "]"}]}], "]"}]}], "]"}], ";", 
             "\[IndentingNewLine]", "\[IndentingNewLine]", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"NewPlanePoleTrend", "[", 
               RowBox[{"ctstat", ",", "dummy"}], "]"}], "=", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"180", "+", 
                  RowBox[{"NewDipDir", "[", "ctstat", "]"}]}], "<", "360"}], 
                ",", 
                RowBox[{"180", "+", 
                 RowBox[{"NewDipDir", "[", "ctstat", "]"}]}], ",", 
                RowBox[{
                 RowBox[{"NewDipDir", "[", "ctstat", "]"}], "-", "180"}]}], 
               "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"NewPlanePolePlunge", "[", 
               RowBox[{"ctstat", ",", "dummy"}], "]"}], "=", 
              RowBox[{"90", "-", 
               RowBox[{"NewDip", "[", "ctstat", "]"}]}]}], ";", 
             "\[IndentingNewLine]", "\[IndentingNewLine]", 
             RowBox[{"n", "=", "1"}], ";", "\[IndentingNewLine]", 
             RowBox[{"While", "[", 
              RowBox[{
               RowBox[{"n", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"PoS", "\[Equal]", "0"}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"New\[CapitalPi]", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "=", 
                    RowBox[{"RandomReal", "[", 
                    RowBox[{"NormalDistribution", "[", 
                    RowBox[{
                    RowBox[{"\[CapitalPi]", "[", "dummy", "]"}], ",", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"SigmaRatio", "[", "dummy", "]"}], "/", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{"numbdata", "[", "dummy", "]"}], "]"}]}], ")"}]}],
                     "]"}], "]"}]}], ";"}], ",", "\[IndentingNewLine]", 
                  "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{"TabbyOneOne", "=", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"EllipMat", "[", 
                    RowBox[{"dummy", ",", "x"}], "]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "1", ",", 
                    RowBox[{"numbdata", "[", "dummy", "]"}]}], "}"}]}], 
                    "]"}]}], ";", "\[IndentingNewLine]", 
                   RowBox[{"TabbyOneTwo", "=", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"EllipMat", "[", 
                    RowBox[{"dummy", ",", "x"}], "]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "1", ",", 
                    RowBox[{"numbdata", "[", "dummy", "]"}]}], "}"}]}], 
                    "]"}]}], ";", "\[IndentingNewLine]", 
                   RowBox[{"TabbyTwoTwo", "=", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"EllipMat", "[", 
                    RowBox[{"dummy", ",", "x"}], "]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "1", ",", 
                    RowBox[{"numbdata", "[", "dummy", "]"}]}], "}"}]}], 
                    "]"}]}], ";", "\[IndentingNewLine]", 
                   RowBox[{"MuOne", "=", 
                    RowBox[{"Mean", "[", "TabbyOneOne", "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"MuTwo", "=", 
                    RowBox[{"Mean", "[", "TabbyOneTwo", "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"MuThree", "=", 
                    RowBox[{"Mean", "[", "TabbyTwoTwo", "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"VaryOneOne", "=", 
                    RowBox[{"Variance", "[", "TabbyOneOne", "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"VaryOneTwo", "=", 
                    RowBox[{"Variance", "[", "TabbyOneTwo", "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"VaryTwoTwo", "=", 
                    RowBox[{"Variance", "[", "TabbyTwoTwo", "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"CoVaryOneTwo", "=", 
                    RowBox[{"Covariance", "[", 
                    RowBox[{"TabbyOneOne", ",", "TabbyOneTwo"}], "]"}]}], ";",
                    "\[IndentingNewLine]", 
                   RowBox[{"CoVaryOneThree", "=", 
                    RowBox[{"Covariance", "[", 
                    RowBox[{"TabbyOneOne", ",", "TabbyTwoTwo"}], "]"}]}], ";",
                    "\[IndentingNewLine]", 
                   RowBox[{"CoVaryTwoThree", "=", 
                    RowBox[{"Covariance", "[", 
                    RowBox[{"TabbyOneTwo", ",", "TabbyTwoTwo"}], "]"}]}], ";",
                    "\[IndentingNewLine]", 
                   RowBox[{"VarCoVarMat", "=", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    "VaryOneOne", ",", "CoVaryOneTwo", ",", 
                    "CoVaryOneThree"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    "CoVaryOneTwo", ",", "VaryOneTwo", ",", 
                    "CoVaryTwoThree"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    "CoVaryOneThree", ",", "CoVaryTwoThree", ",", 
                    "VaryTwoTwo"}], "}"}]}], "}"}]}], ";", 
                   "\[IndentingNewLine]", "\[IndentingNewLine]", 
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    "PositiveDefiniteMatrixQ", "[", "VarCoVarMat", "]"}], 
                    "\[Equal]", "True"}], ",", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Inv", "=", 
                    RowBox[{"Inverse", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"VarCoVarMat", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "2"}], "]"}], "]"}], ",", 
                    RowBox[{"VarCoVarMat", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "3"}], "]"}], "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"VarCoVarMat", "[", 
                    RowBox[{"[", 
                    RowBox[{"3", ",", "2"}], "]"}], "]"}], ",", 
                    RowBox[{"VarCoVarMat", "[", 
                    RowBox[{"[", 
                    RowBox[{"3", ",", "3"}], "]"}], "]"}]}], "}"}]}], "}"}], 
                    "]"}]}], ";", "\[IndentingNewLine]", 
                    RowBox[{"x3", "=", 
                    RowBox[{"RandomReal", "[", 
                    RowBox[{"NormalDistribution", "[", 
                    RowBox[{"MuThree", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{"VarCoVarMat", "[", 
                    RowBox[{"[", 
                    RowBox[{"3", ",", "3"}], "]"}], "]"}], "]"}], ")"}], "/", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{"numbdata", "[", "dummy", "]"}], "]"}]}]}], "]"}],
                     "]"}]}], ";", "\[IndentingNewLine]", 
                    RowBox[{"x2gx3", "=", 
                    RowBox[{"RandomReal", "[", 
                    RowBox[{"NormalDistribution", "[", 
                    RowBox[{
                    RowBox[{"MuTwo", "+", 
                    RowBox[{
                    RowBox[{"VarCoVarMat", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "3"}], "]"}], "]"}], "*", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"x3", "-", "MuThree"}], ")"}], "/", 
                    RowBox[{"VarCoVarMat", "[", 
                    RowBox[{"[", 
                    RowBox[{"3", ",", "3"}], "]"}], "]"}]}]}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"VarCoVarMat", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "2"}], "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"VarCoVarMat", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "3"}], "]"}], "]"}], "*", 
                    RowBox[{
                    RowBox[{"VarCoVarMat", "[", 
                    RowBox[{"[", 
                    RowBox[{"3", ",", "2"}], "]"}], "]"}], "/", 
                    RowBox[{"VarCoVarMat", "[", 
                    RowBox[{"[", 
                    RowBox[{"3", ",", "3"}], "]"}], "]"}]}]}]}], "]"}], ")"}],
                     "/", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{"numbdata", "[", "dummy", "]"}], "]"}]}]}], "]"}],
                     "]"}]}], ";", "\[IndentingNewLine]", 
                    RowBox[{"x1gx2x3", "=", 
                    RowBox[{"RandomReal", "[", 
                    RowBox[{"NormalDistribution", "[", 
                    RowBox[{
                    RowBox[{"MuOne", "+", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"VarCoVarMat", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
                    RowBox[{"VarCoVarMat", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], ".", 
                    "Inv", ".", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"x2gx3", "-", "MuTwo"}], ",", 
                    RowBox[{"x3", "-", "MuThree"}]}], "}"}]}]}], ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"VarCoVarMat", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "1"}], "]"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"VarCoVarMat", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
                    RowBox[{"VarCoVarMat", "[", 
                    RowBox[{"[", 
                    RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], ".", 
                    "Inv", ".", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"VarCoVarMat", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "1"}], "]"}], "]"}], ",", 
                    RowBox[{"VarCoVarMat", "[", 
                    RowBox[{"[", 
                    RowBox[{"3", ",", "1"}], "]"}], "]"}]}], "}"}]}]}], "]"}],
                     ")"}], "/", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{"numbdata", "[", "dummy", "]"}], "]"}]}]}], "]"}],
                     "]"}]}], ";", "\[IndentingNewLine]", 
                    RowBox[{"Newoneone", "=", "x1gx2x3"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Newonetwo", "=", "x2gx3"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Newtwotwo", "=", "x3"}], ";"}], ",", 
                    "\[IndentingNewLine]", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Meanoneone", "=", 
                    RowBox[{"Mean", "[", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"EllipMat", "[", 
                    RowBox[{"dummy", ",", "x"}], "]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "1", ",", 
                    RowBox[{"numbdata", "[", "dummy", "]"}]}], "}"}]}], "]"}],
                     "]"}]}], ";", "\[IndentingNewLine]", 
                    RowBox[{"Meanonetwo", "=", 
                    RowBox[{"Mean", "[", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"EllipMat", "[", 
                    RowBox[{"dummy", ",", "x"}], "]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "1", ",", 
                    RowBox[{"numbdata", "[", "dummy", "]"}]}], "}"}]}], "]"}],
                     "]"}]}], ";", "\[IndentingNewLine]", 
                    RowBox[{"Meantwotwo", "=", 
                    RowBox[{"Mean", "[", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"EllipMat", "[", 
                    RowBox[{"dummy", ",", "x"}], "]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "1", ",", 
                    RowBox[{"numbdata", "[", "dummy", "]"}]}], "}"}]}], "]"}],
                     "]"}]}], ";", "\[IndentingNewLine]", 
                    RowBox[{"Stdevoneone", "=", 
                    RowBox[{
                    RowBox[{"StandardDeviation", "[", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"EllipMat", "[", 
                    RowBox[{"dummy", ",", "x"}], "]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "1", ",", 
                    RowBox[{"numbdata", "[", "dummy", "]"}]}], "}"}]}], "]"}],
                     "]"}], "/", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{"numbdata", "[", "dummy", "]"}], "]"}]}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Stdevonetwo", "=", 
                    RowBox[{
                    RowBox[{"StandardDeviation", "[", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"EllipMat", "[", 
                    RowBox[{"dummy", ",", "x"}], "]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "1", ",", 
                    RowBox[{"numbdata", "[", "dummy", "]"}]}], "}"}]}], "]"}],
                     "]"}], "/", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{"numbdata", "[", "dummy", "]"}], "]"}]}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Stdevtwotwo", "=", 
                    RowBox[{
                    RowBox[{"StandardDeviation", "[", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"EllipMat", "[", 
                    RowBox[{"dummy", ",", "x"}], "]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "1", ",", 
                    RowBox[{"numbdata", "[", "dummy", "]"}]}], "}"}]}], "]"}],
                     "]"}], "/", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{"numbdata", "[", "dummy", "]"}], "]"}]}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"Newoneone", "=", 
                    RowBox[{"RandomReal", "[", 
                    RowBox[{"NormalDistribution", "[", 
                    RowBox[{"Meanoneone", ",", "Stdevoneone"}], "]"}], 
                    "]"}]}], ";", "\[IndentingNewLine]", 
                    RowBox[{"Newonetwo", "=", 
                    RowBox[{"RandomReal", "[", 
                    RowBox[{"NormalDistribution", "[", 
                    RowBox[{"Meanonetwo", ",", "Stdevonetwo"}], "]"}], 
                    "]"}]}], ";", "\[IndentingNewLine]", 
                    RowBox[{"Newtwotwo", "=", 
                    RowBox[{"RandomReal", "[", 
                    RowBox[{"NormalDistribution", "[", 
                    RowBox[{"Meantwotwo", ",", "Stdevtwotwo"}], "]"}], 
                    "]"}]}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
                   "\[IndentingNewLine]", 
                   RowBox[{"NewMat", "=", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Newoneone", ",", "Newonetwo"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Newonetwo", ",", "Newtwotwo"}], "}"}]}], "}"}]}],
                    ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"TempMat", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "=", "NewMat"}], 
                   ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
                   RowBox[{"NewEigval", "=", 
                    RowBox[{"Eigenvalues", "[", "NewMat", "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"NewEigvect", "=", 
                    RowBox[{"Eigenvectors", "[", "NewMat", "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"NewT", "=", 
                    RowBox[{"Eigensystem", "[", "NewMat", "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"NewTevl", "=", 
                    RowBox[{"Sort", "[", 
                    RowBox[{"NewEigval", ",", "Greater"}], "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    "NewTevl", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "\[Equal]", 
                    RowBox[{
                    "NewEigval", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], ",", 
                    RowBox[{"NewTevect", "=", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"NewT", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"NewT", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                    "}"}]}], ",", 
                    RowBox[{"NewTevect", "=", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"NewT", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"NewT", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], 
                    "}"}]}]}], "]"}], ";", 
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"NewTevect", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], 
                    "\[Equal]", "0"}], ",", 
                    RowBox[{
                    RowBox[{"New\[CapitalTheta]", "=", 
                    FractionBox["\[Pi]", "2"]}], ";"}], ",", 
                    RowBox[{
                    RowBox[{"New\[CapitalTheta]", "=", 
                    RowBox[{"ArcTan", "[", 
                    FractionBox[
                    RowBox[{"NewTevect", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], 
                    RowBox[{"NewTevect", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]], 
                    "]"}]}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"New\[CapitalPi]", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "=", 
                    FractionBox[
                    RowBox[{
                    "NewTevl", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], 
                    RowBox[{
                    "NewTevl", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]]}], ";", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"New\[CapitalPsi]", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "=", 
                    "New\[CapitalTheta]"}], ";"}]}], "]"}], ";", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"New\[CapitalPi]", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], ">", "1"}], ",", 
                  RowBox[{
                   RowBox[{"n", "=", "0"}], ";"}]}], "]"}], ";"}]}], "]"}], 
             ";", "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"PoS", "\[Equal]", "0"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"NewFee", "[", 
                  RowBox[{"ctstat", ",", "dummy"}], "]"}], "=", 
                 RowBox[{"RandomReal", "[", 
                  RowBox[{"NormalDistribution", "[", 
                   RowBox[{
                    RowBox[{"Fee", "[", "dummy", "]"}], ",", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"SigmaFee", "[", "dummy", "]"}], "/", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{"numbdata", "[", "dummy", "]"}], "]"}]}], ")"}]}],
                    "]"}], "]"}]}], ";"}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{
                 RowBox[{"NewFee", "[", 
                  RowBox[{"ctstat", ",", "dummy"}], "]"}], "=", 
                 RowBox[{
                  FractionBox["180", "\[Pi]"], "*", 
                  RowBox[{"New\[CapitalPsi]", "[", 
                   RowBox[{"ctstat", ",", "dummy"}], "]"}]}]}], ";"}]}], 
              "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
             "\[IndentingNewLine]", "\[IndentingNewLine]", 
             RowBox[{"MaxDipDirDiff", "=", "1"}], ";", "\[IndentingNewLine]", 
             RowBox[{"DipDirVect", "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"DipDir", "[", "dummy", "]"}], "+", "90"}], 
                    "\[GreaterEqual]", "360"}], ",", 
                    RowBox[{
                    RowBox[{"DipDir", "[", "dummy", "]"}], "-", "270"}], ",", 
                    RowBox[{
                    RowBox[{"DipDir", "[", "dummy", "]"}], "+", "90"}]}], 
                   "]"}], "*", 
                  RowBox[{"Pi", "/", "180"}]}], "]"}], ",", 
                RowBox[{"Cos", "[", 
                 RowBox[{
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"DipDir", "[", "dummy", "]"}], "+", "90"}], 
                    "\[GreaterEqual]", "360"}], ",", 
                    RowBox[{
                    RowBox[{"DipDir", "[", "dummy", "]"}], "-", "270"}], ",", 
                    RowBox[{
                    RowBox[{"DipDir", "[", "dummy", "]"}], "+", "90"}]}], 
                   "]"}], "*", 
                  RowBox[{"Pi", "/", "180"}]}], "]"}], ",", "0"}], "}"}]}], 
             ";", "\[IndentingNewLine]", 
             RowBox[{"NewDipDirVect", "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "+", "90"}], 
                    "\[GreaterEqual]", "360"}], ",", 
                    RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "-", "270"}], 
                    ",", 
                    RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "+", "90"}]}], 
                   "]"}], "*", 
                  RowBox[{"Pi", "/", "180"}]}], "]"}], ",", 
                RowBox[{"Cos", "[", 
                 RowBox[{
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "+", "90"}], 
                    "\[GreaterEqual]", "360"}], ",", 
                    RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "-", "270"}], 
                    ",", 
                    RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "+", "90"}]}], 
                   "]"}], "*", 
                  RowBox[{"Pi", "/", "180"}]}], "]"}], ",", "0"}], "}"}]}], 
             ";", "\[IndentingNewLine]", 
             RowBox[{"DipDirDiff", "=", 
              RowBox[{
               RowBox[{"ArcCos", "[", 
                RowBox[{"Dot", "[", 
                 RowBox[{"DipDirVect", ",", "NewDipDirVect"}], "]"}], "]"}], 
               "*", 
               RowBox[{"180", "/", "Pi"}]}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"DipDirDiff", ">", "MaxDipDirDiff"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"strikevect", "=", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"DipDir", "[", "dummy", "]"}], "*", 
                    RowBox[{"Pi", "/", "180"}]}], "]"}], ",", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"DipDir", "[", "dummy", "]"}], "*", 
                    RowBox[{"Pi", "/", "180"}]}], "]"}], ",", "0"}], "}"}]}], 
                ";", "\[IndentingNewLine]", 
                RowBox[{"PreRotVect", "=", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"NewFee", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "*", 
                    RowBox[{"Pi", "/", "180"}]}], "]"}], ",", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"NewFee", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "*", 
                    RowBox[{"Pi", "/", "180"}]}], "]"}], ",", "0"}], "}"}]}], 
                ";", 
                RowBox[{"HorzRot", "=", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Dip", "[", "dummy", "]"}], "*", 
                    RowBox[{"Pi", "/", "180"}]}], "]"}], ",", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"Dip", "[", "dummy", "]"}], "*", 
                    RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"Dip", "[", "dummy", "]"}], "*", 
                    RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"Dip", "[", "dummy", "]"}], "*", 
                    RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}]}], "}"}]}], 
                ";", "\[IndentingNewLine]", 
                RowBox[{"OneRot", "=", 
                 RowBox[{"PreRotVect", ".", "HorzRot"}]}], ";", 
                RowBox[{"VertRot", "=", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"DipDir", "[", "dummy", "]"}], "-", "90"}], ")"}],
                     "*", 
                    RowBox[{"Pi", "/", "180"}]}], "]"}], ",", 
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"DipDir", "[", "dummy", "]"}], "-", "90"}], ")"}],
                     "*", 
                    RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", "0"}], "}"}], 
                   ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"DipDir", "[", "dummy", "]"}], "-", "90"}], ")"}],
                     "*", 
                    RowBox[{"Pi", "/", "180"}]}], "]"}], ",", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"DipDir", "[", "dummy", "]"}], "-", "90"}], ")"}],
                     "*", 
                    RowBox[{"Pi", "/", "180"}]}], "]"}], ",", "0"}], "}"}], 
                   ",", 
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"MajorVect", "=", 
                 RowBox[{"OneRot", ".", "VertRot"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"MajorVect", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], "<", "0"}], ",", 
                  RowBox[{
                   RowBox[{"MajorVect", "=", 
                    RowBox[{"-", "MajorVect"}]}], ";"}]}], "]"}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], 
                    "\[GreaterEqual]", "0"}], "&&", 
                   RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "\[LessEqual]", 
                    "90"}]}], ",", 
                  RowBox[{
                   RowBox[{"\[Theta]", "=", 
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}]}], ";"}]}], "]"}],
                 ";", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], ">", "90"}], "&&", 
                   RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "\[LessEqual]", 
                    "180"}]}], ",", 
                  RowBox[{
                   RowBox[{"\[Theta]", "=", 
                    RowBox[{"180", "-", 
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}]}]}], ";"}]}], 
                 "]"}], ";", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], ">", "180"}], "&&", 
                   RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "\[LessEqual]", 
                    "270"}]}], ",", 
                  RowBox[{
                   RowBox[{"\[Theta]", "=", 
                    RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "-", "180"}]}], 
                   ";"}]}], "]"}], ";", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], ">", "270"}], "&&", 
                   RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "\[LessEqual]", 
                    "360"}]}], ",", 
                  RowBox[{
                   RowBox[{"\[Theta]", "=", 
                    RowBox[{"360", "-", 
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}]}]}], ";"}]}], 
                 "]"}], ";", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"\[Theta]", "\[Equal]", "90"}], "||", 
                   RowBox[{"\[Theta]", "\[Equal]", "270"}]}], ",", 
                  RowBox[{
                   RowBox[{"a", "=", "0"}], ";"}], ",", 
                  RowBox[{
                   RowBox[{"a", "=", 
                    SqrtBox[
                    FractionBox["1", 
                    RowBox[{"1", "+", 
                    SuperscriptBox[
                    RowBox[{"Tan", "[", 
                    FractionBox[
                    RowBox[{"\[Theta]", " ", "\[Pi]"}], "180"], "]"}], 
                    "2"]}]]]}], ";"}]}], "]"}], ";", 
                RowBox[{"b", "=", 
                 SqrtBox[
                  RowBox[{"1", "-", 
                   SuperscriptBox["a", "2"]}]]}], ";", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"NewDip", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "\[Equal]", 
                   "0"}], ",", 
                  RowBox[{
                   RowBox[{"a", "=", "0"}], ";", 
                   RowBox[{"b", "=", "0"}], ";", 
                   RowBox[{"c", "=", "1"}], ";"}], ",", 
                  RowBox[{
                   RowBox[{"c", "=", 
                    RowBox[{"Tan", "[", 
                    RowBox[{
                    FractionBox["1", "180"], " ", 
                    RowBox[{"(", 
                    RowBox[{"90", "-", 
                    RowBox[{"NewDip", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}]}], ")"}], " ", 
                    "\[Pi]"}], "]"}]}], ";"}]}], "]"}], ";", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], 
                    "\[GreaterEqual]", "0"}], "&&", 
                   RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "\[LessEqual]", 
                    "90"}]}], ",", 
                  RowBox[{
                   RowBox[{"a", "=", "a"}], ";", 
                   RowBox[{"b", "=", 
                    RowBox[{"-", "b"}]}], ";"}]}], "]"}], ";", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], ">", "90"}], "&&", 
                   RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "\[LessEqual]", 
                    "180"}]}], ",", 
                  RowBox[{
                   RowBox[{"a", "=", 
                    RowBox[{"-", "a"}]}], ";", 
                   RowBox[{"b", "=", 
                    RowBox[{"-", "b"}]}], ";"}]}], "]"}], ";", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], ">", "180"}], "&&", 
                   RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "\[LessEqual]", 
                    "270"}]}], ",", 
                  RowBox[{
                   RowBox[{"a", "=", 
                    RowBox[{"-", "a"}]}], ";", 
                   RowBox[{"b", "=", "b"}], ";"}]}], "]"}], ";", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], ">", "270"}], "&&", 
                   RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "\[LessEqual]", 
                    "360"}]}], ",", 
                  RowBox[{
                   RowBox[{"a", "=", "a"}], ";", 
                   RowBox[{"b", "=", "b"}], ";"}]}], "]"}], ";", 
                RowBox[{"scale", "=", 
                 FractionBox["1", 
                  SqrtBox[
                   RowBox[{
                    SuperscriptBox["a", "2"], "+", 
                    SuperscriptBox["b", "2"], "+", 
                    SuperscriptBox["c", "2"]}]]]}], ";", 
                RowBox[{"aprime", "=", 
                 RowBox[{"scale", " ", "a"}]}], ";", 
                RowBox[{"bprime", "=", 
                 RowBox[{"scale", " ", "b"}]}], ";", 
                RowBox[{"cprime", "=", 
                 RowBox[{"scale", " ", "c"}]}], ";", 
                RowBox[{
                 RowBox[{"Newnormvect", "[", 
                  RowBox[{"ctstat", ",", "dummy"}], "]"}], "=", 
                 RowBox[{"N", "[", 
                  RowBox[{"{", 
                   RowBox[{"aprime", ",", "bprime", ",", "cprime"}], "}"}], 
                  "]"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"ProjVect", "=", 
                 RowBox[{"Normalize", "[", 
                  RowBox[{"Cross", "[", 
                   RowBox[{
                    RowBox[{"Newnormvect", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], ",", 
                    RowBox[{"Cross", "[", 
                    RowBox[{"MajorVect", ",", 
                    RowBox[{"Newnormvect", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}]}], "]"}]}], "]"}],
                   "]"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"ProjVect", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], "<", "0"}], ",", 
                  RowBox[{
                   RowBox[{"ProjVect", "=", 
                    RowBox[{"-", "ProjVect"}]}], ";"}]}], "]"}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"Newstrikevect", "=", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "*", 
                    RowBox[{"Pi", "/", "180"}]}], "]"}], ",", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"NewDipDir", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "*", 
                    RowBox[{"Pi", "/", "180"}]}], "]"}], ",", "0"}], "}"}]}], 
                ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"NewFeePrime", "[", 
                  RowBox[{"ctstat", ",", "dummy"}], "]"}], "=", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"ArcCos", "[", 
                    RowBox[{"Dot", "[", 
                    RowBox[{"Newstrikevect", ",", "ProjVect"}], "]"}], "]"}], 
                    ">", 
                    RowBox[{"Pi", "/", "2"}]}], ",", 
                   RowBox[{
                    RowBox[{"ArcCos", "[", 
                    RowBox[{"Dot", "[", 
                    RowBox[{"Newstrikevect", ",", "ProjVect"}], "]"}], "]"}], 
                    "-", "Pi"}], ",", 
                   RowBox[{"ArcCos", "[", 
                    RowBox[{"Dot", "[", 
                    RowBox[{"Newstrikevect", ",", "ProjVect"}], "]"}], 
                    "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"NewFee", "[", 
                  RowBox[{"ctstat", ",", "dummy"}], "]"}], "=", 
                 RowBox[{
                  RowBox[{"NewFeePrime", "[", 
                   RowBox[{"ctstat", ",", "dummy"}], "]"}], "*", 
                  RowBox[{"180", "/", "Pi"}]}]}], ";"}]}], "]"}], ";", 
             "\[IndentingNewLine]", "\[IndentingNewLine]", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"New\[CapitalPsi]", "[", 
               RowBox[{"ctstat", ",", "dummy"}], "]"}], "=", 
              RowBox[{
               RowBox[{"NewFee", "[", 
                RowBox[{"ctstat", ",", "dummy"}], "]"}], "*", 
               RowBox[{"Pi", "/", "180"}]}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"dummy", "=", 
              RowBox[{"dummy", "+", "1"}]}], ";"}]}], "]"}], ";", "\n", "\n", 
          "\[IndentingNewLine]", 
          RowBox[{"dummy", "=", "1"}], ";", 
          RowBox[{
           RowBox[{"StatErrorIndex", "[", "0", "]"}], "=", "0"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"dummy", "\[LessEqual]", "numbplanes"}], ",", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"f", "=", 
              RowBox[{
               RowBox[{"NewDipDir", "[", 
                RowBox[{"ctstat", ",", " ", "dummy"}], "]"}], "-", "90"}]}], 
             ";", 
             RowBox[{"j", "=", 
              RowBox[{"90", "-", 
               RowBox[{"NewDip", "[", 
                RowBox[{"ctstat", ",", "dummy"}], "]"}]}]}], ";", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"NewDip", "[", 
                 RowBox[{"ctstat", ",", "dummy"}], "]"}], "\[Equal]", "0"}], 
               ",", 
               RowBox[{"f", "=", "90"}]}], "]"}], ";", 
             RowBox[{"\[Mu]", "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   FractionBox[
                    RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}], ",", 
                  RowBox[{"Sin", "[", 
                   FractionBox[
                    RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}], ",", "0"}], 
                 "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"Sin", "[", 
                    FractionBox[
                    RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}]}], ",", 
                  RowBox[{"Cos", "[", 
                   FractionBox[
                    RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}], ",", "0"}], 
                 "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
             RowBox[{"H", "=", 
              RowBox[{
               RowBox[{"Transpose", "[", "\[Mu]", "]"}], ".", 
               "GeneralEllipsoid", ".", "\[Mu]"}]}], ";", 
             RowBox[{"\[Eta]", "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", 
                  RowBox[{"Cos", "[", 
                   FractionBox[
                    RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}], ",", 
                  RowBox[{"Sin", "[", 
                   FractionBox[
                    RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", 
                   RowBox[{"Sin", "[", 
                    FractionBox[
                    RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}]}], ",", 
                  RowBox[{"Cos", "[", 
                   FractionBox[
                    RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}]}], "}"}]}], 
               "}"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"Q", "=", 
              RowBox[{
               RowBox[{"Transpose", "[", "\[Eta]", "]"}], ".", "H", ".", 
               "\[Eta]"}]}], ";", "\[IndentingNewLine]", 
             "\[IndentingNewLine]", 
             RowBox[{"TempMatEll", "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Q", "\[LeftDoubleBracket]", 
                   RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                  RowBox[{"Q", "\[LeftDoubleBracket]", 
                   RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], 
                 "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Q", "\[LeftDoubleBracket]", 
                   RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                  RowBox[{"Q", "\[LeftDoubleBracket]", 
                   RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], 
                 "}"}]}], "}"}]}], ";", "\[IndentingNewLine]", "\n", 
             RowBox[{
              RowBox[{"SectionEllipse", "[", "dummy", "]"}], "=", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                   RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                  "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
                   RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                  "}"}]}], "}"}], "/", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], " ", 
                    RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], "-", 
                    RowBox[{
                    RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], " ", 
                    RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}]}], 
                   ")"}], "^", "2"}], ")"}], "^", 
                RowBox[{"(", 
                 RowBox[{"1", "/", "4"}], ")"}]}]}]}], ";", 
             "\[IndentingNewLine]", "\[IndentingNewLine]", 
             RowBox[{"PrinMat", "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"N", "[", 
                   SqrtBox[
                    FractionBox["1", 
                    SuperscriptBox[
                    RowBox[{"New\[CapitalPi]", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "2"]]], "]"}], 
                  ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", 
                  RowBox[{"N", "[", 
                   FractionBox["1", 
                    SqrtBox[
                    FractionBox["1", 
                    SuperscriptBox[
                    RowBox[{"New\[CapitalPi]", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "2"]]]], "]"}]}],
                  "}"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
             "\[IndentingNewLine]", 
             RowBox[{"RotMat", "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{"N", "[", 
                    RowBox[{"New\[CapitalPsi]", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "]"}], "]"}], 
                  ",", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"N", "[", 
                    RowBox[{"New\[CapitalPsi]", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "]"}], "]"}]}], 
                 "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"N", "[", 
                    RowBox[{"New\[CapitalPsi]", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "]"}], "]"}]}], 
                  ",", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"N", "[", 
                    RowBox[{"New\[CapitalPsi]", "[", 
                    RowBox[{"ctstat", ",", "dummy"}], "]"}], "]"}], "]"}]}], 
                 "}"}]}], "}"}]}], ";", 
             RowBox[{"TempEllipMat", "=", 
              RowBox[{
               RowBox[{"Transpose", "[", "RotMat", "]"}], ".", "PrinMat", ".",
                "RotMat"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"EllipMat", "[", "dummy", "]"}], "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"TempEllipMat", "\[LeftDoubleBracket]", 
                   RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                  RowBox[{"TempEllipMat", "\[LeftDoubleBracket]", 
                   RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                 "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"TempEllipMat", "\[LeftDoubleBracket]", 
                   RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                  RowBox[{"TempEllipMat", "\[LeftDoubleBracket]", 
                   RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                 "}"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"StatErrorIndex", "[", "dummy", "]"}], "=", 
              RowBox[{
               RowBox[{"StatErrorIndex", "[", 
                RowBox[{"dummy", "-", "1"}], "]"}], "+", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"EllipMat", "[", "dummy", "]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "-", 
                    RowBox[{
                    RowBox[{"SectionEllipse", "[", "dummy", "]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], 
                   ")"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"EllipMat", "[", "dummy", "]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
                    RowBox[{
                    RowBox[{"SectionEllipse", "[", "dummy", "]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                   ")"}], "2"], "+", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"EllipMat", "[", "dummy", "]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
                    RowBox[{
                    RowBox[{"SectionEllipse", "[", "dummy", "]"}], 
                    "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                   ")"}], "2"]}], ")"}]}]}], ";", "\n", 
             RowBox[{"dummy", "=", 
              RowBox[{"dummy", "+", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"\[Lambda]2", "=", "1"}], ";", "\[IndentingNewLine]", 
          RowBox[{"mycons", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "-", "\[Lambda]1", "-", "\[Lambda]3"}], 
               ")"}], "\[LessEqual]", "0"}], ",", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 RowBox[{"\[Gamma]1", "^", "2"}]}], "-", 
                RowBox[{"\[Gamma]2", "^", "2"}], "-", 
                RowBox[{"\[Gamma]3", "^", "2"}], "+", "\[Lambda]1", "+", 
                "\[Lambda]3", "+", 
                RowBox[{"\[Lambda]1", " ", "\[Lambda]3"}]}], ")"}], 
              "\[GreaterEqual]", "0"}], ",", 
             RowBox[{
              RowBox[{
               RowBox[{"\[Gamma]2", "^", "2"}], "-", 
               RowBox[{
               "2", " ", "\[Gamma]1", " ", "\[Gamma]2", " ", "\[Gamma]3"}], 
               "+", 
               RowBox[{
                RowBox[{"\[Gamma]1", "^", "2"}], " ", "\[Lambda]1"}], "+", 
               RowBox[{
                RowBox[{"\[Gamma]3", "^", "2"}], " ", "\[Lambda]3"}], "-", 
               RowBox[{"\[Lambda]1", " ", "\[Lambda]3"}]}], "\[LessEqual]", 
              "0"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"TimeConstrained", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Quiet", "[", 
              RowBox[{
               RowBox[{"stepsize", "=", ".1"}], ";", "\[IndentingNewLine]", 
               RowBox[{"Lamda1max", "=", "10"}], ";", "\[IndentingNewLine]", 
               RowBox[{"Lamda3max", "=", "10"}], ";", "\[IndentingNewLine]", 
               RowBox[{"init\[Lambda]1", "=", ".01"}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"counter", "=", "0"}], ";", "\[IndentingNewLine]", 
               RowBox[{"While", "[", 
                RowBox[{
                 RowBox[{"init\[Lambda]1", "\[LessEqual]", "Lamda1max"}], ",",
                  "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"init\[Lambda]3", "=", ".01"}], ";", 
                  "\[IndentingNewLine]", 
                  RowBox[{"While", "[", 
                   RowBox[{
                    RowBox[{"init\[Lambda]3", "\[LessEqual]", "Lamda3max"}], 
                    ",", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Quiet", "[", 
                    RowBox[{
                    RowBox[{"FindMinimum", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"StatErrorIndex", "[", "numbplanes", "]"}], ",", 
                    "mycons"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
                    RowBox[{
                    "Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}]}], 
                    "]"}], ";", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Length", "[", "$MessageList", "]"}], "\[Equal]", 
                    "0"}], ",", 
                    RowBox[{"Break", "[", "]"}]}], "]"}]}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"init\[Lambda]3", "=", 
                    RowBox[{"init\[Lambda]3", "+", "stepsize"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"counter", "=", 
                    RowBox[{"counter", "+", "1"}]}], ";"}]}], "]"}], ";", 
                  "\[IndentingNewLine]", 
                  RowBox[{"Quiet", "[", 
                   RowBox[{
                    RowBox[{"FindMinimum", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"StatErrorIndex", "[", "numbplanes", "]"}], ",", 
                    "mycons"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
                    RowBox[{
                    "Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}]}], 
                    "]"}], ";", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Length", "[", "$MessageList", "]"}], "\[Equal]", 
                    "0"}], ",", 
                    RowBox[{"Break", "[", "]"}]}], "]"}]}], "]"}], ";", 
                  "\[IndentingNewLine]", 
                  RowBox[{"init\[Lambda]1", "=", 
                   RowBox[{"init\[Lambda]1", "+", "stepsize"}]}], ";"}]}], 
                "]"}], ";", "\[IndentingNewLine]", 
               RowBox[{"reducedprecision", "=", "0"}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"Precise", "\[Equal]", "0"}], ",", 
                 RowBox[{
                  RowBox[{"hmmm", "=", 
                   RowBox[{"FindMinimum", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"StatErrorIndex", "[", "numbplanes", "]"}], ",", 
                    "mycons"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
                    RowBox[{
                    "Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}]}], 
                    "]"}]}], ";"}], ",", 
                 RowBox[{
                  RowBox[{"Quiet", "[", 
                   RowBox[{
                    RowBox[{"FindMinimum", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"StatErrorIndex", "[", "numbplanes", "]"}], ",", 
                    "mycons"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
                    RowBox[{
                    "Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}], ",", 
                    RowBox[{"WorkingPrecision", "\[Rule]", "Precise"}]}], 
                    "]"}], ";", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Length", "[", "$MessageList", "]"}], "\[Equal]", 
                    "0"}], ",", 
                    RowBox[{
                    RowBox[{"hmmm", "=", 
                    RowBox[{"FindMinimum", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"StatErrorIndex", "[", "numbplanes", "]"}], ",", 
                    "mycons"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
                    RowBox[{
                    "Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}], ",", 
                    RowBox[{"WorkingPrecision", "\[Rule]", "Precise"}]}], 
                    "]"}]}], ";"}], ",", 
                    RowBox[{
                    RowBox[{"reducedprecision", "=", "1"}], ";", 
                    RowBox[{"hmmm", "=", 
                    RowBox[{"FindMinimum", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"StatErrorIndex", "[", "numbplanes", "]"}], ",", 
                    "mycons"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
                    RowBox[{
                    "Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}]}], 
                    "]"}]}], ";"}]}], "]"}], ";"}], "]"}], ";"}]}], "]"}], 
               ";", "\n", "\[IndentingNewLine]", 
               RowBox[{"\[Lambda]1", "=", 
                RowBox[{"hmmm", "[", 
                 RowBox[{"[", 
                  RowBox[{"2", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"\[Lambda]3", "=", 
                RowBox[{"hmmm", "[", 
                 RowBox[{"[", 
                  RowBox[{"2", ",", "2", ",", "2"}], "]"}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"\[Gamma]1", "=", 
                RowBox[{"hmmm", "[", 
                 RowBox[{"[", 
                  RowBox[{"2", ",", "3", ",", "2"}], "]"}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"\[Gamma]2", "=", 
                RowBox[{"hmmm", "[", 
                 RowBox[{"[", 
                  RowBox[{"2", ",", "4", ",", "2"}], "]"}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"\[Gamma]3", "=", 
                RowBox[{"hmmm", "[", 
                 RowBox[{"[", 
                  RowBox[{"2", ",", "5", ",", "2"}], "]"}], "]"}]}], ";", 
               "\[IndentingNewLine]", "\[IndentingNewLine]", 
               RowBox[{"Gerror", "=", 
                RowBox[{
                 RowBox[{"StatErrorIndex", "[", "numbplanes", "]"}], "/", 
                 "numbplanes"}]}], ";", "\n", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"StatFitEllipsoid", "[", "ctstat", "]"}], "=", 
                RowBox[{"N", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    "\[Lambda]1", ",", "\[Gamma]3", ",", "\[Gamma]2"}], "}"}],
                     ",", 
                    RowBox[{"{", 
                    RowBox[{
                    "\[Gamma]3", ",", "\[Lambda]2", ",", "\[Gamma]1"}], "}"}],
                     ",", 
                    RowBox[{"{", 
                    RowBox[{
                    "\[Gamma]2", ",", "\[Gamma]1", ",", "\[Lambda]3"}], 
                    "}"}]}], "}"}], ",", "6"}], "]"}]}], ";", 
               RowBox[{"S", "=", 
                RowBox[{"Eigensystem", "[", 
                 RowBox[{"StatFitEllipsoid", "[", "ctstat", "]"}], "]"}]}], 
               ";", "\[IndentingNewLine]", 
               RowBox[{"M", "=", 
                RowBox[{"Transpose", "[", 
                 RowBox[{"Eigenvectors", "[", 
                  RowBox[{"StatFitEllipsoid", "[", "ctstat", "]"}], "]"}], 
                 "]"}]}], ";", "\[IndentingNewLine]", 
               RowBox[{"L", "=", 
                RowBox[{"Eigenvalues", "[", 
                 RowBox[{"StatFitEllipsoid", "[", "ctstat", "]"}], "]"}]}], 
               ";", "\[IndentingNewLine]", 
               RowBox[{"test", "=", 
                RowBox[{"Sort", "[", 
                 RowBox[{
                  RowBox[{"Abs", "[", "L", "]"}], ",", "Greater"}], "]"}]}], 
               ";", "\[IndentingNewLine]", 
               RowBox[{"rat", "=", 
                RowBox[{
                 SqrtBox[
                  RowBox[{
                  "test", "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}]], "/", 
                 SqrtBox[
                  RowBox[{
                  "test", "\[LeftDoubleBracket]", "3", 
                   "\[RightDoubleBracket]"}]]}]}], ";", "\[IndentingNewLine]",
                "\[IndentingNewLine]", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"rat", ">", "10"}], ",", 
                 RowBox[{
                  RowBox[{"Quiet", "[", 
                   RowBox[{
                    RowBox[{"FindMinimum", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"StatErrorIndex", "[", "numbplanes", "]"}], ",", 
                    "mycons"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
                    RowBox[{
                    "Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}], ",", 
                    RowBox[{"WorkingPrecision", "\[Rule]", "40"}]}], "]"}], 
                    ";", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Length", "[", "$MessageList", "]"}], "\[Equal]", 
                    "0"}], ",", 
                    RowBox[{
                    RowBox[{"hmmm", "=", 
                    RowBox[{"FindMinimum", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"StatErrorIndex", "[", "numbplanes", "]"}], ",", 
                    "mycons"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
                    RowBox[{
                    "Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}], ",", 
                    RowBox[{"WorkingPrecision", "\[Rule]", "40"}]}], "]"}]}], 
                    ";"}], ",", 
                    RowBox[{
                    RowBox[{"hmmm", "=", 
                    RowBox[{"FindMinimum", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"StatErrorIndex", "[", "numbplanes", "]"}], ",", 
                    "mycons"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
                    RowBox[{
                    "Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}]}], 
                    "]"}]}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
                    RowBox[{"\[Lambda]1", "=", 
                    RowBox[{"hmmm", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"\[Lambda]3", "=", 
                    RowBox[{"hmmm", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "2", ",", "2"}], "]"}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"\[Gamma]1", "=", 
                    RowBox[{"hmmm", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "3", ",", "2"}], "]"}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"\[Gamma]2", "=", 
                    RowBox[{"hmmm", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "4", ",", "2"}], "]"}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"\[Gamma]3", "=", 
                    RowBox[{"hmmm", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "5", ",", "2"}], "]"}], "]"}]}], ";", 
                    RowBox[{"Gerror", "=", 
                    RowBox[{
                    RowBox[{"StatErrorIndex", "[", "numbplanes", "]"}], "/", 
                    "numbplanes"}]}], ";", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"StatFitEllipsoid", "[", "ctstat", "]"}], "=", 
                    RowBox[{"N", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    "\[Lambda]1", ",", "\[Gamma]3", ",", "\[Gamma]2"}], "}"}],
                     ",", 
                    RowBox[{"{", 
                    RowBox[{
                    "\[Gamma]3", ",", "\[Lambda]2", ",", "\[Gamma]1"}], "}"}],
                     ",", 
                    RowBox[{"{", 
                    RowBox[{
                    "\[Gamma]2", ",", "\[Gamma]1", ",", "\[Lambda]3"}], 
                    "}"}]}], "}"}], ",", "6"}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{"S", "=", 
                    RowBox[{"Eigensystem", "[", 
                    RowBox[{"StatFitEllipsoid", "[", "ctstat", "]"}], "]"}]}],
                     ";", "\[IndentingNewLine]", 
                    RowBox[{"M", "=", 
                    RowBox[{"Transpose", "[", 
                    RowBox[{"Eigenvectors", "[", 
                    RowBox[{"StatFitEllipsoid", "[", "ctstat", "]"}], "]"}], 
                    "]"}]}], ";", "\[IndentingNewLine]", 
                    RowBox[{"L", "=", 
                    RowBox[{"Eigenvalues", "[", 
                    RowBox[{"StatFitEllipsoid", "[", "ctstat", "]"}], "]"}]}],
                     ";", "\[IndentingNewLine]", 
                    RowBox[{"test", "=", 
                    RowBox[{"Sort", "[", 
                    RowBox[{
                    RowBox[{"Abs", "[", "L", "]"}], ",", "Greater"}], "]"}]}],
                     ";", "\[IndentingNewLine]", 
                    RowBox[{"rat", "=", 
                    RowBox[{
                    SqrtBox[
                    RowBox[{
                    "test", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]], "/", 
                    SqrtBox[
                    RowBox[{
                    "test", "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}]]}]}], ";"}], "]"}], ";"}]}], 
                "]"}], ";", "\n", 
               RowBox[{
                RowBox[{"ErrorStat", "[", "ctstat", "]"}], "=", "Gerror"}], 
               ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
               RowBox[{"Problem", "=", "0"}], ";", "\[IndentingNewLine]", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"L", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "<", "0"}], "||", 
                  RowBox[{
                   RowBox[{"L", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "<", "0"}], "||", 
                  RowBox[{
                   RowBox[{"L", "[", 
                    RowBox[{"[", "3", "]"}], "]"}], "<", "0"}]}], ",", 
                 RowBox[{
                  RowBox[{"Problem", "=", "1"}], ";", 
                  RowBox[{"Breaknumb", "=", 
                   RowBox[{"Breaknumb", "+", "1"}]}], ";", 
                  RowBox[{"(*", 
                   RowBox[{
                    RowBox[{"Print", "[", 
                    RowBox[{"\"\<Break number = \>\"", ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{"Breaknumb", ",", "Purple", ",", "Bold"}], "]"}], 
                    ",", "\"\< (negative axial length)\>\""}], "]"}], ";"}], 
                   "*)"}], 
                  RowBox[{"Break", "[", "]"}]}]}], "]"}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{"rat", ">", "1000"}], ",", 
                 RowBox[{
                  RowBox[{"Problem", "=", "1"}], ";", 
                  RowBox[{"Breaknumb", "=", 
                   RowBox[{"Breaknumb", "+", "1"}]}], ";", 
                  RowBox[{"(*", 
                   RowBox[{
                    RowBox[{"Print", "[", 
                    RowBox[{"\"\<Break number = \>\"", ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{"Breaknumb", ",", "Purple", ",", "Bold"}], "]"}], 
                    ",", "\"\< (excessively large axial ratio)\>\""}], "]"}], 
                    ";"}], "*)"}], 
                  RowBox[{"Break", "[", "]"}]}]}], "]"}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Length", "[", "$MessageList", "]"}], 
                  StyleBox["\[NotEqual]", "OperatorCharacter"], "0"}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Breaknumb", "=", 
                   RowBox[{"Breaknumb", "+", "1"}]}], ";", 
                  RowBox[{"(*", 
                   RowBox[{
                    RowBox[{"Print", "[", 
                    RowBox[{"\"\<Break number = \>\"", ",", 
                    RowBox[{"Style", "[", 
                    RowBox[{"Breaknumb", ",", "Purple", ",", "Bold"}], "]"}], 
                    ",", "\"\< (error message)\>\""}], "]"}], ";"}], "*)"}], 
                  RowBox[{"Break", "[", "]"}]}]}], "]"}], ";"}], "]"}], ";"}],
             ",", "200", ",", 
            RowBox[{
             RowBox[{"Breaknumb", "=", 
              RowBox[{"Breaknumb", "+", "1"}]}], ";", 
             RowBox[{"(*", 
              RowBox[{
               RowBox[{"Print", "[", 
                RowBox[{"\"\<Break number = \>\"", ",", 
                 RowBox[{"Style", "[", 
                  RowBox[{"Breaknumb", ",", "Purple", ",", "Bold"}], "]"}], 
                 ",", "\"\< (timed out)\>\""}], "]"}], ";"}], "*)"}], 
             RowBox[{"Break", "[", "]"}]}]}], "]"}], ";", "\n", 
          "\[IndentingNewLine]", 
          RowBox[{"L", "=", 
           RowBox[{"Sort", "[", 
            RowBox[{
             RowBox[{"Abs", "[", "L", "]"}], ",", "Greater"}], "]"}]}], ";", 
          "\n", 
          RowBox[{"Lval", "=", 
           RowBox[{"N", "[", 
            RowBox[{"{", 
             RowBox[{
              FractionBox["1", 
               SqrtBox[
                RowBox[{
                "L", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]]],
               ",", 
              FractionBox["1", 
               SqrtBox[
                RowBox[{
                "L", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]],
               ",", 
              FractionBox["1", 
               SqrtBox[
                RowBox[{
                "L", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}]]]}], "}"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"NormalizedAxesLengths", "[", "ctstat", "]"}], "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"Lval", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "/", 
              RowBox[{"Lval", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], ",", 
             RowBox[{
              RowBox[{"Lval", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "/", 
              RowBox[{"Lval", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], ",", 
             RowBox[{
              RowBox[{"Lval", "[", 
               RowBox[{"[", "3", "]"}], "]"}], "/", 
              RowBox[{"Lval", "[", 
               RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Min", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"S", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                RowBox[{"S", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
                RowBox[{"S", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], "]"}], 
             "\[Equal]", 
             RowBox[{"S", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{"Longnumb", "=", "1"}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Min", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"S", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                RowBox[{"S", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
                RowBox[{"S", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], "]"}], 
             "\[Equal]", 
             RowBox[{"S", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{"Longnumb", "=", "2"}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Min", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"S", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                RowBox[{"S", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
                RowBox[{"S", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], "]"}], 
             "\[Equal]", 
             RowBox[{"S", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{"Longnumb", "=", "3"}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Max", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"S", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                RowBox[{"S", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
                RowBox[{"S", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], "]"}], 
             "\[Equal]", 
             RowBox[{"S", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{"Shortnumb", "=", "1"}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Max", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"S", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                RowBox[{"S", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
                RowBox[{"S", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], "]"}], 
             "\[Equal]", 
             RowBox[{"S", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{"Shortnumb", "=", "2"}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Max", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"S", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
                RowBox[{"S", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
                RowBox[{"S", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], "]"}], 
             "\[Equal]", 
             RowBox[{"S", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ",", 
            RowBox[{
             RowBox[{"Shortnumb", "=", "3"}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"Intermnumb", "=", 
           RowBox[{"6", "-", "Longnumb", "-", "Shortnumb"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"ShortAxis", "=", 
           RowBox[{
            RowBox[{"S", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "Shortnumb"}], "]"}], "]"}], "/", 
            RowBox[{"Norm", "[", 
             RowBox[{"S", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", "Shortnumb"}], "]"}], "]"}], "]"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"IntermAxis", "=", 
           RowBox[{
            RowBox[{"S", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "Intermnumb"}], "]"}], "]"}], "/", 
            RowBox[{"Norm", "[", 
             RowBox[{"S", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", "Intermnumb"}], "]"}], "]"}], "]"}]}]}], ";",
           "\[IndentingNewLine]", 
          RowBox[{"LongAxis", "=", 
           RowBox[{
            RowBox[{"S", "[", 
             RowBox[{"[", 
              RowBox[{"2", ",", "Longnumb"}], "]"}], "]"}], "/", 
            RowBox[{"Norm", "[", 
             RowBox[{"S", "[", 
              RowBox[{"[", 
               RowBox[{"2", ",", "Longnumb"}], "]"}], "]"}], "]"}]}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"ShortAxisStat", "[", "ctstat", "]"}], "=", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"ArcCos", "[", 
               RowBox[{"Dot", "[", 
                RowBox[{"ShortAxisFit", ",", "ShortAxis"}], "]"}], "]"}], ">", 
              FractionBox["\[Pi]", "2"]}], ",", "ShortAxis", ",", 
             RowBox[{"-", "ShortAxis"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"IntermAxisStat", "[", "ctstat", "]"}], "=", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"ArcCos", "[", 
               RowBox[{"Dot", "[", 
                RowBox[{"IntermAxisFit", ",", "IntermAxis"}], "]"}], "]"}], 
              ">", 
              FractionBox["\[Pi]", "2"]}], ",", "IntermAxis", ",", 
             RowBox[{"-", "IntermAxis"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"LongAxisStat", "[", "ctstat", "]"}], "=", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"ArcCos", "[", 
               RowBox[{"Dot", "[", 
                RowBox[{"LongAxisFit", ",", "LongAxis"}], "]"}], "]"}], ">", 
              FractionBox["\[Pi]", "2"]}], ",", "LongAxis", ",", 
             RowBox[{"-", "LongAxis"}]}], "]"}]}], ";", "\[IndentingNewLine]",
           "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}]}], ",", 
            RowBox[{
             RowBox[{"LPlunge", "=", "90"}], ";"}], ",", 
            RowBox[{
             RowBox[{"LPlunge", "=", 
              RowBox[{
               FractionBox["1", "\[Pi]"], 
               RowBox[{"ArcTan", "[", 
                FractionBox[
                 RowBox[{"Abs", "[", 
                  RowBox[{
                  "LongAxis", "\[LeftDoubleBracket]", "3", 
                   "\[RightDoubleBracket]"}], "]"}], 
                 SqrtBox[
                  RowBox[{
                   SuperscriptBox[
                    RowBox[{
                    "LongAxis", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "2"], "+", 
                   SuperscriptBox[
                    RowBox[{
                    "LongAxis", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "2"]}]]], "]"}], " ", 
               "180"}]}], ";"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "LongAxis", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], "\[Equal]", "0"}], ",", 
            RowBox[{
             RowBox[{"Tl", "=", "90"}], ";"}], ",", 
            RowBox[{
             RowBox[{"Tl", "=", 
              RowBox[{"Abs", "[", 
               FractionBox[
                RowBox[{
                 RowBox[{"ArcTan", "[", 
                  FractionBox[
                   RowBox[{
                   "LongAxis", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], 
                   RowBox[{
                   "LongAxis", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]], "]"}], " ", "180"}], "\[Pi]"],
                "]"}]}], ";"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], ",", 
            RowBox[{"LTrend", "=", 
             RowBox[{"180", "-", "Tl"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], ",", 
            RowBox[{"LTrend", "=", "Tl"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], ",", 
            RowBox[{"LTrend", "=", 
             RowBox[{"360", "-", "Tl"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], ",", 
            RowBox[{"LTrend", "=", 
             RowBox[{"180", "+", "Tl"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
            RowBox[{"LTrend", "=", 
             RowBox[{"360", "-", "Tl"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
            RowBox[{"LTrend", "=", 
             RowBox[{"180", "+", "Tl"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
            RowBox[{"LTrend", "=", 
             RowBox[{"180", "-", "Tl"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
            RowBox[{"LTrend", "=", "Tl"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[LessEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "\[LessEqual]", "0"}]}], ",", 
            RowBox[{"LTrend", "=", "90"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], ",", 
            RowBox[{"LTrend", "=", "90"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], ">", "0"}]}], ",", 
            RowBox[{"LTrend", "=", "270"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
            RowBox[{"LTrend", "=", "270"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "LongAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}]}], ",", 
            RowBox[{
             RowBox[{"LPlunge", "=", "90"}], ";", 
             RowBox[{"LTrend", "=", "\"\<NA\>\""}]}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}]}], ",", 
            RowBox[{
             RowBox[{"IPlunge", "=", "90"}], ";"}], ",", 
            RowBox[{
             RowBox[{"IPlunge", "=", 
              RowBox[{
               FractionBox["1", "\[Pi]"], 
               RowBox[{"ArcTan", "[", 
                RowBox[{
                 RowBox[{"Abs", "[", 
                  RowBox[{
                  "IntermAxis", "\[LeftDoubleBracket]", "3", 
                   "\[RightDoubleBracket]"}], "]"}], "/", 
                 RowBox[{"(", 
                  RowBox[{"\[Sqrt]", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{
                    "IntermAxis", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "2"], "+", 
                    SuperscriptBox[
                    RowBox[{
                    "IntermAxis", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "2"]}], ")"}]}], ")"}]}], 
                "]"}], " ", "180"}]}], ";"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "IntermAxis", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], "\[Equal]", "0"}], ",", 
            RowBox[{"\[CapitalTau]i", "=", "90"}], ",", 
            RowBox[{
             RowBox[{"\[CapitalTau]i", "=", 
              RowBox[{"Abs", "[", 
               FractionBox[
                RowBox[{
                 RowBox[{"ArcTan", "[", 
                  FractionBox[
                   RowBox[{
                   "IntermAxis", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], 
                   RowBox[{
                   "IntermAxis", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]], "]"}], " ", "180"}], "\[Pi]"],
                "]"}]}], ";"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], ",", 
            RowBox[{"ITrend", "=", 
             RowBox[{"180", "-", "\[CapitalTau]i"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], ",", 
            RowBox[{"ITrend", "=", "\[CapitalTau]i"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], ",", 
            RowBox[{"ITrend", "=", 
             RowBox[{"360", "-", "\[CapitalTau]i"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], ",", 
            RowBox[{"ITrend", "=", 
             RowBox[{"180", "+", "\[CapitalTau]i"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
            RowBox[{"ITrend", "=", 
             RowBox[{"360", "-", "\[CapitalTau]i"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
            RowBox[{"ITrend", "=", 
             RowBox[{"180", "+", "\[CapitalTau]i"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
            RowBox[{"ITrend", "=", 
             RowBox[{"180", "-", "\[CapitalTau]i"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
            RowBox[{"ITrend", "=", "\[CapitalTau]i"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[LessEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "\[LessEqual]", "0"}]}], ",", 
            RowBox[{"ITrend", "=", "90"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], ",", 
            RowBox[{"ITrend", "=", "90"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], ">", "0"}]}], ",", 
            RowBox[{"ITrend", "=", "270"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
            RowBox[{"ITrend", "=", "270"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "IntermAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}]}], ",", 
            RowBox[{
             RowBox[{"IPlunge", "=", "90"}], ";", 
             RowBox[{"ITrend", "=", "\"\<NA\>\""}]}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}]}], ",", 
            RowBox[{
             RowBox[{"SPlunge", "=", "90"}], ";"}], ",", 
            RowBox[{
             RowBox[{"SPlunge", "=", 
              RowBox[{
               FractionBox["1", "\[Pi]"], 
               RowBox[{"ArcTan", "[", 
                RowBox[{
                 RowBox[{"Abs", "[", 
                  RowBox[{
                  "ShortAxis", "\[LeftDoubleBracket]", "3", 
                   "\[RightDoubleBracket]"}], "]"}], "/", 
                 RowBox[{"(", 
                  RowBox[{"\[Sqrt]", 
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{
                    "ShortAxis", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "2"], "+", 
                    SuperscriptBox[
                    RowBox[{
                    "ShortAxis", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "2"]}], ")"}]}], ")"}]}], 
                "]"}], " ", "180"}]}], ";"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "ShortAxis", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], "\[Equal]", "0"}], ",", 
            RowBox[{"\[CapitalTau]s", "=", "90"}], ",", 
            RowBox[{
             RowBox[{"\[CapitalTau]s", "=", 
              RowBox[{"Abs", "[", 
               FractionBox[
                RowBox[{
                 RowBox[{"ArcTan", "[", 
                  FractionBox[
                   RowBox[{
                   "ShortAxis", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], 
                   RowBox[{
                   "ShortAxis", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]], "]"}], " ", "180"}], "\[Pi]"],
                "]"}]}], ";"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], ",", 
            RowBox[{"STrend", "=", 
             RowBox[{"180", "-", "\[CapitalTau]s"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], ",", 
            RowBox[{"STrend", "=", "\[CapitalTau]s"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], ",", 
            RowBox[{"STrend", "=", 
             RowBox[{"360", "-", "\[CapitalTau]s"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], ",", 
            RowBox[{"STrend", "=", 
             RowBox[{"180", "+", "\[CapitalTau]s"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
            RowBox[{"STrend", "=", 
             RowBox[{"360", "-", "\[CapitalTau]s"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
            RowBox[{"STrend", "=", 
             RowBox[{"180", "+", "\[CapitalTau]s"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
            RowBox[{"STrend", "=", 
             RowBox[{"180", "-", "\[CapitalTau]s"}]}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
            RowBox[{"STrend", "=", "\[CapitalTau]s"}]}], "]"}], ";", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[LessEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "\[LessEqual]", "0"}]}], ",", 
            RowBox[{"STrend", "=", "90"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], ",", 
            RowBox[{"STrend", "=", "90"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], ">", "0"}]}], ",", 
            RowBox[{"STrend", "=", "270"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
            RowBox[{"STrend", "=", "270"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
             RowBox[{
              RowBox[{
              "ShortAxis", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[Equal]", "0"}]}], ",", 
            RowBox[{
             RowBox[{"SPlunge", "=", "90"}], ";", 
             RowBox[{"STrend", "=", "\"\<NA\>\""}]}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"LTrendStat", "[", "ctstat", "]"}], "=", "LTrend"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"LPlungeStat", "[", "ctstat", "]"}], "=", "LPlunge"}], ";",
           "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"ITrendStat", "[", "ctstat", "]"}], "=", "ITrend"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"IPlungeStat", "[", "ctstat", "]"}], "=", "IPlunge"}], ";",
           "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"STrendStat", "[", "ctstat", "]"}], "=", "STrend"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"SPlungeStat", "[", "ctstat", "]"}], "=", "SPlunge"}], ";",
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{"\"\<Finished \>\"", ",", 
              RowBox[{"Style", "[", 
               RowBox[{
               "ctstat", ",", "Bold", ",", " ", "Underlined", ",", "Blue"}], 
               "]"}], ",", "\"\< out of \>\"", ",", "statnumb", ",", 
              "\"\< iterations\>\""}], "]"}], ";", "\[IndentingNewLine]", 
            RowBox[{"Print", "[", 
             RowBox[{
              RowBox[{"DateString", "[", "]"}], ",", 
              RowBox[{"Clock", "[", "]"}]}], "]"}], ";"}], "*)"}], 
          "\[IndentingNewLine]", "\n", 
          RowBox[{"ctstat", "=", 
           RowBox[{"ctstat", "+", "1"}]}], ";"}]}], "]"}], ";"}]}], "]"}], 
    ";"}], "\n", "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"sphericalFromTrendPlungeDeg", "[", 
      RowBox[{"{", 
       RowBox[{"trendDeg_", ",", " ", "plungeDeg_"}], "}"}], "]"}], " ", ":=",
      "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"1.0", ",", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"plungeDeg", "+", "90.0"}], ")"}], " ", "Degree"}], ",", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"90.0", "-", "trendDeg"}], ")"}], " ", "Degree"}]}], "}"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"cartesianFromSpherical", "[", 
      RowBox[{"{", 
       RowBox[{"rho_", ",", " ", "phi_", ",", " ", "theta_"}], "}"}], "]"}], 
     " ", ":=", " ", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"rho", " ", "*", " ", 
        RowBox[{"Sin", "[", "phi", "]"}], " ", "*", " ", 
        RowBox[{"Cos", "[", "theta", "]"}]}], ",", " ", 
       RowBox[{"rho", " ", "*", " ", 
        RowBox[{"Sin", "[", "phi", "]"}], " ", "*", " ", 
        RowBox[{"Sin", "[", "theta", "]"}]}], ",", " ", 
       RowBox[{"rho", " ", "*", " ", 
        RowBox[{"Cos", "[", "phi", "]"}]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"cartesianFromTrendPlungeDeg", "[", "x_", "]"}], " ", ":=", 
     "\[IndentingNewLine]", 
     RowBox[{"cartesianFromSpherical", "[", 
      RowBox[{"sphericalFromTrendPlungeDeg", "[", "x", "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"lowerHemisphere", "[", 
      RowBox[{"{", 
       RowBox[{"x_", ",", " ", "y_", ",", " ", "z_"}], "}"}], "]"}], " ", ":=",
      " ", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", " ", "y", ",", " ", "z"}], "}"}], " ", "/", " ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"z", " ", "<=", " ", "0"}], ",", " ", 
        RowBox[{"Norm", "[", 
         RowBox[{"{", 
          RowBox[{"x", ",", " ", "y", ",", " ", "z"}], "}"}], "]"}], ",", " ", 
        RowBox[{"-", 
         RowBox[{"Norm", "[", 
          RowBox[{"{", 
           RowBox[{"x", ",", " ", "y", ",", " ", "z"}], "}"}], "]"}]}]}], 
       "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"equalAreaProjection", "[", 
      RowBox[{"{", 
       RowBox[{"x_", ",", " ", "y_", ",", " ", "z_"}], "}"}], "]"}], " ", ":=",
      " ", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "scaling", "}"}], ",", " ", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"x", "^", "2"}], " ", "+", " ", 
           RowBox[{"y", "^", "2"}]}], " ", "\[Equal]", " ", "0"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"0", ",", " ", "0"}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"scaling", " ", "=", " ", 
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{"1", " ", "+", " ", "z"}], ")"}]}], ")"}], " ", "/", 
             " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", "^", "2"}], " ", "+", " ", 
               RowBox[{"y", "^", "2"}]}], ")"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"scaling", " ", "*", " ", "x"}], ",", " ", 
            RowBox[{"scaling", " ", "*", " ", "y"}]}], "}"}]}]}], "]"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"fringePrimitive", "[", 
      RowBox[{"plotRadius_", ",", " ", "padding_"}], "]"}], " ", ":=", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", 
       RowBox[{"Circle", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0.", ",", "0."}], "}"}], ",", "plotRadius"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"plotRadius", " ", "*", " ", 
               RowBox[{"Cos", "[", "angle", "]"}]}], ",", " ", 
              RowBox[{"plotRadius", " ", "*", 
               RowBox[{"Sin", "[", "angle", "]"}]}]}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"plotRadius", " ", "+", " ", "padding"}], ")"}], " ", 
               "*", " ", 
               RowBox[{"Cos", "[", "angle", "]"}]}], ",", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"plotRadius", " ", "+", " ", "padding"}], ")"}], " ", 
               "*", " ", 
               RowBox[{"Sin", "[", "angle", "]"}]}]}], "}"}]}], "}"}], "]"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"angle", ",", " ", "0", ",", " ", 
           RowBox[{"2", " ", "Pi"}], ",", " ", 
           RowBox[{"Pi", " ", "/", " ", "2"}]}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<000\>\"", ",", "Large", ",", "Bold"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"plotRadius", " ", "+", " ", 
            RowBox[{"2", " ", "*", " ", 
             RowBox[{"(", 
              RowBox[{"padding", "*", "1.4"}], ")"}]}]}]}], "}"}]}], "]"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<090\>\"", ",", "Large", ",", "Bold"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"plotRadius", " ", "+", " ", 
            RowBox[{"2", " ", "*", " ", 
             RowBox[{"(", 
              RowBox[{"padding", "*", "1.7"}], ")"}]}]}], ",", "0"}], "}"}]}],
         "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<180\>\"", ",", "Large", ",", "Bold"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"plotRadius", " ", "+", " ", 
              RowBox[{"2", " ", "*", " ", 
               RowBox[{"(", 
                RowBox[{"padding", "*", "1.4"}], ")"}]}]}], ")"}]}]}], 
          "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Text", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<270\>\"", ",", "Large", ",", "Bold"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"plotRadius", " ", "+", " ", 
              RowBox[{"2", " ", "*", " ", 
               RowBox[{"(", 
                RowBox[{"padding", "*", "1.7"}], ")"}]}]}], ")"}]}], ",", 
           "0"}], "}"}]}], "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"equalAreaPlot", "[", 
      RowBox[{"diskList_", ",", "pointRadius_", ",", "coloring_"}], "]"}], 
     " ", ":=", " ", "\[IndentingNewLine]", 
     RowBox[{"Graphics", "[", 
      RowBox[{
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"fringePrimitive", "[", 
          RowBox[{
           RowBox[{"Sqrt", "[", "2", "]"}], ",", " ", "0.1"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Map", "[", 
          RowBox[{
           RowBox[{"Function", "[", 
            RowBox[{"vector", ",", 
             RowBox[{"{", 
              RowBox[{"coloring", ",", 
               RowBox[{"Disk", "[", 
                RowBox[{
                 RowBox[{"equalAreaProjection", "[", 
                  RowBox[{"lowerHemisphere", "[", "vector", "]"}], "]"}], ",",
                  " ", "pointRadius"}], "]"}]}], "}"}]}], "]"}], ",", " ", 
           "diskList"}], "]"}]}], "]"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"curvePrimitive", "[", "pointList_", "]"}], " ", ":=", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"pointList", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
          RowBox[{"pointList", "[", 
           RowBox[{"[", 
            RowBox[{"i", " ", "+", " ", "1"}], "]"}], "]"}]}], "}"}], "]"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", 
         RowBox[{
          RowBox[{"Length", "[", "pointList", "]"}], " ", "-", " ", "1"}]}], 
        "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"lowerHemisphereGrid", "[", 
      RowBox[{"gridSkip_", ",", " ", "sampleSkip_"}], "]"}], " ", ":=", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "curves", ",", " ", "curve", ",", " ", "phi", ",", " ", "theta"}], 
        "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"curves", " ", "=", " ", 
         RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"phi", " ", "=", " ", "gridSkip"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"While", "[", 
         RowBox[{
          RowBox[{"phi", " ", "<", " ", "Pi"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"curve", " ", "=", " ", 
            RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"theta", " ", "=", " ", "0"}], ";", "\[IndentingNewLine]", 
           RowBox[{"While", "[", 
            RowBox[{
             RowBox[{"theta", " ", "\[LessEqual]", " ", "Pi"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"curve", " ", "=", " ", 
               RowBox[{"Append", "[", 
                RowBox[{"curve", ",", " ", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Sin", "[", "phi", "]"}], " ", 
                    RowBox[{"Cos", "[", "theta", "]"}]}], ",", " ", 
                   RowBox[{"Cos", "[", "phi", "]"}], ",", " ", 
                   RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "phi", "]"}]}], " ", 
                    RowBox[{"Sin", "[", "theta", "]"}]}]}], "}"}]}], "]"}]}], 
              ";", "\[IndentingNewLine]", 
              RowBox[{"theta", " ", "=", " ", 
               RowBox[{"theta", " ", "+", " ", "sampleSkip"}]}]}]}], "]"}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"curves", " ", "=", " ", 
            RowBox[{"Append", "[", 
             RowBox[{"curves", ",", " ", "curve"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"phi", " ", "=", " ", 
            RowBox[{"phi", " ", "+", " ", "gridSkip"}]}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"theta", " ", "=", " ", "0"}], ";", "\[IndentingNewLine]", 
        RowBox[{"While", "[", 
         RowBox[{
          RowBox[{"theta", " ", "\[LessEqual]", " ", "Pi"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"curve", " ", "=", " ", 
            RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"phi", " ", "=", " ", "0"}], ";", "\[IndentingNewLine]", 
           RowBox[{"While", "[", 
            RowBox[{
             RowBox[{"phi", " ", "\[LessEqual]", " ", "Pi"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"curve", " ", "=", " ", 
               RowBox[{"Append", "[", 
                RowBox[{"curve", ",", " ", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Sin", "[", "phi", "]"}], " ", 
                    RowBox[{"Cos", "[", "theta", "]"}]}], ",", " ", 
                   RowBox[{"Cos", "[", "phi", "]"}], ",", " ", 
                   RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "phi", "]"}]}], " ", 
                    RowBox[{"Sin", "[", "theta", "]"}]}]}], "}"}]}], "]"}]}], 
              ";", "\[IndentingNewLine]", 
              RowBox[{"phi", " ", "=", " ", 
               RowBox[{"phi", " ", "+", " ", "sampleSkip"}]}]}]}], "]"}], ";",
            "\[IndentingNewLine]", 
           RowBox[{"curves", " ", "=", " ", 
            RowBox[{"Append", "[", 
             RowBox[{"curves", ",", " ", "curve"}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"theta", " ", "=", " ", 
            RowBox[{"theta", " ", "+", " ", "gridSkip"}]}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", "curves"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"schmidtNet", "[", 
      RowBox[{"gridSkip_", ",", " ", "sampleSkip_"}], "]"}], " ", ":=", " ", 
     "\[IndentingNewLine]", 
     RowBox[{"Graphics", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"GrayLevel", "[", ".7", "]"}], ",", "Thin", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Map", "[", 
          RowBox[{
           RowBox[{"Function", "[", 
            RowBox[{"curve", ",", " ", 
             RowBox[{"curvePrimitive", "[", 
              RowBox[{"Map", "[", 
               RowBox[{"equalAreaProjection", ",", "curve"}], "]"}], "]"}]}], 
            "]"}], ",", " ", 
           RowBox[{"lowerHemisphereGrid", "[", 
            RowBox[{"gridSkip", ",", " ", "sampleSkip"}], "]"}]}], "]"}]}], 
        "}"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TempAvgLong", "=", 
     RowBox[{"Mean", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"LongAxisStat", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AvgLong", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"TempAvgLong", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgLong", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "2"], ")"}], "+", 
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgLong", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "2"], ")"}], "+", 
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgLong", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "2"], ")"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"TempAvgLong", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgLong", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "2"], ")"}], "+", 
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgLong", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "2"], ")"}], "+", 
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgLong", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "2"], ")"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"TempAvgLong", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgLong", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "2"], ")"}], "+", 
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgLong", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "2"], ")"}], "+", 
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgLong", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "2"], ")"}]}], "]"}]}]}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TempAvgInterm", "=", 
     RowBox[{"Mean", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"IntermAxisStat", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AvgInterm", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"TempAvgInterm", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgInterm", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "2"], ")"}], "+", 
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgInterm", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "2"], ")"}], "+", 
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgInterm", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "2"], ")"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"TempAvgInterm", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgInterm", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "2"], ")"}], "+", 
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgInterm", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "2"], ")"}], "+", 
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgInterm", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "2"], ")"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"TempAvgInterm", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgInterm", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "2"], ")"}], "+", 
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgInterm", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "2"], ")"}], "+", 
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgInterm", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "2"], ")"}]}], "]"}]}]}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TempAvgShort", "=", 
     RowBox[{"Mean", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"ShortAxisStat", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AvgShort", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"TempAvgShort", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgShort", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "2"], ")"}], "+", 
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgShort", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "2"], ")"}], "+", 
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgShort", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "2"], ")"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"TempAvgShort", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgShort", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "2"], ")"}], "+", 
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgShort", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "2"], ")"}], "+", 
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgShort", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "2"], ")"}]}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"TempAvgShort", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgShort", "[", 
             RowBox[{"[", "1", "]"}], "]"}], "2"], ")"}], "+", 
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgShort", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "2"], ")"}], "+", 
          RowBox[{"(", 
           SuperscriptBox[
            RowBox[{"TempAvgShort", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "2"], ")"}]}], "]"}]}]}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p", "=", 
     RowBox[{"1", "-", "alphapercent"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LongR", "=", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"(", 
        SuperscriptBox[
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"LongAxisStat", "[", "x", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], "2"], 
        ")"}], "+", 
       RowBox[{"(", 
        SuperscriptBox[
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"LongAxisStat", "[", "x", "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], "2"], 
        ")"}], "+", 
       RowBox[{"(", 
        SuperscriptBox[
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"LongAxisStat", "[", "x", "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], "2"], 
        ")"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"LongAlpha", "=", 
     RowBox[{
      RowBox[{"ArcCos", "[", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          RowBox[{"(", 
           FractionBox[
            RowBox[{"(", 
             RowBox[{"statnumb", "-", "LongR"}], ")"}], "LongR"], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox["1", "p"], ")"}], 
              RowBox[{"(", 
               FractionBox["1", 
                RowBox[{"(", 
                 RowBox[{"statnumb", "-", "1"}], ")"}]], ")"}]], ")"}], "-", 
            "1"}], ")"}]}]}], ")"}], "]"}], "*", 
      RowBox[{"180", "/", "Pi"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"IntermR", "=", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"(", 
        SuperscriptBox[
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"IntermAxisStat", "[", "x", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], "2"], 
        ")"}], "+", 
       RowBox[{"(", 
        SuperscriptBox[
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"IntermAxisStat", "[", "x", "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], "2"], 
        ")"}], "+", 
       RowBox[{"(", 
        SuperscriptBox[
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"IntermAxisStat", "[", "x", "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], "2"], 
        ")"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"IntermAlpha", "=", 
     RowBox[{
      RowBox[{"ArcCos", "[", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          RowBox[{"(", 
           FractionBox[
            RowBox[{"(", 
             RowBox[{"statnumb", "-", "IntermR"}], ")"}], "IntermR"], ")"}], 
          "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox["1", "p"], ")"}], 
              RowBox[{"(", 
               FractionBox["1", 
                RowBox[{"(", 
                 RowBox[{"statnumb", "-", "1"}], ")"}]], ")"}]], ")"}], "-", 
            "1"}], ")"}]}]}], ")"}], "]"}], "*", 
      RowBox[{"180", "/", "Pi"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ShortR", "=", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"(", 
        SuperscriptBox[
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"ShortAxisStat", "[", "x", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], "2"], 
        ")"}], "+", 
       RowBox[{"(", 
        SuperscriptBox[
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"ShortAxisStat", "[", "x", "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], "2"], 
        ")"}], "+", 
       RowBox[{"(", 
        SuperscriptBox[
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"ShortAxisStat", "[", "x", "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], "2"], 
        ")"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ShortAlpha", "=", 
     RowBox[{
      RowBox[{"ArcCos", "[", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{
          RowBox[{"(", 
           FractionBox[
            RowBox[{"(", 
             RowBox[{"statnumb", "-", "ShortR"}], ")"}], "ShortR"], ")"}], 
          "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             SuperscriptBox[
              RowBox[{"(", 
               FractionBox["1", "p"], ")"}], 
              RowBox[{"(", 
               FractionBox["1", 
                RowBox[{"(", 
                 RowBox[{"statnumb", "-", "1"}], ")"}]], ")"}]], ")"}], "-", 
            "1"}], ")"}]}]}], ")"}], "]"}], "*", 
      RowBox[{"180", "/", "Pi"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}]}], ",", 
      RowBox[{
       RowBox[{"LPlungeMean", "=", "90"}], ";"}], ",", 
      RowBox[{
       RowBox[{"LPlungeMean", "=", 
        FractionBox[
         RowBox[{
          RowBox[{"ArcTan", "[", 
           FractionBox[
            RowBox[{"Abs", "[", 
             RowBox[{
             "AvgLong", "\[LeftDoubleBracket]", "3", 
              "\[RightDoubleBracket]"}], "]"}], 
            SqrtBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{
               "AvgLong", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
               "AvgLong", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], "2"]}]]], "]"}], " ", "180"}], 
         "\[Pi]"]}], ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
       "AvgLong", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"Tl", "=", "90"}], ";"}], ",", 
      RowBox[{
       RowBox[{"Tl", "=", 
        RowBox[{"Abs", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"ArcTan", "[", 
            FractionBox[
             RowBox[{
             "AvgLong", "\[LeftDoubleBracket]", "2", 
              "\[RightDoubleBracket]"}], 
             RowBox[{
             "AvgLong", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}]], "]"}], " ", "180"}], "\[Pi]"], 
         "]"}]}], ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"LTrendMean", "=", 
       RowBox[{"180", "-", "Tl"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"LTrendMean", "=", "Tl"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"LTrendMean", "=", 
       RowBox[{"360", "-", "Tl"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"LTrendMean", "=", 
       RowBox[{"180", "+", "Tl"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"LTrendMean", "=", 
       RowBox[{"360", "-", "Tl"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"LTrendMean", "=", 
       RowBox[{"180", "+", "Tl"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"LTrendMean", "=", 
       RowBox[{"180", "-", "Tl"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"LTrendMean", "=", "Tl"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[LessEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[LessEqual]", "0"}]}], ",", 
      RowBox[{"LTrendMean", "=", "90"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"LTrendMean", "=", "90"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        ">", "0"}]}], ",", 
      RowBox[{"LTrendMean", "=", "270"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"LTrendMean", "=", "270"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgLong", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}]}], ",", 
      RowBox[{
       RowBox[{"LPlungeMean", "=", "90"}], ";", 
       RowBox[{"LTrendMean", "=", "\"\<NA\>\""}]}]}], "]"}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}]}], ",", 
      RowBox[{
       RowBox[{"IPlungeMean", "=", "90"}], ";"}], ",", 
      RowBox[{
       RowBox[{"IPlungeMean", "=", 
        RowBox[{
         FractionBox["1", "\[Pi]"], 
         RowBox[{"ArcTan", "[", 
          FractionBox[
           RowBox[{"Abs", "[", 
            RowBox[{
            "AvgInterm", "\[LeftDoubleBracket]", "3", 
             "\[RightDoubleBracket]"}], "]"}], 
           SqrtBox[
            RowBox[{
             SuperscriptBox[
              RowBox[{
              "AvgInterm", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{
              "AvgInterm", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "2"]}]]], "]"}], " ", "180"}]}], 
       ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
       "AvgInterm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       "\[Equal]", "0"}], ",", 
      RowBox[{"\[CapitalTau]i", "=", "90"}], ",", 
      RowBox[{
       RowBox[{"\[CapitalTau]i", "=", 
        RowBox[{"Abs", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"ArcTan", "[", 
            FractionBox[
             RowBox[{
             "AvgInterm", "\[LeftDoubleBracket]", "2", 
              "\[RightDoubleBracket]"}], 
             RowBox[{
             "AvgInterm", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}]], "]"}], " ", "180"}], "\[Pi]"], 
         "]"}]}], ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"ITrendMean", "=", 
       RowBox[{"180", "-", "\[CapitalTau]i"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"ITrendMean", "=", "\[CapitalTau]i"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"ITrendMean", "=", 
       RowBox[{"360", "-", "\[CapitalTau]i"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"ITrendMean", "=", 
       RowBox[{"180", "+", "\[CapitalTau]i"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"ITrendMean", "=", 
       RowBox[{"360", "-", "\[CapitalTau]i"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"ITrendMean", "=", 
       RowBox[{"180", "+", "\[CapitalTau]i"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"ITrendMean", "=", 
       RowBox[{"180", "-", "\[CapitalTau]i"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"ITrendMean", "=", "\[CapitalTau]i"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[LessEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[LessEqual]", "0"}]}], ",", 
      RowBox[{"ITrendMean", "=", "90"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"ITrendMean", "=", "90"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        ">", "0"}]}], ",", 
      RowBox[{"ITrendMean", "=", "270"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"ITrendMean", "=", "270"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgInterm", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}]}], ",", 
      RowBox[{
       RowBox[{"IPlungeMean", "=", "90"}], ";", 
       RowBox[{"ITrendMean", "=", "\"\<NA\>\""}]}]}], "]"}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}]}], ",", 
      RowBox[{
       RowBox[{"SPlungeMean", "=", "90"}], ";"}], ",", 
      RowBox[{
       RowBox[{"SPlungeMean", "=", 
        FractionBox[
         RowBox[{
          RowBox[{"ArcTan", "[", 
           FractionBox[
            RowBox[{"Abs", "[", 
             RowBox[{
             "AvgShort", "\[LeftDoubleBracket]", "3", 
              "\[RightDoubleBracket]"}], "]"}], 
            SqrtBox[
             RowBox[{
              SuperscriptBox[
               RowBox[{
               "AvgShort", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}], "2"], "+", 
              SuperscriptBox[
               RowBox[{
               "AvgShort", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}], "2"]}]]], "]"}], " ", "180"}], 
         "\[Pi]"]}], ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
       "AvgShort", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       "\[Equal]", "0"}], ",", 
      RowBox[{"\[CapitalTau]s", "=", "90"}], ",", 
      RowBox[{
       RowBox[{"\[CapitalTau]s", "=", 
        RowBox[{"Abs", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"ArcTan", "[", 
            FractionBox[
             RowBox[{
             "AvgShort", "\[LeftDoubleBracket]", "2", 
              "\[RightDoubleBracket]"}], 
             RowBox[{
             "AvgShort", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}]], "]"}], " ", "180"}], "\[Pi]"], 
         "]"}]}], ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"STrendMean", "=", 
       RowBox[{"180", "-", "\[CapitalTau]s"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"STrendMean", "=", "\[CapitalTau]s"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"STrendMean", "=", 
       RowBox[{"360", "-", "\[CapitalTau]s"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"STrendMean", "=", 
       RowBox[{"180", "+", "\[CapitalTau]s"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"STrendMean", "=", 
       RowBox[{"360", "-", "\[CapitalTau]s"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"STrendMean", "=", 
       RowBox[{"180", "+", "\[CapitalTau]s"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"STrendMean", "=", 
       RowBox[{"180", "-", "\[CapitalTau]s"}]}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"STrendMean", "=", "\[CapitalTau]s"}]}], "]"}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[LessEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[LessEqual]", "0"}]}], ",", 
      RowBox[{"STrendMean", "=", "90"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "\[GreaterEqual]", "0"}]}], ",", 
      RowBox[{"STrendMean", "=", "90"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "<", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        ">", "0"}]}], ",", 
      RowBox[{"STrendMean", "=", "270"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        ">", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
        "<", "0"}]}], ",", 
      RowBox[{"STrendMean", "=", "270"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}], "&&", 
       RowBox[{
        RowBox[{
        "AvgShort", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
        "\[Equal]", "0"}]}], ",", 
      RowBox[{
       RowBox[{"SPlungeMean", "=", "90"}], ";", 
       RowBox[{"STrendMean", "=", "\"\<NA\>\""}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LongAngleTable", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ArcCos", "[", 
             RowBox[{"Dot", "[", 
              RowBox[{"LongAxisFit", ",", 
               RowBox[{"LongAxisStat", "[", "x", "]"}]}], "]"}], "]"}], "*", 
            RowBox[{"180", "/", "Pi"}]}], ")"}], "\[GreaterEqual]", "90"}], 
         ",", 
         RowBox[{"180", "-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ArcCos", "[", 
             RowBox[{"Dot", "[", 
              RowBox[{"LongAxisFit", ",", 
               RowBox[{"LongAxisStat", "[", "x", "]"}]}], "]"}], "]"}], "*", 
            RowBox[{"180", "/", "Pi"}]}], ")"}]}], ",", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ArcCos", "[", 
            RowBox[{"Dot", "[", 
             RowBox[{"LongAxisFit", ",", 
              RowBox[{"LongAxisStat", "[", "x", "]"}]}], "]"}], "]"}], "*", 
           RowBox[{"180", "/", "Pi"}]}], ")"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IntermAngleTable", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ArcCos", "[", 
             RowBox[{"Dot", "[", 
              RowBox[{"IntermAxisFit", ",", 
               RowBox[{"IntermAxisStat", "[", "x", "]"}]}], "]"}], "]"}], "*", 
            RowBox[{"180", "/", "Pi"}]}], ")"}], "\[GreaterEqual]", "90"}], 
         ",", 
         RowBox[{"180", "-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ArcCos", "[", 
             RowBox[{"Dot", "[", 
              RowBox[{"IntermAxisFit", ",", 
               RowBox[{"IntermAxisStat", "[", "x", "]"}]}], "]"}], "]"}], "*", 
            RowBox[{"180", "/", "Pi"}]}], ")"}]}], ",", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ArcCos", "[", 
            RowBox[{"Dot", "[", 
             RowBox[{"IntermAxisFit", ",", 
              RowBox[{"IntermAxisStat", "[", "x", "]"}]}], "]"}], "]"}], "*", 
           RowBox[{"180", "/", "Pi"}]}], ")"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ShortAngleTable", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ArcCos", "[", 
             RowBox[{"Dot", "[", 
              RowBox[{"ShortAxisFit", ",", 
               RowBox[{"ShortAxisStat", "[", "x", "]"}]}], "]"}], "]"}], "*", 
            RowBox[{"180", "/", "Pi"}]}], ")"}], "\[GreaterEqual]", "90"}], 
         ",", 
         RowBox[{"180", "-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ArcCos", "[", 
             RowBox[{"Dot", "[", 
              RowBox[{"ShortAxisFit", ",", 
               RowBox[{"ShortAxisStat", "[", "x", "]"}]}], "]"}], "]"}], "*", 
            RowBox[{"180", "/", "Pi"}]}], ")"}]}], ",", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ArcCos", "[", 
            RowBox[{"Dot", "[", 
             RowBox[{"ShortAxisFit", ",", 
              RowBox[{"ShortAxisStat", "[", "x", "]"}]}], "]"}], "]"}], "*", 
           RowBox[{"180", "/", "Pi"}]}], ")"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LongAngleMean", "=", 
     RowBox[{"Mean", "[", "LongAngleTable", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"LongAngleVari", "=", 
     RowBox[{"Variance", "[", "LongAngleTable", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Long\[Alpha]", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"LongAngleMean", "^", "2"}], ")"}], "/", "LongAngleVari"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Long\[Beta]", "=", 
     RowBox[{"LongAngleVari", "/", "LongAngleMean"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"LongCIAngle", "=", 
     RowBox[{
      RowBox[{"FindRoot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Integrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Long\[Beta]", "^", 
                RowBox[{"(", 
                 RowBox[{"-", "Long\[Alpha]"}], ")"}]}], ")"}], "*", 
              RowBox[{"(", 
               RowBox[{"E", "^", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "x"}], "/", "Long\[Beta]"}], ")"}]}], ")"}], 
              "*", 
              RowBox[{"(", 
               RowBox[{"x", "^", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "Long\[Alpha]"}], ")"}]}], ")"}]}],
              ")"}], "/", 
            RowBox[{"Gamma", "[", "Long\[Alpha]", "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", "y"}], "}"}]}], "]"}], "-", 
         "desiredpercentage"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "LongAngleMean"}], "}"}]}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"LongCIAngle", ">", "90"}], ",", 
      RowBox[{"LongCIAngle", "=", "90"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IntermAngleMean", "=", 
     RowBox[{"Mean", "[", "IntermAngleTable", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"IntermAngleVari", "=", 
     RowBox[{"Variance", "[", "IntermAngleTable", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Interm\[Alpha]", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"IntermAngleMean", "^", "2"}], ")"}], "/", 
      "IntermAngleVari"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Interm\[Beta]", "=", 
     RowBox[{"IntermAngleVari", "/", "IntermAngleMean"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"IntermCIAngle", "=", 
     RowBox[{
      RowBox[{"FindRoot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Integrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Interm\[Beta]", "^", 
                RowBox[{"(", 
                 RowBox[{"-", "Interm\[Alpha]"}], ")"}]}], ")"}], "*", 
              RowBox[{"(", 
               RowBox[{"E", "^", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "x"}], "/", "Interm\[Beta]"}], ")"}]}], ")"}], 
              "*", 
              RowBox[{"(", 
               RowBox[{"x", "^", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "Interm\[Alpha]"}], ")"}]}], 
               ")"}]}], ")"}], "/", 
            RowBox[{"Gamma", "[", "Interm\[Alpha]", "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", "y"}], "}"}]}], "]"}], "-", 
         "desiredpercentage"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "IntermAngleMean"}], "}"}]}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"IntermCIAngle", ">", "90"}], ",", 
      RowBox[{"IntermCIAngle", "=", "90"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ShortAngleMean", "=", 
     RowBox[{"Mean", "[", "ShortAngleTable", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ShortAngleVari", "=", 
     RowBox[{"Variance", "[", "ShortAngleTable", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Short\[Alpha]", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"ShortAngleMean", "^", "2"}], ")"}], "/", "ShortAngleVari"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Short\[Beta]", "=", 
     RowBox[{"ShortAngleVari", "/", "ShortAngleMean"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ShortCIAngle", "=", 
     RowBox[{
      RowBox[{"FindRoot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Integrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Short\[Beta]", "^", 
                RowBox[{"(", 
                 RowBox[{"-", "Short\[Alpha]"}], ")"}]}], ")"}], "*", 
              RowBox[{"(", 
               RowBox[{"E", "^", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "x"}], "/", "Short\[Beta]"}], ")"}]}], ")"}], 
              "*", 
              RowBox[{"(", 
               RowBox[{"x", "^", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "Short\[Alpha]"}], ")"}]}], 
               ")"}]}], ")"}], "/", 
            RowBox[{"Gamma", "[", "Short\[Alpha]", "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", "y"}], "}"}]}], "]"}], "-", 
         "desiredpercentage"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "ShortAngleMean"}], "}"}]}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"ShortCIAngle", ">", "90"}], ",", 
      RowBox[{"ShortCIAngle", "=", "90"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NoteBreaking", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"a", ",", "b"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"\[Nu]", "<", "0"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"SolveAxes", "=", 
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Dot", "[", 
              RowBox[{"LongAxisFit", ",", 
               RowBox[{"{", 
                RowBox[{"a", ",", "b", ",", "0"}], "}"}]}], "]"}], "\[Equal]",
              "0"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"a", "^", "2"}], "+", 
              RowBox[{"b", "^", "2"}]}], "\[Equal]", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Ainit", "[", "1", "]"}], "=", 
        RowBox[{"-", 
         RowBox[{"LongAxisFit", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Binit", "[", "1", "]"}], "=", 
        RowBox[{"-", 
         RowBox[{"LongAxisFit", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Ainit", "[", "2", "]"}], "=", 
        RowBox[{
         RowBox[{"Cross", "[", 
          RowBox[{"IntermAxisFit", ",", "ShortAxisFit"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Binit", "[", "2", "]"}], "=", 
        RowBox[{
         RowBox[{"Cross", "[", 
          RowBox[{"IntermAxisFit", ",", "ShortAxisFit"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Ainit", "[", "3", "]"}], "=", 
        RowBox[{
         RowBox[{"Cross", "[", 
          RowBox[{"IntermAxisFit", ",", "ShortAxisFit"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Binit", "[", "3", "]"}], "=", 
        RowBox[{
         RowBox[{"Cross", "[", 
          RowBox[{"IntermAxisFit", ",", "ShortAxisFit"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"SolveAxes", "=", 
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"Dot", "[", 
              RowBox[{"ShortAxisFit", ",", 
               RowBox[{"{", 
                RowBox[{"a", ",", "b", ",", "0"}], "}"}]}], "]"}], "\[Equal]",
              "0"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"a", "^", "2"}], "+", 
              RowBox[{"b", "^", "2"}]}], "\[Equal]", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Ainit", "[", "1", "]"}], "=", 
        RowBox[{
         RowBox[{"Cross", "[", 
          RowBox[{"IntermAxisFit", ",", "LongAxisFit"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Binit", "[", "1", "]"}], "=", 
        RowBox[{
         RowBox[{"Cross", "[", 
          RowBox[{"IntermAxisFit", ",", "LongAxisFit"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Ainit", "[", "2", "]"}], "=", 
        RowBox[{
         RowBox[{"Cross", "[", 
          RowBox[{"IntermAxisFit", ",", "LongAxisFit"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Binit", "[", "2", "]"}], "=", 
        RowBox[{
         RowBox[{"Cross", "[", 
          RowBox[{"IntermAxisFit", ",", "LongAxisFit"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Ainit", "[", "3", "]"}], "=", 
        RowBox[{"-", 
         RowBox[{"ShortAxisFit", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Binit", "[", "3", "]"}], "=", 
        RowBox[{"-", 
         RowBox[{"ShortAxisFit", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LongPlanarFit", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IntermPlanarFit", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ShortPlanarFit", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"axesct", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"axesct", "\[LessEqual]", "3"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"axesct", "\[LessEqual]", "3"}], ",", "\n", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"axesct", "\[Equal]", "1"}], ",", 
            RowBox[{
             RowBox[{"current", "=", "LongCIAngle"}], ";"}], ",", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"axesct", "\[Equal]", "2"}], ",", 
               RowBox[{
                RowBox[{"current", "=", "IntermCIAngle"}], ";"}], ",", 
               RowBox[{
                RowBox[{"current", "=", "ShortCIAngle"}], ";"}]}], "]"}], 
             ";"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"current", ">", "PlanarFitThreshold"}], ",", "\n", 
            RowBox[{
             RowBox[{"Clear", "[", 
              RowBox[{"a", ",", "b"}], "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"FittingPlane", "[", "0", "]"}], "=", "0"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"While", "[", 
              RowBox[{
               RowBox[{"ct", "\[LessEqual]", "statnumb"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{
                 RowBox[{"FittingPlane", "[", "ct", "]"}], "=", 
                 RowBox[{
                  RowBox[{"FittingPlane", "[", 
                   RowBox[{"ct", "-", "1"}], "]"}], "+", 
                  RowBox[{"Abs", "[", 
                   RowBox[{"Dot", "[", 
                    RowBox[{
                    RowBox[{"Normalize", "[", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"axesct", "\[Equal]", "1"}], ",", "LongAxisStat", 
                    ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"axesct", "\[Equal]", "2"}], ",", 
                    "IntermAxisStat", ",", "ShortAxisStat"}], "]"}]}], "]"}], 
                    "[", "ct", "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"a", ",", "b", ",", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{"1", "-", 
                    RowBox[{"(", 
                    RowBox[{"a", "^", "2"}], ")"}], "-", 
                    RowBox[{"(", 
                    RowBox[{"b", "^", "2"}], ")"}]}], "]"}]}], "}"}]}], "]"}],
                    "]"}]}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"ct", "=", 
                 RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", "\n", 
             RowBox[{"Off", "[", 
              RowBox[{"FindMinimum", "::", "lstol"}], "]"}], ";", "\n", 
             "\[IndentingNewLine]", 
             RowBox[{"Quiet", "[", 
              RowBox[{
               RowBox[{"FindMinimum", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"FittingPlane", "[", "statnumb", "]"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"a", ",", 
                   RowBox[{"Ainit", "[", "axesct", "]"}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"b", ",", 
                   RowBox[{"Binit", "[", "axesct", "]"}]}], "}"}]}], "]"}], 
               ";", 
               RowBox[{"If", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Length", "[", "$MessageList", "]"}], ">", "0"}], 
                 ",", 
                 RowBox[{
                  RowBox[{"NoteBreaking", "=", 
                   RowBox[{"NoteBreaking", "+", "1"}]}], ";", 
                  RowBox[{"axesct", "=", 
                   RowBox[{"axesct", "+", "1"}]}], ";", " ", 
                  RowBox[{"Break", "[", "]"}]}]}], "]"}], ";"}], "]"}], ";", 
             "\n", "\[IndentingNewLine]", 
             RowBox[{"yupyup", "=", 
              RowBox[{"FindMinimum", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"FittingPlane", "[", "statnumb", "]"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"a", ",", 
                  RowBox[{"Ainit", "[", "axesct", "]"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"b", ",", 
                  RowBox[{"Binit", "[", "axesct", "]"}]}], "}"}]}], "]"}]}], 
             ";", "\n", "\n", 
             RowBox[{"PlaneFitError", "=", 
              RowBox[{
               RowBox[{"yupyup", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "/", "statnumb"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"FitPole", "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"yupyup", "[", 
                 RowBox[{"[", 
                  RowBox[{"2", ",", "1", ",", "2"}], "]"}], "]"}], ",", 
                RowBox[{"yupyup", "[", 
                 RowBox[{"[", 
                  RowBox[{"2", ",", "2", ",", "2"}], "]"}], "]"}], ",", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Im", "[", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{"1", "-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"yupyup", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "1", ",", "2"}], "]"}], "]"}], "^", 
                    "2"}], ")"}], "-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"yupyup", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "2", ",", "2"}], "]"}], "]"}], "^", 
                    "2"}], ")"}]}], "]"}], "]"}], "<", 
                   RowBox[{"10", "^", 
                    RowBox[{"-", "4"}]}]}], ",", 
                  RowBox[{"Re", "[", 
                   RowBox[{"Sqrt", "[", 
                    RowBox[{"1", "-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"yupyup", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "1", ",", "2"}], "]"}], "]"}], "^", 
                    "2"}], ")"}], "-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"yupyup", "[", 
                    RowBox[{"[", 
                    RowBox[{"2", ",", "2", ",", "2"}], "]"}], "]"}], "^", 
                    "2"}], ")"}]}], "]"}], "]"}]}], "]"}]}], "}"}]}], ";", 
             "\[IndentingNewLine]", "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"axesct", "\[Equal]", "1"}], ",", 
               RowBox[{
                RowBox[{"LongMeanDiff", "=", " ", 
                 RowBox[{"Mean", "[", 
                  RowBox[{"Table", "[", 
                   RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"90", "-", 
                    RowBox[{
                    RowBox[{"ArcCos", "[", 
                    RowBox[{"Dot", "[", 
                    RowBox[{
                    RowBox[{"Normalize", "[", 
                    RowBox[{"LongAxisStat", "[", "x", "]"}], "]"}], ",", 
                    RowBox[{"Normalize", "[", "FitPole", "]"}]}], "]"}], 
                    "]"}], "*", 
                    RowBox[{"180", "/", "Pi"}]}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], 
                  "]"}]}], ";"}], ",", 
               RowBox[{
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"axesct", "\[Equal]", "2"}], ",", 
                  RowBox[{
                   RowBox[{"IntermMeanDiff", "=", 
                    RowBox[{"Mean", "[", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"90", "-", 
                    RowBox[{
                    RowBox[{"ArcCos", "[", 
                    RowBox[{"Dot", "[", 
                    RowBox[{
                    RowBox[{"Normalize", "[", 
                    RowBox[{"IntermAxisStat", "[", "x", "]"}], "]"}], ",", 
                    RowBox[{"Normalize", "[", "FitPole", "]"}]}], "]"}], 
                    "]"}], "*", 
                    RowBox[{"180", "/", "Pi"}]}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], 
                    "]"}]}], ";"}], ",", 
                  RowBox[{
                   RowBox[{"ShortMeanDiff", "=", 
                    RowBox[{"Mean", "[", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"90", "-", 
                    RowBox[{
                    RowBox[{"ArcCos", "[", 
                    RowBox[{"Dot", "[", 
                    RowBox[{
                    RowBox[{"Normalize", "[", 
                    RowBox[{"ShortAxisStat", "[", "x", "]"}], "]"}], ",", 
                    RowBox[{"Normalize", "[", "FitPole", "]"}]}], "]"}], 
                    "]"}], "*", 
                    RowBox[{"180", "/", "Pi"}]}]}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], 
                    "]"}]}], ";"}]}], "]"}], ";"}]}], "]"}], ";", "\n", 
             "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"axesct", "\[Equal]", "1"}], ",", 
               RowBox[{
                RowBox[{"cur", "=", "LongMeanDiff"}], ";"}], ",", 
               RowBox[{
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"axesct", "\[Equal]", "2"}], ",", 
                  RowBox[{
                   RowBox[{"cur", "=", "IntermMeanDiff"}], ";"}], ",", 
                  RowBox[{
                   RowBox[{"cur", "=", "ShortMeanDiff"}], ";"}]}], "]"}], 
                ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"cur", "<", "MeanDiffThreshold"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"axesct", "\[Equal]", "1"}], ",", 
                  RowBox[{
                   RowBox[{"LongPlanarFit", "=", "1"}], ";"}], ",", 
                  RowBox[{
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"axesct", "\[Equal]", "2"}], ",", 
                    RowBox[{
                    RowBox[{"IntermPlanarFit", "=", "1"}], ";"}], ",", 
                    RowBox[{
                    RowBox[{"ShortPlanarFit", "=", "1"}], ";"}]}], "]"}], 
                   ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", "\n", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "\[Equal]", "0"}]}], ",", 
                  RowBox[{
                   RowBox[{"FPlunge", "=", "90"}], ";"}], ",", 
                  RowBox[{
                   RowBox[{"FPlunge", "=", 
                    RowBox[{
                    FractionBox["1", "\[Pi]"], 
                    RowBox[{"ArcTan", "[", 
                    FractionBox[
                    RowBox[{"Abs", "[", 
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "]"}], 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "2"], "+", 
                    SuperscriptBox[
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "2"]}]]], "]"}], " ", 
                    "180"}]}], ";"}]}], "]"}], ";", "\n", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                   "FitPole", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "\[Equal]", "0"}], ",", 
                  RowBox[{
                   RowBox[{"Tl", "=", "90"}], ";"}], ",", 
                  RowBox[{
                   RowBox[{"Tl", "=", 
                    RowBox[{"Abs", "[", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"ArcTan", "[", 
                    FractionBox[
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], 
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]], "]"}], " ", "180"}], "\[Pi]"],
                     "]"}]}], ";"}]}], "]"}], ";", "\n", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], 
                  ",", 
                  RowBox[{"FTrend", "=", 
                   RowBox[{"180", "-", "Tl"}]}]}], "]"}], ";", "\n", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], 
                  ",", 
                  RowBox[{"FTrend", "=", "Tl"}]}], "]"}], ";", "\n", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], 
                  ",", 
                  RowBox[{"FTrend", "=", 
                   RowBox[{"360", "-", "Tl"}]}]}], "]"}], ";", "\n", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], 
                  ",", 
                  RowBox[{"FTrend", "=", 
                   RowBox[{"180", "+", "Tl"}]}]}], "]"}], ";", "\n", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
                  RowBox[{"FTrend", "=", 
                   RowBox[{"360", "-", "Tl"}]}]}], "]"}], ";", "\n", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
                  RowBox[{"FTrend", "=", 
                   RowBox[{"180", "+", "Tl"}]}]}], "]"}], ";", "\n", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
                  RowBox[{"FTrend", "=", 
                   RowBox[{"180", "-", "Tl"}]}]}], "]"}], ";", "\n", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
                  RowBox[{"FTrend", "=", "Tl"}]}], "]"}], ";", "\n", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "\[LessEqual]", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "\[LessEqual]", "0"}]}], ",", 
                  RowBox[{"FTrend", "=", "90"}]}], "]"}], ";", "\n", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "\[GreaterEqual]", "0"}]}], 
                  ",", 
                  RowBox[{"FTrend", "=", "90"}]}], "]"}], ";", "\n", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "<", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], ">", "0"}]}], ",", 
                  RowBox[{"FTrend", "=", "270"}]}], "]"}], ";", "\n", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], ">", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "3", 
                    "\[RightDoubleBracket]"}], "<", "0"}]}], ",", 
                  RowBox[{"FTrend", "=", "270"}]}], "]"}], ";", "\n", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "\[Equal]", "0"}], "&&", 
                   RowBox[{
                    RowBox[{
                    "FitPole", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "\[Equal]", "0"}]}], ",", 
                  RowBox[{
                   RowBox[{"FPlunge", "=", "90"}], ";", 
                   RowBox[{"FTrend", "=", "\"\<NA\>\""}]}]}], "]"}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"StrikeAngle", "[", "ct2", "]"}], "=", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"FTrend", "+", "90"}], ")"}], ">", "360"}], ",", 
                   RowBox[{"FTrend", "-", "270"}], ",", 
                   RowBox[{"FTrend", "+", "90"}]}], "]"}]}], ";", "\n", 
                RowBox[{
                 RowBox[{"DipAngle", "[", "ct2", "]"}], "=", 
                 RowBox[{"90", "-", "FPlunge"}]}], ";", "\n", 
                "\[IndentingNewLine]", 
                RowBox[{"RotMat", "=", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"StrikeAngle", "[", "ct2", "]"}], "\[Degree]"}], 
                    "]"}], ",", 
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"StrikeAngle", "[", "ct2", "]"}], "\[Degree]"}], 
                    "]"}]}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"StrikeAngle", "[", "ct2", "]"}], "\[Degree]"}], 
                    "]"}], ",", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"StrikeAngle", "[", "ct2", "]"}], "\[Degree]"}], 
                    "]"}]}], "}"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"ct", "=", "0"}], ";", "\[IndentingNewLine]", 
                RowBox[{"While", "[", 
                 RowBox[{
                  RowBox[{"ct", "\[LessEqual]", "curveresolution"}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{"iterator", "=", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"180", 
                    RowBox[{"\[Degree]", "/", "curveresolution"}]}], ")"}], 
                    "*", "ct"}]}], ";", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"vect", "[", "ct", "]"}], "=", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Sin", "[", "iterator", "]"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"DipAngle", "[", "ct2", "]"}], "\[Degree]"}], 
                    "]"}]}], ",", " ", 
                    RowBox[{"Cos", "[", "iterator", "]"}], ",", " ", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Sin", "[", "iterator", "]"}]}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"DipAngle", "[", "ct2", "]"}], "\[Degree]"}], 
                    "]"}]}]}], "}"}]}], ";", "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"vectprime", "[", "ct", "]"}], "=", 
                    RowBox[{"lowerHemisphere", "[", 
                    RowBox[{"vect", "[", "ct", "]"}], "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"prerotpt", "[", "ct", "]"}], "=", 
                    RowBox[{"equalAreaProjection", "[", 
                    RowBox[{"vectprime", "[", "ct", "]"}], "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"pt", "[", "ct", "]"}], "=", 
                    RowBox[{
                    RowBox[{"prerotpt", "[", "ct", "]"}], ".", "RotMat"}]}], 
                   ";", "\[IndentingNewLine]", 
                   RowBox[{"ct", "=", 
                    RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"FitDipDir", "[", "axesct", "]"}], "=", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"StrikeAngle", "[", "ct2", "]"}], "+", "90"}], 
                    "\[GreaterEqual]", "360"}], ",", 
                   RowBox[{
                    RowBox[{"StrikeAngle", "[", "ct2", "]"}], "-", "270"}], 
                   ",", 
                   RowBox[{
                    RowBox[{"StrikeAngle", "[", "ct2", "]"}], "+", "90"}]}], 
                  "]"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"FitDip", "[", "axesct", "]"}], "=", 
                 RowBox[{"DipAngle", "[", "ct2", "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"GreatCircle", "[", "axesct", "]"}], "=", 
                 RowBox[{"Show", "[", 
                  RowBox[{"Graphics", "[", 
                   RowBox[{"{", 
                    RowBox[{"greatcolor", ",", 
                    RowBox[{"Thickness", "[", "greatthickness", "]"}], ",", 
                    RowBox[{"Line", "[", 
                    RowBox[{"Table", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"pt", "[", "x", "]"}], ",", " ", 
                    RowBox[{"pt", "[", 
                    RowBox[{"x", " ", "+", " ", "1"}], "]"}]}], "}"}], ",", 
                    " ", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", " ", "0", ",", 
                    RowBox[{"curveresolution", "-", "1"}]}], "}"}]}], "]"}], 
                    "]"}]}], "}"}], "]"}], "]"}]}], ";"}]}], "]"}], ";"}]}], 
           "]"}], ";", 
          RowBox[{"axesct", "=", 
           RowBox[{"axesct", "+", "1"}]}], ";"}]}], "]"}], ";"}]}], "]"}], 
    ";"}], "\n", "\[IndentingNewLine]", "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"new", " ", "contouring"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LongStatTabby", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"LTrendStat", "[", "x", "]"}], ",", 
         RowBox[{"LPlungeStat", "[", "x", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LongXYcoords", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"equalAreaProjection", "[", 
        RowBox[{"lowerHemisphere", "[", 
         RowBox[{"cartesianFromTrendPlungeDeg", "[", 
          RowBox[{"LongStatTabby", "[", 
           RowBox[{"[", "x", "]"}], "]"}], "]"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"CountingCircleRadius", "=", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"2", "*", "0.01", "*", "ContouringPercent"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"HalfNumbGraticules", "=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Sqrt", "[", "2", "]"}], "/", 
            RowBox[{"(", 
             RowBox[{"GridDensity", "*", "CountingCircleRadius"}], ")"}]}], 
           ")"}]}], ")"}], ">", 
        RowBox[{"Round", "[", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Sqrt", "[", "2", "]"}], "/", 
             RowBox[{"(", 
              RowBox[{"GridDensity", "*", "CountingCircleRadius"}], ")"}]}], 
            ")"}]}], ")"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Round", "[", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Sqrt", "[", "2", "]"}], "/", 
             RowBox[{"(", 
              RowBox[{"GridDensity", "*", "CountingCircleRadius"}], ")"}]}], 
            ")"}]}], ")"}], "]"}], "+", "1"}], ",", 
       RowBox[{"Round", "[", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Sqrt", "[", "2", "]"}], "/", 
            RowBox[{"(", 
             RowBox[{"GridDensity", "*", "CountingCircleRadius"}], ")"}]}], 
           ")"}]}], ")"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SqrGridNumb", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"HalfNumbGraticules", "*", "2"}], "+", "1"}], ")"}], "^", 
      "2"}]}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"ct4", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct1", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct1", "\[LessEqual]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"HalfNumbGraticules", "*", "2"}], "+", "1"}], ")"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ct2", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"ct2", "\[LessEqual]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"HalfNumbGraticules", "*", "2"}], "+", "1"}], ")"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"GridCoords", "[", "ct4", "]"}], "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "HalfNumbGraticules"}], "*", 
                RowBox[{"(", 
                 RowBox[{"GridDensity", "*", "CountingCircleRadius"}], 
                 ")"}]}], ")"}], "+", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"ct1", "-", "1"}], ")"}], "*", 
                RowBox[{"(", 
                 RowBox[{"GridDensity", "*", "CountingCircleRadius"}], 
                 ")"}]}], ")"}]}], ",", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "HalfNumbGraticules"}], "*", 
                RowBox[{"(", 
                 RowBox[{"GridDensity", "*", "CountingCircleRadius"}], 
                 ")"}]}], ")"}], "+", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"ct2", "-", "1"}], ")"}], "*", 
                RowBox[{"(", 
                 RowBox[{"GridDensity", "*", "CountingCircleRadius"}], 
                 ")"}]}], ")"}]}]}], "}"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"ct4", "=", 
           RowBox[{"ct4", "+", "1"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"ct2", "=", 
           RowBox[{"ct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ct1", "=", 
        RowBox[{"ct1", "+", "1"}]}], ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"GridTabby", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"GridCoords", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", 
         RowBox[{"ct4", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"nf", "=", 
     RowBox[{"Nearest", "@", "LongXYcoords"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct6", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct6", "\[LessEqual]", "SqrGridNumb"}], ",", "\n", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"GridTabby", "[", 
                RowBox[{"[", 
                 RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "^", "2"}], ")"}], 
             "+", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"GridTabby", "[", 
                RowBox[{"[", 
                 RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "^", "2"}], ")"}]}],
             "]"}], "<", 
           RowBox[{"(", 
            RowBox[{"CountingCircleRadius", "+", 
             RowBox[{"Sqrt", "[", "2", "]"}]}], ")"}]}], "&&", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"GridTabby", "[", 
                RowBox[{"[", 
                 RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "^", "2"}], ")"}], 
             "+", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"GridTabby", "[", 
                RowBox[{"[", 
                 RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "^", "2"}], ")"}]}],
             "]"}], ">", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Sqrt", "[", "2", "]"}], "-", "CountingCircleRadius"}], 
            ")"}]}]}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"firstGridVal", "=", 
           RowBox[{
            RowBox[{"Dimensions", "[", 
             RowBox[{"nf", "[", 
              RowBox[{
               RowBox[{"GridTabby", "[", 
                RowBox[{"[", "ct6", "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Infinity]", ",", "CountingCircleRadius"}], "}"}]}],
               "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"GridTabby", "[", 
              RowBox[{"[", 
               RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "\[Equal]", "0"}], 
            ",", 
            RowBox[{
             RowBox[{"xAcross", "=", "0"}], ";", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"GridTabby", "[", 
                 RowBox[{"[", 
                  RowBox[{"ct6", ",", "2"}], "]"}], "]"}], ">", "0"}], ",", 
               RowBox[{
                RowBox[{"yAcross", "=", 
                 RowBox[{
                  RowBox[{"GridTabby", "[", 
                   RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "-", 
                  RowBox[{"2", "*", 
                   RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], ";"}], ",", 
               RowBox[{
                RowBox[{"yAcross", "=", 
                 RowBox[{
                  RowBox[{"GridTabby", "[", 
                   RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "+", 
                  RowBox[{"2", "*", 
                   RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], ";"}]}], "]"}], 
             ";"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"GridTabby", "[", 
                 RowBox[{"[", 
                  RowBox[{"ct6", ",", "1"}], "]"}], "]"}], ">", "0"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"xAcross", "=", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", 
                    RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "^", "2"}], 
                    ")"}], "+", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "^", "2"}], 
                    ")"}]}], "]"}]}], ")"}]}], "*", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "/", 
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}]}], "]"}], 
                   "]"}]}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"yAcross", "=", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", 
                    RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "^", "2"}], 
                    ")"}], "+", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "^", "2"}], 
                    ")"}]}], "]"}]}], ")"}]}], "*", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "/", 
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}]}], "]"}], 
                   "]"}]}]}], ";"}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"xAcross", "=", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", "*", 
                    RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "^", "2"}], 
                    ")"}], "+", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "^", "2"}], 
                    ")"}]}], "]"}]}], ")"}], "*", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "/", 
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}]}], "]"}], 
                   "]"}]}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"yAcross", "=", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", "*", 
                    RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "^", "2"}], 
                    ")"}], "+", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "^", "2"}], 
                    ")"}]}], "]"}]}], ")"}], "*", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "/", 
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}]}], "]"}], 
                   "]"}]}]}], ";"}]}], "]"}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"secondGridVal", "=", 
           RowBox[{
            RowBox[{"Dimensions", "[", 
             RowBox[{"nf", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"xAcross", ",", "yAcross"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Infinity]", ",", "CountingCircleRadius"}], "}"}]}],
               "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"GridValue", "[", "ct6", "]"}], "=", 
           RowBox[{"firstGridVal", "+", "secondGridVal"}]}], ";"}], ",", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"GridValue", "[", "ct6", "]"}], "=", 
           RowBox[{
            RowBox[{"Dimensions", "[", 
             RowBox[{"nf", "[", 
              RowBox[{
               RowBox[{"GridTabby", "[", 
                RowBox[{"[", "ct6", "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Infinity]", ",", "CountingCircleRadius"}], "}"}]}],
               "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ct6", "=", 
        RowBox[{"ct6", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ContourableValues", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"GridTabby", "[", 
           RowBox[{"[", "x", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"GridTabby", "[", 
           RowBox[{"[", "x", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", 
         RowBox[{"GridValue", "[", "x", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "SqrGridNumb"}], "}"}]}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ct7", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct7", "\[LessEqual]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"HalfNumbGraticules", "*", "2"}], "+", "1"}], ")"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"ContVals", "[", "ct7", "]"}], "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"ContourableValues", "[", 
           RowBox[{"[", 
            RowBox[{"x", ",", "3"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"ct7", "-", "1"}], ")"}], "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"HalfNumbGraticules", "*", "2"}], "+", "1"}], 
                 ")"}]}], ")"}], "+", "1"}], ")"}], ",", 
            RowBox[{"ct7", "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"HalfNumbGraticules", "*", "2"}], "+", "1"}], 
              ")"}]}]}], "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"ct7", "=", 
        RowBox[{"ct7", "+", "1"}]}], ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"f", "=", 
     RowBox[{"ListInterpolation", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"ContVals", "[", "x", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "1", ",", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"HalfNumbGraticules", "*", "2"}], "+", "1"}], ")"}]}], 
          "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"GridTabby", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"Abs", "[", 
            RowBox[{"GridTabby", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"GridTabby", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"Abs", "[", 
            RowBox[{"GridTabby", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}]}], 
        "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"PercentVals", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ContVals", "[", "x", "]"}], "*", "100"}], ")"}], "/", 
         "statnumb"}], ")"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"HalfNumbGraticules", "*", "2"}], "+", "1"}], ")"}]}], 
        "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MaxGridVal", "=", 
     RowBox[{"Max", "[", "PercentVals", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct8", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct9", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct8", "\[LessEqual]", "SqrGridNumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"ContourableValues", "[", 
              RowBox[{"[", 
               RowBox[{"ct8", ",", "1"}], "]"}], "]"}], "^", "2"}], ")"}], 
           "+", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"ContourableValues", "[", 
              RowBox[{"[", 
               RowBox[{"ct8", ",", "2"}], "]"}], "]"}], "^", "2"}], ")"}]}], 
          "\[LessEqual]", "2"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"InCircle", "[", "ct9", "]"}], "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"ContourableValues", "[", 
               RowBox[{"[", 
                RowBox[{"ct8", ",", "3"}], "]"}], "]"}], "*", "100"}], ")"}], 
            "/", "statnumb"}]}], ";", 
          RowBox[{"ct9", "=", 
           RowBox[{"ct9", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ct8", "=", 
        RowBox[{"ct8", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"InCircleDim", "=", 
     RowBox[{"ct9", "-", "1"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"MaxInCircle", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"InCircle", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", "InCircleDim"}], "}"}]}], "]"}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MinInCircle", "=", 
     RowBox[{"Min", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"InCircle", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", "InCircleDim"}], "}"}]}], "]"}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"InCircleRange", "=", 
     RowBox[{"MaxInCircle", "-", "MinInCircle"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TempContInt", "=", 
     RowBox[{"InCircleRange", "/", 
      RowBox[{"(", 
       RowBox[{"NumberOfContours", "+", "1"}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ContoursTabby", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"MinInCircle", "+", 
        RowBox[{"TempContInt", "*", "x"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "NumberOfContours"}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ContTabby", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ContoursTabby", "[", 
            RowBox[{"[", "x", "]"}], "]"}], "*", "statnumb"}], ")"}], "/", 
         "100"}], ")"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "NumberOfContours"}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "MaxContVal", "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ContColorStart", "=", 
     RowBox[{"0.2675", "*", 
      RowBox[{"NumberOfContours", "^", 
       RowBox[{"(", 
        RowBox[{"-", "0.611"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TempContPlot", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"GridTabby", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"Abs", "[", 
          RowBox[{"GridTabby", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"GridTabby", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"Abs", "[", 
          RowBox[{"GridTabby", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"Contours", "\[Rule]", "ContTabby"}], ",", 
       RowBox[{"ContourShading", "\[Rule]", "True"}], ",", 
       RowBox[{"Frame", "\[Rule]", "False"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"DisplayFunction", "\[Rule]", "Identity"}], ",", 
       RowBox[{"BoundaryStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"Thickness", "[", ".003", "]"}]}], "}"}]}], ",", 
       RowBox[{"RegionFunction", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"x", "^", "2"}], "+", 
            RowBox[{"y", "^", "2"}]}], "<", "2"}]}], "]"}]}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "20"}], ",", 
       RowBox[{"ContourStyle", "\[Rule]", 
        RowBox[{"Opacity", "[", ".30", "]"}]}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"f", ",", 
          RowBox[{
           RowBox[{"temp", "=", "f"}], ";", 
           RowBox[{"Opacity", "[", 
            RowBox[{"1.0", ",", 
             RowBox[{"GrayLevel", "[", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"(", 
                 RowBox[{"f", "-", "ContColorStart"}], ")"}]}], ")"}], 
              "]"}]}], "]"}]}]}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"MaxColorLevel", "=", "0.15"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"percent", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"MaxColorLevel", "-", "MaxContVal"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "MaxContVal"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MaxContVal", "=", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"(", 
        RowBox[{"temp", "-", "ContColorStart"}], ")"}]}], ")"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"intvl", "=", 
     RowBox[{"0.5447", "*", 
      RowBox[{"NumberOfContours", "^", 
       RowBox[{"(", 
        RowBox[{"-", "0.797"}], ")"}]}]}]}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ContPlot", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"GridTabby", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"Abs", "[", 
          RowBox[{"GridTabby", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"GridTabby", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"Abs", "[", 
          RowBox[{"GridTabby", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"Contours", "\[Rule]", "ContTabby"}], ",", 
       RowBox[{"ContourShading", "\[Rule]", "True"}], ",", 
       RowBox[{"Frame", "\[Rule]", "False"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"DisplayFunction", "\[Rule]", "Identity"}], ",", 
       RowBox[{"BoundaryStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"Thickness", "[", ".003", "]"}]}], "}"}]}], ",", 
       RowBox[{"RegionFunction", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"x", "^", "2"}], "+", 
            RowBox[{"y", "^", "2"}]}], "<", "2"}]}], "]"}]}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "20"}], ",", 
       RowBox[{"ContourStyle", "\[Rule]", 
        RowBox[{"Opacity", "[", ".30", "]"}]}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"f", ",", 
          RowBox[{"Opacity", "[", 
           RowBox[{"1.0", ",", 
            RowBox[{"GrayLevel", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"(", 
                 RowBox[{"f", "-", "ContColorStart"}], ")"}]}], ")"}], "+", 
              RowBox[{"percent", "*", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   RowBox[{"(", 
                    RowBox[{"f", "-", "ContColorStart"}], ")"}]}], ")"}]}], 
                ")"}]}]}], "]"}]}], "]"}]}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LongFit", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"equalAreaPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"cartesianFromTrendPlungeDeg", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"FitTrendLong", "\[Equal]", "\"\<NA\>\""}], ",", "000", 
              ",", "FitTrendLong"}], "]"}], ",", "FitPlungeLong"}], "}"}], 
          "]"}], "}"}], ",", " ", 
        RowBox[{"FitSizePercent", "*", "ptsize"}], ",", "Red"}], "]"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LgMean", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"equalAreaPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"cartesianFromTrendPlungeDeg", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"LTrendMean", "\[Equal]", "\"\<NA\>\""}], ",", "000", 
              ",", "LTrendMean"}], "]"}], ",", "LPlungeMean"}], "}"}], "]"}], 
         "}"}], ",", " ", 
        RowBox[{"MeanSizePercent", "*", "ptsize"}], ",", "Blue"}], "]"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"LongPlanarFit", "\[Equal]", "1"}], ",", 
      RowBox[{
       RowBox[{"LongContStatPlot", "=", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{"N", " ", "==", " ", 
                 RowBox[{"(", "statnumb", ")"}]}], ",", 
                RowBox[{"FontSize", "\[Rule]", "20"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1.3"}], ",", 
                RowBox[{"-", "1.6"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Equal Area Projection\>\"", ",", 
                RowBox[{"FontSize", "\[Rule]", "20"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1.9"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
          "ContPlot", ",", 
          RowBox[{"GreatCircle", "[", "1", "]"}], ",", 
          RowBox[{"equalAreaPlot", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"cartesianFromTrendPlungeDeg", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"LTrendStat", "[", "x", "]"}], ",", 
                 RowBox[{"LPlungeStat", "[", "x", "]"}]}], "}"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], ",", 
            " ", "ptsize", ",", "Black"}], "]"}], ",", "LongFit", ",", 
          "LgMean", ",", 
          RowBox[{"PlotLabel", "\[Rule]", 
           RowBox[{"Style", "[", 
            RowBox[{
            "\"\<Long Axes Orientations\>\"", ",", "24", ",", "Blue", ",", 
             "Bold"}], "]"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], ";"}], ",", 
      RowBox[{
       RowBox[{"LongContStatPlot", "=", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{"N", " ", "==", " ", 
                 RowBox[{"(", "statnumb", ")"}]}], ",", 
                RowBox[{"FontSize", "\[Rule]", "20"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1.3"}], ",", 
                RowBox[{"-", "1.6"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Equal Area Projection\>\"", ",", 
                RowBox[{"FontSize", "\[Rule]", "20"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1.9"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
          "ContPlot", ",", 
          RowBox[{"equalAreaPlot", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"cartesianFromTrendPlungeDeg", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"LTrendStat", "[", "x", "]"}], ",", 
                 RowBox[{"LPlungeStat", "[", "x", "]"}]}], "}"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], ",", 
            " ", "ptsize", ",", "Black"}], "]"}], ",", "LongFit", ",", 
          "LgMean", ",", 
          RowBox[{"PlotLabel", "\[Rule]", 
           RowBox[{"Style", "[", 
            RowBox[{
            "\"\<Long Axes Orientations\>\"", ",", "24", ",", "Blue", ",", 
             "Bold"}], "]"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], ";"}]}], "]"}], 
    ";"}], "\n", "\[IndentingNewLine]", "\[IndentingNewLine]", "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IntermStatTabby", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"ITrendStat", "[", "x", "]"}], ",", 
         RowBox[{"IPlungeStat", "[", "x", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"IntermXYcoords", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"equalAreaProjection", "[", 
        RowBox[{"lowerHemisphere", "[", 
         RowBox[{"cartesianFromTrendPlungeDeg", "[", 
          RowBox[{"IntermStatTabby", "[", 
           RowBox[{"[", "x", "]"}], "]"}], "]"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"nf", "=", 
     RowBox[{"Nearest", "@", "IntermXYcoords"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct6", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct6", "\[LessEqual]", "SqrGridNumb"}], ",", "\n", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"GridTabby", "[", 
                RowBox[{"[", 
                 RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "^", "2"}], ")"}], 
             "+", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"GridTabby", "[", 
                RowBox[{"[", 
                 RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "^", "2"}], ")"}]}],
             "]"}], "<", 
           RowBox[{"(", 
            RowBox[{"CountingCircleRadius", "+", 
             RowBox[{"Sqrt", "[", "2", "]"}]}], ")"}]}], "&&", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"GridTabby", "[", 
                RowBox[{"[", 
                 RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "^", "2"}], ")"}], 
             "+", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"GridTabby", "[", 
                RowBox[{"[", 
                 RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "^", "2"}], ")"}]}],
             "]"}], ">", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Sqrt", "[", "2", "]"}], "-", "CountingCircleRadius"}], 
            ")"}]}]}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"firstGridVal", "=", 
           RowBox[{
            RowBox[{"Dimensions", "[", 
             RowBox[{"nf", "[", 
              RowBox[{
               RowBox[{"GridTabby", "[", 
                RowBox[{"[", "ct6", "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Infinity]", ",", "CountingCircleRadius"}], "}"}]}],
               "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"GridTabby", "[", 
              RowBox[{"[", 
               RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "\[Equal]", "0"}], 
            ",", 
            RowBox[{
             RowBox[{"xAcross", "=", "0"}], ";", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"GridTabby", "[", 
                 RowBox[{"[", 
                  RowBox[{"ct6", ",", "2"}], "]"}], "]"}], ">", "0"}], ",", 
               RowBox[{
                RowBox[{"yAcross", "=", 
                 RowBox[{
                  RowBox[{"GridTabby", "[", 
                   RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "-", 
                  RowBox[{"2", "*", 
                   RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], ";"}], ",", 
               RowBox[{
                RowBox[{"yAcross", "=", 
                 RowBox[{
                  RowBox[{"GridTabby", "[", 
                   RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "+", 
                  RowBox[{"2", "*", 
                   RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], ";"}]}], "]"}], 
             ";"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"GridTabby", "[", 
                 RowBox[{"[", 
                  RowBox[{"ct6", ",", "1"}], "]"}], "]"}], ">", "0"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"xAcross", "=", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", 
                    RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "^", "2"}], 
                    ")"}], "+", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "^", "2"}], 
                    ")"}]}], "]"}]}], ")"}]}], "*", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "/", 
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}]}], "]"}], 
                   "]"}]}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"yAcross", "=", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", 
                    RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "^", "2"}], 
                    ")"}], "+", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "^", "2"}], 
                    ")"}]}], "]"}]}], ")"}]}], "*", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "/", 
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}]}], "]"}], 
                   "]"}]}]}], ";"}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"xAcross", "=", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", "*", 
                    RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "^", "2"}], 
                    ")"}], "+", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "^", "2"}], 
                    ")"}]}], "]"}]}], ")"}], "*", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "/", 
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}]}], "]"}], 
                   "]"}]}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"yAcross", "=", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", "*", 
                    RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "^", "2"}], 
                    ")"}], "+", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "^", "2"}], 
                    ")"}]}], "]"}]}], ")"}], "*", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "/", 
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}]}], "]"}], 
                   "]"}]}]}], ";"}]}], "]"}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"secondGridVal", "=", 
           RowBox[{
            RowBox[{"Dimensions", "[", 
             RowBox[{"nf", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"xAcross", ",", "yAcross"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Infinity]", ",", "CountingCircleRadius"}], "}"}]}],
               "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"GridValue", "[", "ct6", "]"}], "=", 
           RowBox[{"firstGridVal", "+", "secondGridVal"}]}], ";"}], ",", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"GridValue", "[", "ct6", "]"}], "=", 
           RowBox[{
            RowBox[{"Dimensions", "[", 
             RowBox[{"nf", "[", 
              RowBox[{
               RowBox[{"GridTabby", "[", 
                RowBox[{"[", "ct6", "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Infinity]", ",", "CountingCircleRadius"}], "}"}]}],
               "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ct6", "=", 
        RowBox[{"ct6", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ContourableValues", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"GridTabby", "[", 
           RowBox[{"[", "x", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"GridTabby", "[", 
           RowBox[{"[", "x", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", 
         RowBox[{"GridValue", "[", "x", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "SqrGridNumb"}], "}"}]}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ct7", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct7", "\[LessEqual]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"HalfNumbGraticules", "*", "2"}], "+", "1"}], ")"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"ContVals", "[", "ct7", "]"}], "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"ContourableValues", "[", 
           RowBox[{"[", 
            RowBox[{"x", ",", "3"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"ct7", "-", "1"}], ")"}], "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"HalfNumbGraticules", "*", "2"}], "+", "1"}], 
                 ")"}]}], ")"}], "+", "1"}], ")"}], ",", 
            RowBox[{"ct7", "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"HalfNumbGraticules", "*", "2"}], "+", "1"}], 
              ")"}]}]}], "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"ct7", "=", 
        RowBox[{"ct7", "+", "1"}]}], ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"f", "=", 
     RowBox[{"ListInterpolation", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"ContVals", "[", "x", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "1", ",", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"HalfNumbGraticules", "*", "2"}], "+", "1"}], ")"}]}], 
          "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"GridTabby", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"Abs", "[", 
            RowBox[{"GridTabby", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"GridTabby", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"Abs", "[", 
            RowBox[{"GridTabby", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}]}], 
        "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"PercentVals", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ContVals", "[", "x", "]"}], "*", "100"}], ")"}], "/", 
         "statnumb"}], ")"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"HalfNumbGraticules", "*", "2"}], "+", "1"}], ")"}]}], 
        "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MaxGridVal", "=", 
     RowBox[{"Max", "[", "PercentVals", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct8", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct9", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct8", "\[LessEqual]", "SqrGridNumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"ContourableValues", "[", 
              RowBox[{"[", 
               RowBox[{"ct8", ",", "1"}], "]"}], "]"}], "^", "2"}], ")"}], 
           "+", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"ContourableValues", "[", 
              RowBox[{"[", 
               RowBox[{"ct8", ",", "2"}], "]"}], "]"}], "^", "2"}], ")"}]}], 
          "\[LessEqual]", "2"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"InCircle", "[", "ct9", "]"}], "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"ContourableValues", "[", 
               RowBox[{"[", 
                RowBox[{"ct8", ",", "3"}], "]"}], "]"}], "*", "100"}], ")"}], 
            "/", "statnumb"}]}], ";", 
          RowBox[{"ct9", "=", 
           RowBox[{"ct9", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ct8", "=", 
        RowBox[{"ct8", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"InCircleDim", "=", 
     RowBox[{"ct9", "-", "1"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"MaxInCircle", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"InCircle", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", "InCircleDim"}], "}"}]}], "]"}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MinInCircle", "=", 
     RowBox[{"Min", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"InCircle", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", "InCircleDim"}], "}"}]}], "]"}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"InCircleRange", "=", 
     RowBox[{"MaxInCircle", "-", "MinInCircle"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IntermTempContInt", "=", 
     RowBox[{"InCircleRange", "/", 
      RowBox[{"(", 
       RowBox[{"NumberOfContours", "+", "1"}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"IntermContoursTabby", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"MinInCircle", "+", 
        RowBox[{"IntermTempContInt", "*", "x"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "NumberOfContours"}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IntermContTabby", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"IntermContoursTabby", "[", 
            RowBox[{"[", "x", "]"}], "]"}], "*", "statnumb"}], ")"}], "/", 
         "100"}], ")"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "NumberOfContours"}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", "MaxContVal", "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ContColorStart", "=", 
     RowBox[{"0.2675", "*", 
      RowBox[{"NumberOfContours", "^", 
       RowBox[{"(", 
        RowBox[{"-", "0.611"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TempContPlot", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"GridTabby", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"Abs", "[", 
          RowBox[{"GridTabby", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"GridTabby", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"Abs", "[", 
          RowBox[{"GridTabby", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"Contours", "\[Rule]", "IntermContTabby"}], ",", 
       RowBox[{"ContourShading", "\[Rule]", "True"}], ",", 
       RowBox[{"Frame", "\[Rule]", "False"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"DisplayFunction", "\[Rule]", "Identity"}], ",", 
       RowBox[{"BoundaryStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"Thickness", "[", ".003", "]"}]}], "}"}]}], ",", 
       RowBox[{"RegionFunction", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"x", "^", "2"}], "+", 
            RowBox[{"y", "^", "2"}]}], "<", "2"}]}], "]"}]}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "20"}], ",", 
       RowBox[{"ContourStyle", "\[Rule]", 
        RowBox[{"Opacity", "[", ".30", "]"}]}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"f", ",", 
          RowBox[{
           RowBox[{"temp", "=", "f"}], ";", 
           RowBox[{"Opacity", "[", 
            RowBox[{"1.0", ",", 
             RowBox[{"GrayLevel", "[", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"(", 
                 RowBox[{"f", "-", "ContColorStart"}], ")"}]}], ")"}], 
              "]"}]}], "]"}]}]}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"MaxColorLevel", "=", "0.15"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"percent", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"MaxColorLevel", "-", "MaxContVal"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "MaxContVal"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MaxContVal", "=", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"(", 
        RowBox[{"temp", "-", "ContColorStart"}], ")"}]}], ")"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"intvl", "=", 
     RowBox[{"0.5447", "*", 
      RowBox[{"NumberOfContours", "^", 
       RowBox[{"(", 
        RowBox[{"-", "0.797"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   "\n", 
   RowBox[{
    RowBox[{"IntermContPlot", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"GridTabby", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"Abs", "[", 
          RowBox[{"GridTabby", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"GridTabby", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"Abs", "[", 
          RowBox[{"GridTabby", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"Contours", "\[Rule]", "IntermContTabby"}], ",", 
       RowBox[{"ContourShading", "\[Rule]", "True"}], ",", 
       RowBox[{"Frame", "\[Rule]", "False"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"DisplayFunction", "\[Rule]", "Identity"}], ",", 
       RowBox[{"BoundaryStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"Thickness", "[", ".003", "]"}]}], "}"}]}], ",", 
       RowBox[{"RegionFunction", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"x", "^", "2"}], "+", 
            RowBox[{"y", "^", "2"}]}], "<", "2"}]}], "]"}]}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "20"}], ",", 
       RowBox[{"ContourStyle", "\[Rule]", 
        RowBox[{"Opacity", "[", ".30", "]"}]}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"f", ",", 
          RowBox[{"Opacity", "[", 
           RowBox[{"1.0", ",", 
            RowBox[{"GrayLevel", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"(", 
                 RowBox[{"f", "-", "ContColorStart"}], ")"}]}], ")"}], "+", 
              RowBox[{"percent", "*", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   RowBox[{"(", 
                    RowBox[{"f", "-", "ContColorStart"}], ")"}]}], ")"}]}], 
                ")"}]}]}], "]"}]}], "]"}]}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ItFit", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"equalAreaPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"cartesianFromTrendPlungeDeg", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"FitTrendInterm", "\[Equal]", "\"\<NA\>\""}], ",", 
              "000", ",", "FitTrendInterm"}], "]"}], ",", "FitPlungeInterm"}],
            "}"}], "]"}], "}"}], ",", " ", 
        RowBox[{"FitSizePercent", "*", "ptsize"}], ",", "Red"}], "]"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ItMean", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"equalAreaPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"cartesianFromTrendPlungeDeg", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"ITrendMean", "\[Equal]", "\"\<NA\>\""}], ",", "000", 
              ",", "ITrendMean"}], "]"}], ",", "IPlungeMean"}], "}"}], "]"}], 
         "}"}], ",", " ", 
        RowBox[{"MeanSizePercent", "*", "ptsize"}], ",", "Blue"}], "]"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"IntermPlanarFit", "\[Equal]", "1"}], ",", 
      RowBox[{
       RowBox[{"IntermContStatPlot", "=", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{"N", " ", "==", " ", 
                 RowBox[{"(", "statnumb", ")"}]}], ",", 
                RowBox[{"FontSize", "\[Rule]", "20"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1.3"}], ",", 
                RowBox[{"-", "1.6"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Equal Area Projection\>\"", ",", 
                RowBox[{"FontSize", "\[Rule]", "20"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1.9"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
          "IntermContPlot", ",", 
          RowBox[{"GreatCircle", "[", "2", "]"}], ",", 
          RowBox[{"equalAreaPlot", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"cartesianFromTrendPlungeDeg", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"ITrendStat", "[", "x", "]"}], ",", 
                 RowBox[{"IPlungeStat", "[", "x", "]"}]}], "}"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], ",", 
            " ", "ptsize", ",", "Black"}], "]"}], ",", "ItFit", ",", "ItMean",
           ",", 
          RowBox[{"PlotLabel", "\[Rule]", 
           RowBox[{"Style", "[", 
            RowBox[{
            "\"\<Intermediate Axes Orientations\>\"", ",", "24", ",", "Blue", 
             ",", "Bold"}], "]"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], ";"}], ",", 
      RowBox[{
       RowBox[{"IntermContStatPlot", "=", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{"N", " ", "==", " ", 
                 RowBox[{"(", "statnumb", ")"}]}], ",", 
                RowBox[{"FontSize", "\[Rule]", "20"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1.3"}], ",", 
                RowBox[{"-", "1.6"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Equal Area Projection\>\"", ",", 
                RowBox[{"FontSize", "\[Rule]", "20"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1.9"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
          "IntermContPlot", ",", 
          RowBox[{"equalAreaPlot", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"cartesianFromTrendPlungeDeg", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"ITrendStat", "[", "x", "]"}], ",", 
                 RowBox[{"IPlungeStat", "[", "x", "]"}]}], "}"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], ",", 
            " ", "ptsize", ",", "Black"}], "]"}], ",", "ItFit", ",", "ItMean",
           ",", 
          RowBox[{"PlotLabel", "\[Rule]", 
           RowBox[{"Style", "[", 
            RowBox[{
            "\"\<Intermediate Axes Orientations\>\"", ",", "24", ",", "Blue", 
             ",", "Bold"}], "]"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], ";"}]}], "]"}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ShortStatTabby", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"STrendStat", "[", "x", "]"}], ",", 
         RowBox[{"SPlungeStat", "[", "x", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ShortXYcoords", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"equalAreaProjection", "[", 
        RowBox[{"lowerHemisphere", "[", 
         RowBox[{"cartesianFromTrendPlungeDeg", "[", 
          RowBox[{"ShortStatTabby", "[", 
           RowBox[{"[", "x", "]"}], "]"}], "]"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}]}], ";"}], 
   "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nf", "=", 
     RowBox[{"Nearest", "@", "ShortXYcoords"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct6", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct6", "\[LessEqual]", "SqrGridNumb"}], ",", "\n", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"GridTabby", "[", 
                RowBox[{"[", 
                 RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "^", "2"}], ")"}], 
             "+", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"GridTabby", "[", 
                RowBox[{"[", 
                 RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "^", "2"}], ")"}]}],
             "]"}], "<", 
           RowBox[{"(", 
            RowBox[{"CountingCircleRadius", "+", 
             RowBox[{"Sqrt", "[", "2", "]"}]}], ")"}]}], "&&", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"GridTabby", "[", 
                RowBox[{"[", 
                 RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "^", "2"}], ")"}], 
             "+", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"GridTabby", "[", 
                RowBox[{"[", 
                 RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "^", "2"}], ")"}]}],
             "]"}], ">", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Sqrt", "[", "2", "]"}], "-", "CountingCircleRadius"}], 
            ")"}]}]}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"firstGridVal", "=", 
           RowBox[{
            RowBox[{"Dimensions", "[", 
             RowBox[{"nf", "[", 
              RowBox[{
               RowBox[{"GridTabby", "[", 
                RowBox[{"[", "ct6", "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Infinity]", ",", "CountingCircleRadius"}], "}"}]}],
               "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"GridTabby", "[", 
              RowBox[{"[", 
               RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "\[Equal]", "0"}], 
            ",", 
            RowBox[{
             RowBox[{"xAcross", "=", "0"}], ";", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"GridTabby", "[", 
                 RowBox[{"[", 
                  RowBox[{"ct6", ",", "2"}], "]"}], "]"}], ">", "0"}], ",", 
               RowBox[{
                RowBox[{"yAcross", "=", 
                 RowBox[{
                  RowBox[{"GridTabby", "[", 
                   RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "-", 
                  RowBox[{"2", "*", 
                   RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], ";"}], ",", 
               RowBox[{
                RowBox[{"yAcross", "=", 
                 RowBox[{
                  RowBox[{"GridTabby", "[", 
                   RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "+", 
                  RowBox[{"2", "*", 
                   RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], ";"}]}], "]"}], 
             ";"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"GridTabby", "[", 
                 RowBox[{"[", 
                  RowBox[{"ct6", ",", "1"}], "]"}], "]"}], ">", "0"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"xAcross", "=", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", 
                    RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "^", "2"}], 
                    ")"}], "+", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "^", "2"}], 
                    ")"}]}], "]"}]}], ")"}]}], "*", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "/", 
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}]}], "]"}], 
                   "]"}]}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"yAcross", "=", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", "*", 
                    RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "^", "2"}], 
                    ")"}], "+", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "^", "2"}], 
                    ")"}]}], "]"}]}], ")"}]}], "*", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "/", 
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}]}], "]"}], 
                   "]"}]}]}], ";"}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"xAcross", "=", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", "*", 
                    RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "^", "2"}], 
                    ")"}], "+", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "^", "2"}], 
                    ")"}]}], "]"}]}], ")"}], "*", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "/", 
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}]}], "]"}], 
                   "]"}]}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"yAcross", "=", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"2", "*", 
                    RowBox[{"Sqrt", "[", "2", "]"}]}], "-", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}], "^", "2"}], 
                    ")"}], "+", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "^", "2"}], 
                    ")"}]}], "]"}]}], ")"}], "*", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"ArcTan", "[", 
                    RowBox[{
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "2"}], "]"}], "]"}], "/", 
                    RowBox[{"GridTabby", "[", 
                    RowBox[{"[", 
                    RowBox[{"ct6", ",", "1"}], "]"}], "]"}]}], "]"}], 
                   "]"}]}]}], ";"}]}], "]"}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"secondGridVal", "=", 
           RowBox[{
            RowBox[{"Dimensions", "[", 
             RowBox[{"nf", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"xAcross", ",", "yAcross"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Infinity]", ",", "CountingCircleRadius"}], "}"}]}],
               "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"GridValue", "[", "ct6", "]"}], "=", 
           RowBox[{"firstGridVal", "+", "secondGridVal"}]}], ";"}], ",", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"GridValue", "[", "ct6", "]"}], "=", 
           RowBox[{
            RowBox[{"Dimensions", "[", 
             RowBox[{"nf", "[", 
              RowBox[{
               RowBox[{"GridTabby", "[", 
                RowBox[{"[", "ct6", "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"\[Infinity]", ",", "CountingCircleRadius"}], "}"}]}],
               "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ct6", "=", 
        RowBox[{"ct6", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ContourableValues", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"GridTabby", "[", 
           RowBox[{"[", "x", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{"GridTabby", "[", 
           RowBox[{"[", "x", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", 
         RowBox[{"GridValue", "[", "x", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "SqrGridNumb"}], "}"}]}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ct7", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct7", "\[LessEqual]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"HalfNumbGraticules", "*", "2"}], "+", "1"}], ")"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"ContVals", "[", "ct7", "]"}], "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"ContourableValues", "[", 
           RowBox[{"[", 
            RowBox[{"x", ",", "3"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"ct7", "-", "1"}], ")"}], "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"HalfNumbGraticules", "*", "2"}], "+", "1"}], 
                 ")"}]}], ")"}], "+", "1"}], ")"}], ",", 
            RowBox[{"ct7", "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"HalfNumbGraticules", "*", "2"}], "+", "1"}], 
              ")"}]}]}], "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"ct7", "=", 
        RowBox[{"ct7", "+", "1"}]}], ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"f", "=", 
     RowBox[{"ListInterpolation", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"ContVals", "[", "x", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "1", ",", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"HalfNumbGraticules", "*", "2"}], "+", "1"}], ")"}]}], 
          "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"GridTabby", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"Abs", "[", 
            RowBox[{"GridTabby", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"GridTabby", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{"Abs", "[", 
            RowBox[{"GridTabby", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}]}], 
        "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"PercentVals", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ContVals", "[", "x", "]"}], "*", "100"}], ")"}], "/", 
         "statnumb"}], ")"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"HalfNumbGraticules", "*", "2"}], "+", "1"}], ")"}]}], 
        "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MaxGridVal", "=", 
     RowBox[{"Max", "[", "PercentVals", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct8", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct9", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct8", "\[LessEqual]", "SqrGridNumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"ContourableValues", "[", 
              RowBox[{"[", 
               RowBox[{"ct8", ",", "1"}], "]"}], "]"}], "^", "2"}], ")"}], 
           "+", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"ContourableValues", "[", 
              RowBox[{"[", 
               RowBox[{"ct8", ",", "2"}], "]"}], "]"}], "^", "2"}], ")"}]}], 
          "\[LessEqual]", "2"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"InCircle", "[", "ct9", "]"}], "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"ContourableValues", "[", 
               RowBox[{"[", 
                RowBox[{"ct8", ",", "3"}], "]"}], "]"}], "*", "100"}], ")"}], 
            "/", "statnumb"}]}], ";", 
          RowBox[{"ct9", "=", 
           RowBox[{"ct9", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ct8", "=", 
        RowBox[{"ct8", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"InCircleDim", "=", 
     RowBox[{"ct9", "-", "1"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"MaxInCircle", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"InCircle", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", "InCircleDim"}], "}"}]}], "]"}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MinInCircle", "=", 
     RowBox[{"Min", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"InCircle", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", "InCircleDim"}], "}"}]}], "]"}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"InCircleRange", "=", 
     RowBox[{"MaxInCircle", "-", "MinInCircle"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ShortTempContInt", "=", 
     RowBox[{"InCircleRange", "/", 
      RowBox[{"(", 
       RowBox[{"NumberOfContours", "+", "1"}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ShortContoursTabby", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"MinInCircle", "+", 
        RowBox[{"ShortTempContInt", "*", "x"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "NumberOfContours"}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ShortContTabby", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ShortContoursTabby", "[", 
            RowBox[{"[", "x", "]"}], "]"}], "*", "statnumb"}], ")"}], "/", 
         "100"}], ")"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "NumberOfContours"}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"Clear", "[", "MaxContVal", "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ContColorStart", "=", 
     RowBox[{"0.2675", "*", 
      RowBox[{"NumberOfContours", "^", 
       RowBox[{"(", 
        RowBox[{"-", "0.611"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TempContPlot", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"GridTabby", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"Abs", "[", 
          RowBox[{"GridTabby", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"GridTabby", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"Abs", "[", 
          RowBox[{"GridTabby", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"Contours", "\[Rule]", "ShortContTabby"}], ",", 
       RowBox[{"ContourShading", "\[Rule]", "True"}], ",", 
       RowBox[{"Frame", "\[Rule]", "False"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"DisplayFunction", "\[Rule]", "Identity"}], ",", 
       RowBox[{"BoundaryStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"Thickness", "[", ".003", "]"}]}], "}"}]}], ",", 
       RowBox[{"RegionFunction", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"x", "^", "2"}], "+", 
            RowBox[{"y", "^", "2"}]}], "<", "2"}]}], "]"}]}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "20"}], ",", 
       RowBox[{"ContourStyle", "\[Rule]", 
        RowBox[{"Opacity", "[", ".30", "]"}]}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"f", ",", 
          RowBox[{
           RowBox[{"temp", "=", "f"}], ";", 
           RowBox[{"Opacity", "[", 
            RowBox[{"1.0", ",", 
             RowBox[{"GrayLevel", "[", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"(", 
                 RowBox[{"f", "-", "ContColorStart"}], ")"}]}], ")"}], 
              "]"}]}], "]"}]}]}], "]"}]}]}], "]"}]}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MaxColorLevel", "=", "0.15"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"percent", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"MaxColorLevel", "-", "MaxContVal"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "-", "MaxContVal"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MaxContVal", "=", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"(", 
        RowBox[{"temp", "-", "ContColorStart"}], ")"}]}], ")"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"intvl", "=", 
     RowBox[{"0.5447", "*", 
      RowBox[{"NumberOfContours", "^", 
       RowBox[{"(", 
        RowBox[{"-", "0.797"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   "\n", 
   RowBox[{
    RowBox[{"ShortContPlot", "=", 
     RowBox[{"ContourPlot", "[", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"x", ",", "y"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"GridTabby", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"Abs", "[", 
          RowBox[{"GridTabby", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"GridTabby", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"Abs", "[", 
          RowBox[{"GridTabby", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"Contours", "\[Rule]", "ShortContTabby"}], ",", 
       RowBox[{"ContourShading", "\[Rule]", "True"}], ",", 
       RowBox[{"Frame", "\[Rule]", "False"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"DisplayFunction", "\[Rule]", "Identity"}], ",", 
       RowBox[{"BoundaryStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Black", ",", 
          RowBox[{"Thickness", "[", ".003", "]"}]}], "}"}]}], ",", 
       RowBox[{"RegionFunction", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"x", "^", "2"}], "+", 
            RowBox[{"y", "^", "2"}]}], "<", "2"}]}], "]"}]}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "20"}], ",", 
       RowBox[{"ContourStyle", "\[Rule]", 
        RowBox[{"Opacity", "[", ".30", "]"}]}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", 
        RowBox[{"Function", "[", 
         RowBox[{"f", ",", 
          RowBox[{"Opacity", "[", 
           RowBox[{"1.0", ",", 
            RowBox[{"GrayLevel", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"(", 
                 RowBox[{"f", "-", "ContColorStart"}], ")"}]}], ")"}], "+", 
              RowBox[{"percent", "*", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 RowBox[{"(", 
                  RowBox[{"1", "-", 
                   RowBox[{"(", 
                    RowBox[{"f", "-", "ContColorStart"}], ")"}]}], ")"}]}], 
                ")"}]}]}], "]"}]}], "]"}]}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ShFit", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"equalAreaPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"cartesianFromTrendPlungeDeg", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"FitTrendShort", "\[Equal]", "\"\<NA\>\""}], ",", "000",
               ",", "FitTrendShort"}], "]"}], ",", "FitPlungeShort"}], "}"}], 
          "]"}], "}"}], ",", " ", 
        RowBox[{"FitSizePercent", "*", "ptsize"}], ",", "Red"}], "]"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ShMean", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"equalAreaPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"cartesianFromTrendPlungeDeg", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"STrendMean", "\[Equal]", "\"\<NA\>\""}], ",", "000", 
              ",", "STrendMean"}], "]"}], ",", "SPlungeMean"}], "}"}], "]"}], 
         "}"}], ",", " ", 
        RowBox[{"MeanSizePercent", "*", "ptsize"}], ",", "Blue"}], "]"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"ShortPlanarFit", "\[Equal]", "1"}], ",", 
      RowBox[{
       RowBox[{"ShortContStatPlot", "=", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{"N", " ", "==", " ", 
                 RowBox[{"(", "statnumb", ")"}]}], ",", 
                RowBox[{"FontSize", "\[Rule]", "20"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1.3"}], ",", 
                RowBox[{"-", "1.6"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Equal Area Projection\>\"", ",", 
                RowBox[{"FontSize", "\[Rule]", "20"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1.9"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
          "ShortContPlot", ",", 
          RowBox[{"GreatCircle", "[", "3", "]"}], ",", 
          RowBox[{"equalAreaPlot", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"cartesianFromTrendPlungeDeg", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"STrendStat", "[", "x", "]"}], ",", 
                 RowBox[{"SPlungeStat", "[", "x", "]"}]}], "}"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], ",", 
            " ", "ptsize", ",", "Black"}], "]"}], ",", "ShFit", ",", "ShMean",
           ",", 
          RowBox[{"PlotLabel", "\[Rule]", 
           RowBox[{"Style", "[", 
            RowBox[{
            "\"\<Short Axes Orientations\>\"", ",", "24", ",", "Blue", ",", 
             "Bold"}], "]"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], ";"}], ",", 
      RowBox[{
       RowBox[{"ShortContStatPlot", "=", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
                RowBox[{"N", " ", "==", " ", 
                 RowBox[{"(", "statnumb", ")"}]}], ",", 
                RowBox[{"FontSize", "\[Rule]", "20"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1.3"}], ",", 
                RowBox[{"-", "1.6"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{"Text", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Equal Area Projection\>\"", ",", 
                RowBox[{"FontSize", "\[Rule]", "20"}]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"-", "1.9"}]}], "}"}]}], "]"}], "}"}], "]"}], ",", 
          "ShortContPlot", ",", 
          RowBox[{"equalAreaPlot", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"cartesianFromTrendPlungeDeg", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"STrendStat", "[", "x", "]"}], ",", 
                 RowBox[{"SPlungeStat", "[", "x", "]"}]}], "}"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], ",", 
            " ", "ptsize", ",", "Black"}], "]"}], ",", "ShFit", ",", "ShMean",
           ",", 
          RowBox[{"PlotLabel", "\[Rule]", 
           RowBox[{"Style", "[", 
            RowBox[{
            "\"\<Short Axes Orientations\>\"", ",", "24", ",", "Blue", ",", 
             "Bold"}], "]"}]}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], ";"}]}], "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Needs", "[", "\"\<PlotLegends`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Off", "[", 
     RowBox[{"LegendPosition", "::", "\"\<shdw\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Off", "[", 
     RowBox[{"ShowLegend", "::", "\"\<shdw\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"LongAxesPlot", "=", 
    RowBox[{"Show", "[", 
     RowBox[{
      RowBox[{"ShowLegend", "[", 
       RowBox[{"LongContStatPlot", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{"Blue", ",", 
                 RowBox[{"Disk", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", ".1"}], "]"}]}], 
                "}"}], "]"}], ",", 
              RowBox[{"Text", "[", 
               RowBox[{"Style", "[", 
                RowBox[{"\"\<Mean Orientation\>\"", ",", 
                 RowBox[{"FontSize", "\[Rule]", "18"}]}], "]"}], "]"}]}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{"Red", ",", 
                 RowBox[{"Disk", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", ".1"}], "]"}]}], 
                "}"}], "]"}], ",", 
              RowBox[{"Text", "[", 
               RowBox[{"Style", "[", 
                RowBox[{"\"\<Fit Orientation\>\"", ",", 
                 RowBox[{"FontSize", "\[Rule]", "18"}]}], "]"}], "]"}]}], 
             "}"}]}], "}"}], ",", 
          RowBox[{"LegendPosition", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"0.75", ",", 
             RowBox[{"-", "0.9"}]}], "}"}]}]}], "}"}]}], "]"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "800"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"AlphaOn", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<The Trend:Plunge of the Mean Orientation = \>\"", ",", 
         RowBox[{"N", "[", "LTrendMean", "]"}], ",", "\"\<\[Degree]:\>\"", 
         ",", 
         RowBox[{"N", "[", "LPlungeMean", "]"}], ",", "\"\<\[Degree]\>\"", 
         ",", "\"\< with an \[Alpha]\>\"", ",", 
         RowBox[{"Round", "[", 
          RowBox[{"100", "*", "alphapercent"}], "]"}], ",", "\"\< = \>\"", 
         ",", "LongAlpha", " ", ",", "\"\<\[Degree]\>\""}], "]"}], ";"}], ",", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<The Trend:Plunge of the Mean Orientation = \>\"", ",", 
         RowBox[{"N", "[", "LTrendMean", "]"}], ",", "\"\<\[Degree]:\>\"", 
         ",", 
         RowBox[{"N", "[", "LPlungeMean", "]"}], ",", "\"\<\[Degree]\>\""}], 
        "]"}], ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The Trend:Plunge of the Fit Orientation = \>\"", ",", 
      RowBox[{"N", "[", "FitTrendLong", "]"}], ",", "\"\<\[Degree]:\>\"", ",", 
      RowBox[{"N", "[", "FitPlungeLong", "]"}], ",", 
      "\"\<\[Degree] with a \>\"", ",", 
      RowBox[{"Round", "[", 
       RowBox[{"100", "*", "desiredpercentage"}], "]"}], ",", 
      "\"\<% error angle = \>\"", ",", "LongCIAngle", ",", 
      "\"\<\[Degree]\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"LongPlanarFit", "\[Equal]", "1"}], ",", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<The Dip:Dip Direction of the Fit Plane = \>\"", ",", 
         RowBox[{"N", "[", 
          RowBox[{"FitDip", "[", "1", "]"}], "]"}], ",", "\"\<\[Degree]:\>\"",
          ",", 
         RowBox[{"N", "[", 
          RowBox[{"FitDipDir", "[", "1", "]"}], "]"}], ",", 
         "\"\<\[Degree] and a Mean Difference Angle of: \>\"", ",", 
         RowBox[{"N", "[", "LongMeanDiff", "]"}], ",", "\"\<\[Degree]\>\""}], 
        "]"}], ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<Contour Interval = \>\"", ",", 
     RowBox[{"N", "[", 
      RowBox[{"TempContInt", ",", "3"}], "]"}], ",", "\"\<%\>\""}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<Contour Values: \>\"", ",", 
     RowBox[{"TableForm", "[", 
      RowBox[{
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{
             RowBox[{"N", "[", 
              RowBox[{
               RowBox[{"ContoursTabby", "[", 
                RowBox[{"[", "x", "]"}], "]"}], ",", "3"}], "]"}], 
             "\"\<%,\>\""}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "1", ",", 
             RowBox[{"NumberOfContours", "-", "1"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"N", "[", 
            RowBox[{
             RowBox[{"ContoursTabby", "[", 
              RowBox[{"[", "NumberOfContours", "]"}], "]"}], ",", "3"}], 
            "]"}], "\"\<%\>\""}], "]"}]}], "]"}], ",", 
       RowBox[{"TableDirections", "\[Rule]", "Row"}]}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"IntermediateAxesPlot", "=", 
    RowBox[{"Show", "[", 
     RowBox[{
      RowBox[{"ShowLegend", "[", 
       RowBox[{"IntermContStatPlot", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{"Blue", ",", 
                 RowBox[{"Disk", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", ".1"}], "]"}]}], 
                "}"}], "]"}], ",", 
              RowBox[{"Text", "[", 
               RowBox[{"Style", "[", 
                RowBox[{"\"\<Mean Orientation\>\"", ",", 
                 RowBox[{"FontSize", "\[Rule]", "18"}]}], "]"}], "]"}]}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{"Red", ",", 
                 RowBox[{"Disk", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", ".1"}], "]"}]}], 
                "}"}], "]"}], ",", 
              RowBox[{"Text", "[", 
               RowBox[{"Style", "[", 
                RowBox[{"\"\<Fit Orientation\>\"", ",", 
                 RowBox[{"FontSize", "\[Rule]", "18"}]}], "]"}], "]"}]}], 
             "}"}]}], "}"}], ",", 
          RowBox[{"LegendPosition", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"0.75", ",", 
             RowBox[{"-", "0.9"}]}], "}"}]}]}], "}"}]}], "]"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "800"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"AlphaOn", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<The Trend:Plunge of the Mean Orientation = \>\"", ",", 
         RowBox[{"N", "[", "ITrendMean", "]"}], ",", "\"\<\[Degree]:\>\"", 
         ",", 
         RowBox[{"N", "[", "IPlungeMean", "]"}], ",", "\"\<\[Degree]\>\"", 
         ",", "\"\< with an \[Alpha]\>\"", ",", 
         RowBox[{"Round", "[", 
          RowBox[{"100", "*", "alphapercent"}], "]"}], ",", "\"\< = \>\"", 
         ",", "IntermAlpha", " ", ",", "\"\<\[Degree]\>\""}], "]"}], ";"}], 
      ",", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<The Trend:Plunge of the Mean Orientation = \>\"", ",", 
         RowBox[{"N", "[", "ITrendMean", "]"}], ",", "\"\<\[Degree]:\>\"", 
         ",", 
         RowBox[{"N", "[", "IPlungeMean", "]"}], ",", "\"\<\[Degree]\>\""}], 
        "]"}], ";"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The Trend:Plunge of the Fit Orientation = \>\"", ",", 
      RowBox[{"N", "[", "FitTrendInterm", "]"}], ",", "\"\<\[Degree]:\>\"", 
      ",", 
      RowBox[{"N", "[", "FitPlungeInterm", "]"}], ",", 
      "\"\<\[Degree] with a \>\"", ",", 
      RowBox[{"Round", "[", 
       RowBox[{"100", "*", "desiredpercentage"}], "]"}], ",", 
      "\"\<% error angle = \>\"", ",", "IntermCIAngle", ",", 
      "\"\<\[Degree]\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"IntermPlanarFit", "\[Equal]", "1"}], ",", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<The Dip:Dip Direction of the Fit Plane = \>\"", ",", 
         RowBox[{"N", "[", 
          RowBox[{"FitDip", "[", "2", "]"}], "]"}], ",", "\"\<\[Degree]:\>\"",
          ",", 
         RowBox[{"N", "[", 
          RowBox[{"FitDipDir", "[", "2", "]"}], "]"}], ",", 
         "\"\<\[Degree] and a Mean Difference Angle of: \>\"", ",", 
         RowBox[{"N", "[", "IntermMeanDiff", "]"}], ",", 
         "\"\<\[Degree]\>\""}], "]"}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<Contour Interval = \>\"", ",", 
     RowBox[{"N", "[", 
      RowBox[{"IntermTempContInt", ",", "3"}], "]"}], ",", "\"\<%\>\""}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<Contour Values: \>\"", ",", 
     RowBox[{"TableForm", "[", 
      RowBox[{
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{
             RowBox[{"N", "[", 
              RowBox[{
               RowBox[{"IntermContoursTabby", "[", 
                RowBox[{"[", "x", "]"}], "]"}], ",", "3"}], "]"}], 
             "\"\<%,\>\""}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "1", ",", 
             RowBox[{"NumberOfContours", "-", "1"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"N", "[", 
            RowBox[{
             RowBox[{"IntermContoursTabby", "[", 
              RowBox[{"[", "NumberOfContours", "]"}], "]"}], ",", "3"}], 
            "]"}], "\"\<%\>\""}], "]"}]}], "]"}], ",", 
       RowBox[{"TableDirections", "\[Rule]", "Row"}]}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"ShortAxesPlot", "=", 
    RowBox[{"Show", "[", 
     RowBox[{
      RowBox[{"ShowLegend", "[", 
       RowBox[{"ShortContStatPlot", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{"Blue", ",", 
                 RowBox[{"Disk", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", ".1"}], "]"}]}], 
                "}"}], "]"}], ",", 
              RowBox[{"Text", "[", 
               RowBox[{"Style", "[", 
                RowBox[{"\"\<Mean Orientation\>\"", ",", 
                 RowBox[{"FontSize", "\[Rule]", "18"}]}], "]"}], "]"}]}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{"Red", ",", 
                 RowBox[{"Disk", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", ".1"}], "]"}]}], 
                "}"}], "]"}], ",", 
              RowBox[{"Text", "[", 
               RowBox[{"Style", "[", 
                RowBox[{"\"\<Fit Orientation\>\"", ",", 
                 RowBox[{"FontSize", "\[Rule]", "18"}]}], "]"}], "]"}]}], 
             "}"}]}], "}"}], ",", 
          RowBox[{"LegendPosition", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"0.75", ",", 
             RowBox[{"-", "0.9"}]}], "}"}]}]}], "}"}]}], "]"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "800"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"AlphaOn", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<The Trend:Plunge of the Mean Orientation = \>\"", ",", 
         RowBox[{"N", "[", "STrendMean", "]"}], ",", "\"\<\[Degree]:\>\"", 
         ",", 
         RowBox[{"N", "[", "SPlungeMean", "]"}], ",", "\"\<\[Degree]\>\"", 
         ",", "\"\< with an \[Alpha]\>\"", ",", 
         RowBox[{"Round", "[", 
          RowBox[{"100", "*", "alphapercent"}], "]"}], ",", "\"\< = \>\"", 
         ",", "ShortAlpha", " ", ",", "\"\<\[Degree]\>\""}], "]"}], ";"}], 
      ",", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<The Trend:Plunge of the Mean Orientation = \>\"", ",", 
         RowBox[{"N", "[", "STrendMean", "]"}], ",", "\"\<\[Degree]:\>\"", 
         ",", 
         RowBox[{"N", "[", "SPlungeMean", "]"}], ",", "\"\<\[Degree]\>\""}], 
        "]"}], ";"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The Trend:Plunge of the Fit Orientation = \>\"", ",", 
      RowBox[{"N", "[", "FitTrendShort", "]"}], ",", "\"\<\[Degree]:\>\"", 
      ",", 
      RowBox[{"N", "[", "FitPlungeShort", "]"}], ",", 
      "\"\<\[Degree] with a \>\"", ",", 
      RowBox[{"Round", "[", 
       RowBox[{"100", "*", "desiredpercentage"}], "]"}], ",", 
      "\"\<% error angle = \>\"", ",", "ShortCIAngle", ",", 
      "\"\<\[Degree]\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"ShortPlanarFit", "\[Equal]", "1"}], ",", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<The Dip:Dip Direction of the Fit Plane = \>\"", ",", 
         RowBox[{"N", "[", 
          RowBox[{"FitDip", "[", "3", "]"}], "]"}], ",", "\"\<\[Degree]:\>\"",
          ",", 
         RowBox[{"N", "[", 
          RowBox[{"FitDipDir", "[", "3", "]"}], "]"}], ",", 
         "\"\<\[Degree] and a Mean Difference Angle of: \>\"", ",", 
         RowBox[{"N", "[", "ShortMeanDiff", "]"}], ",", "\"\<\[Degree]\>\""}],
         "]"}], ";"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<Contour Interval = \>\"", ",", 
     RowBox[{"N", "[", 
      RowBox[{"ShortTempContInt", ",", "3"}], "]"}], ",", "\"\<%\>\""}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<Contour Values: \>\"", ",", 
     RowBox[{"TableForm", "[", 
      RowBox[{
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Text", "[", 
            RowBox[{
             RowBox[{"N", "[", 
              RowBox[{
               RowBox[{"ShortContoursTabby", "[", 
                RowBox[{"[", "x", "]"}], "]"}], ",", "3"}], "]"}], 
             "\"\<%,\>\""}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "1", ",", 
             RowBox[{"NumberOfContours", "-", "1"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"N", "[", 
            RowBox[{
             RowBox[{"ShortContoursTabby", "[", 
              RowBox[{"[", "NumberOfContours", "]"}], "]"}], ",", "3"}], 
            "]"}], "\"\<%\>\""}], "]"}]}], "]"}], ",", 
       RowBox[{"TableDirections", "\[Rule]", "Row"}]}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"LongAxesTab", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"NormalizedAxesLengths", "[", "x", "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ShortAxesTab", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"NormalizedAxesLengths", "[", "x", "]"}], "[", 
        RowBox[{"[", "3", "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LongAndShort", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"LongAxesTab", "[", 
          RowBox[{"[", "x", "]"}], "]"}], ",", 
         RowBox[{"ShortAxesTab", "[", 
          RowBox[{"[", "x", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"hx", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.06", "*", 
        RowBox[{"Min", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{"Variance", "[", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"LongAndShort", "[", 
                RowBox[{"[", 
                 RowBox[{"x", ",", "1"}], "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", "1", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "LongAndShort", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
            "]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Quantile", "[", 
               RowBox[{
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"LongAndShort", "[", 
                   RowBox[{"[", 
                    RowBox[{"x", ",", "1"}], "]"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"x", ",", "1", ",", 
                    RowBox[{
                    RowBox[{"Dimensions", "[", "LongAndShort", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
                ".75"}], "]"}], "-", 
              RowBox[{"Quantile", "[", 
               RowBox[{
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"LongAndShort", "[", 
                   RowBox[{"[", 
                    RowBox[{"x", ",", "1"}], "]"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"x", ",", "1", ",", 
                    RowBox[{
                    RowBox[{"Dimensions", "[", "LongAndShort", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
                ".25"}], "]"}]}], ")"}], "/", "1.34"}]}], "}"}], "]"}]}], 
       ")"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Dimensions", "[", "LongAndShort", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "5"}], ")"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"hy", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1.06", "*", 
        RowBox[{"Min", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{"Variance", "[", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"LongAndShort", "[", 
                RowBox[{"[", 
                 RowBox[{"x", ",", "2"}], "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", "1", ",", 
                 RowBox[{
                  RowBox[{"Dimensions", "[", "LongAndShort", "]"}], "[", 
                  RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], "]"}], 
            "]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Quantile", "[", 
               RowBox[{
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"LongAndShort", "[", 
                   RowBox[{"[", 
                    RowBox[{"x", ",", "2"}], "]"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"x", ",", "1", ",", 
                    RowBox[{
                    RowBox[{"Dimensions", "[", "LongAndShort", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
                ".75"}], "]"}], "-", 
              RowBox[{"Quantile", "[", 
               RowBox[{
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"LongAndShort", "[", 
                   RowBox[{"[", 
                    RowBox[{"x", ",", "2"}], "]"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"x", ",", "1", ",", 
                    RowBox[{
                    RowBox[{"Dimensions", "[", "LongAndShort", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
                ".25"}], "]"}]}], ")"}], "/", "1.34"}]}], "}"}], "]"}]}], 
       ")"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Dimensions", "[", "LongAndShort", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "^", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "/", "5"}], ")"}]}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"n", "=", 
     RowBox[{"Length", "[", "LongAndShort", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"KDE", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"(", 
        RowBox[{"2", "\[Pi]", "*", "n", "*", "hx", "*", "hy"}], ")"}]], "*", 
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"i", "=", "1"}], "n"], 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], "*", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox[
              RowBox[{"(", 
               RowBox[{"x", "-", 
                RowBox[{"LongAndShort", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "1"}], "]"}], "]"}]}], ")"}], "hx"], 
             ")"}], "2"], "+", 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox[
              RowBox[{"(", 
               RowBox[{"y", "-", 
                RowBox[{"LongAndShort", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "2"}], "]"}], "]"}]}], ")"}], "hy"], 
             ")"}], "2"]}], ")"}]}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MaxLong", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"LongAndShort", "[", 
         RowBox[{"[", 
          RowBox[{"x", ",", "1"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", "n"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MinLong", "=", 
     RowBox[{"Min", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"LongAndShort", "[", 
         RowBox[{"[", 
          RowBox[{"x", ",", "1"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", "n"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MaxShort", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"LongAndShort", "[", 
         RowBox[{"[", 
          RowBox[{"x", ",", "2"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", "n"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MinShort", "=", 
     RowBox[{"Min", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"LongAndShort", "[", 
         RowBox[{"[", 
          RowBox[{"x", ",", "2"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", "n"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xSigma", "=", 
     RowBox[{"StandardDeviation", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"LongAndShort", "[", 
         RowBox[{"[", 
          RowBox[{"x", ",", "1"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", "n"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"ySigma", "=", 
     RowBox[{"StandardDeviation", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"LongAndShort", "[", 
         RowBox[{"[", 
          RowBox[{"x", ",", "2"}], "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", "n"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Lflim", "=", 
     RowBox[{"MinLong", "-", 
      RowBox[{"(", 
       RowBox[{"SigmaBuffer", "*", "xSigma"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Rtlim", "=", 
     RowBox[{"MaxLong", "+", 
      RowBox[{"(", 
       RowBox[{"SigmaBuffer", "*", "xSigma"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"horzlen", "=", 
     RowBox[{"Rtlim", "-", "Lflim"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Lowerlim", "=", 
     RowBox[{"MinShort", "-", 
      RowBox[{"(", 
       RowBox[{"SigmaBuffer", "*", "ySigma"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Upperlim", "=", 
     RowBox[{"MaxShort", "+", 
      RowBox[{"(", 
       RowBox[{"SigmaBuffer", "*", "ySigma"}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"vertlen", "=", 
     RowBox[{"Upperlim", "-", "Lowerlim"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"bufferedvertnumb", "=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Round", "[", 
         RowBox[{"Sqrt", "[", "ApproxNumbSqrs", "]"}], "]"}], 
        "\[GreaterEqual]", 
        RowBox[{"Sqrt", "[", "ApproxNumbSqrs", "]"}]}], ",", 
       RowBox[{"Round", "[", 
        RowBox[{"Sqrt", "[", "ApproxNumbSqrs", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"Round", "[", 
         RowBox[{"Sqrt", "[", "ApproxNumbSqrs", "]"}], "]"}], "+", "1"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"bufferedhorznumb", "=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Round", "[", 
         RowBox[{"Sqrt", "[", "ApproxNumbSqrs", "]"}], "]"}], 
        "\[GreaterEqual]", 
        RowBox[{"Sqrt", "[", "ApproxNumbSqrs", "]"}]}], ",", 
       RowBox[{"Round", "[", 
        RowBox[{"Sqrt", "[", "ApproxNumbSqrs", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"Round", "[", 
         RowBox[{"Sqrt", "[", "ApproxNumbSqrs", "]"}], "]"}], "+", "1"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"vertcellsize", "=", 
     RowBox[{"vertlen", "/", "bufferedvertnumb"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"horzcellsize", "=", 
     RowBox[{"horzlen", "/", "bufferedhorznumb"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"cttot", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct1", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct1", "\[LessEqual]", "bufferedvertnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ytemp", "=", 
        RowBox[{"Upperlim", "-", 
         RowBox[{"0.5", "*", "vertcellsize"}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ct1", "-", "1"}], ")"}], "*", "vertcellsize"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ct2", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"ct2", "\[LessEqual]", "bufferedhorznumb"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"xtemp", "=", 
           RowBox[{"Lflim", "+", 
            RowBox[{"0.5", "*", "horzcellsize"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"ct2", "-", "1"}], ")"}], "*", "horzcellsize"}]}]}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"xtemp", ">", "ytemp"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"histo", "[", "cttot", "]"}], "=", 
              RowBox[{"{", 
               RowBox[{"xtemp", ",", "ytemp", ",", 
                RowBox[{"KDE", "[", 
                 RowBox[{"xtemp", ",", "ytemp"}], "]"}]}], "}"}]}], ";"}], 
            ",", 
            RowBox[{
             RowBox[{
              RowBox[{"histo", "[", "cttot", "]"}], "=", 
              RowBox[{"{", 
               RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ";"}]}], "]"}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{"cttot", "=", 
           RowBox[{"cttot", "+", "1"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"ct2", "=", 
           RowBox[{"ct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ct1", "=", 
        RowBox[{"ct1", "+", "1"}]}], ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"TotVol", "=", 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{"horzcellsize", "*", "vertcellsize", "*", 
        RowBox[{
         RowBox[{"histo", "[", "x", "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", 
         RowBox[{"cttot", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"HighestColumn", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"histo", "[", "x", "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", 
          RowBox[{"cttot", "-", "1"}]}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Vol", "[", "z_", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", 
      RowBox[{
       RowBox[{"ct", "=", "1"}], ";", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"ct", "<", "cttot"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"incvol", "[", "ct", "]"}], "=", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"histo", "[", "ct", "]"}], "[", 
               RowBox[{"[", "3", "]"}], "]"}], "\[LessEqual]", "z"}], ",", 
             "0", ",", 
             RowBox[{"horzcellsize", "*", "vertcellsize", "*", 
              RowBox[{
               RowBox[{"histo", "[", "ct", "]"}], "[", 
               RowBox[{"[", "3", "]"}], "]"}]}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"ct", "=", 
           RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "/", "TotVol"}], ")"}], "*", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{"incvol", "[", "x", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "1", ",", 
               RowBox[{"cttot", "-", "1"}]}], "}"}]}], "]"}]}], ")"}], "-", 
         "desiredpercentage"}], ")"}]}]}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", "HighestColumn"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"precise", "=", 
     RowBox[{"SetPrec", "+", "1"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct3", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"precise", "\[GreaterEqual]", "SetPrec"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"m", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "+", "b"}], ")"}], "/", "2"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Vol", "[", "a", "]"}], "*", 
           RowBox[{"Vol", "[", "m", "]"}]}], ">", "0"}], ",", 
         RowBox[{"a", "=", "m"}], ",", 
         RowBox[{"b", "=", "m"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"precise", "=", 
        RowBox[{"Abs", "[", 
         RowBox[{"a", "-", "b"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"TempSolve", "[", "ct3", "]"}], "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "+", "b"}], ")"}], "/", "2"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ct3", "=", 
        RowBox[{"ct3", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"HeightThresh", "=", 
     RowBox[{"TempSolve", "[", 
      RowBox[{"ct3", "-", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"OctStrainList", "[", "0", "]"}], "=", "\[Epsilon]s"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"FlinnKList", "[", "0", "]"}], "=", "K"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"LodesList", "[", "0", "]"}], "=", "\[Nu]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"histoLengths", "[", "0", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{"NormLong", ",", "NormShort"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"globalct", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct", "<", "cttot"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"histo", "[", "ct", "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}], ">", "HeightThresh"}], "&&", 
          RowBox[{
           RowBox[{
            RowBox[{"histo", "[", "ct", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], "\[GreaterEqual]", "1"}], "&&", 
          RowBox[{
           RowBox[{
            RowBox[{"histo", "[", "ct", "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}], "\[LessEqual]", "1"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"globalct", "=", 
           RowBox[{"globalct", "+", "1"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"lnaught", "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"histo", "[", "ct", "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "*", 
              RowBox[{
               RowBox[{"histo", "[", "ct", "]"}], "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "3"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"\[Epsilon]1", "=", 
           RowBox[{"Log", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"histo", "[", "ct", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], "/", "lnaught"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"\[Epsilon]2", "=", 
           RowBox[{"Log", "[", 
            RowBox[{"1", "/", "lnaught"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"\[Epsilon]3", "=", 
           RowBox[{"Log", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"histo", "[", "ct", "]"}], "[", 
              RowBox[{"[", "2", "]"}], "]"}], "/", "lnaught"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"OctStrainList", "[", "globalct", "]"}], "=", 
           RowBox[{
            FractionBox["1", "3"], " ", 
            SqrtBox["3"], 
            RowBox[{"(", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"\[Epsilon]3", "-", "\[Epsilon]2"}], ")"}], "2"], 
                "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"\[Epsilon]2", "-", "\[Epsilon]1"}], ")"}], "2"], 
                "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"\[Epsilon]1", "-", "\[Epsilon]3"}], ")"}], "2"]}], 
               ")"}], ".5"], ")"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"FlinnKList", "[", "globalct", "]"}], "=", 
           FractionBox[
            RowBox[{
             FractionBox[
              RowBox[{
               RowBox[{"histo", "[", "ct", "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "1"], "-", "1"}], 
            RowBox[{
             FractionBox["1", 
              RowBox[{
               RowBox[{"histo", "[", "ct", "]"}], "[", 
               RowBox[{"[", "2", "]"}], "]"}]], "-", "1"}]]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"LodesList", "[", "globalct", "]"}], "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "*", "\[Epsilon]2"}], ")"}], "-", "\[Epsilon]3", 
              "-", "\[Epsilon]1"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Epsilon]1", "-", "\[Epsilon]3"}], ")"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"histoLengths", "[", "globalct", "]"}], "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"histo", "[", "ct", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"histo", "[", "ct", "]"}], "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ct", "=", 
        RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Epsilon]smax", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"OctStrainList", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", "globalct"}], "}"}]}], "]"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Epsilon]smin", "=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Min", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"OctStrainList", "[", "x", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", "globalct"}], "}"}]}], "]"}], "]"}], 
        "<", "0"}], ",", "0", ",", 
       RowBox[{"Min", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"OctStrainList", "[", "x", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", "globalct"}], "}"}]}], "]"}], "]"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Kmax", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"FlinnKList", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", "globalct"}], "}"}]}], "]"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Kmin", "=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Min", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"FlinnKList", "[", "x", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", "globalct"}], "}"}]}], "]"}], "]"}], 
        "<", "0"}], ",", "0", ",", 
       RowBox[{"Min", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"FlinnKList", "[", "x", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", "globalct"}], "}"}]}], "]"}], "]"}]}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"\[Nu]max", "=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Max", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"LodesList", "[", "x", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", "globalct"}], "}"}]}], "]"}], "]"}], 
        ">", "1"}], ",", "1", ",", 
       RowBox[{"Max", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"LodesList", "[", "x", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", "globalct"}], "}"}]}], "]"}], "]"}]}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"\[Nu]min", "=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Min", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"LodesList", "[", "x", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", "globalct"}], "}"}]}], "]"}], "]"}], 
        "<", 
        RowBox[{"-", "1"}]}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"Min", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"LodesList", "[", "x", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", "globalct"}], "}"}]}], "]"}], "]"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct", "\[LessEqual]", "statnumb"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"l0", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"LongAndShort", "[", 
            RowBox[{"[", 
             RowBox[{"ct", ",", "1"}], "]"}], "]"}], "*", "1", "*", 
           RowBox[{"LongAndShort", "[", 
            RowBox[{"[", 
             RowBox[{"ct", ",", "2"}], "]"}], "]"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "3"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"e1", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"LongAndShort", "[", 
            RowBox[{"[", 
             RowBox[{"ct", ",", "1"}], "]"}], "]"}], "-", "l0"}], ")"}], "/", 
         "l0"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"e2", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "l0"}], ")"}], "/", "l0"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"e3", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"LongAndShort", "[", 
            RowBox[{"[", 
             RowBox[{"ct", ",", "2"}], "]"}], "]"}], "-", "l0"}], ")"}], "/", 
         "l0"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Statxkpt", "[", "ct", "]"}], "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "e2"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"1", "+", "e3"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Statykpt", "[", "ct", "]"}], "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "e1"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"1", "+", "e2"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"ct", "=", 
        RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Kcount", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"Kcount", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"Kcount", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"kcont", "[", "ct", "]"}], "\[Element]", "Reals"}], ",", 
            RowBox[{"Break", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"Kcount", "=", "0"}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ct", "=", 
        RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"NumbKConts", "=", 
     RowBox[{"ct", "-", "2"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contour", "[", "d_", "]"}], ":=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Tooltip", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x", "-", "1"}], ")"}], "*", 
          RowBox[{"kcont", "[", "d", "]"}]}], "+", "1"}], ",", 
        RowBox[{"\"\<k = \>\"", " ", "<>", 
         RowBox[{"ToString", "[", 
          RowBox[{"N", "[", 
           RowBox[{"kcont", "[", "d", "]"}], "]"}], "]"}]}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "1", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"kcont", "[", "d", "]"}], "\[LessEqual]", "1"}], ",", 
          RowBox[{"(", 
           RowBox[{"plotmax", "*", "1.1"}], ")"}], ",", 
          RowBox[{"1", "+", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"plotmax", "*", "1.1"}], ")"}], "-", "1"}], ")"}], 
             "/", 
             RowBox[{"kcont", "[", "d", "]"}]}], ")"}]}]}], "]"}]}], "}"}], 
      ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Hue", "[", ".57", "]"}], ",", "Thin"}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"corner", "[", "1", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{"Kmax", ",", "\[Epsilon]smax"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"corner", "[", "2", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{"Kmax", ",", "\[Epsilon]smin"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"corner", "[", "3", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{"Kmin", ",", "\[Epsilon]smin"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"corner", "[", "4", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{"Kmin", ",", "\[Epsilon]smax"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lnaught", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"NormLong", "*", "1", "*", "NormShort"}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"1", "/", "3"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"e1", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"NormLong", "-", "lnaught"}], ")"}], "/", "lnaught"}]}], ";"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"e2", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", "lnaught"}], ")"}], "/", "lnaught"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"e3", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"NormShort", "-", "lnaught"}], ")"}], "/", "lnaught"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"khorzval", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "e2"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", "e3"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"kvertval", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", "e1"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", "e2"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"NormShort", "\[Equal]", "1"}], ",", 
      RowBox[{"K", "=", "\"\<\[Infinity]\>\""}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"kpt", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Tooltip", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PointSize", "[", "FlinnPtSize", "]"}], ",", "Flinncolor", 
           ",", 
           RowBox[{"Point", "[", 
            RowBox[{"{", 
             RowBox[{"khorzval", ",", "kvertval"}], "}"}], "]"}]}], "}"}], 
         ",", 
         RowBox[{"DisplayForm", "[", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"\"\<k = \>\"", "<>", 
              RowBox[{"ToString", "[", 
               RowBox[{"N", "[", "K", "]"}], "]"}]}], 
             RowBox[{"\"\<,  \[Epsilon]s = \>\"", "<>", 
              RowBox[{"ToString", "[", 
               RowBox[{"N", "[", "\[Epsilon]s", "]"}], "]"}]}]}], "}"}], 
           "]"}], "]"}]}], "]"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct", "\[LessEqual]", "4"}], ",", "\n", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"corner", "[", "ct", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], "\[Equal]", "0"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"LamdaOne", "=", "1"}], ";", 
          RowBox[{"LamdaTwo", "=", "1"}], ";", 
          RowBox[{"LamdaThree", "=", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", 
              SqrtBox[
               FractionBox["3", "2"]]}], " ", 
             RowBox[{
              RowBox[{"corner", "[", "ct", "]"}], "[", 
              RowBox[{"[", "2", "]"}], "]"}]}]]}], ";"}], ",", 
         RowBox[{
          RowBox[{"templong", "=", 
           RowBox[{"FindRoot", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               FractionBox["1", 
                SqrtBox["3"]], 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "/", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"corner", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], " ", "LongLenStat"}], 
                    ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    RowBox[{"corner", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "+", "LongLenStat"}], 
                    ")"}]}], ")"}], 
                    RowBox[{"1", "/", "3"}]]}], "]"}], "-", 
                    RowBox[{"Log", "[", 
                    RowBox[{"LongLenStat", "/", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"corner", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], " ", "LongLenStat"}], 
                    ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    RowBox[{"corner", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "+", "LongLenStat"}], 
                    ")"}]}], ")"}], 
                    RowBox[{"1", "/", "3"}]]}], "]"}]}], ")"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    RowBox[{"LongLenStat", "/", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"corner", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], " ", "LongLenStat"}], 
                    ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    RowBox[{"corner", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "+", "LongLenStat"}], 
                    ")"}]}], ")"}], 
                    RowBox[{"1", "/", "3"}]]}], "]"}], "-", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"corner", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"corner", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], " ", "LongLenStat"}], 
                    ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    RowBox[{"corner", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "+", "LongLenStat"}], 
                    ")"}]}], ")"}], 
                    RowBox[{"1", "/", "3"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    RowBox[{"corner", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "+", "LongLenStat"}], 
                    ")"}]}], ")"}]}], "]"}]}], ")"}], "2"], "+", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Log", "[", 
                    RowBox[{"1", "/", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"corner", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], " ", "LongLenStat"}], 
                    ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    RowBox[{"corner", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "+", "LongLenStat"}], 
                    ")"}]}], ")"}], 
                    RowBox[{"1", "/", "3"}]]}], "]"}]}], "+", 
                    RowBox[{"Log", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"corner", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"corner", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], " ", "LongLenStat"}], 
                    ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    RowBox[{"corner", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "+", "LongLenStat"}], 
                    ")"}]}], ")"}], 
                    RowBox[{"1", "/", "3"}]], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{
                    RowBox[{"corner", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "+", "LongLenStat"}], 
                    ")"}]}], ")"}]}], "]"}]}], ")"}], "2"]}], ")"}], 
                "0.5`"]}], "-", 
              RowBox[{
               RowBox[{"corner", "[", "ct", "]"}], "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"LongLenStat", ",", "1.00000001"}], "}"}]}], "]"}]}], 
          ";", 
          RowBox[{"LamdaOne", "=", 
           RowBox[{"templong", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";", 
          RowBox[{"LamdaTwo", "=", "1"}], ";", 
          RowBox[{"LamdaThree", "=", 
           FractionBox[
            RowBox[{
             RowBox[{"corner", "[", "ct", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              RowBox[{"corner", "[", "ct", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], "+", "LamdaOne"}]]}], ";"}]}], 
        "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"PrinMat", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            FractionBox["1", 
             SuperscriptBox["LamdaOne", "2"]], ",", "0", ",", "0"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            FractionBox["1", 
             SuperscriptBox["LamdaTwo", "2"]], ",", "0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", 
            FractionBox["1", 
             SuperscriptBox["LamdaThree", "2"]]}], "}"}]}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"L", "=", 
        RowBox[{"Eigenvalues", "[", "PrinMat", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"L", "=", 
        RowBox[{"Sort", "[", 
         RowBox[{"L", ",", "Greater"}], "]"}]}], ";", "\n", 
       RowBox[{"CornerLengths", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"L", "[", 
              RowBox[{"[", "3", "]"}], "]"}], "]"}]}], ")"}], ",", 
          RowBox[{"(", 
           RowBox[{"1", "/", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"L", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "]"}]}], ")"}], ",", 
          RowBox[{"(", 
           RowBox[{"1", "/", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"L", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ")"}]}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"lnaught", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"CornerLengths", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "*", 
           RowBox[{"CornerLengths", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "*", 
           RowBox[{"CornerLengths", "[", 
            RowBox[{"[", "3", "]"}], "]"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "3"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"e1", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"CornerLengths", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "-", "lnaught"}], ")"}], "/", 
         "lnaught"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"e2", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"CornerLengths", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "-", "lnaught"}], ")"}], "/", 
         "lnaught"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"e3", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"CornerLengths", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "-", "lnaught"}], ")"}], "/", 
         "lnaught"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Cornerkhorzval", "[", "ct", "]"}], "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "e2"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"1", "+", "e3"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Cornerkvertval", "[", "ct", "]"}], "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "e1"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"1", "+", "e2"}], ")"}]}]}], ";", "\n", 
       RowBox[{"ct", "=", 
        RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct", "\[LessEqual]", "statnumb"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"lnaught", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"NormalizedAxesLengths", "[", "ct", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], "*", 
           RowBox[{
            RowBox[{"NormalizedAxesLengths", "[", "ct", "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}], "*", 
           RowBox[{
            RowBox[{"NormalizedAxesLengths", "[", "ct", "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "3"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"e1", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"NormalizedAxesLengths", "[", "ct", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], "-", "lnaught"}], ")"}], "/", 
         "lnaught"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"e2", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"NormalizedAxesLengths", "[", "ct", "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}], "-", "lnaught"}], ")"}], "/", 
         "lnaught"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"e3", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"NormalizedAxesLengths", "[", "ct", "]"}], "[", 
            RowBox[{"[", "3", "]"}], "]"}], "-", "lnaught"}], ")"}], "/", 
         "lnaught"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Samplekhorzval", "[", "ct", "]"}], "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "e2"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"1", "+", "e3"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Samplekvertval", "[", "ct", "]"}], "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "e1"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"1", "+", "e2"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"ct", "=", 
        RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MaxVal", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Max", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Cornerkhorzval", "[", "x", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Samplekhorzval", "[", "x", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}]}], 
          "}"}], "]"}], ",", 
        RowBox[{"Max", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Cornerkvertval", "[", "x", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "1", ",", "4"}], "}"}]}], "]"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Samplekvertval", "[", "x", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}]}], 
          "}"}], "]"}]}], "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plotmax", "=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Round", "[", "MaxVal", "]"}], ">", "MaxVal"}], ",", 
       RowBox[{"Round", "[", "MaxVal", "]"}], ",", 
       RowBox[{
        RowBox[{"Round", "[", "MaxVal", "]"}], "+", "1"}]}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<plotmax\>\"", " ", "determines", " ", "the", " ", "maximum", " ", 
     "range", " ", "of", " ", "the", " ", "Flinn", " ", 
     RowBox[{"plot", ".", "  ", "You"}], " ", "can", " ", "overwrite", " ", 
     "this", " ", "value", " ", "by", " ", "deleting", " ", "the", " ", 
     "comment", " ", "marks", " ", "from", " ", "the", " ", "next", " ", 
     "line", " ", "and", " ", "input", " ", "any", " ", "value", " ", "that", 
     " ", "you", " ", 
     RowBox[{"wish", "."}]}], "  ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"plotmax", "=", "4"}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tempEpiSMax", "=", 
     RowBox[{
      SqrtBox[
       FractionBox["2", "3"]], " ", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Log", "[", 
           FractionBox["1", "plotmax"], "]"}], "2"], "-", 
         RowBox[{
          RowBox[{"Log", "[", 
           FractionBox["1", "plotmax"], "]"}], " ", 
          RowBox[{"Log", "[", "plotmax", "]"}]}], "+", 
         SuperscriptBox[
          RowBox[{"Log", "[", "plotmax", "]"}], "2"]}], ")"}]}]}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"\[Epsilon]scontmax", "=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Round", "[", 
         RowBox[{"tempEpiSMax", ",", "Flinncontinterval"}], "]"}], 
        "\[GreaterEqual]", "tempEpiSMax"}], ",", 
       RowBox[{
        RowBox[{"Round", "[", 
         RowBox[{"tempEpiSMax", ",", "Flinncontinterval"}], "]"}], "-", 
        "Flinncontinterval"}], ",", 
       RowBox[{"Round", "[", 
        RowBox[{"tempEpiSMax", ",", "Flinncontinterval"}], "]"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numb\[Epsilon]scontours", "=", 
     RowBox[{"\[Epsilon]scontmax", "/", "Flinncontinterval"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct", "\[LessEqual]", "numb\[Epsilon]scontours"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Epsilon]scont", "[", "ct", "]"}], "=", 
        RowBox[{"ct", "*", 
         RowBox[{"(", 
          RowBox[{"\[Epsilon]scontmax", "/", "numb\[Epsilon]scontours"}], 
          ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"ct", "=", 
        RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Epsilon]splot", "[", "d_", "]"}], ":=", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Tooltip", "[", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Log", "[", 
              FractionBox["1", "b"], "]"}], "+", 
             RowBox[{
              SqrtBox["3"], " ", 
              SqrtBox[
               RowBox[{
                RowBox[{"2", " ", 
                 SuperscriptBox[
                  RowBox[{"\[Epsilon]scont", "[", "d", "]"}], "2"]}], "-", 
                SuperscriptBox[
                 RowBox[{"Log", "[", 
                  FractionBox["1", "b"], "]"}], "2"]}]]}]}], ")"}]}]], ",", 
         RowBox[{"\"\<\[Epsilon]s = \>\"", "<>", 
          RowBox[{"ToString", "[", 
           RowBox[{"N", "[", 
            RowBox[{"\[Epsilon]scont", "[", "d", "]"}], "]"}], "]"}]}]}], 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"b", ",", "1", ",", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           SqrtBox[
            FractionBox["3", "2"]], "  ", 
           RowBox[{"\[Epsilon]scont", "[", "d", "]"}]}]]}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"GrayLevel", "[", ".5", "]"}], ",", 
          RowBox[{"Thickness", "[", ".001", "]"}], ",", 
          RowBox[{"Dashing", "[", 
           RowBox[{"{", 
            RowBox[{".015", ",", ".01"}], "}"}], "]"}]}], "}"}]}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"Flinn", ":=", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"contour", "[", "x", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "1", ",", "NumbKConts"}], "}"}]}], "]"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"\[Epsilon]splot", "[", "x", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "1", ",", "numb\[Epsilon]scontours"}], "}"}]}], 
        "]"}], ",", 
       RowBox[{"Axes", "\[Rule]", "True"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AxesStyle", "\[Rule]", "Thick"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ErrorPoly", "=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"khorzval", "\[Equal]", "1"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Thickness", "[", ".01", "]"}], ",", "Purple", ",", 
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"1", ",", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    FractionBox["1", "1"], "]"}], "+", 
                    RowBox[{
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smax", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "1"], "]"}], "2"]}]]}]}], ")"}]}]]}], 
                 "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    FractionBox["1", "1"], "]"}], "+", 
                    RowBox[{
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smin", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "1"], "]"}], "2"]}]]}]}], ")"}]}]]}], 
                 "}"}]}], "}"}], "]"}]}], "}"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Thickness", "[", ".01", "]"}], ",", "Purple", ",", 
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0.92", ",", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    FractionBox["1", "1"], "]"}], "+", 
                    RowBox[{
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smax", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "1"], "]"}], "2"]}]]}]}], ")"}]}]]}], 
                 "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"1.08", ",", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    FractionBox["1", "1"], "]"}], "+", 
                    RowBox[{
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smax", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "1"], "]"}], "2"]}]]}]}], ")"}]}]]}], 
                 "}"}]}], "}"}], "]"}]}], "}"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}]}], "]"}], ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Thickness", "[", ".01", "]"}], ",", "Purple", ",", 
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0.92", ",", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    FractionBox["1", "1"], "]"}], "+", 
                    RowBox[{
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smin", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "1"], "]"}], "2"]}]]}]}], ")"}]}]]}], 
                 "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"1.08", ",", 
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{
                    FractionBox["1", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    FractionBox["1", "1"], "]"}], "+", 
                    RowBox[{
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smin", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "1"], "]"}], "2"]}]]}]}], ")"}]}]]}], 
                 "}"}]}], "}"}], "]"}]}], "}"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}]}], "]"}]}], 
        "]"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Cornerkhorzval", "[", "1", "]"}], "<", 
          RowBox[{"Cornerkhorzval", "[", "3", "]"}]}], ",", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"x", "-", "1"}], ")"}], "*", "Kmax"}], "+", "1"}], 
               ",", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{
                 FractionBox["1", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "+", 
                   RowBox[{
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smin", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "2"]}]]}]}], ")"}]}]]}], 
              "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{"Cornerkhorzval", "[", "2", "]"}], ",", 
               RowBox[{"Cornerkhorzval", "[", "1", "]"}]}], "}"}], ",", 
             RowBox[{"Filling", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"1", "\[Rule]", 
                RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
             RowBox[{"FillingStyle", "\[Rule]", 
              RowBox[{"Directive", "[", 
               RowBox[{
                RowBox[{"Opacity", "[", "0.3", "]"}], ",", "Purple"}], 
               "]"}]}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{
                 FractionBox["1", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "+", 
                   RowBox[{
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smax", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "2"]}]]}]}], ")"}]}]], ",", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{
                 FractionBox["1", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "+", 
                   RowBox[{
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smin", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "2"]}]]}]}], ")"}]}]]}], 
              "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{"Cornerkhorzval", "[", "3", "]"}], ",", 
               RowBox[{"Cornerkhorzval", "[", "1", "]"}]}], "}"}], ",", 
             RowBox[{"Filling", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"1", "\[Rule]", 
                RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
             RowBox[{"FillingStyle", "\[Rule]", 
              RowBox[{"Directive", "[", 
               RowBox[{
                RowBox[{"Opacity", "[", "0.3", "]"}], ",", "Purple"}], 
               "]"}]}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{
                 FractionBox["1", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "+", 
                   RowBox[{
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smax", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "2"]}]]}]}], ")"}]}]], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"x", "-", "1"}], ")"}], "*", "Kmin"}], "+", "1"}]}],
               "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{"Cornerkhorzval", "[", "3", "]"}], ",", 
               RowBox[{"Cornerkhorzval", "[", "4", "]"}]}], "}"}], ",", 
             RowBox[{"Filling", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"1", "\[Rule]", 
                RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
             RowBox[{"FillingStyle", "\[Rule]", 
              RowBox[{"Directive", "[", 
               RowBox[{
                RowBox[{"Opacity", "[", "0.3", "]"}], ",", "Purple"}], 
               "]"}]}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"Plot", "[", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               FractionBox["1", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Log", "[", 
                  FractionBox["1", "x"], "]"}], "+", 
                 RowBox[{
                  SqrtBox["3"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smax", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "2"]}]]}]}], ")"}]}]], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{"Cornerkhorzval", "[", "4", "]"}], ",", 
               RowBox[{"Cornerkhorzval", "[", "1", "]"}]}], "}"}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Purple", ",", 
                RowBox[{"Thickness", "[", ".005", "]"}]}], "}"}]}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"Plot", "[", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               FractionBox["1", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Log", "[", 
                  FractionBox["1", "x"], "]"}], "+", 
                 RowBox[{
                  SqrtBox["3"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smin", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "2"]}]]}]}], ")"}]}]], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{"Cornerkhorzval", "[", "2", "]"}], ",", 
               RowBox[{"Cornerkhorzval", "[", "3", "]"}]}], "}"}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Purple", ",", 
                RowBox[{"Thickness", "[", ".005", "]"}]}], "}"}]}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"x", "-", "1"}], ")"}], "*", "Kmax"}], "+", "1"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{"Cornerkhorzval", "[", "2", "]"}], ",", 
               RowBox[{"Cornerkhorzval", "[", "1", "]"}]}], "}"}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Purple", ",", 
                RowBox[{"Thickness", "[", ".005", "]"}]}], "}"}]}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"x", "-", "1"}], ")"}], "*", "Kmin"}], "+", "1"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{"Cornerkhorzval", "[", "3", "]"}], ",", 
               RowBox[{"Cornerkhorzval", "[", "4", "]"}]}], "}"}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Purple", ",", 
                RowBox[{"Thickness", "[", ".005", "]"}]}], "}"}]}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}]}], "]"}]}], 
          "]"}], ",", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"x", "-", "1"}], ")"}], "*", "Kmax"}], "+", "1"}], 
               ",", 
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{
                 FractionBox["1", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "+", 
                   RowBox[{
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smin", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "2"]}]]}]}], ")"}]}]]}], 
              "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{"Cornerkhorzval", "[", "2", "]"}], ",", 
               RowBox[{"Cornerkhorzval", "[", "3", "]"}]}], "}"}], ",", 
             RowBox[{"Filling", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"1", "\[Rule]", 
                RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
             RowBox[{"FillingStyle", "\[Rule]", 
              RowBox[{"Directive", "[", 
               RowBox[{
                RowBox[{"Opacity", "[", "0.3", "]"}], ",", "Purple"}], 
               "]"}]}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"x", "-", "1"}], ")"}], "*", "Kmax"}], "+", "1"}], 
               ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"x", "-", "1"}], ")"}], "*", "Kmin"}], "+", "1"}]}],
               "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{"Cornerkhorzval", "[", "3", "]"}], ",", 
               RowBox[{"Cornerkhorzval", "[", "1", "]"}]}], "}"}], ",", 
             RowBox[{"Filling", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"1", "\[Rule]", 
                RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
             RowBox[{"FillingStyle", "\[Rule]", 
              RowBox[{"Directive", "[", 
               RowBox[{
                RowBox[{"Opacity", "[", "0.3", "]"}], ",", "Purple"}], 
               "]"}]}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               SuperscriptBox["\[ExponentialE]", 
                RowBox[{
                 FractionBox["1", "2"], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "+", 
                   RowBox[{
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smax", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "2"]}]]}]}], ")"}]}]], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"x", "-", "1"}], ")"}], "*", "Kmin"}], "+", "1"}]}],
               "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{"Cornerkhorzval", "[", "4", "]"}], ",", 
               RowBox[{"Cornerkhorzval", "[", "1", "]"}]}], "}"}], ",", 
             RowBox[{"Filling", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"1", "\[Rule]", 
                RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
             RowBox[{"FillingStyle", "\[Rule]", 
              RowBox[{"Directive", "[", 
               RowBox[{
                RowBox[{"Opacity", "[", "0.3", "]"}], ",", "Purple"}], 
               "]"}]}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"Plot", "[", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               FractionBox["1", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Log", "[", 
                  FractionBox["1", "x"], "]"}], "+", 
                 RowBox[{
                  SqrtBox["3"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smax", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "2"]}]]}]}], ")"}]}]], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{"Cornerkhorzval", "[", "4", "]"}], ",", 
               RowBox[{"Cornerkhorzval", "[", "1", "]"}]}], "}"}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Purple", ",", 
                RowBox[{"Thickness", "[", ".005", "]"}]}], "}"}]}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"Plot", "[", 
            RowBox[{
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               FractionBox["1", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Log", "[", 
                  FractionBox["1", "x"], "]"}], "+", 
                 RowBox[{
                  SqrtBox["3"], " ", 
                  SqrtBox[
                   RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smin", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "2"]}]]}]}], ")"}]}]], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{"Cornerkhorzval", "[", "2", "]"}], ",", 
               RowBox[{"Cornerkhorzval", "[", "3", "]"}]}], "}"}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Purple", ",", 
                RowBox[{"Thickness", "[", ".005", "]"}]}], "}"}]}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"x", "-", "1"}], ")"}], "*", "Kmax"}], "+", "1"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{"Cornerkhorzval", "[", "2", "]"}], ",", 
               RowBox[{"Cornerkhorzval", "[", "1", "]"}]}], "}"}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Purple", ",", 
                RowBox[{"Thickness", "[", ".005", "]"}]}], "}"}]}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}]}], "]"}], 
           ",", 
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"x", "-", "1"}], ")"}], "*", "Kmin"}], "+", "1"}], 
             ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{"Cornerkhorzval", "[", "3", "]"}], ",", 
               RowBox[{"Cornerkhorzval", "[", "4", "]"}]}], "}"}], ",", 
             RowBox[{"PlotStyle", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"Purple", ",", 
                RowBox[{"Thickness", "[", ".005", "]"}]}], "}"}]}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}]}], "]"}]}], 
          "]"}]}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"khorzval", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"IrregularErrorArea", "=", "\n", 
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"Integrate", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Log", "[", 
                   FractionBox["1", "x"], "]"}], "+", 
                  RowBox[{
                   SqrtBox["3"], " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smax", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "2"]}]]}]}], ")"}]}]], 
              ")"}], "-", 
             RowBox[{"(", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Log", "[", 
                   FractionBox["1", "x"], "]"}], "+", 
                  RowBox[{
                   SqrtBox["3"], " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smin", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "2"]}]]}]}], ")"}]}]], 
              ")"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "0", ",", 
              RowBox[{"Cornerkhorzval", "[", "3", "]"}]}], "}"}]}], "]"}], 
          "]"}], "+", 
         RowBox[{"N", "[", 
          RowBox[{"Integrate", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Log", "[", 
                   FractionBox["1", "x"], "]"}], "+", 
                  RowBox[{
                   SqrtBox["3"], " ", 
                   SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smax", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "2"]}]]}]}], ")"}]}]], 
              ")"}], "-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"x", "-", "1"}], ")"}], "*", "Kmin"}], "+", "1"}], 
              ")"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", 
              RowBox[{"Cornerkhorzval", "[", "3", "]"}], ",", 
              RowBox[{"Cornerkhorzval", "[", "4", "]"}]}], "}"}]}], "]"}], 
          "]"}]}]}], ";"}], ",", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Cornerkhorzval", "[", "1", "]"}], ">", 
          RowBox[{"Cornerkhorzval", "[", "3", "]"}]}], ",", 
         RowBox[{
          RowBox[{"IrregularErrorArea", "=", 
           RowBox[{
            RowBox[{"N", "[", 
             RowBox[{"Integrate", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"x", "-", "1"}], ")"}], "*", "Kmax"}], "+", "1"}],
                  ")"}], "-", 
                RowBox[{"(", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{
                   FractionBox["1", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "+", 
                    RowBox[{
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smin", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "2"]}]]}]}], ")"}]}]], 
                 ")"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", 
                 RowBox[{"Cornerkhorzval", "[", "2", "]"}], ",", 
                 RowBox[{"Cornerkhorzval", "[", "3", "]"}]}], "}"}]}], "]"}], 
             "]"}], "+", 
            RowBox[{"N", "[", 
             RowBox[{"Integrate", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"x", "-", "1"}], ")"}], "*", "Kmax"}], "+", "1"}],
                  ")"}], "-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"x", "-", "1"}], ")"}], "*", "Kmin"}], "+", "1"}],
                  ")"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", 
                 RowBox[{"Cornerkhorzval", "[", "3", "]"}], ",", 
                 RowBox[{"Cornerkhorzval", "[", "1", "]"}]}], "}"}]}], "]"}], 
             "]"}], "+", 
            RowBox[{"N", "[", 
             RowBox[{"Integrate", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{
                   FractionBox["1", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "+", 
                    RowBox[{
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smax", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "2"]}]]}]}], ")"}]}]], 
                 ")"}], "-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"x", "-", "1"}], ")"}], "*", "Kmin"}], "+", "1"}],
                  ")"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", 
                 RowBox[{"Cornerkhorzval", "[", "1", "]"}], ",", 
                 RowBox[{"Cornerkhorzval", "[", "4", "]"}]}], "}"}]}], "]"}], 
             "]"}]}]}], ";"}]}], "]"}], ";", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Cornerkhorzval", "[", "1", "]"}], "\[LessEqual]", 
          RowBox[{"Cornerkhorzval", "[", "3", "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"IrregularErrorArea", "=", 
           RowBox[{
            RowBox[{"N", "[", 
             RowBox[{"Integrate", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"x", "-", "1"}], ")"}], "*", "Kmax"}], "+", "1"}],
                  ")"}], "-", 
                RowBox[{"(", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{
                   FractionBox["1", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "+", 
                    RowBox[{
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smin", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "2"]}]]}]}], ")"}]}]], 
                 ")"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", 
                 RowBox[{"Cornerkhorzval", "[", "2", "]"}], ",", 
                 RowBox[{"Cornerkhorzval", "[", "1", "]"}]}], "}"}]}], "]"}], 
             "]"}], "+", 
            RowBox[{"N", "[", 
             RowBox[{"Integrate", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{
                   FractionBox["1", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "+", 
                    RowBox[{
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smax", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "2"]}]]}]}], ")"}]}]], 
                 ")"}], "-", 
                RowBox[{"(", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{
                   FractionBox["1", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "+", 
                    RowBox[{
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smin", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "2"]}]]}]}], ")"}]}]], 
                 ")"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", 
                 RowBox[{"Cornerkhorzval", "[", "1", "]"}], ",", 
                 RowBox[{"Cornerkhorzval", "[", "3", "]"}]}], "}"}]}], "]"}], 
             "]"}], "+", 
            RowBox[{"N", "[", 
             RowBox[{"Integrate", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 SuperscriptBox["\[ExponentialE]", 
                  RowBox[{
                   FractionBox["1", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "+", 
                    RowBox[{
                    SqrtBox["3"], " ", 
                    SqrtBox[
                    RowBox[{
                    RowBox[{"2", " ", 
                    SuperscriptBox["\[Epsilon]smax", "2"]}], "-", 
                    SuperscriptBox[
                    RowBox[{"Log", "[", 
                    FractionBox["1", "x"], "]"}], "2"]}]]}]}], ")"}]}]], 
                 ")"}], "-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"x", "-", "1"}], ")"}], "*", "Kmin"}], "+", "1"}],
                  ")"}]}], ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", 
                 RowBox[{"Cornerkhorzval", "[", "3", "]"}], ",", 
                 RowBox[{"Cornerkhorzval", "[", "4", "]"}]}], "}"}]}], "]"}], 
             "]"}]}]}], ";"}]}], "]"}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Max95Kvert", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"histoLengths", "[", "x", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", "globalct"}], "}"}]}], "]"}], "]"}]}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"Min95Kvert", "=", 
     RowBox[{"Min", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"histoLengths", "[", "x", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", "globalct"}], "}"}]}], "]"}], "]"}]}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"Min95Khorz", "=", 
     RowBox[{"(", 
      RowBox[{"1", "/", 
       RowBox[{"Max", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"histoLengths", "[", "x", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", "globalct"}], "}"}]}], "]"}], "]"}]}], 
      ")"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Max95Khorz", "=", 
     RowBox[{"(", 
      RowBox[{"1", "/", 
       RowBox[{"Min", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"histoLengths", "[", "x", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", "globalct"}], "}"}]}], "]"}], "]"}]}], 
      ")"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"RectErrorArea", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Max", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"histoLengths", "[", "x", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", "globalct"}], "}"}]}], "]"}], "]"}], 
        "-", 
        RowBox[{"Min", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"histoLengths", "[", "x", "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "0", ",", "globalct"}], "}"}]}], "]"}], "]"}]}],
        ")"}], "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "/", 
          RowBox[{"Min", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"histoLengths", "[", "x", "]"}], "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "0", ",", "globalct"}], "}"}]}], "]"}], 
           "]"}]}], ")"}], "-", 
        RowBox[{"(", 
         RowBox[{"1", "/", 
          RowBox[{"Max", "[", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"histoLengths", "[", "x", "]"}], "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "0", ",", "globalct"}], "}"}]}], "]"}], 
           "]"}]}], ")"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"RectErrorArea", "*", "ErrorShapePercent"}], "<", 
       "IrregularErrorArea"}], ",", 
      RowBox[{
       RowBox[{"ErrorPoly", "=", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{"Purple", ",", 
           RowBox[{"Opacity", "[", "0.5", "]"}], ",", 
           RowBox[{"EdgeForm", "[", 
            RowBox[{"Directive", "[", 
             RowBox[{"Thick", ",", "Purple"}], "]"}], "]"}], ",", 
           RowBox[{"Polygon", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"Min95Khorz", ",", "Max95Kvert"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"Max95Khorz", ",", "Max95Kvert"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"Max95Khorz", ",", "Min95Kvert"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"Min95Khorz", ",", "Min95Kvert"}], "}"}]}], "}"}], 
            "]"}]}], "}"}], "]"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"RectErrorArea", "*", "ErrorShapePercent"}], "<", 
       "IrregularErrorArea"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"Pt", "[", "1", "]"}], "=", 
        RowBox[{"{", 
         RowBox[{"Min95Khorz", ",", "Max95Kvert"}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Pt", "[", "2", "]"}], "=", 
        RowBox[{"{", 
         RowBox[{"Min95Khorz", ",", "Min95Kvert"}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Pt", "[", "3", "]"}], "=", 
        RowBox[{"{", 
         RowBox[{"Max95Khorz", ",", "Min95Kvert"}], "}"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Pt", "[", "4", "]"}], "=", 
        RowBox[{"{", 
         RowBox[{"Max95Khorz", ",", "Max95Kvert"}], "}"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"PosRxy", "=", 
        RowBox[{"Max95Khorz", "-", 
         RowBox[{"(", 
          RowBox[{"1", "/", "NormShort"}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"NegRxy", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "/", "NormShort"}], ")"}], "-", "Min95Khorz"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"PosRyz", "=", 
        RowBox[{"Max95Kvert", "-", "NormLong"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"NegRyz", "=", 
        RowBox[{"NormLong", "-", "Min95Kvert"}]}], ";", "\[IndentingNewLine]",
        "\[IndentingNewLine]", 
       RowBox[{"l0", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Max95Kvert", "*", "1", "*", 
           RowBox[{"(", 
            RowBox[{"1", "/", "Min95Khorz"}], ")"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "3"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"\[Epsilon]1", "=", 
        RowBox[{"Log", "[", 
         RowBox[{"Max95Kvert", "/", "l0"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Epsilon]2", "=", 
        RowBox[{"Log", "[", 
         RowBox[{"1", "/", "l0"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"\[Epsilon]3", "=", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", "Min95Khorz"}], ")"}], "/", "l0"}], "]"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"EpiS", "[", "1", "]"}], "=", 
        RowBox[{
         FractionBox["1", "3"], " ", 
         SqrtBox["3"], 
         RowBox[{"(", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"\[Epsilon]3", "-", "\[Epsilon]2"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"\[Epsilon]2", "-", "\[Epsilon]1"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"\[Epsilon]1", "-", "\[Epsilon]3"}], ")"}], "2"]}], 
            ")"}], ".5"], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"kvalue", "[", "1", "]"}], "=", 
        FractionBox[
         RowBox[{
          FractionBox["Max95Kvert", "1"], "-", "1"}], 
         RowBox[{
          FractionBox["1", 
           RowBox[{"(", 
            RowBox[{"1", "/", "Min95Khorz"}], ")"}]], "-", "1"}]]}], ";", 
       "\n", 
       RowBox[{"l0", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Min95Kvert", "*", "1", "*", 
           RowBox[{"(", 
            RowBox[{"1", "/", "Min95Khorz"}], ")"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "3"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"\[Epsilon]1", "=", 
        RowBox[{"Log", "[", 
         RowBox[{"Min95Kvert", "/", "l0"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Epsilon]2", "=", 
        RowBox[{"Log", "[", 
         RowBox[{"1", "/", "l0"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"\[Epsilon]3", "=", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", "Min95Khorz"}], ")"}], "/", "l0"}], "]"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"EpiS", "[", "2", "]"}], "=", 
        RowBox[{
         FractionBox["1", "3"], " ", 
         SqrtBox["3"], 
         RowBox[{"(", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"\[Epsilon]3", "-", "\[Epsilon]2"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"\[Epsilon]2", "-", "\[Epsilon]1"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"\[Epsilon]1", "-", "\[Epsilon]3"}], ")"}], "2"]}], 
            ")"}], ".5"], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"kvalue", "[", "2", "]"}], "=", 
        FractionBox[
         RowBox[{
          FractionBox["Min95Kvert", "1"], "-", "1"}], 
         RowBox[{
          FractionBox["1", 
           RowBox[{"(", 
            RowBox[{"1", "/", "Min95Khorz"}], ")"}]], "-", "1"}]]}], ";", 
       "\n", 
       RowBox[{"l0", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Min95Kvert", "*", "1", "*", 
           RowBox[{"(", 
            RowBox[{"1", "/", "Max95Khorz"}], ")"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "3"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"\[Epsilon]1", "=", 
        RowBox[{"Log", "[", 
         RowBox[{"Min95Kvert", "/", "l0"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Epsilon]2", "=", 
        RowBox[{"Log", "[", 
         RowBox[{"1", "/", "l0"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"\[Epsilon]3", "=", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", "Max95Khorz"}], ")"}], "/", "l0"}], "]"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"EpiS", "[", "3", "]"}], "=", 
        RowBox[{
         FractionBox["1", "3"], " ", 
         SqrtBox["3"], 
         RowBox[{"(", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"\[Epsilon]3", "-", "\[Epsilon]2"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"\[Epsilon]2", "-", "\[Epsilon]1"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"\[Epsilon]1", "-", "\[Epsilon]3"}], ")"}], "2"]}], 
            ")"}], ".5"], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"kvalue", "[", "3", "]"}], "=", 
        FractionBox[
         RowBox[{
          FractionBox["Min95Kvert", "1"], "-", "1"}], 
         RowBox[{
          FractionBox["1", 
           RowBox[{"(", 
            RowBox[{"1", "/", "Max95Khorz"}], ")"}]], "-", "1"}]]}], ";", 
       "\n", 
       RowBox[{"l0", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Max95Kvert", "*", "1", "*", 
           RowBox[{"(", 
            RowBox[{"1", "/", "Max95Khorz"}], ")"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "3"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"\[Epsilon]1", "=", 
        RowBox[{"Log", "[", 
         RowBox[{"Max95Kvert", "/", "l0"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Epsilon]2", "=", 
        RowBox[{"Log", "[", 
         RowBox[{"1", "/", "l0"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"\[Epsilon]3", "=", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", "Max95Khorz"}], ")"}], "/", "l0"}], "]"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"EpiS", "[", "4", "]"}], "=", 
        RowBox[{
         FractionBox["1", "3"], " ", 
         SqrtBox["3"], 
         RowBox[{"(", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"\[Epsilon]3", "-", "\[Epsilon]2"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"\[Epsilon]2", "-", "\[Epsilon]1"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"\[Epsilon]1", "-", "\[Epsilon]3"}], ")"}], "2"]}], 
            ")"}], ".5"], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"kvalue", "[", "4", "]"}], "=", 
        FractionBox[
         RowBox[{
          FractionBox["Max95Kvert", "1"], "-", "1"}], 
         RowBox[{
          FractionBox["1", 
           RowBox[{"(", 
            RowBox[{"1", "/", "Max95Khorz"}], ")"}]], "-", "1"}]]}], ";"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"Pt", "[", "1", "]"}], "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cornerkhorzval", "[", "1", "]"}], ",", 
          RowBox[{"Cornerkvertval", "[", "1", "]"}]}], "}"}]}], ";", 
       RowBox[{
        RowBox[{"kvalue", "[", "1", "]"}], "=", "Kmax"}], ";", 
       RowBox[{
        RowBox[{"EpiS", "[", "1", "]"}], "=", "\[Epsilon]smax"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Pt", "[", "2", "]"}], "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cornerkhorzval", "[", "2", "]"}], ",", 
          RowBox[{"Cornerkvertval", "[", "2", "]"}]}], "}"}]}], ";", 
       RowBox[{
        RowBox[{"kvalue", "[", "2", "]"}], "=", "Kmax"}], ";", 
       RowBox[{
        RowBox[{"EpiS", "[", "2", "]"}], "=", "\[Epsilon]smin"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Pt", "[", "3", "]"}], "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cornerkhorzval", "[", "3", "]"}], ",", 
          RowBox[{"Cornerkvertval", "[", "3", "]"}]}], "}"}]}], ";", 
       RowBox[{
        RowBox[{"kvalue", "[", "3", "]"}], "=", "Kmin"}], ";", 
       RowBox[{
        RowBox[{"EpiS", "[", "3", "]"}], "=", "\[Epsilon]smin"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Pt", "[", "4", "]"}], "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cornerkhorzval", "[", "4", "]"}], ",", 
          RowBox[{"Cornerkvertval", "[", "4", "]"}]}], "}"}]}], ";", 
       RowBox[{
        RowBox[{"kvalue", "[", "4", "]"}], "=", "Kmin"}], ";", 
       RowBox[{
        RowBox[{"EpiS", "[", "4", "]"}], "=", "\[Epsilon]smax"}], ";"}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LabelCorners", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Tooltip", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"PointSize", "[", "0.001", "]"}], ",", "Purple", ",", 
             RowBox[{"Point", "[", 
              RowBox[{"Pt", "[", "x", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"DisplayForm", "[", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\"\<k = \>\"", "<>", 
                RowBox[{"ToString", "[", 
                 RowBox[{"N", "[", 
                  RowBox[{"kvalue", "[", "x", "]"}], "]"}], "]"}]}], 
               RowBox[{"\"\<,  \[Epsilon]s = \>\"", "<>", 
                RowBox[{"ToString", "[", 
                 RowBox[{"N", "[", 
                  RowBox[{"EpiS", "[", "x", "]"}], "]"}], "]"}]}]}], "}"}], 
             "]"}], "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "1", ",", "4"}], "}"}]}], "]"}], "]"}], "]"}]}], 
    ";"}], "\n", "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ctvert", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"globalct", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ctvert", "\[LessEqual]", "bufferedvertnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"cthorz", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"cthorz", "\[LessEqual]", "bufferedhorznumb"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"histo", "[", "ct", "]"}], "[", 
              RowBox[{"[", "3", "]"}], "]"}], ">", "HeightThresh"}], ",", 
            RowBox[{
             RowBox[{"globalct", "=", 
              RowBox[{"globalct", "+", "1"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"containgrid", "[", "globalct", "]"}], "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Round", "[", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"histo", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", "Lflim"}], ")"}], 
                    "/", "horzcellsize"}], ")"}], "+", "0.5"}], "]"}], ",", 
                RowBox[{"Round", "[", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Upperlim", "-", 
                    RowBox[{
                    RowBox[{"histo", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "/", 
                    "vertcellsize"}], ")"}], "+", "0.5"}], "]"}]}], "}"}]}], 
             ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"newgridsqr", "[", 
               RowBox[{"cthorz", ",", "ctvert"}], "]"}], "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Round", "[", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"histo", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "-", "Lflim"}], ")"}], 
                    "/", "horzcellsize"}], ")"}], "+", "0.5"}], "]"}], ",", 
                RowBox[{"Round", "[", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"Upperlim", "-", 
                    RowBox[{
                    RowBox[{"histo", "[", "ct", "]"}], "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "/", 
                    "vertcellsize"}], ")"}], "+", "0.5"}], "]"}]}], "}"}]}], 
             ";"}], ",", 
            RowBox[{
             RowBox[{"newgridsqr", "[", 
              RowBox[{"cthorz", ",", "ctvert"}], "]"}], "=", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"ct", "=", 
           RowBox[{"ct", "+", "1"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"cthorz", "=", 
           RowBox[{"cthorz", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ctvert", "=", 
        RowBox[{"ctvert", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"sqrnumb", "=", 
     RowBox[{
      RowBox[{"Dimensions", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"containgrid", "[", "x", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "1", ",", "globalct"}], "}"}]}], "]"}], "]"}], 
      "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cnting", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"perimnumb", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"cnting", "\[LessEqual]", "sqrnumb"}], ",", "\n", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"newgridsqr", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"containgrid", "[", "cnting", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"containgrid", "[", "cnting", "]"}], "[", 
              RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "]"}], "\[Equal]", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}]}], ",", 
         RowBox[{
          RowBox[{"top", "=", "0"}], ";"}], ",", 
         RowBox[{
          RowBox[{"top", "=", "1"}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"newgridsqr", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"containgrid", "[", "cnting", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], "+", "1"}], ",", 
            RowBox[{
             RowBox[{"containgrid", "[", "cnting", "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "\[Equal]", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}]}], ",", 
         RowBox[{
          RowBox[{"rt", "=", "0"}], ";"}], ",", 
         RowBox[{
          RowBox[{"rt", "=", "1"}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"newgridsqr", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"containgrid", "[", "cnting", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"containgrid", "[", "cnting", "]"}], "[", 
              RowBox[{"[", "2", "]"}], "]"}], "+", "1"}]}], "]"}], "\[Equal]", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}]}], ",", 
         RowBox[{
          RowBox[{"bottom", "=", "0"}], ";"}], ",", 
         RowBox[{
          RowBox[{"bottom", "=", "1"}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"newgridsqr", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"containgrid", "[", "cnting", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
            RowBox[{
             RowBox[{"containgrid", "[", "cnting", "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "\[Equal]", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}]}], ",", 
         RowBox[{
          RowBox[{"lf", "=", "0"}], ";"}], ",", 
         RowBox[{
          RowBox[{"lf", "=", "1"}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"top", "\[Equal]", "0"}], 
          StyleBox["||", "OperatorCharacter"], 
          RowBox[{
           StyleBox["rt", "OperatorCharacter"], 
           StyleBox["\[Equal]", "OperatorCharacter"], "0"}], 
          StyleBox["||", "OperatorCharacter"], 
          RowBox[{
           StyleBox["bottom", "OperatorCharacter"], 
           StyleBox["\[Equal]", "OperatorCharacter"], "0"}], 
          StyleBox["||", "OperatorCharacter"], 
          RowBox[{
           StyleBox["lf", "OperatorCharacter"], 
           StyleBox["\[Equal]", "OperatorCharacter"], "0"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"perimnumb", "=", 
           RowBox[{"perimnumb", "+", "1"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"perimdata", "[", "perimnumb", "]"}], "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"containgrid", "[", "cnting", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"containgrid", "[", "cnting", "]"}], "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "top", ",", "rt", ",", 
             "bottom", ",", "lf"}], "}"}]}], ";"}]}], "]"}], ";", "\n", 
       RowBox[{"cnting", "=", 
        RowBox[{"cnting", "+", "1"}]}], ";"}]}], "]"}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"cnting2", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"edgect", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"cnting2", "\[LessEqual]", "perimnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
           RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"edgect", "=", 
           RowBox[{"edgect", "+", "1"}]}], ";", 
          RowBox[{
           RowBox[{"edgelist", "[", "edgect", "]"}], "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
             "0"}], "}"}]}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
           RowBox[{"[", "4", "]"}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"edgect", "=", 
           RowBox[{"edgect", "+", "1"}]}], ";", 
          RowBox[{
           RowBox[{"edgelist", "[", "edgect", "]"}], "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", "0"}], "}"}]}], 
          ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
           RowBox[{"[", "5", "]"}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"edgect", "=", 
           RowBox[{"edgect", "+", "1"}]}], ";", 
          RowBox[{
           RowBox[{"edgelist", "[", "edgect", "]"}], "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", 
               RowBox[{
                RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
               RowBox[{
                RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", "0"}], "}"}]}], 
          ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
           RowBox[{"[", "6", "]"}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"edgect", "=", 
           RowBox[{"edgect", "+", "1"}]}], ";", 
          RowBox[{
           RowBox[{"edgelist", "[", "edgect", "]"}], "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
               RowBox[{
                RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
                 RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"perimdata", "[", "cnting2", "]"}], "[", 
                 RowBox[{"[", "2", "]"}], "]"}], "-", "1"}]}], "}"}], ",", 
             "0"}], "}"}]}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"cnting2", "=", 
        RowBox[{"cnting2", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"edgedim", "=", 
     RowBox[{
      RowBox[{"Dimensions", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"edgelist", "[", "x", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "1", ",", "edgect"}], "}"}]}], "]"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ReorganizedEdgeList", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"edgelist", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "edgedim"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"edgingct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"perimct", "=", "2"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nextposition", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"islandnumb", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"StartPt", "[", "1", "]"}], "=", 
     RowBox[{"ReorganizedEdgeList", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PerimeterList", "[", 
      RowBox[{"1", ",", "1"}], "]"}], "=", 
     RowBox[{"ReorganizedEdgeList", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ReorganizedEdgeList", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "=", 
     RowBox[{"ReplacePart", "[", 
      RowBox[{
       RowBox[{"ReorganizedEdgeList", "[", 
        RowBox[{"[", "edgingct", "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"{", "3", "}"}], "\[Rule]", "1"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"edgingct", "\[LessEqual]", "edgedim"}], ",", "\n", 
      RowBox[{
       RowBox[{"positdim", "=", 
        RowBox[{
         RowBox[{"Dimensions", "[", 
          RowBox[{"Position", "[", 
           RowBox[{
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"ReorganizedEdgeList", "[", 
               RowBox[{"[", 
                RowBox[{"x", ",", "1"}], "]"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", "1", ",", "edgedim"}], "}"}]}], "]"}], ",", 
            RowBox[{"ReorganizedEdgeList", "[", 
             RowBox[{"[", 
              RowBox[{"nextposition", ",", "2"}], "]"}], "]"}]}], "]"}], 
          "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", 
       RowBox[{"nextposition", "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"positdim", "\[Equal]", "1"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Position", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"ReorganizedEdgeList", "[", 
                 RowBox[{"[", 
                  RowBox[{"x", ",", "1"}], "]"}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"x", ",", "1", ",", "edgedim"}], "}"}]}], "]"}], ",", 
              RowBox[{"ReorganizedEdgeList", "[", 
               RowBox[{"[", 
                RowBox[{"nextposition", ",", "2"}], "]"}], "]"}]}], "]"}], 
            "[", 
            RowBox[{"[", "1", "]"}], "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"firstpos", "=", 
            RowBox[{
             RowBox[{
              RowBox[{"Position", "[", 
               RowBox[{
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"ReorganizedEdgeList", "[", 
                   RowBox[{"[", 
                    RowBox[{"x", ",", "1"}], "]"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"x", ",", "1", ",", "edgedim"}], "}"}]}], "]"}], 
                ",", 
                RowBox[{"ReorganizedEdgeList", "[", 
                 RowBox[{"[", 
                  RowBox[{"nextposition", ",", "2"}], "]"}], "]"}]}], "]"}], 
              "[", 
              RowBox[{"[", "1", "]"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"secondpos", "=", 
            RowBox[{
             RowBox[{
              RowBox[{"Position", "[", 
               RowBox[{
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"ReorganizedEdgeList", "[", 
                   RowBox[{"[", 
                    RowBox[{"x", ",", "1"}], "]"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"x", ",", "1", ",", "edgedim"}], "}"}]}], "]"}], 
                ",", 
                RowBox[{"ReorganizedEdgeList", "[", 
                 RowBox[{"[", 
                  RowBox[{"nextposition", ",", "2"}], "]"}], "]"}]}], "]"}], 
              "[", 
              RowBox[{"[", "2", "]"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"ReorganizedEdgeList", "[", 
                RowBox[{"[", "firstpos", "]"}], "]"}], "[", 
               RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "0"}], ",", 
             "firstpos", ",", "secondpos"}], "]"}]}]}], "]"}]}], ";", "\n", 
       "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ReorganizedEdgeList", "[", 
           RowBox[{"[", 
            RowBox[{"nextposition", ",", "1"}], "]"}], "]"}], "\[NotEqual]", 
          RowBox[{"StartPt", "[", "islandnumb", "]"}]}], ",", "\n", 
         RowBox[{
          RowBox[{
           RowBox[{"PerimeterList", "[", 
            RowBox[{"islandnumb", ",", "perimct"}], "]"}], "=", 
           RowBox[{"ReorganizedEdgeList", "[", 
            RowBox[{"[", 
             RowBox[{"nextposition", ",", "1"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"ReorganizedEdgeList", "[", 
            RowBox[{"[", "nextposition", "]"}], "]"}], "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{
             RowBox[{"ReorganizedEdgeList", "[", 
              RowBox[{"[", "nextposition", "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"{", "3", "}"}], "\[Rule]", "1"}]}], "]"}]}], ";", "\n", 
          RowBox[{"perimct", "=", 
           RowBox[{"perimct", "+", "1"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"edgingct", "=", 
           RowBox[{"edgingct", "+", "1"}]}], ";"}], ",", 
         "\[IndentingNewLine]", "\n", 
         RowBox[{
          RowBox[{
           RowBox[{"DimPerimeterList", "[", "islandnumb", "]"}], "=", 
           "perimct"}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"PerimeterList", "[", 
            RowBox[{"islandnumb", ",", "perimct"}], "]"}], "=", 
           RowBox[{"ReorganizedEdgeList", "[", 
            RowBox[{"[", 
             RowBox[{"nextposition", ",", "1"}], "]"}], "]"}]}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"edgingct", "\[Equal]", "edgedim"}], ",", 
            RowBox[{"Break", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"perimct", "=", "2"}], ";", "\[IndentingNewLine]", 
          RowBox[{"islandnumb", "=", 
           RowBox[{"islandnumb", "+", "1"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"StartPt", "[", "islandnumb", "]"}], "=", 
           RowBox[{
            RowBox[{"ReorganizedEdgeList", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{
                RowBox[{"Position", "[", 
                 RowBox[{
                  RowBox[{"Table", "[", 
                   RowBox[{
                    RowBox[{"ReorganizedEdgeList", "[", 
                    RowBox[{"[", 
                    RowBox[{"x", ",", "3"}], "]"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "1", ",", "edgedim"}], "}"}]}], "]"}], 
                  ",", "0"}], "]"}], "[", 
                RowBox[{"[", "1", "]"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", 
          RowBox[{"nextposition", "=", 
           RowBox[{
            RowBox[{
             RowBox[{"Position", "[", 
              RowBox[{
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"ReorganizedEdgeList", "[", 
                  RowBox[{"[", 
                   RowBox[{"x", ",", "3"}], "]"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"x", ",", "1", ",", "edgedim"}], "}"}]}], "]"}], 
               ",", "0"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"PerimeterList", "[", 
            RowBox[{"islandnumb", ",", "1"}], "]"}], "=", 
           RowBox[{"ReorganizedEdgeList", "[", 
            RowBox[{"[", 
             RowBox[{"nextposition", ",", "1"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"ReorganizedEdgeList", "[", 
            RowBox[{"[", "nextposition", "]"}], "]"}], "=", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{
             RowBox[{"ReorganizedEdgeList", "[", 
              RowBox[{"[", "nextposition", "]"}], "]"}], ",", 
             RowBox[{
              RowBox[{"{", "3", "}"}], "\[Rule]", "1"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"edgingct", "=", 
           RowBox[{"edgingct", "+", "1"}]}], ";"}]}], "]"}], ";"}]}], "]"}], 
    ";"}], "\n", "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"reducect2", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"reducect2", "\[LessEqual]", "islandnumb"}], ",", "\n", 
      RowBox[{
       RowBox[{"reducect", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"PerimeterList", "[", 
         RowBox[{"reducect2", ",", 
          RowBox[{
           RowBox[{"DimPerimeterList", "[", "reducect2", "]"}], "+", "1"}]}], 
         "]"}], "=", 
        RowBox[{"PerimeterList", "[", 
         RowBox[{"reducect2", ",", "2"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"PerimeterList", "[", 
         RowBox[{"reducect2", ",", 
          RowBox[{
           RowBox[{"DimPerimeterList", "[", "reducect2", "]"}], "+", "2"}]}], 
         "]"}], "=", 
        RowBox[{"PerimeterList", "[", 
         RowBox[{"reducect2", ",", "3"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tempPerimList", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"PerimeterList", "[", 
           RowBox[{"reducect2", ",", "x"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "1", ",", 
            RowBox[{
             RowBox[{"DimPerimeterList", "[", "reducect2", "]"}], "+", 
             "2"}]}], "}"}]}], "]"}]}], ";", "\n", "\[IndentingNewLine]", 
       RowBox[{"globalreducect", "=", "1"}], ";", "\n", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"globalreducect", "\[LessEqual]", 
          RowBox[{"DimPerimeterList", "[", "reducect2", "]"}]}], ",", "\n", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"tempPerimList", "[", 
              RowBox[{"[", 
               RowBox[{"reducect", ",", "2"}], "]"}], "]"}], "\[Equal]", 
             RowBox[{"tempPerimList", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"reducect", "+", "1"}], ",", "2"}], "]"}], "]"}], 
             "\[Equal]", 
             RowBox[{"tempPerimList", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"reducect", "+", "2"}], ",", "2"}], "]"}], "]"}]}], 
            ",", 
            RowBox[{
             RowBox[{"tempPerimList", "=", 
              RowBox[{"Delete", "[", 
               RowBox[{"tempPerimList", ",", 
                RowBox[{"reducect", "+", "1"}]}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"reducect", "=", 
              RowBox[{"reducect", "-", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"reducect", "=", 
           RowBox[{"reducect", "+", "1"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"globalreducect", "=", 
           RowBox[{"globalreducect", "+", "1"}]}], ";"}]}], "]"}], ";", "\n", 
       RowBox[{"deletingct", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"diff", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "tempPerimList", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{
          RowBox[{
           RowBox[{"Position", "[", 
            RowBox[{"tempPerimList", ",", 
             RowBox[{"tempPerimList", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"deletingct", "\[LessEqual]", "diff"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"tempPerimList", "=", 
           RowBox[{"Delete", "[", 
            RowBox[{"tempPerimList", ",", 
             RowBox[{
              RowBox[{"Dimensions", "[", "tempPerimList", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"deletingct", "=", 
           RowBox[{"deletingct", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"tempdim", "=", 
        RowBox[{
         RowBox[{"Dimensions", "[", "tempPerimList", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", 
       RowBox[{"tempPerimList", "=", 
        RowBox[{"Append", "[", 
         RowBox[{"tempPerimList", ",", 
          RowBox[{"tempPerimList", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"tempPerimList", "=", 
        RowBox[{"Append", "[", 
         RowBox[{"tempPerimList", ",", 
          RowBox[{"tempPerimList", "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], "]"}]}], ";", "\n", "\n", 
       "\[IndentingNewLine]", 
       RowBox[{"reducect", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"globalreducect", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"globalreducect", "\[LessEqual]", "tempdim"}], ",", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"tempPerimList", "[", 
              RowBox[{"[", 
               RowBox[{"reducect", ",", "1"}], "]"}], "]"}], "\[Equal]", 
             RowBox[{"tempPerimList", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"reducect", "+", "1"}], ",", "1"}], "]"}], "]"}], 
             "\[Equal]", 
             RowBox[{"tempPerimList", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"reducect", "+", "2"}], ",", "1"}], "]"}], "]"}]}], 
            ",", 
            RowBox[{
             RowBox[{"tempPerimList", "=", 
              RowBox[{"Delete", "[", 
               RowBox[{"tempPerimList", ",", 
                RowBox[{"reducect", "+", "1"}]}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"reducect", "=", 
              RowBox[{"reducect", "-", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"reducect", "=", 
           RowBox[{"reducect", "+", "1"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"globalreducect", "=", 
           RowBox[{"globalreducect", "+", "1"}]}], ";"}]}], "]"}], ";", "\n", 
       "\n", 
       RowBox[{"deletingct", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"diff", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"Dimensions", "[", "tempPerimList", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", 
         RowBox[{
          RowBox[{
           RowBox[{"Position", "[", 
            RowBox[{"tempPerimList", ",", 
             RowBox[{"tempPerimList", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"deletingct", "\[LessEqual]", "diff"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"tempPerimList", "=", 
           RowBox[{"Delete", "[", 
            RowBox[{"tempPerimList", ",", 
             RowBox[{
              RowBox[{"Dimensions", "[", "tempPerimList", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"deletingct", "=", 
           RowBox[{"deletingct", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", "\n", 
       RowBox[{
        RowBox[{"ReducedList", "[", "reducect2", "]"}], "=", 
        "tempPerimList"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"DimPerimeterList", "[", "reducect2", "]"}], "=", 
        RowBox[{
         RowBox[{"Dimensions", "[", "tempPerimList", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\n", 
       RowBox[{"reducect2", "=", 
        RowBox[{"reducect2", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"renumbct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"renumbct", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"renumbct2", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"renumbct2", "\[LessEqual]", 
          RowBox[{"DimPerimeterList", "[", "renumbct", "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"RenumbPerimeterList", "[", 
            RowBox[{"renumbct", ",", "renumbct2"}], "]"}], "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"ReducedList", "[", "renumbct", "]"}], "[", 
                 RowBox[{"[", 
                  RowBox[{"renumbct2", ",", "1"}], "]"}], "]"}], "*", 
                "horzcellsize"}], ")"}], "+", "Lflim"}], ",", 
             RowBox[{"Upperlim", "-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"ReducedList", "[", "renumbct", "]"}], "[", 
                 RowBox[{"[", 
                  RowBox[{"renumbct2", ",", "2"}], "]"}], "]"}], "*", 
                "vertcellsize"}], ")"}]}]}], "}"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"renumbct2", "=", 
           RowBox[{"renumbct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"renumbct", "=", 
        RowBox[{"renumbct", "+", "1"}]}], ";"}]}], "]"}], ";"}], "\n", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"HsuPerimPtct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"HsuPerimPtct", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"HsuPerimPtct2", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"HsuPerimPtct2", "\[LessEqual]", 
          RowBox[{"DimPerimeterList", "[", "HsuPerimPtct", "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"l0", "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"RenumbPerimeterList", "[", 
                RowBox[{"HsuPerimPtct", ",", "HsuPerimPtct2"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "*", "1", "*", 
              RowBox[{
               RowBox[{"RenumbPerimeterList", "[", 
                RowBox[{"HsuPerimPtct", ",", "HsuPerimPtct2"}], "]"}], "[", 
               RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "3"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"\[Epsilon]1", "=", 
           RowBox[{"Log", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"RenumbPerimeterList", "[", 
               RowBox[{"HsuPerimPtct", ",", "HsuPerimPtct2"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], "/", "l0"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"\[Epsilon]2", "=", 
           RowBox[{"Log", "[", 
            RowBox[{"1", "/", "l0"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"\[Epsilon]3", "=", 
           RowBox[{"Log", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"RenumbPerimeterList", "[", 
               RowBox[{"HsuPerimPtct", ",", "HsuPerimPtct2"}], "]"}], "[", 
              RowBox[{"[", "2", "]"}], "]"}], "/", "l0"}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"e1", "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"RenumbPerimeterList", "[", 
                RowBox[{"HsuPerimPtct", ",", "HsuPerimPtct2"}], "]"}], "[", 
               RowBox[{"[", "1", "]"}], "]"}], "-", "l0"}], ")"}], "/", 
            "l0"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"e2", "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", "l0"}], ")"}], "/", "l0"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"e3", "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"RenumbPerimeterList", "[", 
                RowBox[{"HsuPerimPtct", ",", "HsuPerimPtct2"}], "]"}], "[", 
               RowBox[{"[", "2", "]"}], "]"}], "-", "l0"}], ")"}], "/", 
            "l0"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"nu", "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "*", "\[Epsilon]2"}], ")"}], "-", "\[Epsilon]3", 
              "-", "\[Epsilon]1"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Epsilon]1", "-", "\[Epsilon]3"}], ")"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"EpsolonSPerim", "[", 
            RowBox[{"HsuPerimPtct", ",", "HsuPerimPtct2"}], "]"}], "=", 
           RowBox[{
            FractionBox["1", "3"], " ", 
            SqrtBox["3"], 
            RowBox[{"(", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"\[Epsilon]3", "-", "\[Epsilon]2"}], ")"}], "2"], 
                "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"\[Epsilon]2", "-", "\[Epsilon]1"}], ")"}], "2"], 
                "+", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"\[Epsilon]1", "-", "\[Epsilon]3"}], ")"}], "2"]}], 
               ")"}], ".5"], ")"}]}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Hsu\[Theta]Perim", "[", 
            RowBox[{"HsuPerimPtct", ",", "HsuPerimPtct2"}], "]"}], "=", 
           RowBox[{"90", "-", 
            RowBox[{"30", "*", "nu"}]}]}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Perimxkpt", "[", 
            RowBox[{"HsuPerimPtct", ",", "HsuPerimPtct2"}], "]"}], "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "e2"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"1", "+", "e3"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Perimykpt", "[", 
            RowBox[{"HsuPerimPtct", ",", "HsuPerimPtct2"}], "]"}], "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "e1"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"1", "+", "e2"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"HsuPerimPtct2", "=", 
           RowBox[{"HsuPerimPtct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"HsuPerimPtct", "=", 
        RowBox[{"HsuPerimPtct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\n", "\n", 
   RowBox[{
    RowBox[{"listct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"listctglobal", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"listct", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"listct2", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"listct2", "\[LessEqual]", 
          RowBox[{"DimPerimeterList", "[", "listct", "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"EpsolonSPerimList", "[", "listctglobal", "]"}], "=", 
           RowBox[{"EpsolonSPerim", "[", 
            RowBox[{"listct", ",", "listct2"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"listct2", "=", 
           RowBox[{"listct2", "+", "1"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"listctglobal", "=", 
           RowBox[{"listctglobal", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"listct", "=", 
        RowBox[{"listct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct", "\[LessEqual]", "statnumb"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"l0", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"LongAndShort", "[", 
            RowBox[{"[", 
             RowBox[{"ct", ",", "1"}], "]"}], "]"}], "*", "1", "*", 
           RowBox[{"LongAndShort", "[", 
            RowBox[{"[", 
             RowBox[{"ct", ",", "2"}], "]"}], "]"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "3"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"\[Epsilon]1", "=", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{"LongAndShort", "[", 
           RowBox[{"[", 
            RowBox[{"ct", ",", "1"}], "]"}], "]"}], "/", "l0"}], "]"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"\[Epsilon]2", "=", 
        RowBox[{"Log", "[", 
         RowBox[{"1", "/", "l0"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"\[Epsilon]3", "=", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{"LongAndShort", "[", 
           RowBox[{"[", 
            RowBox[{"ct", ",", "2"}], "]"}], "]"}], "/", "l0"}], "]"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"nu", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "*", "\[Epsilon]2"}], ")"}], "-", "\[Epsilon]3", "-",
            "\[Epsilon]1"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"\[Epsilon]1", "-", "\[Epsilon]3"}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"EpsolonS", "[", "ct", "]"}], "=", 
        RowBox[{
         FractionBox["1", "3"], " ", 
         SqrtBox["3"], 
         RowBox[{"(", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"\[Epsilon]3", "-", "\[Epsilon]2"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"\[Epsilon]2", "-", "\[Epsilon]1"}], ")"}], "2"], "+", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"\[Epsilon]1", "-", "\[Epsilon]3"}], ")"}], "2"]}], 
            ")"}], ".5"], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"ct", "=", 
        RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"HsuEpsolonSMaxPerimVal", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"EpsolonSPerimList", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", 
          RowBox[{"listctglobal", "-", "1"}]}], "}"}]}], "]"}], "]"}]}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"HsuMaxVal", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"{", 
       RowBox[{"\[Epsilon]smax", ",", 
        RowBox[{"Max", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"EpsolonS", "[", "x", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}], "]"}]}],
        "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AbsHsuMax", "=", 
     RowBox[{"Max", "[", 
      RowBox[{"{", 
       RowBox[{"HsuEpsolonSMaxPerimVal", ",", "HsuMaxVal"}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EsMax", "=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Round", "[", 
         RowBox[{"AbsHsuMax", ",", "continterval"}], "]"}], "<", 
        "AbsHsuMax"}], ",", 
       RowBox[{
        RowBox[{"Round", "[", 
         RowBox[{"AbsHsuMax", ",", "continterval"}], "]"}], "+", 
        "continterval"}], ",", 
       RowBox[{"Round", "[", 
        RowBox[{"AbsHsuMax", ",", "continterval"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{"(*", " ", 
    RowBox[{
    "\"\<EsMax\>\"", " ", "determines", " ", "the", " ", "maximum", " ", 
     "Octehedral", " ", "Shear", " ", "Strain", " ", "for", " ", "the", " ", 
     "Hsu", " ", 
     RowBox[{"plot", ".", "  ", "You"}], " ", "can", " ", "overwrite", " ", 
     "this", " ", "value", " ", "by", " ", "deleting", " ", "the", " ", 
     "comment", " ", "marks", " ", "from", " ", "the", " ", "next", " ", 
     RowBox[{"line", "."}]}], "  ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"EsMax", "=", "1.25"}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ct", "\[LessEqual]", "statnumb"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"l0", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"LongAndShort", "[", 
            RowBox[{"[", 
             RowBox[{"ct", ",", "1"}], "]"}], "]"}], "*", "1", "*", 
           RowBox[{"LongAndShort", "[", 
            RowBox[{"[", 
             RowBox[{"ct", ",", "2"}], "]"}], "]"}]}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "3"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"\[Epsilon]1", "=", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{"LongAndShort", "[", 
           RowBox[{"[", 
            RowBox[{"ct", ",", "1"}], "]"}], "]"}], "/", "l0"}], "]"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"\[Epsilon]2", "=", 
        RowBox[{"Log", "[", 
         RowBox[{"1", "/", "l0"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"\[Epsilon]3", "=", 
        RowBox[{"Log", "[", 
         RowBox[{
          RowBox[{"LongAndShort", "[", 
           RowBox[{"[", 
            RowBox[{"ct", ",", "2"}], "]"}], "]"}], "/", "l0"}], "]"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"nu", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "*", "\[Epsilon]2"}], ")"}], "-", "\[Epsilon]3", "-",
            "\[Epsilon]1"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"\[Epsilon]1", "-", "\[Epsilon]3"}], ")"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Esprime", "=", 
        RowBox[{
         RowBox[{"EpsolonS", "[", "ct", "]"}], "/", "EsMax"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Hsu\[Theta]", "=", 
        RowBox[{"90", "-", 
         RowBox[{"30", "*", "nu"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"StatxHsupt", "[", "ct", "]"}], "=", 
        RowBox[{"Esprime", "*", 
         RowBox[{"Cos", "[", 
          RowBox[{"Hsu\[Theta]", "*", 
           RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"StatyHsupt", "[", "ct", "]"}], "=", 
        RowBox[{"Esprime", "*", 
         RowBox[{"Sin", "[", 
          RowBox[{"Hsu\[Theta]", "*", 
           RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ct", "=", 
        RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"HsuPerimPtct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"HsuPerimPtct", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"HsuPerimPtct2", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"HsuPerimPtct2", "\[LessEqual]", 
          RowBox[{"DimPerimeterList", "[", "HsuPerimPtct", "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Esprime", "=", 
           RowBox[{
            RowBox[{"EpsolonSPerim", "[", 
             RowBox[{"HsuPerimPtct", ",", "HsuPerimPtct2"}], "]"}], "/", 
            "EsMax"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"PerimxHsupt", "[", 
            RowBox[{"HsuPerimPtct", ",", "HsuPerimPtct2"}], "]"}], "=", 
           RowBox[{"Esprime", "*", 
            RowBox[{"Cos", "[", 
             RowBox[{
              RowBox[{"Hsu\[Theta]Perim", "[", 
               RowBox[{"HsuPerimPtct", ",", "HsuPerimPtct2"}], "]"}], "*", 
              RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"PerimyHsupt", "[", 
            RowBox[{"HsuPerimPtct", ",", "HsuPerimPtct2"}], "]"}], "=", 
           RowBox[{"Esprime", "*", 
            RowBox[{"Sin", "[", 
             RowBox[{
              RowBox[{"Hsu\[Theta]Perim", "[", 
               RowBox[{"HsuPerimPtct", ",", "HsuPerimPtct2"}], "]"}], "*", 
              RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"HsuPerimPtct2", "=", 
           RowBox[{"HsuPerimPtct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"HsuPerimPtct", "=", 
        RowBox[{"HsuPerimPtct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"testingct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"testingct", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"testingct2", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"testingct2", "\[LessEqual]", 
          RowBox[{"DimPerimeterList", "[", "testingct", "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Tan", "[", 
                RowBox[{"60", "\[Degree]"}], "]"}], "*", 
               RowBox[{"PerimxHsupt", "[", 
                RowBox[{"testingct", ",", "testingct2"}], "]"}]}], ">", 
              RowBox[{"PerimyHsupt", "[", 
               RowBox[{"testingct", ",", "testingct2"}], "]"}]}], "&&", 
             RowBox[{
              RowBox[{
               RowBox[{"Tan", "[", 
                RowBox[{"60", "\[Degree]"}], "]"}], "*", 
               RowBox[{"PerimxHsupt", "[", 
                RowBox[{"testingct", ",", 
                 RowBox[{"testingct2", "-", "1"}]}], "]"}]}], "<", 
              RowBox[{"PerimyHsupt", "[", 
               RowBox[{"testingct", ",", 
                RowBox[{"testingct2", "-", "1"}]}], "]"}]}]}], ",", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Tan", "[", 
                  RowBox[{"60", "\[Degree]"}], "]"}], "*", 
                 RowBox[{"PerimxHsupt", "[", 
                  RowBox[{"testingct", ",", 
                   RowBox[{"testingct2", "+", "1"}]}], "]"}]}], "<", 
                RowBox[{"PerimyHsupt", "[", 
                 RowBox[{"testingct", ",", 
                  RowBox[{"testingct2", "+", "1"}]}], "]"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"tempinterceptXptOne", "=", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "*", " ", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}], "*", " ", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}]}], 
                   ")"}], "/", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}], "-", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}], "*", " ", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"60", "\[Degree]"}], "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], " ", "*", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"60", "\[Degree]"}], "]"}]}]}], ")"}]}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"tempinterceptYptOne", "=", 
                 RowBox[{"tempinterceptXptOne", "*", 
                  RowBox[{"Tan", "[", 
                   RowBox[{"60", "\[Degree]"}], "]"}]}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"tempinterceptXptTwo", "=", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "*", " ", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}], "*", " ", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}]}], 
                   ")"}], "/", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}], "-", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}], "*", " ", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"60", "\[Degree]"}], "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], " ", "*", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"60", "\[Degree]"}], "]"}]}]}], ")"}]}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"tempinterceptYptTwo", "=", 
                 RowBox[{"tempinterceptXptTwo", "*", 
                  RowBox[{"Tan", "[", 
                   RowBox[{"60", "\[Degree]"}], "]"}]}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"DimPerimeterList", "[", "testingct", "]"}], "=", 
                 RowBox[{
                  RowBox[{"DimPerimeterList", "[", "testingct", "]"}], "+", 
                  "1"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
                RowBox[{"While", "[", 
                 RowBox[{
                  RowBox[{"ct", "\[LessEqual]", 
                   RowBox[{"DimPerimeterList", "[", "testingct", "]"}]}], ",",
                   "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"ct", "<", "testingct2"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"TPerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";"}], ",", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"ct", "\[Equal]", "testingct2"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"TPerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    "tempinterceptYptOne"}], ";", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    "tempinterceptXptOne"}], ";", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "+", "1"}]}], "]"}], "=", 
                    "tempinterceptYptTwo"}], ";", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "+", "1"}]}], "]"}], "=", 
                    "tempinterceptXptTwo"}], ";", "\[IndentingNewLine]", 
                    RowBox[{"ct", "=", 
                    RowBox[{"ct", "+", "1"}]}], ";"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"TPerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "-", "1"}]}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "-", "1"}]}], "]"}]}], ";"}]}], "]"}], 
                    ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
                   RowBox[{"ct", "=", 
                    RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
                RowBox[{"While", "[", 
                 RowBox[{
                  RowBox[{"ct", "\[LessEqual]", 
                   RowBox[{"DimPerimeterList", "[", "testingct", "]"}]}], ",",
                   "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"TPerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"TPerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"ct", "=", 
                    RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}]}], 
              "]"}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"testingct2", "=", 
           RowBox[{"testingct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"testingct", "=", 
        RowBox[{"testingct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"testingct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"testingct", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"testingct2", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"testingct2", "\[LessEqual]", 
          RowBox[{"DimPerimeterList", "[", "testingct", "]"}]}], ",", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Tan", "[", 
                RowBox[{"120", "\[Degree]"}], "]"}], "*", 
               RowBox[{"PerimxHsupt", "[", 
                RowBox[{"testingct", ",", "testingct2"}], "]"}]}], ">", 
              RowBox[{"PerimyHsupt", "[", 
               RowBox[{"testingct", ",", "testingct2"}], "]"}]}], "&&", 
             RowBox[{
              RowBox[{
               RowBox[{"Tan", "[", 
                RowBox[{"120", "\[Degree]"}], "]"}], "*", 
               RowBox[{"PerimxHsupt", "[", 
                RowBox[{"testingct", ",", 
                 RowBox[{"testingct2", "-", "1"}]}], "]"}]}], "<", 
              RowBox[{"PerimyHsupt", "[", 
               RowBox[{"testingct", ",", 
                RowBox[{"testingct2", "-", "1"}]}], "]"}]}]}], ",", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"Tan", "[", 
                  RowBox[{"120", "\[Degree]"}], "]"}], "*", 
                 RowBox[{"PerimxHsupt", "[", 
                  RowBox[{"testingct", ",", 
                   RowBox[{"testingct2", "+", "1"}]}], "]"}]}], "<", 
                RowBox[{"PerimyHsupt", "[", 
                 RowBox[{"testingct", ",", 
                  RowBox[{"testingct2", "+", "1"}]}], "]"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"tempinterceptXptOne", "=", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "*", " ", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}], "*", " ", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}]}], 
                   ")"}], "/", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}], "-", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}], "*", " ", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"120", "\[Degree]"}], "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], " ", "*", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"120", "\[Degree]"}], "]"}]}]}], ")"}]}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"tempinterceptYptOne", "=", 
                 RowBox[{"tempinterceptXptOne", "*", 
                  RowBox[{"Tan", "[", 
                   RowBox[{"120", "\[Degree]"}], "]"}]}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"tempinterceptXptTwo", "=", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "*", " ", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}], "*", " ", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}]}], 
                   ")"}], "/", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}], "-", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "-", 
                    RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}], "*", " ", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"120", "\[Degree]"}], "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], " ", "*", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"120", "\[Degree]"}], "]"}]}]}], ")"}]}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"tempinterceptYptTwo", "=", 
                 RowBox[{"tempinterceptXptTwo", "*", 
                  RowBox[{"Tan", "[", 
                   RowBox[{"120", "\[Degree]"}], "]"}]}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"DimPerimeterList", "[", "testingct", "]"}], "=", 
                 RowBox[{
                  RowBox[{"DimPerimeterList", "[", "testingct", "]"}], "+", 
                  "1"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
                RowBox[{"While", "[", 
                 RowBox[{
                  RowBox[{"ct", "\[LessEqual]", 
                   RowBox[{"DimPerimeterList", "[", "testingct", "]"}]}], ",",
                   "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"ct", "<", "testingct2"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"TPerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";"}], ",", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"ct", "\[Equal]", "testingct2"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"TPerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    "tempinterceptYptOne"}], ";", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    "tempinterceptXptOne"}], ";", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "+", "1"}]}], "]"}], "=", 
                    "tempinterceptYptTwo"}], ";", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "+", "1"}]}], "]"}], "=", 
                    "tempinterceptXptTwo"}], ";", "\[IndentingNewLine]", 
                    RowBox[{"ct", "=", 
                    RowBox[{"ct", "+", "1"}]}], ";"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"TPerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "-", "1"}]}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "-", "1"}]}], "]"}]}], ";"}]}], "]"}], 
                    ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
                   RowBox[{"ct", "=", 
                    RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
                RowBox[{"While", "[", 
                 RowBox[{
                  RowBox[{"ct", "\[LessEqual]", 
                   RowBox[{"DimPerimeterList", "[", "testingct", "]"}]}], ",",
                   "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"TPerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"TPerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"ct", "=", 
                    RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}]}], 
              "]"}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"testingct2", "=", 
           RowBox[{"testingct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"testingct", "=", 
        RowBox[{"testingct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"testingct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"newptct", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"testingct", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"testingct2", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"testingct2", "\[LessEqual]", 
          RowBox[{"DimPerimeterList", "[", "testingct", "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"PerimyHsupt", "[", 
            RowBox[{"1", ",", "0"}], "]"}], "=", 
           RowBox[{"PerimyHsupt", "[", 
            RowBox[{"1", ",", 
             RowBox[{
              RowBox[{"DimPerimeterList", "[", "testingct", "]"}], "-", 
              "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"PerimxHsupt", "[", 
            RowBox[{"1", ",", "0"}], "]"}], "=", 
           RowBox[{"PerimxHsupt", "[", 
            RowBox[{"1", ",", 
             RowBox[{
              RowBox[{"DimPerimeterList", "[", "testingct", "]"}], "-", 
              "1"}]}], "]"}]}], ";", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Tan", "[", 
                RowBox[{"60", "\[Degree]"}], "]"}], "*", 
               RowBox[{"PerimxHsupt", "[", 
                RowBox[{"testingct", ",", "testingct2"}], "]"}]}], ">", 
              RowBox[{"PerimyHsupt", "[", 
               RowBox[{"testingct", ",", "testingct2"}], "]"}]}], "&&", 
             RowBox[{
              RowBox[{
               RowBox[{"Tan", "[", 
                RowBox[{"60", "\[Degree]"}], "]"}], "*", 
               RowBox[{"PerimxHsupt", "[", 
                RowBox[{"testingct", ",", 
                 RowBox[{"testingct2", "-", "1"}]}], "]"}]}], "<", 
              RowBox[{"PerimyHsupt", "[", 
               RowBox[{"testingct", ",", 
                RowBox[{"testingct2", "-", "1"}]}], "]"}]}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"NewHsuxPt", "[", "newptct", "]"}], "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "*", " ", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}]}], "-", 
                   RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}], "*", " ", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}]}], 
                  ")"}], "/", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}], "-", 
                   RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "-", 
                   RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}], "*", " ", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"60", "\[Degree]"}], "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], " ", "*", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"60", "\[Degree]"}], "]"}]}]}], ")"}]}], ",", 
                "testingct", ",", "testingct2"}], "}"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"NewHsuyPt", "[", "newptct", "]"}], "=", 
              RowBox[{
               RowBox[{"NewHsuxPt", "[", "newptct", "]"}], "*", 
               RowBox[{"Tan", "[", 
                RowBox[{"60", "\[Degree]"}], "]"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"newptct", "=", 
              RowBox[{"newptct", "+", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Tan", "[", 
                RowBox[{"60", "\[Degree]"}], "]"}], "*", 
               RowBox[{"PerimxHsupt", "[", 
                RowBox[{"testingct", ",", "testingct2"}], "]"}]}], ">", 
              RowBox[{"PerimyHsupt", "[", 
               RowBox[{"testingct", ",", "testingct2"}], "]"}]}], "&&", 
             RowBox[{
              RowBox[{
               RowBox[{"Tan", "[", 
                RowBox[{"60", "\[Degree]"}], "]"}], "*", 
               RowBox[{"PerimxHsupt", "[", 
                RowBox[{"testingct", ",", 
                 RowBox[{"testingct2", "+", "1"}]}], "]"}]}], "<", 
              RowBox[{"PerimyHsupt", "[", 
               RowBox[{"testingct", ",", 
                RowBox[{"testingct2", "+", "1"}]}], "]"}]}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"NewHsuxPt", "[", "newptct", "]"}], "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "*", " ", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}]}], "-", 
                   RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}], "*", " ", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}]}], 
                  ")"}], "/", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}], "-", 
                   RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "-", 
                   RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}], "*", " ", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"60", "\[Degree]"}], "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], " ", "*", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"60", "\[Degree]"}], "]"}]}]}], ")"}]}], ",", 
                "testingct", ",", "testingct2"}], "}"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"NewHsuyPt", "[", "newptct", "]"}], "=", 
              RowBox[{
               RowBox[{"NewHsuxPt", "[", "newptct", "]"}], "*", 
               RowBox[{"Tan", "[", 
                RowBox[{"60", "\[Degree]"}], "]"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"newptct", "=", 
              RowBox[{"newptct", "+", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"testingct2", "=", 
           RowBox[{"testingct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"testingct", "=", 
        RowBox[{"testingct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"testingct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"testingct", "\[LessEqual]", "islandnumb"}], ",", "\n", 
      RowBox[{
       RowBox[{"testingct2", "=", "1"}], ";", "\n", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"testingct2", "<", 
          RowBox[{"DimPerimeterList", "[", "testingct", "]"}]}], ",", "\n", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Tan", "[", 
                RowBox[{"120", "\[Degree]"}], "]"}], "*", 
               RowBox[{"PerimxHsupt", "[", 
                RowBox[{"testingct", ",", "testingct2"}], "]"}]}], ">", 
              RowBox[{"PerimyHsupt", "[", 
               RowBox[{"testingct", ",", "testingct2"}], "]"}]}], "&&", 
             RowBox[{
              RowBox[{
               RowBox[{"Tan", "[", 
                RowBox[{"120", "\[Degree]"}], "]"}], "*", 
               RowBox[{"PerimxHsupt", "[", 
                RowBox[{"testingct", ",", 
                 RowBox[{"testingct2", "-", "1"}]}], "]"}]}], "<", 
              RowBox[{"PerimyHsupt", "[", 
               RowBox[{"testingct", ",", 
                RowBox[{"testingct2", "-", "1"}]}], "]"}]}]}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"NewHsuxPt", "[", "newptct", "]"}], "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "*", " ", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}]}], "-", 
                   RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}], "*", " ", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}]}], 
                  ")"}], "/", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}], "-", 
                   RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "-", 
                   RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}], "*", " ", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"120", "\[Degree]"}], "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], " ", "*", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"120", "\[Degree]"}], "]"}]}]}], ")"}]}], ",", 
                "testingct", ",", "testingct2"}], "}"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"NewHsuyPt", "[", "newptct", "]"}], "=", 
              RowBox[{
               RowBox[{"NewHsuxPt", "[", "newptct", "]"}], "*", 
               RowBox[{"Tan", "[", 
                RowBox[{"120", "\[Degree]"}], "]"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"newptct", "=", 
              RowBox[{"newptct", "+", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Tan", "[", 
                RowBox[{"120", "\[Degree]"}], "]"}], "*", 
               RowBox[{"PerimxHsupt", "[", 
                RowBox[{"testingct", ",", "testingct2"}], "]"}]}], ">", 
              RowBox[{"PerimyHsupt", "[", 
               RowBox[{"testingct", ",", "testingct2"}], "]"}]}], "&&", 
             RowBox[{
              RowBox[{
               RowBox[{"Tan", "[", 
                RowBox[{"120", "\[Degree]"}], "]"}], "*", 
               RowBox[{"PerimxHsupt", "[", 
                RowBox[{"testingct", ",", 
                 RowBox[{"testingct2", "+", "1"}]}], "]"}]}], "<", 
              RowBox[{"PerimyHsupt", "[", 
               RowBox[{"testingct", ",", 
                RowBox[{"testingct2", "+", "1"}]}], "]"}]}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"NewHsuxPt", "[", "newptct", "]"}], "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "*", " ", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}]}], "-", 
                   RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}], "*", " ", 
                    RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}]}], 
                  ")"}], "/", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}], "-", 
                   RowBox[{"PerimyHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "-", 
                   RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}], "*", " ", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"120", "\[Degree]"}], "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"PerimxHsupt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], " ", "*", 
                    RowBox[{"Tan", "[", 
                    RowBox[{"120", "\[Degree]"}], "]"}]}]}], ")"}]}], ",", 
                "testingct", ",", "testingct2"}], "}"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"NewHsuyPt", "[", "newptct", "]"}], "=", 
              RowBox[{
               RowBox[{"NewHsuxPt", "[", "newptct", "]"}], "*", 
               RowBox[{"Tan", "[", 
                RowBox[{"120", "\[Degree]"}], "]"}]}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"newptct", "=", 
              RowBox[{"newptct", "+", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"testingct2", "=", 
           RowBox[{"testingct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"testingct", "=", 
        RowBox[{"testingct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"newptct3", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"newptct3", "<", "newptct"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"PerimxHsupt", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"NewHsuxPt", "[", "newptct3", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"NewHsuxPt", "[", "newptct3", "]"}], "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], "]"}], "=", 
        RowBox[{
         RowBox[{"NewHsuxPt", "[", "newptct3", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"PerimyHsupt", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"NewHsuxPt", "[", "newptct3", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"NewHsuxPt", "[", "newptct3", "]"}], "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], "]"}], "=", 
        RowBox[{
         RowBox[{"NewHsuyPt", "[", "newptct3", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"newptct3", "=", 
        RowBox[{"newptct3", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"testingct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"testingct", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"overptct", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"testingct2", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"testingct2", "\[LessEqual]", 
          RowBox[{"DimPerimeterList", "[", "testingct", "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Tan", "[", 
               RowBox[{"60", "\[Degree]"}], "]"}], "*", 
              RowBox[{"PerimxHsupt", "[", 
               RowBox[{"testingct", ",", "testingct2"}], "]"}]}], ">", 
             RowBox[{"PerimyHsupt", "[", 
              RowBox[{"testingct", ",", "testingct2"}], "]"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"OverPts", "[", 
               RowBox[{"testingct", ",", "overptct"}], "]"}], "=", 
              "testingct2"}], ";", "\[IndentingNewLine]", 
             RowBox[{"overptct", "=", 
              RowBox[{"overptct", "+", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Tan", "[", 
               RowBox[{"120", "\[Degree]"}], "]"}], "*", 
              RowBox[{"PerimxHsupt", "[", 
               RowBox[{"testingct", ",", "testingct2"}], "]"}]}], ">", 
             RowBox[{"PerimyHsupt", "[", 
              RowBox[{"testingct", ",", "testingct2"}], "]"}]}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"OverPts", "[", 
               RowBox[{"testingct", ",", "overptct"}], "]"}], "=", 
              "testingct2"}], ";", "\[IndentingNewLine]", 
             RowBox[{"overptct", "=", 
              RowBox[{"overptct", "+", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"testingct2", "=", 
           RowBox[{"testingct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"overptnumb", "[", "testingct", "]"}], "=", 
        RowBox[{"overptct", "-", "1"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"testingct", "=", 
        RowBox[{"testingct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"newhsuct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"newhsuct", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"NewHsuX", "[", "newhsuct", "]"}], "=", 
        RowBox[{"Delete", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"PerimxHsupt", "[", 
             RowBox[{"newhsuct", ",", "x"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "1", ",", 
              RowBox[{"DimPerimeterList", "[", "newhsuct", "]"}]}], "}"}]}], 
           "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"OverPts", "[", 
              RowBox[{"newhsuct", ",", "x"}], "]"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "1", ",", 
              RowBox[{"overptnumb", "[", "newhsuct", "]"}]}], "}"}]}], 
           "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"NewHsuY", "[", "newhsuct", "]"}], "=", 
        RowBox[{"Delete", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"PerimyHsupt", "[", 
             RowBox[{"newhsuct", ",", "x"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "1", ",", 
              RowBox[{"DimPerimeterList", "[", "newhsuct", "]"}]}], "}"}]}], 
           "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"OverPts", "[", 
              RowBox[{"newhsuct", ",", "x"}], "]"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "1", ",", 
              RowBox[{"overptnumb", "[", "newhsuct", "]"}]}], "}"}]}], 
           "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"newhsuct", "=", 
        RowBox[{"newhsuct", "+", "1"}]}], ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ctt", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ctt", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ctt2", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"NewDimPerimeterList", "[", "ctt", "]"}], "=", 
        RowBox[{
         RowBox[{"Dimensions", "[", 
          RowBox[{"NewHsuX", "[", "ctt", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"ctt2", "\[LessEqual]", 
          RowBox[{"NewDimPerimeterList", "[", "ctt", "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"NewPerimxHsupt", "[", 
            RowBox[{"ctt", ",", "ctt2"}], "]"}], "=", 
           RowBox[{
            RowBox[{"NewHsuX", "[", "ctt", "]"}], "[", 
            RowBox[{"[", "ctt2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"NewPerimyHsupt", "[", 
            RowBox[{"ctt", ",", "ctt2"}], "]"}], "=", 
           RowBox[{
            RowBox[{"NewHsuY", "[", "ctt", "]"}], "[", 
            RowBox[{"[", "ctt2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"ctt2", "=", 
           RowBox[{"ctt2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ctt", "=", 
        RowBox[{"ctt", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"graphicsct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"graphicsct", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"PerimGraphic", "[", "graphicsct", "]"}], "=", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Opacity", "[", ".3", "]"}], ",", "Purple", ",", 
           RowBox[{"EdgeForm", "[", 
            RowBox[{"Directive", "[", 
             RowBox[{
              RowBox[{"Thickness", "[", ".003", "]"}], ",", "Purple"}], "]"}],
             "]"}], ",", 
           RowBox[{"Polygon", "[", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"NewPerimxHsupt", "[", 
                 RowBox[{"graphicsct", ",", "x"}], "]"}], ",", 
                RowBox[{"NewPerimyHsupt", "[", 
                 RowBox[{"graphicsct", ",", "x"}], "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", "1", ",", 
                RowBox[{"NewDimPerimeterList", "[", "graphicsct", "]"}], ",", 
                "ReduceRes"}], "}"}]}], "]"}], "]"}]}], "}"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"graphicsct", "=", 
        RowBox[{"graphicsct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"contnumb", "=", 
     RowBox[{"EsMax", "/", "continterval"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Esprime", "=", 
     RowBox[{"\[Epsilon]s", "/", "EsMax"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Hsu\[Theta]", "=", 
     RowBox[{"90", "-", 
      RowBox[{"30", "*", "\[Nu]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xHsupt", "=", 
     RowBox[{"Esprime", "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"Hsu\[Theta]", "*", 
        RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"yHsupt", "=", 
     RowBox[{"Esprime", "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"Hsu\[Theta]", "*", 
        RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EsprimeUpperLeft", "=", 
     RowBox[{"\[Epsilon]smax", "/", "EsMax"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Hsu\[Theta]UpperLeft", "=", 
     RowBox[{"90", "-", 
      RowBox[{"30", "*", "\[Nu]min"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xHsuptUpperLeft", "=", 
     RowBox[{"EsprimeUpperLeft", "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"Hsu\[Theta]UpperLeft", "*", 
        RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"yHsuptUpperLeft", "=", 
     RowBox[{"EsprimeUpperLeft", "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"Hsu\[Theta]UpperLeft", "*", 
        RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EsprimeUpperRt", "=", 
     RowBox[{"\[Epsilon]smax", "/", "EsMax"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Hsu\[Theta]UpperRt", "=", 
     RowBox[{"90", "-", 
      RowBox[{"30", "*", "\[Nu]max"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xHsuptUpperRt", "=", 
     RowBox[{"EsprimeUpperRt", "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"Hsu\[Theta]UpperRt", "*", 
        RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"yHsuptUpperRt", "=", 
     RowBox[{"EsprimeUpperRt", "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"Hsu\[Theta]UpperRt", "*", 
        RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EsprimeLowerRt", "=", 
     RowBox[{"\[Epsilon]smin", "/", "EsMax"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Hsu\[Theta]LowerRt", "=", 
     RowBox[{"90", "-", 
      RowBox[{"30", "*", "\[Nu]max"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xHsuptLowerRt", "=", 
     RowBox[{"EsprimeLowerRt", "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"Hsu\[Theta]LowerRt", "*", 
        RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"yHsuptLowerRt", "=", 
     RowBox[{"EsprimeLowerRt", "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"Hsu\[Theta]LowerRt", "*", 
        RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EsprimeLowerLeft", "=", 
     RowBox[{"\[Epsilon]smin", "/", "EsMax"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Hsu\[Theta]LowerLeft", "=", 
     RowBox[{"90", "-", 
      RowBox[{"30", "*", "\[Nu]min"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"xHsuptLowerLeft", "=", 
     RowBox[{"EsprimeLowerLeft", "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"Hsu\[Theta]LowerLeft", "*", 
        RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"yHsuptLowerLeft", "=", 
     RowBox[{"EsprimeLowerLeft", "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"Hsu\[Theta]LowerLeft", "*", 
        RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LeftRegion", "=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"xHsuptLowerLeft", "\[GreaterEqual]", "xHsuptUpperLeft"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"xHsuptUpperRt", "\[LessEqual]", "xHsuptLowerLeft"}], ",", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Sqrt", "[", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"\[Epsilon]smax", "/", "EsMax"}], ")"}], "2"], "-", 
               SuperscriptBox["x", "2"]}], "]"}], ",", 
             RowBox[{"x", "*", 
              RowBox[{"Tan", "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"90", "-", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"180", "/", "Pi"}], ")"}], "*", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"xHsuptUpperLeft", "/", "yHsuptUpperLeft"}], 
                    "]"}]}], ")"}]}], ")"}], "*", 
                RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "xHsuptUpperLeft", ",", "xHsuptUpperRt"}], 
            "}"}], ",", 
           RowBox[{"Filling", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"1", "\[Rule]", 
              RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
           RowBox[{"FillingStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{
              RowBox[{"Opacity", "[", "0.3", "]"}], ",", "Purple"}], 
             "]"}]}]}], "]"}], ",", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Sqrt", "[", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"\[Epsilon]smax", "/", "EsMax"}], ")"}], "2"], "-", 
               SuperscriptBox["x", "2"]}], "]"}], ",", 
             RowBox[{"x", "*", 
              RowBox[{"Tan", "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"90", "-", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"180", "/", "Pi"}], ")"}], "*", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"xHsuptUpperLeft", "/", "yHsuptUpperLeft"}], 
                    "]"}]}], ")"}]}], ")"}], "*", 
                RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "xHsuptUpperLeft", ",", "xHsuptLowerLeft"}], 
            "}"}], ",", 
           RowBox[{"Filling", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"1", "\[Rule]", 
              RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
           RowBox[{"FillingStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{
              RowBox[{"Opacity", "[", "0.3", "]"}], ",", "Purple"}], 
             "]"}]}]}], "]"}]}], "]"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"xHsuptUpperLeft", "\[GreaterEqual]", "xHsuptLowerRt"}], ",", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Sqrt", "[", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"\[Epsilon]smin", "/", "EsMax"}], ")"}], "2"], "-", 
               SuperscriptBox["x", "2"]}], "]"}], ",", 
             RowBox[{"x", "*", 
              RowBox[{"Tan", "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"90", "-", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"180", "/", "Pi"}], ")"}], "*", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"xHsuptUpperLeft", "/", "yHsuptUpperLeft"}], 
                    "]"}]}], ")"}]}], ")"}], "*", 
                RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "xHsuptLowerLeft", ",", "xHsuptLowerRt"}], 
            "}"}], ",", 
           RowBox[{"Filling", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"1", "\[Rule]", 
              RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
           RowBox[{"FillingStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{
              RowBox[{"Opacity", "[", "0.3", "]"}], ",", "Purple"}], 
             "]"}]}]}], "]"}], ",", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Sqrt", "[", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"\[Epsilon]smin", "/", "EsMax"}], ")"}], "2"], "-", 
               SuperscriptBox["x", "2"]}], "]"}], ",", 
             RowBox[{"x", "*", 
              RowBox[{"Tan", "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"90", "-", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"180", "/", "Pi"}], ")"}], "*", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"xHsuptUpperLeft", "/", "yHsuptUpperLeft"}], 
                    "]"}]}], ")"}]}], ")"}], "*", 
                RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "xHsuptLowerLeft", ",", "xHsuptUpperLeft"}], 
            "}"}], ",", 
           RowBox[{"Filling", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"1", "\[Rule]", 
              RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
           RowBox[{"FillingStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{
              RowBox[{"Opacity", "[", "0.3", "]"}], ",", "Purple"}], 
             "]"}]}]}], "]"}]}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MidRegion", "=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"xHsuptUpperLeft", "\[LessEqual]", "xHsuptLowerLeft"}], "&&", 
        RowBox[{"xHsuptUpperRt", "\[LessEqual]", "xHsuptLowerRt"}]}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"xHsuptUpperRt", "\[GreaterEqual]", "xHsuptLowerLeft"}], ",", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Sqrt", "[", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"\[Epsilon]smax", "/", "EsMax"}], ")"}], "2"], "-", 
               SuperscriptBox["x", "2"]}], "]"}], ",", 
             RowBox[{"Sqrt", "[", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"\[Epsilon]smin", "/", "EsMax"}], ")"}], "2"], "-", 
               SuperscriptBox["x", "2"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "xHsuptLowerLeft", ",", "xHsuptUpperRt"}], 
            "}"}], ",", 
           RowBox[{"Filling", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"1", "\[Rule]", 
              RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
           RowBox[{"FillingStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{
              RowBox[{"Opacity", "[", "0.3", "]"}], ",", "Purple"}], 
             "]"}]}]}], "]"}], ",", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"x", "*", 
              RowBox[{"Tan", "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"90", "-", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"180", "/", "Pi"}], ")"}], "*", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"xHsuptUpperLeft", "/", "yHsuptUpperLeft"}], 
                    "]"}]}], ")"}]}], ")"}], "*", 
                RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", 
             RowBox[{"x", "*", 
              RowBox[{"Tan", "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"90", "-", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"180", "/", "Pi"}], ")"}], "*", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"xHsuptUpperRt", "/", "yHsuptUpperRt"}], "]"}]}], 
                   ")"}]}], ")"}], "*", 
                RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "xHsuptUpperRt", ",", "xHsuptLowerLeft"}], 
            "}"}], ",", 
           RowBox[{"Filling", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"1", "\[Rule]", 
              RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
           RowBox[{"FillingStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{
              RowBox[{"Opacity", "[", "0.3", "]"}], ",", "Purple"}], 
             "]"}]}]}], "]"}]}], "]"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"xHsuptUpperLeft", "\[GreaterEqual]", "xHsuptLowerLeft"}], "&&", 
          RowBox[{"xHsuptUpperRt", "\[GreaterEqual]", "xHsuptLowerRt"}]}], 
         ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"xHsuptUpperLeft", "\[LessEqual]", "xHsuptLowerRt"}], ",", 
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Sqrt", "[", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"\[Epsilon]smax", "/", "EsMax"}], ")"}], "2"], "-", 
                 SuperscriptBox["x", "2"]}], "]"}], ",", 
               RowBox[{"Sqrt", "[", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"\[Epsilon]smin", "/", "EsMax"}], ")"}], "2"], "-", 
                 SuperscriptBox["x", "2"]}], "]"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "xHsuptUpperLeft", ",", "xHsuptLowerRt"}], 
              "}"}], ",", 
             RowBox[{"Filling", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"1", "\[Rule]", 
                RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
             RowBox[{"FillingStyle", "\[Rule]", 
              RowBox[{"Directive", "[", 
               RowBox[{
                RowBox[{"Opacity", "[", "0.3", "]"}], ",", "Purple"}], 
               "]"}]}]}], "]"}], ",", 
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"x", "*", 
                RowBox[{"Tan", "[", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"90", "-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"180", "/", "Pi"}], ")"}], "*", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"xHsuptUpperLeft", "/", "yHsuptUpperLeft"}], 
                    "]"}]}], ")"}]}], ")"}], "*", 
                  RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", 
               RowBox[{"x", "*", 
                RowBox[{"Tan", "[", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"90", "-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"180", "/", "Pi"}], ")"}], "*", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"xHsuptUpperRt", "/", "yHsuptUpperRt"}], "]"}]}], 
                    ")"}]}], ")"}], "*", 
                  RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "xHsuptLowerRt", ",", "xHsuptUpperLeft"}], 
              "}"}], ",", 
             RowBox[{"Filling", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"1", "\[Rule]", 
                RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
             RowBox[{"FillingStyle", "\[Rule]", 
              RowBox[{"Directive", "[", 
               RowBox[{
                RowBox[{"Opacity", "[", "0.3", "]"}], ",", "Purple"}], 
               "]"}]}]}], "]"}]}], "]"}], ",", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Sqrt", "[", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"\[Epsilon]smax", "/", "EsMax"}], ")"}], "2"], "-", 
               SuperscriptBox["x", "2"]}], "]"}], ",", 
             RowBox[{"Sqrt", "[", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"\[Epsilon]smin", "/", "EsMax"}], ")"}], "2"], "-", 
               SuperscriptBox["x", "2"]}], "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "xHsuptLowerLeft", ",", "xHsuptLowerRt"}], 
            "}"}], ",", 
           RowBox[{"Filling", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"1", "\[Rule]", 
              RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
           RowBox[{"FillingStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{
              RowBox[{"Opacity", "[", "0.3", "]"}], ",", "Purple"}], 
             "]"}]}]}], "]"}]}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RightRegion", "=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"xHsuptLowerRt", "\[GreaterEqual]", "xHsuptUpperRt"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"xHsuptUpperRt", "\[LessEqual]", "xHsuptLowerLeft"}], ",", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Sqrt", "[", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"\[Epsilon]smin", "/", "EsMax"}], ")"}], "2"], "-", 
               SuperscriptBox["x", "2"]}], "]"}], ",", 
             RowBox[{"x", "*", 
              RowBox[{"Tan", "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"90", "-", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"180", "/", "Pi"}], ")"}], "*", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"xHsuptUpperRt", "/", "yHsuptUpperRt"}], "]"}]}], 
                   ")"}]}], ")"}], "*", 
                RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "xHsuptLowerLeft", ",", "xHsuptLowerRt"}], 
            "}"}], ",", 
           RowBox[{"Filling", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"1", "\[Rule]", 
              RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
           RowBox[{"FillingStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{
              RowBox[{"Opacity", "[", "0.3", "]"}], ",", "Purple"}], 
             "]"}]}]}], "]"}], ",", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Sqrt", "[", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"\[Epsilon]smin", "/", "EsMax"}], ")"}], "2"], "-", 
               SuperscriptBox["x", "2"]}], "]"}], ",", 
             RowBox[{"x", "*", 
              RowBox[{"Tan", "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"90", "-", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"180", "/", "Pi"}], ")"}], "*", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"xHsuptUpperRt", "/", "yHsuptUpperRt"}], "]"}]}], 
                   ")"}]}], ")"}], "*", 
                RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "xHsuptUpperRt", ",", "xHsuptLowerRt"}], "}"}], 
           ",", 
           RowBox[{"Filling", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"1", "\[Rule]", 
              RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
           RowBox[{"FillingStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{
              RowBox[{"Opacity", "[", "0.3", "]"}], ",", "Purple"}], 
             "]"}]}]}], "]"}]}], "]"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"xHsuptUpperLeft", "\[GreaterEqual]", "xHsuptLowerRt"}], ",", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Sqrt", "[", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"\[Epsilon]smax", "/", "EsMax"}], ")"}], "2"], "-", 
               SuperscriptBox["x", "2"]}], "]"}], ",", 
             RowBox[{"x", "*", 
              RowBox[{"Tan", "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"90", "-", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"180", "/", "Pi"}], ")"}], "*", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"xHsuptUpperRt", "/", "yHsuptUpperRt"}], "]"}]}], 
                   ")"}]}], ")"}], "*", 
                RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "xHsuptUpperLeft", ",", "xHsuptUpperRt"}], 
            "}"}], ",", 
           RowBox[{"Filling", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"1", "\[Rule]", 
              RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
           RowBox[{"FillingStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{
              RowBox[{"Opacity", "[", "0.3", "]"}], ",", "Purple"}], 
             "]"}]}]}], "]"}], ",", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Sqrt", "[", 
              RowBox[{
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"\[Epsilon]smax", "/", "EsMax"}], ")"}], "2"], "-", 
               SuperscriptBox["x", "2"]}], "]"}], ",", 
             RowBox[{"x", "*", 
              RowBox[{"Tan", "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"90", "-", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"180", "/", "Pi"}], ")"}], "*", 
                    RowBox[{"ArcTan", "[", 
                    RowBox[{"xHsuptUpperRt", "/", "yHsuptUpperRt"}], "]"}]}], 
                   ")"}]}], ")"}], "*", 
                RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "xHsuptLowerRt", ",", "xHsuptUpperRt"}], "}"}], 
           ",", 
           RowBox[{"Filling", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"1", "\[Rule]", 
              RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
           RowBox[{"FillingStyle", "\[Rule]", 
            RowBox[{"Directive", "[", 
             RowBox[{
              RowBox[{"Opacity", "[", "0.3", "]"}], ",", "Purple"}], 
             "]"}]}]}], "]"}]}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Perimeter", "=", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"ParametricPlot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Epsilon]smax", "/", "EsMax"}], ")"}], 
            RowBox[{"Cos", "[", 
             RowBox[{"t", "*", 
              RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Epsilon]smax", "/", "EsMax"}], ")"}], 
            RowBox[{"Sin", "[", 
             RowBox[{"t", "*", 
              RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", 
           RowBox[{"90", "-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"180", "/", "Pi"}], ")"}], "*", 
              RowBox[{"ArcTan", "[", 
               RowBox[{"xHsuptUpperLeft", "/", "yHsuptUpperLeft"}], "]"}]}], 
             ")"}]}], ",", 
           RowBox[{"90", "-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"180", "/", "Pi"}], ")"}], "*", 
              RowBox[{"ArcTan", "[", 
               RowBox[{"xHsuptUpperRt", "/", "yHsuptUpperRt"}], "]"}]}], 
             ")"}]}]}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Purple", ",", 
            RowBox[{"Thickness", "[", ".003", "]"}]}], "}"}]}]}], "]"}], ",", 
       RowBox[{"ParametricPlot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Epsilon]smin", "/", "EsMax"}], ")"}], 
            RowBox[{"Cos", "[", 
             RowBox[{"t", "*", 
              RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Epsilon]smin", "/", "EsMax"}], ")"}], 
            RowBox[{"Sin", "[", 
             RowBox[{"t", "*", 
              RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", 
           RowBox[{"90", "-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"180", "/", "Pi"}], ")"}], "*", 
              RowBox[{"ArcTan", "[", 
               RowBox[{"xHsuptUpperLeft", "/", "yHsuptUpperLeft"}], "]"}]}], 
             ")"}]}], ",", 
           RowBox[{"90", "-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"180", "/", "Pi"}], ")"}], "*", 
              RowBox[{"ArcTan", "[", 
               RowBox[{"xHsuptUpperRt", "/", "yHsuptUpperRt"}], "]"}]}], 
             ")"}]}]}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Purple", ",", 
            RowBox[{"Thickness", "[", ".003", "]"}]}], "}"}]}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"x", "*", 
          RowBox[{"Tan", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"90", "-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"180", "/", "Pi"}], ")"}], "*", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"xHsuptUpperLeft", "/", "yHsuptUpperLeft"}], "]"}]}],
                ")"}]}], ")"}], "*", 
            RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "xHsuptLowerLeft", ",", "xHsuptUpperLeft"}], 
          "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Purple", ",", 
            RowBox[{"Thickness", "[", ".003", "]"}]}], "}"}]}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{"x", "*", 
          RowBox[{"Tan", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"90", "-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"180", "/", "Pi"}], ")"}], "*", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"xHsuptUpperRt", "/", "yHsuptUpperRt"}], "]"}]}], 
               ")"}]}], ")"}], "*", 
            RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "xHsuptLowerRt", ",", "xHsuptUpperRt"}], "}"}], 
         ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Purple", ",", 
            RowBox[{"Thickness", "[", ".003", "]"}]}], "}"}]}]}], "]"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ErrorArea", "=", 
     RowBox[{"Show", "[", 
      RowBox[{
      "LeftRegion", ",", "MidRegion", ",", "RightRegion", ",", "Perimeter"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Stuff", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Tooltip", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PointSize", "[", "PtSize", "]"}], ",", "color", ",", 
           RowBox[{"Point", "[", 
            RowBox[{"{", 
             RowBox[{"xHsupt", ",", "yHsupt"}], "}"}], "]"}]}], "}"}], ",", 
         RowBox[{"DisplayForm", "[", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"\"\< \[Nu] = \>\"", "<>", 
              RowBox[{"ToString", "[", 
               RowBox[{"N", "[", "\[Nu]", "]"}], "]"}]}], ",", 
             RowBox[{"\"\<, \[Epsilon]s = \>\"", "<>", 
              RowBox[{"ToString", "[", 
               RowBox[{"N", "[", "\[Epsilon]s", "]"}], "]"}]}]}], "}"}], 
           "]"}], "]"}]}], "]"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"UpperLeftCorner", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Tooltip", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.001", "]"}], ",", "Purple", ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{"xHsuptUpperLeft", ",", "yHsuptUpperLeft"}], "}"}], 
           "]"}]}], "}"}], ",", 
        RowBox[{"DisplayForm", "[", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\"\< \[Nu] = \>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"N", "[", "\[Nu]min", "]"}], "]"}]}], ",", 
            RowBox[{"\"\<, \[Epsilon]s = \>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"N", "[", "\[Epsilon]smax", "]"}], "]"}]}]}], "}"}], 
          "]"}], "]"}]}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"UpperRtCorner", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Tooltip", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.001", "]"}], ",", "Purple", ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{"xHsuptUpperRt", ",", "yHsuptUpperRt"}], "}"}], "]"}]}], 
         "}"}], ",", 
        RowBox[{"DisplayForm", "[", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\"\< \[Nu] = \>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"N", "[", "\[Nu]max", "]"}], "]"}]}], ",", 
            RowBox[{"\"\<, \[Epsilon]s = \>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"N", "[", "\[Epsilon]smax", "]"}], "]"}]}]}], "}"}], 
          "]"}], "]"}]}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LowerRtCorner", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Tooltip", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.001", "]"}], ",", "Purple", ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{"xHsuptLowerRt", ",", "yHsuptLowerRt"}], "}"}], "]"}]}], 
         "}"}], ",", 
        RowBox[{"DisplayForm", "[", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\"\< \[Nu] = \>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"N", "[", "\[Nu]max", "]"}], "]"}]}], ",", 
            RowBox[{"\"\<, \[Epsilon]s = \>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"N", "[", "\[Epsilon]smin", "]"}], "]"}]}]}], "}"}], 
          "]"}], "]"}]}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LowerLeftCorner", "=", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Tooltip", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"PointSize", "[", "0.001", "]"}], ",", "Purple", ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{"xHsuptLowerLeft", ",", "yHsuptLowerLeft"}], "}"}], 
           "]"}]}], "}"}], ",", 
        RowBox[{"DisplayForm", "[", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\"\< \[Nu] = \>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"N", "[", "\[Nu]min", "]"}], "]"}]}], ",", 
            RowBox[{"\"\<, \[Epsilon]s = \>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"N", "[", "\[Epsilon]smin", "]"}], "]"}]}]}], "}"}], 
          "]"}], "]"}]}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"HsuCorners", "=", 
     RowBox[{"Show", "[", 
      RowBox[{
      "LowerLeftCorner", ",", "LowerRtCorner", ",", "UpperRtCorner", ",", 
       "UpperLeftCorner"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"jazz", "=", "1"}], ";"}], "\n", 
   RowBox[{"While", "[", 
    RowBox[{
     RowBox[{"jazz", "\[LessEqual]", "contnumb"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Arc", "[", "jazz", "]"}], "=", 
       RowBox[{"ParametricPlot", "[", 
        RowBox[{
         RowBox[{"Tooltip", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"jazz", "/", "contnumb"}], ")"}], 
              RowBox[{"Cos", "[", 
               RowBox[{"t", "*", 
                RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"jazz", "/", "contnumb"}], ")"}], 
              RowBox[{"Sin", "[", 
               RowBox[{"t", "*", 
                RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], "}"}], ",", 
           RowBox[{"\"\<\[Epsilon]s = \>\"", "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{"N", "[", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"EsMax", "/", "contnumb"}], ")"}], "*", "jazz"}], 
               ")"}], "]"}], "]"}]}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "60", ",", "120"}], "}"}], ",", 
         RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
         RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
         RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"jazz", "=", 
       RowBox[{"jazz", "+", "1"}]}], ";"}]}], "]"}], "\n", 
   RowBox[{
    RowBox[{"Arcs", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Arc", "[", "jazz", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"jazz", ",", "contnumb"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"FinalArc", "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Tooltip", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"t", "*", 
             RowBox[{"Pi", "/", "180"}]}], "]"}], ",", 
           RowBox[{"Sin", "[", 
            RowBox[{"t", "*", 
             RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}], ",", 
         RowBox[{"\"\<\[Epsilon]s = \>\"", "<>", 
          RowBox[{"ToString", "[", 
           RowBox[{"N", "[", 
            RowBox[{"(", 
             RowBox[{"(", "EsMax", ")"}], ")"}], "]"}], "]"}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "60", ",", "120"}], "}"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
       RowBox[{"Axes", "\[Rule]", "None"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Thick", ",", "Black"}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Radii1", ":=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Tooltip", "[", 
       RowBox[{
        RowBox[{"x", "*", 
         RowBox[{"Tan", "[", 
          RowBox[{"60", "*", 
           RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", 
        "\"\<\[Nu] = 1.0\>\""}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", 
        RowBox[{"Cos", "[", 
         RowBox[{"60", "*", 
          RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"Axes", "\[Rule]", "None"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Black"}], "}"}]}]}], "]"}]}], "\n", 
   RowBox[{"Radii2", ":=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Tooltip", "[", 
       RowBox[{
        RowBox[{"x", "*", 
         RowBox[{"Tan", "[", 
          RowBox[{"67.5", "*", 
           RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", 
        "\"\<\[Nu] = 0.75\>\""}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", 
        RowBox[{"Cos", "[", 
         RowBox[{"67.5", "*", 
          RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]}], "\n", 
   RowBox[{"Radii3", ":=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Tooltip", "[", 
       RowBox[{
        RowBox[{"x", "*", 
         RowBox[{"Tan", "[", 
          RowBox[{"75", "*", 
           RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", 
        "\"\<\[Nu] = 0.5\>\""}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", 
        RowBox[{"Cos", "[", 
         RowBox[{"75", "*", 
          RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]}], "\n", 
   RowBox[{"Radii4", ":=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Tooltip", "[", 
       RowBox[{
        RowBox[{"x", "*", 
         RowBox[{"Tan", "[", 
          RowBox[{"82.5", "*", 
           RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", 
        "\"\<\[Nu] = 0.25\>\""}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", 
        RowBox[{"Cos", "[", 
         RowBox[{"82.5", "*", 
          RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]}], "\n", 
   RowBox[{"Radii5", ":=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Tooltip", "[", 
       RowBox[{
        RowBox[{"x", "*", 
         RowBox[{"Tan", "[", 
          RowBox[{"97.5", "*", 
           RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", 
        "\"\<\[Nu] = -0.25\>\""}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", 
        RowBox[{"Cos", "[", 
         RowBox[{"97.5", "*", 
          RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]}], "\n", 
   RowBox[{"Radii6", ":=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Tooltip", "[", 
       RowBox[{
        RowBox[{"x", "*", 
         RowBox[{"Tan", "[", 
          RowBox[{"105", "*", 
           RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", 
        "\"\<\[Nu] = -0.5\>\""}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", 
        RowBox[{"Cos", "[", 
         RowBox[{"105", "*", 
          RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]}], "\n", 
   RowBox[{"Radii7", ":=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Tooltip", "[", 
       RowBox[{
        RowBox[{"x", "*", 
         RowBox[{"Tan", "[", 
          RowBox[{"112.5", "*", 
           RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", 
        "\"\<\[Nu] = -0.75\>\""}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", 
        RowBox[{"Cos", "[", 
         RowBox[{"112.5", "*", 
          RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]}], "\n", 
   RowBox[{"Radii8", ":=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Tooltip", "[", 
       RowBox[{
        RowBox[{"x", "*", 
         RowBox[{"Tan", "[", 
          RowBox[{"120", "*", 
           RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", 
        "\"\<\[Nu] = -1.0\>\""}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", 
        RowBox[{"Cos", "[", 
         RowBox[{"120", "*", 
          RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}], ",", 
      RowBox[{"Axes", "\[Rule]", "None"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Thick", ",", "Black"}], "}"}]}]}], "]"}]}], "\n", 
   RowBox[{"vert", ":=", 
    RowBox[{"Show", "[", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", 
        RowBox[{"Tooltip", "[", 
         RowBox[{
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "1"}], "}"}]}], "}"}], "]"}], ",", 
          "\"\<\[Nu] = 0\>\""}], "]"}]}], "}"}], "]"}], "]"}]}], "\n", 
   RowBox[{"HsuPlot", ":=", 
    RowBox[{"Show", "[", 
     RowBox[{
     "Arcs", ",", "FinalArc", ",", "Radii1", ",", "Radii2", ",", "Radii3", 
      ",", "Radii4", ",", "Radii5", ",", "Radii6", ",", "Radii7", ",", 
      "Radii8", ",", "vert"}], "]"}]}], "\n", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"testingct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"testingct", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"testingct2", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"testingct2", "\[LessEqual]", 
          RowBox[{"DimPerimeterList", "[", "testingct", "]"}]}], ",", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Perimxkpt", "[", 
               RowBox[{"testingct", ",", "testingct2"}], "]"}], "<", "1"}], "&&", 
             RowBox[{
              RowBox[{"Perimxkpt", "[", 
               RowBox[{"testingct", ",", 
                RowBox[{"testingct2", "-", "1"}]}], "]"}], ">", "1"}]}], ",", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Perimxkpt", "[", 
                 RowBox[{"testingct", ",", 
                  RowBox[{"testingct2", "+", "1"}]}], "]"}], ">", "1"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"tempFlinninterceptXptOne", "=", "1"}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"tempFlinninterceptYptOne", "=", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}], "-", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}], ")"}], 
                    "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}], "-", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}], 
                    ")"}]}], ")"}], "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}], 
                    ")"}]}], ")"}], "+", 
                   RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}], 
                  ")"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"tempFlinninterceptXptTwo", "=", "1"}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"tempFlinninterceptYptTwo", "=", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}], "-", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}], ")"}], 
                    "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}], "-", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}], 
                    ")"}]}], ")"}], "*", 
                    RowBox[{"(", 
                    RowBox[{"1", "-", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}], 
                    ")"}]}], ")"}], "+", 
                   RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}], 
                  ")"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
                RowBox[{"While", "[", 
                 RowBox[{
                  RowBox[{"ct", "\[LessEqual]", 
                   RowBox[{"DimPerimeterList", "[", "testingct", "]"}]}], ",",
                   "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"ct", "<", "testingct2"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"TPerimykpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxkpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";"}], ",", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"ct", "\[Equal]", "testingct2"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"TPerimykpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    "tempFlinninterceptYptOne"}], ";", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxkpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    "tempFlinninterceptXptOne"}], ";", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimykpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "+", "1"}]}], "]"}], "=", 
                    "tempFlinninterceptYptTwo"}], ";", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxkpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "+", "1"}]}], "]"}], "=", 
                    "tempFlinninterceptXptTwo"}], ";", "\[IndentingNewLine]", 
                    RowBox[{"ct", "=", 
                    RowBox[{"ct", "+", "1"}]}], ";"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"TPerimykpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "-", "1"}]}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxkpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "-", "1"}]}], "]"}]}], ";"}]}], "]"}], 
                    ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
                   RowBox[{"ct", "=", 
                    RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
                RowBox[{"While", "[", 
                 RowBox[{
                  RowBox[{"ct", "\[LessEqual]", 
                   RowBox[{"DimPerimeterList", "[", "testingct", "]"}]}], ",",
                   "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"TPerimxkpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"TPerimykpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"ct", "=", 
                    RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}]}], 
              "]"}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"testingct2", "=", 
           RowBox[{"testingct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"testingct", "=", 
        RowBox[{"testingct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"testingct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"testingct", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"testingct2", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"testingct2", "\[LessEqual]", 
          RowBox[{"DimPerimeterList", "[", "testingct", "]"}]}], ",", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Perimxkpt", "[", 
               RowBox[{"testingct", ",", "testingct2"}], "]"}], "<", "1"}], "&&", 
             RowBox[{
              RowBox[{"Perimxkpt", "[", 
               RowBox[{"testingct", ",", 
                RowBox[{"testingct2", "-", "1"}]}], "]"}], ">", "1"}]}], ",", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Perimxkpt", "[", 
                 RowBox[{"testingct", ",", 
                  RowBox[{"testingct2", "+", "1"}]}], "]"}], ">", "1"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"tempFlinninterceptXptOne", "=", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], " ", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "testingct2"}]}], "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "testingct2"}]}], "]"}], " ", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], " ", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}]}], 
                   ")"}], "/", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "testingct2"}]}], "]"}], "-", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}], 
                   ")"}]}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"tempFlinninterceptYptOne", "=", "1"}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"tempFlinninterceptXptTwo", "=", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], " ", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"1", "+", "testingct2"}]}], "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"1", "+", "testingct2"}]}], "]"}], " ", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], " ", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}]}], 
                   ")"}], "/", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"1", "+", "testingct2"}]}], "]"}], "-", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}], 
                   ")"}]}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"tempFlinninterceptYptTwo", "=", "1"}], ";", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", 
                RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
                RowBox[{"While", "[", 
                 RowBox[{
                  RowBox[{"ct", "\[LessEqual]", 
                   RowBox[{"DimPerimeterList", "[", "testingct", "]"}]}], ",",
                   "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"ct", "<", "testingct2"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"TPerimykpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxkpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";"}], ",", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"ct", "\[Equal]", "testingct2"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"TPerimykpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    "tempFlinninterceptYptOne"}], ";", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxkpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    "tempFlinninterceptXptOne"}], ";", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimykpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "+", "1"}]}], "]"}], "=", 
                    "tempFlinninterceptYptTwo"}], ";", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxkpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "+", "1"}]}], "]"}], "=", 
                    "tempFlinninterceptXptTwo"}], ";", "\[IndentingNewLine]", 
                    RowBox[{"ct", "=", 
                    RowBox[{"ct", "+", "1"}]}], ";"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"TPerimykpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "-", "1"}]}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxkpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "-", "1"}]}], "]"}]}], ";"}]}], "]"}], 
                    ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
                   RowBox[{"ct", "=", 
                    RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
                RowBox[{"While", "[", 
                 RowBox[{
                  RowBox[{"ct", "\[LessEqual]", 
                   RowBox[{"DimPerimeterList", "[", "testingct", "]"}]}], ",",
                   "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"TPerimxkpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"TPerimykpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"ct", "=", 
                    RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}]}], 
              "]"}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"testingct2", "=", 
           RowBox[{"testingct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"testingct", "=", 
        RowBox[{"testingct", "+", "1"}]}], ";"}]}], "]"}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"testingct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"testingct", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"testingct2", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"testingct2", "\[LessEqual]", 
          RowBox[{"DimPerimeterList", "[", "testingct", "]"}]}], ",", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Perimykpt", "[", 
               RowBox[{"testingct", ",", "testingct2"}], "]"}], "<", "1"}], "&&", 
             RowBox[{
              RowBox[{"Perimykpt", "[", 
               RowBox[{"testingct", ",", 
                RowBox[{"testingct2", "-", "1"}]}], "]"}], ">", "1"}]}], ",", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Perimykpt", "[", 
                 RowBox[{"testingct", ",", 
                  RowBox[{"testingct2", "+", "1"}]}], "]"}], ">", "1"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"tempFlinninterceptXptOne", "=", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], " ", "-", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}], "+", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}], "*", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}], ")"}], 
                    "-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "*", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}]}], ")"}]}], 
                    ")"}], "/", 
                   RowBox[{"(", " ", 
                    RowBox[{
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "-", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "-", "1"}]}], "]"}]}], ")"}]}], 
                  ")"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"tempFlinninterceptYptOne", "=", "1"}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"tempFlinninterceptXptTwo", "=", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], " ", "-", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}], "+", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}], "*", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}]}], ")"}], 
                    "-", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "*", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}]}], ")"}]}], 
                    ")"}], "/", 
                   RowBox[{"(", " ", 
                    RowBox[{
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "testingct2"}], "]"}], "-", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"testingct2", "+", "1"}]}], "]"}]}], ")"}]}], 
                  ")"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"tempFlinninterceptYptTwo", "=", "1"}], ";", 
                "\[IndentingNewLine]", "\[IndentingNewLine]", 
                RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
                RowBox[{"While", "[", 
                 RowBox[{
                  RowBox[{"ct", "\[LessEqual]", 
                   RowBox[{"DimPerimeterList", "[", "testingct", "]"}]}], ",",
                   "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"ct", "<", "testingct2"}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"TPerimykpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxkpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";"}], ",", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"ct", "\[Equal]", "testingct2"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"TPerimykpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    "tempFlinninterceptYptOne"}], ";", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxkpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    "tempFlinninterceptXptOne"}], ";", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimykpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "+", "1"}]}], "]"}], "=", 
                    "tempFlinninterceptYptTwo"}], ";", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxkpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "+", "1"}]}], "]"}], "=", 
                    "tempFlinninterceptXptTwo"}], ";", "\[IndentingNewLine]", 
                    RowBox[{"ct", "=", 
                    RowBox[{"ct", "+", "1"}]}], ";"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"TPerimykpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "-", "1"}]}], "]"}]}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"TPerimxkpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", 
                    RowBox[{"ct", "-", "1"}]}], "]"}]}], ";"}]}], "]"}], 
                    ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
                   RowBox[{"ct", "=", 
                    RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
                RowBox[{"While", "[", 
                 RowBox[{
                  RowBox[{"ct", "\[LessEqual]", 
                   RowBox[{"DimPerimeterList", "[", "testingct", "]"}]}], ",",
                   "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"TPerimxkpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}], "=", 
                    RowBox[{"TPerimykpt", "[", 
                    RowBox[{"testingct", ",", "ct"}], "]"}]}], ";", 
                   "\[IndentingNewLine]", 
                   RowBox[{"ct", "=", 
                    RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}]}], 
              "]"}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"testingct2", "=", 
           RowBox[{"testingct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"testingct", "=", 
        RowBox[{"testingct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"flinntestingct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"flinnnewptct", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"flinntestingct", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"flinntestingct2", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"flinntestingct2", "\[LessEqual]", 
          RowBox[{"DimPerimeterList", "[", "flinntestingct", "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Perimykpt", "[", 
            RowBox[{"1", ",", "0"}], "]"}], "=", 
           RowBox[{"Perimykpt", "[", 
            RowBox[{"1", ",", 
             RowBox[{
              RowBox[{"DimPerimeterList", "[", "flinntestingct", "]"}], "-", 
              "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Perimxkpt", "[", 
            RowBox[{"1", ",", "0"}], "]"}], "=", 
           RowBox[{"Perimxkpt", "[", 
            RowBox[{"1", ",", 
             RowBox[{
              RowBox[{"DimPerimeterList", "[", "flinntestingct", "]"}], "-", 
              "1"}]}], "]"}]}], ";", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Perimykpt", "[", 
               RowBox[{"flinntestingct", ",", "flinntestingct2"}], "]"}], "<",
               "1"}], "&&", 
             RowBox[{
              RowBox[{"Perimykpt", "[", 
               RowBox[{"flinntestingct", ",", 
                RowBox[{"flinntestingct2", "-", "1"}]}], "]"}], ">", "1"}]}], 
            ",", 
            RowBox[{
             RowBox[{
              RowBox[{"NewFlinnxPt", "[", "flinnnewptct", "]"}], "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"flinntestingct", ",", "flinntestingct2"}], "]"}],
                     " ", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"flinntestingct", ",", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "flinntestingct2"}]}], "]"}]}], 
                   "+", 
                   RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"flinntestingct", ",", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "flinntestingct2"}]}], "]"}], 
                    " ", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"flinntestingct", ",", "flinntestingct2"}], 
                    "]"}]}], "-", 
                   RowBox[{"2", " ", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"flinntestingct", ",", "flinntestingct2"}], "]"}],
                     " ", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"flinntestingct", ",", "flinntestingct2"}], 
                    "]"}]}]}], ")"}], "/", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Perimykpt", "[", 
                    RowBox[{"flinntestingct", ",", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "flinntestingct2"}]}], "]"}], 
                   "-", 
                   RowBox[{"Perimykpt", "[", 
                    RowBox[{"flinntestingct", ",", "flinntestingct2"}], 
                    "]"}]}], ")"}]}], ",", "flinntestingct", ",", 
                "flinntestingct2"}], "}"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"NewFlinnyPt", "[", "flinnnewptct", "]"}], "=", "1"}], 
             ";", "\[IndentingNewLine]", 
             RowBox[{"flinnnewptct", "=", 
              RowBox[{"flinnnewptct", "+", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Perimykpt", "[", 
               RowBox[{"flinntestingct", ",", "flinntestingct2"}], "]"}], "<",
               "1"}], "&&", 
             RowBox[{
              RowBox[{"Perimykpt", "[", 
               RowBox[{"flinntestingct", ",", 
                RowBox[{"flinntestingct2", "+", "1"}]}], "]"}], ">", "1"}]}], 
            ",", 
            RowBox[{
             RowBox[{
              RowBox[{"NewFlinnxPt", "[", "flinnnewptct", "]"}], "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"flinntestingct", ",", "flinntestingct2"}], "]"}],
                     " ", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"flinntestingct", ",", 
                    RowBox[{"1", "+", "flinntestingct2"}]}], "]"}]}], "+", 
                   RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"flinntestingct", ",", 
                    RowBox[{"1", "+", "flinntestingct2"}]}], "]"}], " ", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"flinntestingct", ",", "flinntestingct2"}], 
                    "]"}]}], "-", 
                   RowBox[{"2", " ", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"flinntestingct", ",", "flinntestingct2"}], "]"}],
                     " ", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"flinntestingct", ",", "flinntestingct2"}], 
                    "]"}]}]}], ")"}], "/", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Perimykpt", "[", 
                    RowBox[{"flinntestingct", ",", 
                    RowBox[{"1", "+", "flinntestingct2"}]}], "]"}], "-", 
                   RowBox[{"Perimykpt", "[", 
                    RowBox[{"flinntestingct", ",", "flinntestingct2"}], 
                    "]"}]}], ")"}]}], ",", "flinntestingct", ",", 
                "flinntestingct2"}], "}"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"NewFlinnyPt", "[", "flinnnewptct", "]"}], "=", "1"}], 
             ";", "\[IndentingNewLine]", 
             RowBox[{"flinnnewptct", "=", 
              RowBox[{"flinnnewptct", "+", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"flinntestingct2", "=", 
           RowBox[{"flinntestingct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"flinntestingct", "=", 
        RowBox[{"flinntestingct", "+", "1"}]}], ";"}]}], "]"}], ";"}], "\n", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"flinntestingct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"flinntestingct", "\[LessEqual]", "islandnumb"}], ",", "\n", 
      RowBox[{
       RowBox[{"flinntestingct2", "=", "1"}], ";", "\n", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"flinntestingct2", "<", 
          RowBox[{"DimPerimeterList", "[", "flinntestingct", "]"}]}], ",", 
         "\n", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Perimxkpt", "[", 
               RowBox[{"flinntestingct", ",", "flinntestingct2"}], "]"}], "<",
               "1"}], "&&", 
             RowBox[{
              RowBox[{"Perimxkpt", "[", 
               RowBox[{"flinntestingct", ",", 
                RowBox[{"flinntestingct2", "-", "1"}]}], "]"}], ">", "1"}]}], 
            ",", 
            RowBox[{
             RowBox[{
              RowBox[{"NewFlinnxPt", "[", "flinnnewptct", "]"}], "=", 
              RowBox[{"{", 
               RowBox[{"1", ",", "flinntestingct", ",", "flinntestingct2"}], 
               "}"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"NewFlinnyPt", "[", "flinnnewptct", "]"}], "=", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"flinntestingct", ",", 
                    RowBox[{"flinntestingct2", "-", "1"}]}], "]"}], "-", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"flinntestingct", ",", "flinntestingct2"}], 
                    "]"}]}], ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"flinntestingct", ",", 
                    RowBox[{"flinntestingct2", "-", "1"}]}], "]"}], "-", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"flinntestingct", ",", "flinntestingct2"}], 
                    "]"}]}], ")"}]}], ")"}], "*", 
                  RowBox[{"(", 
                   RowBox[{"-", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"flinntestingct", ",", "flinntestingct2"}], 
                    "]"}]}], ")"}]}], ")"}], "+", 
                RowBox[{"Perimykpt", "[", 
                 RowBox[{"flinntestingct", ",", 
                  RowBox[{"flinntestingct2", "-", "1"}]}], "]"}]}], ")"}]}], 
             ";", "\[IndentingNewLine]", 
             RowBox[{"flinnnewptct", "=", 
              RowBox[{"flinnnewptct", "+", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Perimxkpt", "[", 
               RowBox[{"flinntestingct", ",", "flinntestingct2"}], "]"}], "<",
               "1"}], "&&", 
             RowBox[{
              RowBox[{"Perimxkpt", "[", 
               RowBox[{"flinntestingct", ",", 
                RowBox[{"flinntestingct2", "+", "1"}]}], "]"}], ">", "1"}]}], 
            ",", 
            RowBox[{
             RowBox[{
              RowBox[{"NewFlinnxPt", "[", "flinnnewptct", "]"}], "=", 
              RowBox[{"{", 
               RowBox[{"1", ",", "flinntestingct", ",", "flinntestingct2"}], 
               "}"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"NewFlinnyPt", "[", "flinnnewptct", "]"}], "=", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"flinntestingct", ",", 
                    RowBox[{"flinntestingct2", "+", "1"}]}], "]"}], "-", 
                    RowBox[{"Perimykpt", "[", 
                    RowBox[{"flinntestingct", ",", "flinntestingct2"}], 
                    "]"}]}], ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"flinntestingct", ",", 
                    RowBox[{"flinntestingct2", "+", "1"}]}], "]"}], "-", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"flinntestingct", ",", "flinntestingct2"}], 
                    "]"}]}], ")"}]}], ")"}], "*", 
                  RowBox[{"(", 
                   RowBox[{"-", 
                    RowBox[{"Perimxkpt", "[", 
                    RowBox[{"flinntestingct", ",", "flinntestingct2"}], 
                    "]"}]}], ")"}]}], ")"}], "+", 
                RowBox[{"Perimykpt", "[", 
                 RowBox[{"flinntestingct", ",", 
                  RowBox[{"flinntestingct2", "+", "1"}]}], "]"}]}], ")"}]}], 
             ";", "\[IndentingNewLine]", 
             RowBox[{"flinnnewptct", "=", 
              RowBox[{"flinnnewptct", "+", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"flinntestingct2", "=", 
           RowBox[{"flinntestingct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"flinntestingct", "=", 
        RowBox[{"flinntestingct", "+", "1"}]}], ";"}]}], "]"}], ";"}], "\n", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"flinnnewptct3", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"flinnnewptct3", "<", "flinnnewptct"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"Perimxkpt", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"NewFlinnxPt", "[", "flinnnewptct3", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"NewFlinnxPt", "[", "flinnnewptct3", "]"}], "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], "]"}], "=", 
        RowBox[{
         RowBox[{"NewFlinnxPt", "[", "flinnnewptct3", "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Perimykpt", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"NewFlinnxPt", "[", "flinnnewptct3", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", 
          RowBox[{
           RowBox[{"NewFlinnxPt", "[", "flinnnewptct3", "]"}], "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], "]"}], "=", 
        RowBox[{"NewFlinnyPt", "[", "flinnnewptct3", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"flinnnewptct3", "=", 
        RowBox[{"flinnnewptct3", "+", "1"}]}], ";"}]}], "]"}], ";"}], "\n", 
   "\n", 
   RowBox[{
    RowBox[{"flinntestingct", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"flinntestingct", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"flinnoverptct", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"flinntestingct2", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"flinntestingct2", "\[LessEqual]", 
          RowBox[{"DimPerimeterList", "[", "flinntestingct", "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Perimykpt", "[", 
              RowBox[{"flinntestingct", ",", "flinntestingct2"}], "]"}], "<", 
             "1"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"FlinnOverPts", "[", 
               RowBox[{"flinntestingct", ",", "flinnoverptct"}], "]"}], "=", 
              "flinntestingct2"}], ";", "\[IndentingNewLine]", 
             RowBox[{"flinnoverptct", "=", 
              RowBox[{"flinnoverptct", "+", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Perimxkpt", "[", 
              RowBox[{"flinntestingct", ",", "flinntestingct2"}], "]"}], "<", 
             "1"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"FlinnOverPts", "[", 
               RowBox[{"flinntestingct", ",", "flinnoverptct"}], "]"}], "=", 
              "flinntestingct2"}], ";", "\[IndentingNewLine]", 
             RowBox[{"flinnoverptct", "=", 
              RowBox[{"flinnoverptct", "+", "1"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"flinntestingct2", "=", 
           RowBox[{"flinntestingct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"flinnoverptnumb", "[", "flinntestingct", "]"}], "=", 
        RowBox[{"flinnoverptct", "-", "1"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"flinntestingct", "=", 
        RowBox[{"flinntestingct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"newflinnct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"newflinnct", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"NewFlinnX", "[", "newflinnct", "]"}], "=", 
        RowBox[{"Delete", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Perimxkpt", "[", 
             RowBox[{"newflinnct", ",", "x"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "1", ",", 
              RowBox[{"DimPerimeterList", "[", "newflinnct", "]"}]}], "}"}]}],
            "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"FlinnOverPts", "[", 
              RowBox[{"newflinnct", ",", "x"}], "]"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "1", ",", 
              RowBox[{"flinnoverptnumb", "[", "newflinnct", "]"}]}], "}"}]}], 
           "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"NewFlinnY", "[", "newflinnct", "]"}], "=", 
        RowBox[{"Delete", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Perimykpt", "[", 
             RowBox[{"newflinnct", ",", "x"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "1", ",", 
              RowBox[{"DimPerimeterList", "[", "newflinnct", "]"}]}], "}"}]}],
            "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"FlinnOverPts", "[", 
              RowBox[{"newflinnct", ",", "x"}], "]"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "1", ",", 
              RowBox[{"flinnoverptnumb", "[", "newflinnct", "]"}]}], "}"}]}], 
           "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"newflinnct", "=", 
        RowBox[{"newflinnct", "+", "1"}]}], ";"}]}], "]"}], ";"}], "\n", 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"ctt", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"ctt", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ctt2", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"NewFlinnDimPerimeterList", "[", "ctt", "]"}], "=", 
        RowBox[{
         RowBox[{"Dimensions", "[", 
          RowBox[{"NewFlinnX", "[", "ctt", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"ctt2", "\[LessEqual]", 
          RowBox[{"NewFlinnDimPerimeterList", "[", "ctt", "]"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"NewPerimxFlinnpt", "[", 
            RowBox[{"ctt", ",", "ctt2"}], "]"}], "=", 
           RowBox[{
            RowBox[{"NewFlinnX", "[", "ctt", "]"}], "[", 
            RowBox[{"[", "ctt2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"NewPerimyFlinnpt", "[", 
            RowBox[{"ctt", ",", "ctt2"}], "]"}], "=", 
           RowBox[{
            RowBox[{"NewFlinnY", "[", "ctt", "]"}], "[", 
            RowBox[{"[", "ctt2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"ctt2", "=", 
           RowBox[{"ctt2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ctt", "=", 
        RowBox[{"ctt", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"flinnct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"flinnct", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"FlinnPerimGraphic", "[", "flinnct", "]"}], "=", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Opacity", "[", ".3", "]"}], ",", "Purple", ",", 
           RowBox[{"EdgeForm", "[", 
            RowBox[{"Directive", "[", 
             RowBox[{
              RowBox[{"Thickness", "[", ".003", "]"}], ",", "Purple"}], "]"}],
             "]"}], ",", 
           RowBox[{"Polygon", "[", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"NewPerimxFlinnpt", "[", 
                 RowBox[{"flinnct", ",", "x"}], "]"}], ",", 
                RowBox[{"NewPerimyFlinnpt", "[", 
                 RowBox[{"flinnct", ",", "x"}], "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", "1", ",", 
                RowBox[{"NewFlinnDimPerimeterList", "[", "flinnct", "]"}], 
                ",", "ReduceRes"}], "}"}]}], "]"}], "]"}]}], "}"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"flinnct", "=", 
        RowBox[{"flinnct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FlinnErrorPoly", "=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ReduceRes", "==", "1"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"FlinnPerimGraphic", "[", "x", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "1", ",", "islandnumb"}], "}"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{"ErrorPoly", ",", "LabelCorners"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"FlinnDiagram", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"Flinn", ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"PointSize", "[", 
          RowBox[{"PercentFlinnPtsSize", "*", "FlinnPtSize"}], "]"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Point", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Statxkpt", "[", "x", "]"}], ",", 
              RowBox[{"Statykpt", "[", "x", "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}]}], "}"}],
        "]"}], ",", "FlinnErrorPoly", ",", "kpt", ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"Axes", "\[Rule]", "True"}], ",", 
      RowBox[{"AxesOrigin", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], ",", 
      RowBox[{"PlotLabel", "\[Rule]", 
       RowBox[{"Style", "[", 
        RowBox[{
        "\"\<Flinn Diagram\>\"", ",", "32", ",", "Blue", ",", "Bold"}], 
        "]"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<\!\(\*SubscriptBox[\(\[Epsilon]\), \(s\)]\) contour interval: \>\"", 
     ",", 
     RowBox[{"N", "[", "Flinncontinterval", "]"}]}], "]"}], "\n", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<Flinn's k-value contours: \>\"", ",", 
     RowBox[{"TableForm", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"N", "[", 
          RowBox[{"kcont", "[", "x", "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "1", ",", "NumbKConts"}], "}"}]}], "]"}], ",", 
       RowBox[{"TableDirections", "\[Rule]", "Row"}]}], "]"}]}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"HsuBoundary", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"FinalArc", ",", "Radii1", ",", "Radii8", ",", 
       RowBox[{"PlotRange", "->", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", ".6"}], ",", ".6"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.15"}], "}"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ErrorRegion", "=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ComplexPolyOrRegularPoly", "\[Equal]", "1"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"PerimGraphic", "[", "x", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "1", ",", "islandnumb"}], "}"}]}], "]"}], ",", 
       RowBox[{"Show", "[", 
        RowBox[{"ErrorArea", ",", "HsuCorners"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"FullHsu", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"HsuPlot", ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"PointSize", "[", 
          RowBox[{"PercentHsuPtSize", "*", "PtSize"}], "]"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Point", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"StatxHsupt", "[", "x", "]"}], ",", 
              RowBox[{"StatyHsupt", "[", "x", "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "1", ",", "statnumb"}], "}"}]}], "]"}]}], "}"}],
        "]"}], ",", "ErrorRegion", ",", "HsuBoundary", ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<\!\(\*SubscriptBox[\(\[Epsilon]\), \(s\)]\) \[Rule]\>\"", " ",
             ",", 
            RowBox[{"FontSize", "\[Rule]", "30"}], ",", "Bold"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.3", ",", "0.4"}], "}"}], ",", "Automatic", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{"30", "\[Degree]"}], "]"}], ",", 
            RowBox[{"Cos", "[", 
             RowBox[{"30", "\[Degree]"}], "]"}]}], "}"}]}], "]"}], "}"}], 
       "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{
           "\"\<\[LeftArrow] \!\(\*SubscriptBox[\(\[Epsilon]\), \(s\)]\)\>\"",
             " ", ",", 
            RowBox[{"FontSize", "\[Rule]", "30"}], ",", "Bold"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.3"}], ",", "0.4"}], "}"}], ",", "Automatic", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{"30", "\[Degree]"}], "]"}], ",", 
            RowBox[{"-", 
             RowBox[{"Cos", "[", 
              RowBox[{"30", "\[Degree]"}], "]"}]}]}], "}"}]}], "]"}], "}"}], 
       "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<\[Nu] = -1\>\"", " ", ",", 
            RowBox[{"FontSize", "\[Rule]", "24"}], ",", "Bold"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", ".51"}], ",", "0.91"}], "}"}], ",", "Automatic", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"30", "\[Degree]"}], "]"}], ",", 
            RowBox[{"Sin", "[", 
             RowBox[{"30", "\[Degree]"}], "]"}]}], "}"}]}], "]"}], "}"}], 
       "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<\[Nu] = 0\>\"", " ", ",", 
            RowBox[{"FontSize", "\[Rule]", "24"}], ",", "Bold"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"0.0", ",", "1.04"}], "}"}]}], "]"}], "}"}], "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<\[Nu] = 1\>\"", " ", ",", 
            RowBox[{"FontSize", "\[Rule]", "24"}], ",", "Bold"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{".525", ",", "0.9"}], "}"}], ",", "Automatic", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Cos", "[", 
             RowBox[{"30", "\[Degree]"}], "]"}], ",", 
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              RowBox[{"30", "\[Degree]"}], "]"}]}]}], "}"}]}], "]"}], "}"}], 
       "]"}], ",", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"Text", "[", 
         RowBox[{
          RowBox[{"Style", "[", 
           RowBox[{"\"\<Hsu Diagram\>\"", ",", 
            RowBox[{"FontSize", "\[Rule]", "24"}], ",", "Blue", ",", "Bold"}],
            "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", "1.125"}], "}"}]}], "]"}], "}"}], "]"}], ",", 
      "Stuff", ",", 
      RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
      RowBox[{"PlotRange", "->", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", ".6"}], ",", ".6"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1.15"}], "}"}]}], "}"}]}]}], "]"}]}], "\n", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<Plot Range for strain is 0 to \>\"", ",", 
     RowBox[{"N", "[", "EsMax", "]"}]}], "]"}], "\n", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<Strain contour interval is \>\"", ",", 
     RowBox[{"N", "[", "continterval", "]"}]}], "]"}], "\n", 
   RowBox[{
   "Print", "[", "\"\<Plot Range for Lode's Ratio is -1 to 1\>\"", "]"}], 
   "\n", 
   RowBox[{
   "Print", "[", "\"\<Lode's Ratio contour interal is 0.25\>\"", "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"IntermPtLabel", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Tooltip", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Blue", ",", 
           RowBox[{"PointSize", "[", ".025", "]"}], ",", 
           RowBox[{"Point", "[", 
            RowBox[{"equalAreaProjection", "[", 
             RowBox[{"lowerHemisphere", "[", 
              RowBox[{"IntermAxisFit", ".", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], "]"}], 
             "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"DisplayForm", "[", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"N", "[", "FitTrendInterm", "]"}], "]"}], "<>", 
             RowBox[{"ToString", "[", "\"\<,\>\"", "]"}], "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"N", "[", "FitPlungeInterm", "]"}], "]"}], "<>", 
             RowBox[{"ToString", "[", "\"\<)\>\"", "]"}]}], "}"}], "]"}], 
          "]"}]}], "]"}], "]"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"LongPtLabel", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Tooltip", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"Red", ",", 
           RowBox[{"PointSize", "[", ".025", "]"}], ",", 
           RowBox[{"Point", "[", 
            RowBox[{"equalAreaProjection", "[", 
             RowBox[{"lowerHemisphere", "[", 
              RowBox[{"LongAxisFit", ".", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], "]"}], 
             "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"DisplayForm", "[", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"N", "[", "FitTrendLong", "]"}], "]"}], "<>", 
             RowBox[{"ToString", "[", "\"\<,\>\"", "]"}], "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"N", "[", "FitPlungeLong", "]"}], "]"}], "<>", 
             RowBox[{"ToString", "[", "\"\<)\>\"", "]"}]}], "}"}], "]"}], 
          "]"}]}], "]"}], "]"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ShortPtLabel", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Tooltip", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CMYKColor", "[", 
            RowBox[{".95", ",", ".3", ",", "1", ",", ".2"}], "]"}], ",", 
           RowBox[{"PointSize", "[", ".025", "]"}], ",", 
           RowBox[{"Point", "[", 
            RowBox[{"equalAreaProjection", "[", 
             RowBox[{"lowerHemisphere", "[", 
              RowBox[{"ShortAxisFit", ".", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], "]"}], 
             "]"}], "]"}]}], "}"}], ",", 
         RowBox[{"DisplayForm", "[", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"N", "[", "FitTrendShort", "]"}], "]"}], "<>", 
             RowBox[{"ToString", "[", "\"\<,\>\"", "]"}], "<>", 
             RowBox[{"ToString", "[", 
              RowBox[{"N", "[", "FitPlungeShort", "]"}], "]"}], "<>", 
             RowBox[{"ToString", "[", "\"\<)\>\"", "]"}]}], "}"}], "]"}], 
          "]"}]}], "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sumptsize", "=", "0.015"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SumShortFit", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"equalAreaPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"cartesianFromTrendPlungeDeg", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"FitTrendShort", "\[Equal]", "\"\<NA\>\""}], ",", "000",
               ",", "FitTrendShort"}], "]"}], ",", "FitPlungeShort"}], "}"}], 
          "]"}], "}"}], ",", " ", 
        RowBox[{"FitSizePercent", "*", "sumptsize"}], ",", 
        RowBox[{"CMYKColor", "[", 
         RowBox[{".95", ",", ".3", ",", "1", ",", ".2"}], "]"}]}], "]"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SumIntermFit", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"equalAreaPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"cartesianFromTrendPlungeDeg", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"FitTrendInterm", "\[Equal]", "\"\<NA\>\""}], ",", 
              "000", ",", "FitTrendInterm"}], "]"}], ",", "FitPlungeInterm"}],
            "}"}], "]"}], "}"}], ",", " ", 
        RowBox[{"FitSizePercent", "*", "sumptsize"}], ",", "Blue"}], "]"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SumLongFit", "=", 
     RowBox[{"Show", "[", 
      RowBox[{"equalAreaPlot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"cartesianFromTrendPlungeDeg", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"FitTrendLong", "\[Equal]", "\"\<NA\>\""}], ",", "000", 
              ",", "FitTrendLong"}], "]"}], ",", "FitPlungeLong"}], "}"}], 
          "]"}], "}"}], ",", " ", 
        RowBox[{"FitSizePercent", "*", "sumptsize"}], ",", "Red"}], "]"}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AxesPlot", "=", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"schmidtNet", "[", 
        RowBox[{
         RowBox[{"10", " ", "Degree"}], ",", " ", 
         RowBox[{"5", " ", "Degree"}]}], "]"}], ",", "SumLongFit", ",", 
       "SumShortFit", ",", "SumIntermFit", ",", "LongPtLabel", ",", 
       "IntermPtLabel", ",", "ShortPtLabel", ",", 
       RowBox[{"PlotLabel", "\[Rule]", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<Principal Axes Orientations\>\"", ",", "24", ",", "Blue", ",", 
          "Bold"}], "]"}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{"PrinAxesPlot", "=", 
    RowBox[{"Show", "[", 
     RowBox[{
      RowBox[{"ShowLegend", "[", 
       RowBox[{"AxesPlot", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{"Red", ",", 
                 RowBox[{"Disk", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", ".1"}], "]"}]}], 
                "}"}], "]"}], ",", 
              RowBox[{"Text", "[", 
               RowBox[{"Style", "[", 
                RowBox[{"\"\<Long Axis\>\"", ",", 
                 RowBox[{"FontSize", "\[Rule]", "18"}]}], "]"}], "]"}]}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{"Blue", ",", 
                 RowBox[{"Disk", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", ".1"}], "]"}]}], 
                "}"}], "]"}], ",", 
              RowBox[{"Text", "[", 
               RowBox[{"Style", "[", 
                RowBox[{"\"\<Intermediate Axis\>\"", ",", 
                 RowBox[{"FontSize", "\[Rule]", "18"}]}], "]"}], "]"}]}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Graphics", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"CMYKColor", "[", 
                  RowBox[{".95", ",", ".3", ",", "1", ",", ".2"}], "]"}], ",", 
                 RowBox[{"Disk", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", ".1"}], "]"}]}], 
                "}"}], "]"}], ",", 
              RowBox[{"Text", "[", 
               RowBox[{"Style", "[", 
                RowBox[{"\"\<Short Axis\>\"", ",", 
                 RowBox[{"FontSize", "\[Rule]", "18"}]}], "]"}], "]"}]}], 
             "}"}]}], "}"}], ",", 
          RowBox[{"LegendPosition", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"0.85", ",", 
             RowBox[{"-", "0.95"}]}], "}"}]}]}], "}"}]}], "]"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "850"}]}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"ElleWOplanes", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"Vellipsoid", ",", 
      RowBox[{"BoxRatios", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<\[UpArrow] North \>\"", ",", "\"\<East \[Rule] \>\"", ",", 
         "\"\<Up \[UpArrow] \>\""}], "}"}]}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "ForPlotRange"}], "*", "1.1"}], ",", 
           RowBox[{"ForPlotRange", "*", "1.1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "ForPlotRange"}], "*", "1.1"}], ",", 
           RowBox[{"ForPlotRange", "*", "1.1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "ForPlotRange"}], "*", "1.1"}], ",", 
           RowBox[{"ForPlotRange", "*", "1.1"}]}], "}"}]}], "}"}]}], ",", 
      RowBox[{"ViewPoint", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", "0", ",", "3"}], "}"}]}], ",", 
      RowBox[{"Ticks", "\[Rule]", "False"}]}], "]"}]}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<The Octahedral Shear Strain (\[Epsilon]s) = \>\"", ",", 
     "\[Epsilon]s", ",", "\"\<  +\>\"", ",", 
     RowBox[{"\[Epsilon]smax", "-", "\[Epsilon]s"}], ",", "\"\</-\>\"", ",", 
     RowBox[{"\[Epsilon]s", "-", "\[Epsilon]smin"}], ",", " ", 
     "\"\< with \>\"", ",", 
     RowBox[{"Round", "[", 
      RowBox[{"100", "*", "desiredpercentage"}], "]"}], ",", 
     "\"\<% error margins\>\""}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<Normalized Axes Lengths = \>\"", ",", 
     RowBox[{"N", "[", "NormLong", "]"}], ",", "\"\< : 1.0 : \>\"", ",", 
     RowBox[{"N", "[", "NormShort", "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<The Flinn's k-value = \>\"", ",", "K", ",", "\"\<  +\>\"", ",", 
     RowBox[{"Abs", "[", 
      RowBox[{"Kmax", "-", "K"}], "]"}], ",", "\"\</-\>\"", ",", 
     RowBox[{"Abs", "[", 
      RowBox[{"K", "-", "Kmin"}], "]"}], " ", ",", "\"\< with \>\"", ",", 
     RowBox[{"Round", "[", 
      RowBox[{"100", "*", "desiredpercentage"}], "]"}], ",", 
     "\"\<% error margins\>\""}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<The Lodes's Ratio (\[Nu]) = \>\"", ",", "\[Nu]", ",", "\"\<  +\>\"", 
     ",", 
     RowBox[{"Abs", "[", 
      RowBox[{"\[Nu]max", "-", "\[Nu]"}], "]"}], " ", ",", "\"\</-\>\"", ",", 
     RowBox[{"Abs", "[", 
      RowBox[{"\[Nu]", "-", "\[Nu]min"}], "]"}], " ", ",", "\"\< with \>\"", 
     ",", 
     RowBox[{"Round", "[", 
      RowBox[{"100", "*", "desiredpercentage"}], "]"}], ",", 
     "\"\<% error margins\>\""}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"AlphaOn", "\[Equal]", "1"}], ",", "\n", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<The Trend:Plunge of the Long Axis = \>\"", ",", 
         RowBox[{"N", "[", "FitTrendLong", "]"}], ",", "\"\<\[Degree]:\>\"", 
         ",", 
         RowBox[{"N", "[", "FitPlungeLong", "]"}], ",", 
         "\"\<\[Degree] with a \>\"", ",", 
         RowBox[{"Round", "[", 
          RowBox[{"100", "*", "desiredpercentage"}], "]"}], ",", 
         "\"\<% error angle = \>\"", ",", "LongCIAngle", ",", 
         "\"\<\[Degree] and an \[Alpha]\>\"", ",", 
         RowBox[{"Round", "[", 
          RowBox[{"100", "*", "alphapercent"}], "]"}], ",", "\"\< = \>\"", 
         ",", "LongAlpha", " ", ",", "\"\<\[Degree]\>\""}], "]"}], ";"}], ",", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<The Trend:Plunge of the Long Axis = \>\"", ",", 
         RowBox[{"N", "[", "FitTrendLong", "]"}], ",", "\"\<\[Degree]:\>\"", 
         ",", 
         RowBox[{"N", "[", "FitPlungeLong", "]"}], ",", 
         "\"\<\[Degree] with a \>\"", ",", 
         RowBox[{"Round", "[", 
          RowBox[{"100", "*", "desiredpercentage"}], "]"}], ",", 
         "\"\<% error angle = \>\"", ",", "LongCIAngle", ",", 
         "\"\<\[Degree]\>\""}], "]"}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"AlphaOn", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<The Trend:Plunge of the Intermediate Axis = \>\"", ",", 
         RowBox[{"N", "[", "FitTrendInterm", "]"}], ",", "\"\<\[Degree]:\>\"",
          ",", 
         RowBox[{"N", "[", "FitPlungeInterm", "]"}], ",", 
         "\"\<\[Degree] with a \>\"", ",", 
         RowBox[{"Round", "[", 
          RowBox[{"100", "*", "desiredpercentage"}], "]"}], ",", 
         "\"\<% error angle = \>\"", ",", "IntermCIAngle", ",", 
         "\"\<\[Degree] and an \[Alpha]\>\"", ",", 
         RowBox[{"Round", "[", 
          RowBox[{"100", "*", "alphapercent"}], "]"}], ",", "\"\< = \>\"", 
         ",", "IntermAlpha", " ", ",", "\"\<\[Degree]\>\""}], "]"}], ";"}], 
      ",", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<The Trend:Plunge of the Intermediate Axis = \>\"", ",", 
         RowBox[{"N", "[", "FitTrendInterm", "]"}], ",", "\"\<\[Degree]:\>\"",
          ",", 
         RowBox[{"N", "[", "FitPlungeInterm", "]"}], ",", 
         "\"\<\[Degree] with a \>\"", ",", 
         RowBox[{"Round", "[", 
          RowBox[{"100", "*", "desiredpercentage"}], "]"}], ",", 
         "\"\<% error angle = \>\"", ",", "IntermCIAngle", ",", 
         "\"\<\[Degree]\>\""}], "]"}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"AlphaOn", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<The Trend:Plunge of the Short Axis = \>\"", ",", 
         RowBox[{"N", "[", "FitTrendShort", "]"}], ",", "\"\<\[Degree]:\>\"", 
         ",", 
         RowBox[{"N", "[", "FitPlungeShort", "]"}], ",", 
         "\"\<\[Degree] with a \>\"", ",", 
         RowBox[{"Round", "[", 
          RowBox[{"100", "*", "desiredpercentage"}], "]"}], ",", 
         "\"\<% error angle = \>\"", ",", "ShortCIAngle", ",", 
         "\"\<\[Degree] and an \[Alpha]\>\"", ",", 
         RowBox[{"Round", "[", 
          RowBox[{"100", "*", "alphapercent"}], "]"}], ",", "\"\< = \>\"", 
         ",", "ShortAlpha", " ", ",", "\"\<\[Degree]\>\""}], "]"}], ";"}], 
      ",", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<The Trend:Plunge of the Short Axis = \>\"", ",", 
         RowBox[{"N", "[", "FitTrendShort", "]"}], ",", "\"\<\[Degree]:\>\"", 
         ",", 
         RowBox[{"N", "[", "FitPlungeShort", "]"}], ",", 
         "\"\<\[Degree] with a \>\"", ",", 
         RowBox[{"Round", "[", 
          RowBox[{"100", "*", "desiredpercentage"}], "]"}], ",", 
         "\"\<% error angle = \>\"", ",", "ShortCIAngle", ",", 
         "\"\<\[Degree]\>\""}], "]"}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<Mean Error (zero is a perfect fit) = \>\"", ",", "MeanDiffError"}], 
     "]"}], ";"}], "\[IndentingNewLine]", "\n", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"Problem", "\[Equal]", "1"}], ",", 
     RowBox[{
     "Print", "[", "\"\<More data are needed to constrain the solution.\>\"", 
      "]"}]}], "]"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"Problem", "\[Equal]", "1"}], ",", 
     RowBox[{"EmitSound", "[", 
      RowBox[{"Sound", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"SoundNote", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"DeleteCases", "[", 
             RowBox[{
              RowBox[{"3", " ", 
               RowBox[{"Range", "[", "21", "]"}], 
               RowBox[{"Reverse", "[", "#", "]"}]}], ",", "0"}], "]"}], "-", 
            "24"}], ",", ".1"}], "]"}], "&"}], "/@", 
        RowBox[{"Transpose", "[", 
         RowBox[{"CellularAutomaton", "[", 
          RowBox[{"90", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", "1", "}"}], ",", "0"}], "}"}], ",", "20"}], "]"}], 
         "]"}]}], "]"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"reducedprecision", "\[Equal]", "1"}], ",", 
      RowBox[{
      "Print", "[", 
       "\"\<The working precision was reduced in order to make the function \
converge\>\"", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.487174247242574*^9, 3.4871742776123114`*^9}, 
   3.4871743338275266`*^9, {3.487174762772061*^9, 3.4871747985711083`*^9}, {
   3.48717490176101*^9, 3.4871749090874295`*^9}, {3.4871749554500813`*^9, 
   3.48717502361598*^9}, {3.4871862392520313`*^9, 3.487186271423872*^9}, {
   3.487186360744981*^9, 3.4871863936968656`*^9}, 3.487186428625863*^9, {
   3.4871865765023212`*^9, 3.487186577094355*^9}, {3.4871866405469847`*^9, 
   3.4871866966911955`*^9}, {3.487186901263897*^9, 3.4871869297615266`*^9}, {
   3.4871869857947316`*^9, 3.487186995583291*^9}, {3.487187104629528*^9, 
   3.487187110441861*^9}, {3.487187144660818*^9, 3.487187203680194*^9}, 
   3.4871883033280897`*^9, {3.487203071425685*^9, 3.487203090535719*^9}, 
   3.4872045032274*^9, {3.4872463495157666`*^9, 3.4872463693439007`*^9}, {
   3.487246433157551*^9, 3.487246435278672*^9}, {3.4872473815177937`*^9, 
   3.487247450426735*^9}, {3.4872474820085416`*^9, 3.4872477205581856`*^9}, {
   3.487248117408884*^9, 3.4872481184019413`*^9}, {3.487248178762394*^9, 
   3.4872482110042377`*^9}, {3.4872482608720903`*^9, 3.487248319881465*^9}, 
   3.4872483575806217`*^9, {3.487248908602138*^9, 3.487248909463187*^9}, {
   3.487249340737855*^9, 3.4872493588798923`*^9}, {3.4872496780271463`*^9, 
   3.4872497003824253`*^9}, {3.487250023118885*^9, 3.487250027655144*^9}, {
   3.487250575263466*^9, 3.487250676430252*^9}, {3.487251411085272*^9, 
   3.487251471173709*^9}, {3.487251816966487*^9, 3.487251829224188*^9}, {
   3.4872519179082603`*^9, 3.487251966365032*^9}, {3.4872520257294273`*^9, 
   3.487252033389866*^9}, {3.4872523305878644`*^9, 3.487252332862994*^9}, {
   3.4872523688660536`*^9, 3.4872523709751744`*^9}, 3.4872527765613728`*^9, {
   3.4872528923829975`*^9, 3.487252892648012*^9}, {3.487499290280834*^9, 
   3.48749930069143*^9}, {3.48749933355931*^9, 3.487499376693777*^9}, {
   3.4874994538371897`*^9, 3.48749946608889*^9}, {3.487499503736044*^9, 
   3.4874995041570673`*^9}, {3.487507728289461*^9, 3.487507734874838*^9}, {
   3.4875080286316395`*^9, 3.4875080768673983`*^9}, {3.4875082677043138`*^9, 
   3.4875083238205233`*^9}, {3.487508913094228*^9, 3.487508937050598*^9}, {
   3.4875876017805667`*^9, 3.487587603337656*^9}, {3.4875892032991686`*^9, 
   3.4875892051122723`*^9}, {3.487589275342289*^9, 3.4875892781714506`*^9}, {
   3.4875909175242167`*^9, 3.4875909362422867`*^9}, {3.487591048960734*^9, 
   3.4875911435141425`*^9}, 3.487591236332451*^9, {3.487591325170532*^9, 
   3.4875913269496346`*^9}, {3.4875913587614536`*^9, 
   3.4875913744783525`*^9}, {3.4875915221567993`*^9, 3.487591533167429*^9}, {
   3.487591630017969*^9, 3.487591630756011*^9}, {3.4875916701542645`*^9, 
   3.487591717766988*^9}, {3.487591978521902*^9, 3.4875919790189304`*^9}, {
   3.4876119442692347`*^9, 3.487611949521535*^9}, {3.4876123171505623`*^9, 
   3.4876123207197666`*^9}, {3.4876123583329177`*^9, 3.487612362155136*^9}, {
   3.487620968917506*^9, 3.4876209735663147`*^9}, {3.487621086931713*^9, 
   3.4876211069621487`*^9}, {3.4876211776146727`*^9, 3.48762118185788*^9}, {
   3.4876223429523196`*^9, 3.4876224066628313`*^9}, {3.4876226462948523`*^9, 
   3.4876226545940666`*^9}, {3.4879378505605435`*^9, 3.487937852526147*^9}, {
   3.4879389595976915`*^9, 3.4879389806109285`*^9}, 3.487954506800294*^9, 
   3.4879552059462833`*^9, {3.487955354226764*^9, 3.4879553548828015`*^9}, 
   3.4879778865925393`*^9, {3.488026762836731*^9, 3.4880267855730314`*^9}, {
   3.4880286760411596`*^9, 3.488028691873065*^9}, {3.48802875996296*^9, 
   3.4880287779629893`*^9}, {3.488029402590716*^9, 3.488029423166893*^9}, 
   3.4881035588680367`*^9, 3.4881039206262083`*^9, 3.488104120777656*^9, 
   3.488104903078401*^9, {3.4881050616464705`*^9, 3.488105078194417*^9}, {
   3.4881111465675077`*^9, 3.488111160340296*^9}, {3.488112068437236*^9, 
   3.4881120941107044`*^9}, 3.4881151584709883`*^9, {3.488131862127383*^9, 
   3.4881319519195185`*^9}, {3.4881327730814867`*^9, 3.488132802714182*^9}, {
   3.4881871755509825`*^9, 3.488187183630445*^9}, 3.4881889555927954`*^9, {
   3.488189998898469*^9, 3.488190098602172*^9}, {3.4881901543543606`*^9, 
   3.488190173469454*^9}, {3.4881903638923454`*^9, 3.488190380942321*^9}, {
   3.4882137973446627`*^9, 3.4882138365939074`*^9}, {3.4882140471889524`*^9, 
   3.488214056358477*^9}, {3.4882148881910553`*^9, 3.4882148951354523`*^9}, 
   3.4882149283413515`*^9, {3.4882302297011557`*^9, 3.4882302344904294`*^9}, 
   3.488231704599515*^9, {3.4882319839284916`*^9, 3.4882319992813697`*^9}, {
   3.488275876124522*^9, 3.488275881496829*^9}, 3.488276068637533*^9, 
   3.4882765579205184`*^9, 3.488277169769514*^9, 3.48827741201637*^9, {
   3.488277522075665*^9, 3.488277525446858*^9}, 3.488278079202531*^9, {
   3.488278397793753*^9, 3.488278425786354*^9}, {3.488278718245082*^9, 
   3.488278719804171*^9}, {3.488281865350086*^9, 3.488281871320428*^9}, {
   3.4882830136195784`*^9, 3.4882830192511883`*^9}, {3.488283407479191*^9, 
   3.48828342058294*^9}, {3.488285026388787*^9, 3.4882850392645235`*^9}, 
   3.4882907709793587`*^9, {3.488291081025092*^9, 3.4882910896975884`*^9}, {
   3.4882911289018307`*^9, 3.4882911544232903`*^9}, {3.488291200132905*^9, 
   3.4882912002289104`*^9}, {3.4882912461585374`*^9, 
   3.4882912662906885`*^9}, {3.4882912993615804`*^9, 3.488291313319379*^9}, {
   3.488292675314749*^9, 3.4882926928803797`*^9}, {3.488292814825794*^9, 
   3.4882928340762277`*^9}, 3.488293248100955*^9, {3.488293668880494*^9, 
   3.4882943519120936`*^9}, {3.488294386169754*^9, 3.4882944270418253`*^9}, 
   3.488294576739689*^9, {3.4883963963753386`*^9, 3.4883964781840177`*^9}, {
   3.4883965083107405`*^9, 3.488396598437896*^9}, {3.4883970123125677`*^9, 
   3.488397038351057*^9}, {3.4883973207822113`*^9, 3.4883973230023384`*^9}, {
   3.4884010355926867`*^9, 3.4884010418300433`*^9}, {3.4884029584056654`*^9, 
   3.4884029600077567`*^9}, {3.4884030443625813`*^9, 
   3.4884030517140017`*^9}, {3.4884559968958817`*^9, 3.4884560201222105`*^9}, 
   3.4884561828885202`*^9, {3.4884595324081016`*^9, 3.4884595557644377`*^9}, 
   3.488488413833895*^9, {3.488488614512373*^9, 3.488488650284419*^9}, 
   3.4884941868160906`*^9, 3.488494307578998*^9, 3.488494915640777*^9, {
   3.4884969399105587`*^9, 3.4884969446568303`*^9}, 3.4884970443505325`*^9, {
   3.488497121122924*^9, 3.4884971234120545`*^9}, {3.488497153530777*^9, 
   3.4884971544248285`*^9}, 3.488497216257365*^9, 3.4884982796191854`*^9, {
   3.4884985827925262`*^9, 3.4884985838495865`*^9}, 3.488548766839347*^9, {
   3.4885546595003877`*^9, 3.48855467351919*^9}, {3.488554768972649*^9, 
   3.488554780388302*^9}, {3.4885548176644344`*^9, 3.488554834780413*^9}, 
   3.4885558246670313`*^9, {3.488555877735067*^9, 3.488555885167492*^9}, {
   3.488555925882821*^9, 3.488555968589263*^9}, {3.488556183800573*^9, 
   3.4885561926470785`*^9}, {3.4885565714927473`*^9, 3.488556578579153*^9}, {
   3.488556819261919*^9, 3.488556860995306*^9}, 3.489757221378025*^9, {
   3.4897714976971006`*^9, 3.489771499584704*^9}, {3.4899235962696867`*^9, 
   3.489923596809717*^9}, {3.4900048505124407`*^9, 3.4900048575248413`*^9}, {
   3.490004927360836*^9, 3.490004927640852*^9}, {3.4900054204690404`*^9, 
   3.49000542064305*^9}, {3.4900273743567305`*^9, 3.490027413935995*^9}, 
   3.4900274660839777`*^9, {3.4900314898301225`*^9, 3.4900314904871597`*^9}, 
   3.490031551025623*^9, {3.4900342535741997`*^9, 3.4900342782086086`*^9}, {
   3.490036273490732*^9, 3.4900362852984076`*^9}, {3.4900363603587008`*^9, 
   3.490036371115316*^9}, 3.490037162197563*^9, 3.4900403448696017`*^9, 
   3.490048845135789*^9, 3.4904418396813517`*^9, {3.4904419441003237`*^9, 
   3.490441947441515*^9}, {3.490441986359741*^9, 3.4904420592999134`*^9}, 
   3.490444327068622*^9, {3.4904444014798784`*^9, 3.4904444022399216`*^9}, 
   3.4904474676582537`*^9, 3.49044858339207*^9, 3.490450905146867*^9, 
   3.490451714886181*^9, 3.490452510791704*^9, 3.490453288249172*^9, 
   3.490464459496053*^9, {3.4904681593526726`*^9, 3.4904681643289576`*^9}, {
   3.4904682052062955`*^9, 3.4904682058513327`*^9}, 3.490531867888402*^9, {
   3.4905333015014*^9, 3.4905333019644265`*^9}, 3.4907062892196035`*^9, {
   3.490708250619789*^9, 3.4907082541179895`*^9}, {3.490712025183682*^9, 
   3.4907120313920374`*^9}, {3.4907128353390207`*^9, 3.490712841327363*^9}, 
   3.490714884718238*^9, 3.4907291944635754`*^9, 3.490729713173244*^9, {
   3.490730085218524*^9, 3.490730101265442*^9}, {3.4907306694449396`*^9, 
   3.4907306727751303`*^9}, {3.490731048785637*^9, 3.49073105373092*^9}, {
   3.4907317737701035`*^9, 3.4907318297893076`*^9}, {3.49073192354667*^9, 
   3.490731949549157*^9}, 3.490732404969206*^9, {3.490732482961667*^9, 
   3.490732520929838*^9}, {3.490732560906125*^9, 3.490732566699456*^9}, {
   3.4907951817937293`*^9, 3.4907952097603292`*^9}, 3.49079688138494*^9, 
   3.4909578135058956`*^9, {3.490966426065824*^9, 3.4909664589038815`*^9}, 
   3.4909679863493643`*^9, {3.4909682970395103`*^9, 3.4909683252911596`*^9}, {
   3.490972673956398*^9, 3.4909726987292414`*^9}, 3.4909728202534547`*^9, {
   3.490972862435929*^9, 3.4909728817019625`*^9}, {3.490972913073618*^9, 
   3.4909729566132946`*^9}, {3.490973518869482*^9, 3.4909735657475643`*^9}, {
   3.4909736125476465`*^9, 3.490973619021658*^9}, {3.490973703355406*^9, 
   3.4909737369578648`*^9}, {3.490973801963179*^9, 3.4909738048959846`*^9}, 
   3.490974014136751*^9, 3.4911489290724*^9, 3.491152414014719*^9, {
   3.4911532777726364`*^9, 3.491153287179453*^9}, {3.4911533826048203`*^9, 
   3.4911533843676233`*^9}, 3.4911608269218388`*^9, 3.4911610198473773`*^9, {
   3.4912215420326176`*^9, 3.4912215503786325`*^9}, 3.4912215809234858`*^9, {
   3.491221615103146*^9, 3.4912217052401047`*^9}, 3.4912220487527075`*^9, {
   3.4912290845968103`*^9, 3.4912290884968166`*^9}, {3.4912385323231597`*^9, 
   3.491238550410194*^9}, 3.491238719776881*^9, {3.4912389233205233`*^9, 
   3.4912389754925075`*^9}, 3.491241094984701*^9, 3.4912414098657107`*^9, {
   3.491385847243327*^9, 3.4913859619878902`*^9}, 3.4913859937217054`*^9, {
   3.491386060978552*^9, 3.4913860866870227`*^9}, 3.491386146561447*^9, {
   3.491386424457342*^9, 3.4913864460755787`*^9}, {3.4913864766593275`*^9, 
   3.49138647687934*^9}, 3.491397677026628*^9, 3.4913977115026884`*^9, 
   3.4913978076456575`*^9, 3.4913980532212887`*^9, {3.491398197490342*^9, 
   3.491398204603955*^9}, {3.491398273540476*^9, 3.4913983694494443`*^9}, {
   3.4913984869332504`*^9, 3.491398496948468*^9}, 3.4914136297351246`*^9, 
   3.4914140468859844`*^9, {3.491416748060483*^9, 3.4914167482264924`*^9}, 
   3.4914168077348957`*^9, {3.4916705003527727`*^9, 3.491670503035977*^9}, {
   3.491670536529236*^9, 3.4916706071469603`*^9}, {3.4916706472234306`*^9, 
   3.4916706812470903`*^9}, {3.4916708342053595`*^9, 3.491670835266161*^9}, {
   3.4916709879504294`*^9, 3.491670997248046*^9}, 3.4916710720657773`*^9, {
   3.4917362307280855`*^9, 3.491736236375295*^9}, {3.491736287652585*^9, 
   3.49173648371373*^9}, {3.4917372333262467`*^9, 3.4917372347458496`*^9}, 
   3.4917372742763186`*^9, 3.4919082205276723`*^9, {3.4919119105893536`*^9, 
   3.491912016341939*^9}, {3.4919120510988007`*^9, 3.4919121843698344`*^9}, {
   3.4919122453659415`*^9, 3.49191232420848*^9}, 3.491912366468954*^9, {
   3.491912782459285*^9, 3.4919127896664977`*^9}, {3.4919128248289595`*^9, 
   3.4919128626122255`*^9}, {3.491912894685882*^9, 3.4919129023142953`*^9}, {
   3.491939989477577*^9, 3.491939990054778*^9}, {3.4919402721188736`*^9, 
   3.4919403022893267`*^9}, {3.491940402628703*^9, 3.4919404235327396`*^9}, 
   3.4919404704420223`*^9, {3.4919405081472883`*^9, 3.491940559736579*^9}, {
   3.49202404416138*^9, 3.4920240977464447`*^9}, {3.49242695295825*^9, 
   3.492426960928706*^9}, {3.4924274079002714`*^9, 3.4924274936281743`*^9}, {
   3.492429755126525*^9, 3.4924297663601675`*^9}, 3.492430005904868*^9, 
   3.4925176209259377`*^9, {3.492524070261691*^9, 3.492524209569936*^9}, {
   3.492524256307618*^9, 3.492524311375715*^9}, {3.4925243522321863`*^9, 
   3.492524413134693*^9}, {3.4925249191527824`*^9, 3.492524967247667*^9}, {
   3.492525646082859*^9, 3.4925257238333955`*^9}, {3.492525878897668*^9, 
   3.4925258791472683`*^9}, {3.4925259167589345`*^9, 
   3.4925259230457454`*^9}, {3.4925259878794594`*^9, 
   3.4925260273319283`*^9}, {3.492526105347666*^9, 3.492526110058874*^9}, {
   3.4925261765617905`*^9, 3.4925261767801914`*^9}, {3.492526908390276*^9, 
   3.4925269104962797`*^9}, {3.492528210586963*^9, 3.492528269336666*^9}, {
   3.492529581907372*^9, 3.4925295828745737`*^9}, 3.4925310829264083`*^9, {
   3.4925318994031415`*^9, 3.4925319537382493`*^9}, {3.4925325056878195`*^9, 
   3.492532557138762*^9}, 3.492546829170968*^9, {3.4925471184425135`*^9, 
   3.4925471617349896`*^9}, 3.4925478648532057`*^9, {3.492548568908475*^9, 
   3.4925486204084206`*^9}, {3.492548706400339*^9, 3.4925487108025913`*^9}, {
   3.4926268569978995`*^9, 3.492626870601678*^9}, {3.4926269585827103`*^9, 
   3.4926269670201926`*^9}, {3.492628618347546*^9, 3.49262863184157*^9}, {
   3.492682809002535*^9, 3.4926828117016892`*^9}, {3.492682945169323*^9, 
   3.492682989060834*^9}, {3.4926835100366316`*^9, 3.4926835126247797`*^9}, 
   3.4926838684481316`*^9, {3.4926900347309127`*^9, 3.492690047740657*^9}, 
   3.492710342549739*^9, {3.492710385083172*^9, 3.4927103979199057`*^9}, {
   3.492710432210867*^9, 3.4927104741602664`*^9}, {3.492710593448089*^9, 
   3.492710600949518*^9}, {3.4927189766195793`*^9, 3.492719002922084*^9}, {
   3.4927190721920457`*^9, 3.492719088081955*^9}, {3.492719125151075*^9, 
   3.492719145102216*^9}, {3.492727300714779*^9, 3.492727305062028*^9}, {
   3.4927281173454876`*^9, 3.492728119784627*^9}, {3.4927283875879445`*^9, 
   3.492728404046886*^9}, 3.4927289046075163`*^9, {3.4927291538217707`*^9, 
   3.4927291539677787`*^9}, 3.4927292768868093`*^9, {3.4927294685367713`*^9, 
   3.4927294774412804`*^9}, {3.49272960698769*^9, 3.492729607266706*^9}, {
   3.492729744372548*^9, 3.4927297490508156`*^9}, 3.4927299071708593`*^9, {
   3.492778411399394*^9, 3.4927784426351805`*^9}, {3.4927785404987783`*^9, 
   3.492778551832426*^9}, {3.4927786763575487`*^9, 3.4927786769105806`*^9}, {
   3.492779724409494*^9, 3.4927797708181486`*^9}, {3.492790123809662*^9, 
   3.492790138446499*^9}, {3.4927903951891837`*^9, 3.4927904245448627`*^9}, {
   3.492821080958194*^9, 3.4928210821032596`*^9}, {3.4928214436589394`*^9, 
   3.4928214494102683`*^9}, {3.4928217538016787`*^9, 3.492821757987918*^9}, 
   3.4932149620048323`*^9, {3.4932197267613606`*^9, 3.493219729078493*^9}, {
   3.493300695736334*^9, 3.493300697042409*^9}, {3.493301382824633*^9, 
   3.493301385175768*^9}, {3.4933014348096066`*^9, 3.4933014361546836`*^9}, 
   3.493302186921625*^9, 3.493302574539796*^9, 3.493303216205497*^9, {
   3.4933052727491527`*^9, 3.493305274995557*^9}, {3.4933053496884875`*^9, 
   3.493305359344905*^9}, {3.493990289383895*^9, 3.4939902996175127`*^9}, 
   3.4951067730111494`*^9, {3.4951075023688664`*^9, 3.4951075943631277`*^9}, {
   3.4951077429466267`*^9, 3.4951077827679043`*^9}, {3.495107988846691*^9, 
   3.4951080408306646`*^9}, {3.496249393404581*^9, 3.4962493997629447`*^9}, {
   3.496249517742693*^9, 3.4962495241740603`*^9}, {3.4962504367102547`*^9, 
   3.4962506848184457`*^9}, {3.4962511280127945`*^9, 
   3.4962511725353413`*^9}, {3.496252659690402*^9, 3.496252663619626*^9}, {
   3.496252775997054*^9, 3.4962528186284924`*^9}, {3.4962528566016645`*^9, 
   3.496252934179102*^9}, {3.4962531055849056`*^9, 3.496253111856264*^9}, {
   3.496253303659235*^9, 3.496253325826503*^9}, {3.4962535830612154`*^9, 
   3.4962535892585697`*^9}, {3.4962536671860275`*^9, 3.496253746664573*^9}, {
   3.496253817684635*^9, 3.4962538195107393`*^9}, {3.4962540869140344`*^9, 
   3.4962540989007196`*^9}, {3.4962542003365216`*^9, 3.4962542022086287`*^9}, 
   3.4962570634892845`*^9, {3.4962573220690746`*^9, 3.496257350614707*^9}, {
   3.4962573857817187`*^9, 3.496257457257807*^9}, {3.4962631308633184`*^9, 
   3.496263135208567*^9}, {3.4962633593543873`*^9, 3.4962633614155054`*^9}, 
   3.496264113967549*^9, {3.4962641494865804`*^9, 3.4962641500456123`*^9}, 
   3.4962648067911763`*^9, {3.496264853575852*^9, 3.4962648557719774`*^9}, {
   3.4962649063518705`*^9, 3.4962649135172806`*^9}, {3.4962652379268355`*^9, 
   3.496265260586132*^9}, {3.4962653150252457`*^9, 3.4962653408867245`*^9}, {
   3.4962656427409897`*^9, 3.4962656443250804`*^9}, {3.4962656800131216`*^9, 
   3.4962656802401347`*^9}, {3.4962657925425577`*^9, 
   3.4962657952267113`*^9}, {3.4962658605994506`*^9, 3.496265865046705*^9}, {
   3.4962659644853926`*^9, 3.496266027489996*^9}, 3.496266085484313*^9, {
   3.4962662616493893`*^9, 3.496266325559045*^9}, {3.4962663729537554`*^9, 
   3.49626639750416*^9}, {3.4962667301991887`*^9, 3.4962667466761312`*^9}, 
   3.4962667895145817`*^9, {3.496273938045205*^9, 3.4962739389752584`*^9}, {
   3.4962740641104155`*^9, 3.4962740668405724`*^9}, {3.4962745264618607`*^9, 
   3.4962746192781696`*^9}, {3.4962747349147835`*^9, 
   3.4962747933961287`*^9}, {3.496274878005968*^9, 3.496274939433481*^9}, {
   3.4962750006389823`*^9, 3.4962750825406666`*^9}, {3.496275128985323*^9, 
   3.4962751782531414`*^9}, {3.4962752186854534`*^9, 3.496275232517245*^9}, {
   3.4962753831828623`*^9, 3.496275495675297*^9}, {3.4962755263080487`*^9, 
   3.496275550545435*^9}, {3.4962756083867435`*^9, 3.4962756167652225`*^9}, {
   3.496275703072159*^9, 3.4962757084604673`*^9}, {3.496275763139595*^9, 
   3.4962758193598104`*^9}, {3.4962758746959753`*^9, 3.496275897606286*^9}, {
   3.4962759389476504`*^9, 3.4962759433028994`*^9}, {3.4962760278687363`*^9, 
   3.496276068053035*^9}, {3.496276098095753*^9, 3.496276137917031*^9}, {
   3.4962762166925364`*^9, 3.496276328596937*^9}, 3.496276383702089*^9, {
   3.496276419615143*^9, 3.496276468913963*^9}, 3.4962764990526867`*^9, {
   3.4962765311715236`*^9, 3.496276642389885*^9}, {3.496276784493013*^9, 
   3.4962767945595884`*^9}, {3.49627684231032*^9, 3.496276842640339*^9}, {
   3.496276880439501*^9, 3.4962769575279098`*^9}, {3.4962770017584395`*^9, 
   3.496277045238927*^9}, {3.49627714775079*^9, 3.4962772936441345`*^9}, {
   3.4962773253679495`*^9, 3.4962773585938497`*^9}, {3.4962773925407915`*^9, 
   3.4962775057182646`*^9}, {3.496277587689953*^9, 3.4962776741198964`*^9}, {
   3.4962777555175524`*^9, 3.496277829911807*^9}, {3.4962778778235474`*^9, 
   3.4962778937944613`*^9}, {3.4962781559824576`*^9, 3.496278366425494*^9}, {
   3.4962784000974197`*^9, 3.4962785390573683`*^9}, 3.4963130417666345`*^9, 
   3.4963411876102586`*^9, {3.4963412259514513`*^9, 3.496341265948739*^9}, {
   3.496342025122162*^9, 3.4963420951971693`*^9}, {3.496342132812321*^9, 
   3.496342169225404*^9}, {3.4963422046664305`*^9, 3.4963422509220767`*^9}, {
   3.496342408461087*^9, 3.4963424117702765`*^9}, {3.4963425639299793`*^9, 
   3.4963425770357294`*^9}, {3.4963426516819987`*^9, 
   3.4963426827967787`*^9}, {3.4963432208015504`*^9, 3.496343243572853*^9}, {
   3.496343871909792*^9, 3.496343890563859*^9}, 3.4963439419137955`*^9, {
   3.496344071837227*^9, 3.496344095982608*^9}, {3.4963441655775886`*^9, 
   3.4963441898289757`*^9}, {3.4963442916337986`*^9, 3.4963443684051895`*^9}, 
   3.496344919354702*^9, {3.4963465157030077`*^9, 3.496346517018083*^9}, {
   3.4963554793772297`*^9, 3.496355479970031*^9}, 3.496357706312751*^9, 
   3.496358112235968*^9, {3.496358504813422*^9, 3.4963585049134283`*^9}, {
   3.4964007126742764`*^9, 3.4964007709523797`*^9}, {3.4964012407612047`*^9, 
   3.496401259621638*^9}, {3.4964016459251165`*^9, 3.496401669746358*^9}, {
   3.496402841680416*^9, 3.4964028662348595`*^9}, {3.4964309767679796`*^9, 
   3.496431026391818*^9}, {3.4964861928761473`*^9, 3.496486200894562*^9}, {
   3.4964870009107666`*^9, 3.496487107895755*^9}, {3.496487155163838*^9, 
   3.4964872581240187`*^9}, {3.4964873188081255`*^9, 
   3.4964873858066435`*^9}, {3.496487447535952*^9, 3.4964874815752115`*^9}, {
   3.49648758286619*^9, 3.4964876255322647`*^9}, {3.4964876835955667`*^9, 
   3.496487700927197*^9}, {3.4964879795124865`*^9, 3.496487979840087*^9}, 
   3.496488857965629*^9, {3.496533855758939*^9, 3.496533857547041*^9}, {
   3.4965339148893204`*^9, 3.496533985938384*^9}, {3.496534466396865*^9, 
   3.4965346870484858`*^9}, 3.496534894253337*^9, {3.496535067076222*^9, 
   3.4965351252365484`*^9}, {3.496535286704784*^9, 3.4965352879258537`*^9}, 
   3.496575466148961*^9, {3.496588699586239*^9, 3.496588718424316*^9}, 
   3.496589235934916*^9, {3.4965893168905463`*^9, 3.4965893174695797`*^9}, {
   3.4965903762951407`*^9, 3.496590471613593*^9}, {3.496590526395726*^9, 
   3.4965905418086076`*^9}, {3.4965906464305916`*^9, 3.496590686982911*^9}, {
   3.496592355110668*^9, 3.4965923552822685`*^9}, {3.496597560005642*^9, 
   3.4965975603332424`*^9}, 3.4966019887882214`*^9, {3.4966025632592306`*^9, 
   3.4966025888432755`*^9}, {3.496602702317875*^9, 3.4966027034410768`*^9}, {
   3.4966040196153884`*^9, 3.4966040363386183`*^9}, {3.496605075752844*^9, 
   3.496605077016446*^9}, {3.496792153774726*^9, 3.496792191718878*^9}, {
   3.496796042069557*^9, 3.49679604719385*^9}, {3.4967962082492495`*^9, 
   3.496796210102356*^9}, {3.4967965959475327`*^9, 3.4967966458990755`*^9}, {
   3.4967967187404885`*^9, 3.496796749306396*^9}, {3.4968269786152935`*^9, 
   3.496826983531564*^9}, {3.49683203907484*^9, 3.4968321651120462`*^9}, {
   3.4968336055810337`*^9, 3.49683374313284*^9}, {3.4968354825019073`*^9, 
   3.4968355552220144`*^9}, {3.496835592420142*^9, 3.496835652697587*^9}, {
   3.496835779309822*^9, 3.4968357889293723`*^9}, {3.496870699994177*^9, 
   3.4968707222744513`*^9}, {3.4968709413719835`*^9, 
   3.4968709419680176`*^9}, {3.4968710849581957`*^9, 3.496871089713468*^9}, {
   3.4968717117140446`*^9, 3.496871714343195*^9}, {3.4968719962973213`*^9, 
   3.4968720623520994`*^9}, {3.496907853920217*^9, 3.4969078550742826`*^9}, 
   3.496907890460307*^9, {3.496928575570428*^9, 3.496928588825186*^9}, 
   3.4969391433368692`*^9, {3.497035194414822*^9, 3.4970352098652506`*^9}, 
   3.497035282671988*^9, {3.4970384886161027`*^9, 3.497038519777576*^9}, 
   3.4970387093701982`*^9, {3.4970389359828053`*^9, 3.4970389637069035`*^9}, {
   3.4970509071071467`*^9, 3.497050926197239*^9}, {3.4970510968169975`*^9, 
   3.4970511292678537`*^9}, 3.4994673226249847`*^9, {3.4994752280431485`*^9, 
   3.499475233465459*^9}, 3.4994756693973923`*^9, {3.499475905677907*^9, 
   3.499475922075845*^9}, {3.4994759534516397`*^9, 3.499475962097134*^9}, {
   3.499476087115285*^9, 3.4994760986329436`*^9}, {3.4994761489148197`*^9, 
   3.4994762280633464`*^9}, {3.5002182565548167`*^9, 3.500218281577261*^9}, {
   3.5002183753958254`*^9, 3.500218404177876*^9}, {3.500506545699105*^9, 
   3.500506606175564*^9}, {3.5028238929104424`*^9, 3.5028240032650366`*^9}, {
   3.50282406235794*^9, 3.502824248934268*^9}, {3.502824922728138*^9, 
   3.5028249611198053`*^9}, {3.502824996173067*^9, 3.502825155620947*^9}, {
   3.5031661769375*^9, 3.5031662401875*^9}, {3.5031662946875*^9, 
   3.503166439*^9}, {3.5032345718438067`*^9, 3.503234724811578*^9}, {
   3.503234757514494*^9, 3.503235015731591*^9}, {3.503235153074462*^9, 
   3.503235304651617*^9}, {3.503235467791198*^9, 3.503235532290785*^9}, {
   3.503235609790289*^9, 3.5032356404619675`*^9}, {3.5032357104771447`*^9, 
   3.503235711805261*^9}, 3.503235815492098*^9, {3.5032358620855494`*^9, 
   3.503235973272338*^9}, {3.5032365751747355`*^9, 3.5032365920340023`*^9}, {
   3.5032374975438323`*^9, 3.5032374979969544`*^9}, 3.503237540434183*^9, {
   3.503237945103468*^9, 3.5032380888837976`*^9}, {3.503238412241103*^9, 
   3.5032384227879105`*^9}, {3.5032545241223617`*^9, 
   3.5032546472934484`*^9}, {3.50325470712119*^9, 3.5032547517771544`*^9}, {
   3.503256881044777*^9, 3.5032569406381454`*^9}, 3.50333091967708*^9, {
   3.5033331634908447`*^9, 3.503333164897086*^9}, {3.5033396730585585`*^9, 
   3.503339687511591*^9}, 3.503339893650896*^9, 3.503339959337976*^9, {
   3.5033399994470944`*^9, 3.503340039821836*^9}, {3.5033400878996534`*^9, 
   3.5033401016339407`*^9}, 3.503340151180498*^9, {3.503340211976984*^9, 
   3.50334023061749*^9}, 3.5033402651797686`*^9, {3.5033412236580095`*^9, 
   3.5033413216105075`*^9}, {3.503344229426872*^9, 3.5033443096796227`*^9}, {
   3.5033446868679485`*^9, 3.5033446909144697`*^9}, {3.503762533866213*^9, 
   3.5037626546561303`*^9}, {3.5037682036021175`*^9, 3.5037682079456177`*^9}, 
   3.503770411631178*^9, {3.5037704840020094`*^9, 3.503770494563901*^9}, {
   3.503770544889127*^9, 3.5037706391961946`*^9}, {3.503771503490158*^9, 
   3.503771581610658*^9}, 3.5037771581800547`*^9, {3.503779138159751*^9, 
   3.5037791437531786`*^9}, 3.503875871125*^9, {3.503875954296875*^9, 
   3.5038760145*^9}, {3.50387610853125*^9, 3.50387616021875*^9}, 
   3.50387704946875*^9, {3.503877282140625*^9, 3.503877292671875*^9}, 
   3.504263332031617*^9, {3.5042841041560473`*^9, 3.5042841788113174`*^9}, 
   3.5045718367702103`*^9, 3.5045724698817225`*^9, {3.504618247000557*^9, 
   3.504618247076562*^9}, {3.50461934133515*^9, 3.504619347140482*^9}, 
   3.5046386428331323`*^9, 3.504639130015998*^9, 3.5046394913636656`*^9, {
   3.5047313869644547`*^9, 3.504731392534462*^9}, {3.504731489666709*^9, 
   3.504731504936731*^9}, {3.5047317413432283`*^9, 3.504731750953242*^9}, {
   3.5047318508933816`*^9, 3.5047318557933884`*^9}, {3.50478333812172*^9, 
   3.5047833458817306`*^9}, {3.5047875678103266`*^9, 3.504787589333412*^9}, {
   3.504787627233465*^9, 3.504787683423544*^9}, {3.5047946775590086`*^9, 
   3.5047946871190214`*^9}, {3.504801199064604*^9, 3.504801228864645*^9}, {
   3.5048019639603524`*^9, 3.504801964300353*^9}, {3.504805693076744*^9, 
   3.504805736626805*^9}, {3.5048061545595827`*^9, 3.5048061697696037`*^9}, {
   3.5048128291314945`*^9, 3.5048128604615383`*^9}, {3.5048137503681183`*^9, 
   3.5048137619581347`*^9}, {3.504814007904668*^9, 3.5048140196346846`*^9}, {
   3.5048149217092795`*^9, 3.504814945009312*^9}, {3.5048152965999765`*^9, 
   3.5048153117599983`*^9}, {3.504815548109805*^9, 3.5048155612098236`*^9}, {
   3.5048158060421677`*^9, 3.5048158186621857`*^9}, {3.5048160607855797`*^9, 
   3.504816073775598*^9}, {3.5048164392454453`*^9, 3.504816456125469*^9}, {
   3.5048165152155523`*^9, 3.5048165383655844`*^9}, {3.504817022888318*^9, 
   3.50481702426832*^9}, 3.504817089438411*^9, 3.5048176902024765`*^9, 
   3.5048180530780964`*^9, 3.5051363253980637`*^9, {3.5051363748508925`*^9, 
   3.5051363897337437`*^9}, {3.5052424477440586`*^9, 
   3.5052424724857025`*^9}, {3.505427530740261*^9, 3.505427710641551*^9}, 
   3.505427741193299*^9, 3.5059191173923073`*^9, {3.505940047854461*^9, 
   3.5059400885287876`*^9}, {3.5059401226627398`*^9, 
   3.5059401437069435`*^9}, {3.506021224071969*^9, 3.5060212515295396`*^9}, {
   3.517673925143483*^9, 3.5176739326938963`*^9}, 3.517674044265292*^9, {
   3.5179275988338833`*^9, 3.517927604685218*^9}, {3.51795725869333*^9, 
   3.5179572588083367`*^9}, {3.5179572952224197`*^9, 3.517957302346827*^9}, {
   3.5181879078279243`*^9, 3.51818793969878*^9}, {3.5192958250838985`*^9, 
   3.51929585080737*^9}, {3.519295908193652*^9, 3.5192959396184497`*^9}, {
   3.519302676942752*^9, 3.519302693089676*^9}, 3.5193918335073586`*^9, {
   3.519473841927334*^9, 3.519473846820614*^9}, 3.522014980641412*^9, {
   3.5220150827747912`*^9, 3.5220150828995914`*^9}, {3.522015115940449*^9, 
   3.5220151206048574`*^9}, {3.5220161801119184`*^9, 3.522016196913148*^9}, 
   3.5221021281063643`*^9, {3.5365897033047633`*^9, 3.536589706502769*^9}, {
   3.5371363524779387`*^9, 3.537136355535544*^9}, {3.537183465951604*^9, 
   3.5371834665444045`*^9}, {3.537183501675666*^9, 3.537183554481759*^9}, {
   3.5371836437607155`*^9, 3.5371840618102503`*^9}, {3.5371841469707994`*^9, 
   3.5371842048479013`*^9}, {3.537184752549263*^9, 3.5371848088965626`*^9}, {
   3.5371848467578287`*^9, 3.5371848479902306`*^9}, {3.541159311845445*^9, 
   3.5411593134715385`*^9}, {3.541159386314705*^9, 3.541159386595721*^9}, {
   3.541159754361756*^9, 3.5411597683085537`*^9}, {3.541160083686592*^9, 
   3.5411601735907345`*^9}, {3.54116020515854*^9, 3.5411603516979218`*^9}, {
   3.541160382643691*^9, 3.541160394492369*^9}, {3.5411604610111737`*^9, 
   3.5411604633173056`*^9}, {3.5411605027745624`*^9, 3.541160528067009*^9}, {
   3.541160578794911*^9, 3.5411606235304694`*^9}, {3.541160760065279*^9, 
   3.5411608376147146`*^9}, {3.541161304336409*^9, 3.541161325086596*^9}, {
   3.5411727286288414`*^9, 3.541172773374401*^9}, 3.5411750375189023`*^9, {
   3.541176087800975*^9, 3.5411761311454544`*^9}, {3.5411766244436693`*^9, 
   3.5411766391665115`*^9}, {3.541177255749778*^9, 3.5411772558647842`*^9}, {
   3.541177540384058*^9, 3.5411775405040646`*^9}, {3.5411778254293613`*^9, 
   3.5411778255503683`*^9}, {3.541177924855048*^9, 3.5411779336825533`*^9}, {
   3.541178182447782*^9, 3.5411781869180374`*^9}, 3.5411787853152637`*^9, {
   3.541249956702276*^9, 3.5412499568114767`*^9}, 3.541425625520338*^9, {
   3.5414259297079873`*^9, 3.541425951420018*^9}, 3.5414261381352806`*^9, {
   3.5435878936991725`*^9, 3.543587894073573*^9}, {3.543588496235631*^9, 
   3.543588496594431*^9}, 3.5436702091216583`*^9, {3.5436825882264028`*^9, 
   3.543682594827412*^9}, {3.5436841227332573`*^9, 3.543684128244265*^9}, {
   3.5436842212453957`*^9, 3.5436842272064047`*^9}, 3.5437114574891157`*^9, 
   3.5439196342175145`*^9, {3.543936285564108*^9, 3.5439362856941085`*^9}, {
   3.543940306620766*^9, 3.543940306890766*^9}, 3.5452429508018675`*^9, 
   3.545243680028099*^9, {3.545244399737174*^9, 3.5452444000171742`*^9}, 
   3.5453417759634247`*^9, 3.5459962700963097`*^9, {3.546016216612791*^9, 
   3.546016244339377*^9}, {3.5460163238409243`*^9, 3.546016370364585*^9}, {
   3.5460164431867504`*^9, 3.546016445151863*^9}, {3.5460164918815355`*^9, 
   3.546016492252557*^9}, {3.5460165466876707`*^9, 3.5460165472997055`*^9}, {
   3.546016589851139*^9, 3.5460165973595686`*^9}, {3.5460166801113014`*^9, 
   3.546016861514677*^9}, 3.5460169374300194`*^9, 3.5460172772684574`*^9, 
   3.5460175503050737`*^9, {3.5460181833682833`*^9, 3.5460181983381395`*^9}, {
   3.5460206064488754`*^9, 3.546020758915596*^9}, {3.5460208195320635`*^9, 
   3.5460208278425384`*^9}, {3.546020981916351*^9, 3.5460210269999294`*^9}, {
   3.546021058946757*^9, 3.5460211811867485`*^9}, {3.546021252049802*^9, 
   3.5460212530988617`*^9}, {3.5460213050838346`*^9, 3.546021320291705*^9}, 
   3.5460213566487846`*^9, 3.546021694193091*^9, {3.546021724549827*^9, 
   3.546021759996855*^9}, 3.5460221888133817`*^9, 3.546022952730075*^9, 
   3.5460232716873183`*^9, 3.5460244096514063`*^9, 3.546026552983998*^9, 
   3.5460271042765303`*^9, {3.546034374097197*^9, 3.5460344410252914`*^9}, 
   3.546034503513379*^9, 3.5461049525343013`*^9, {3.5461052321520977`*^9, 
   3.546105243054113*^9}, {3.5461058889770217`*^9, 3.5461059124090548`*^9}, 
   3.546106142325381*^9, 3.546109553483386*^9, 3.5461097951590104`*^9, 
   3.5461105193278823`*^9, 3.5461110171715565`*^9, {3.546121569660225*^9, 
   3.54612157259303*^9}, {3.546121611405898*^9, 3.5461216550547743`*^9}, {
   3.5461217238664956`*^9, 3.546121756704553*^9}, {3.5461219001156054`*^9, 
   3.546121903391611*^9}, {3.546121950737694*^9, 3.5461219578045063`*^9}, 
   3.5461220317340364`*^9, {3.546165992364087*^9, 3.546166036416607*^9}, {
   3.546166395816163*^9, 3.5461664128521376`*^9}, {3.5461857187630377`*^9, 
   3.5461857837059517`*^9}, {3.5462027599395556`*^9, 
   3.5462027641203628`*^9}, {3.546203034500038*^9, 3.54620303587284*^9}, {
   3.5462510123665085`*^9, 3.54625103021753*^9}, 3.5462569937958975`*^9, {
   3.5462583825425367`*^9, 3.5462583914501524`*^9}, 3.546258857321278*^9, {
   3.5462593180520544`*^9, 3.5462593773233585`*^9}, {3.5462609215272713`*^9, 
   3.5462609325096903`*^9}, {3.5462629910581064`*^9, 
   3.5462630038189287`*^9}, {3.546263053161815*^9, 3.546263056874622*^9}, {
   3.5462632533257666`*^9, 3.5462632780830107`*^9}, {3.546263338891917*^9, 
   3.5462633441803265`*^9}, {3.546263374225979*^9, 3.54626338051279*^9}, {
   3.5462659080216303`*^9, 3.5462659144800415`*^9}, 3.546267567392502*^9, 
   3.546268690266874*^9, {3.546268913534466*^9, 3.546268915453269*^9}, {
   3.5462689616449504`*^9, 3.5462689641565547`*^9}, {3.546269225613014*^9, 
   3.546269255611867*^9}, 3.5462719167663145`*^9, {3.5462898040130663`*^9, 
   3.54628980664307*^9}, 3.5466908513540373`*^9, {3.5466908907690935`*^9, 
   3.5466908983601036`*^9}, 3.5466912859796543`*^9, 3.546691615404122*^9, {
   3.546692214063971*^9, 3.5466922293159924`*^9}, 3.5466947414355307`*^9, {
   3.546695017502923*^9, 3.546695067046995*^9}, {3.5466975307339*^9, 
   3.54669754460592*^9}, {3.5467006199162493`*^9, 3.546700650170292*^9}, {
   3.5467006957053556`*^9, 3.5467007069773717`*^9}, {3.5467009298096886`*^9, 
   3.5467009313896904`*^9}, 3.546701549588564*^9, 3.5467025193699365`*^9, 
   3.546702983942593*^9, 3.5467044090740604`*^9, 3.5467074912082815`*^9, 
   3.546715094836115*^9, {3.5467151590627885`*^9, 3.546715161982955*^9}, {
   3.5467788811243567`*^9, 3.546778882914359*^9}, {3.546781192966967*^9, 
   3.5467812372440295`*^9}, {3.5467859027185955`*^9, 3.546785911669608*^9}, {
   3.5467862305742826`*^9, 3.5467862394846153`*^9}, {3.5467886775334907`*^9, 
   3.546788680893668*^9}, {3.5467888265349073`*^9, 3.5467888358284383`*^9}, {
   3.546790216772724*^9, 3.546790233298669*^9}, {3.5467921244957123`*^9, 
   3.5467921333067245`*^9}, {3.5467925121612577`*^9, 3.546792516051263*^9}, {
   3.5467925641693306`*^9, 3.546792620778413*^9}, {3.5467926829175005`*^9, 
   3.546792749415594*^9}, {3.5468725426734505`*^9, 3.5468725629974785`*^9}, {
   3.546872763411762*^9, 3.546872763561762*^9}, 3.547293263527161*^9, 
   3.547293302984885*^9, {3.547294540076372*^9, 3.547294550537387*^9}, {
   3.547296255806402*^9, 3.5472962559468026`*^9}, {3.5472966180702386`*^9, 
   3.5472966214086447`*^9}, 3.547399689339428*^9, {3.547420254864196*^9, 
   3.547420255574197*^9}, {3.547420368549356*^9, 3.5474203688793564`*^9}, 
   3.547661061251045*^9, {3.547673765258037*^9, 3.5476737655180373`*^9}, {
   3.547674136049564*^9, 3.547674261828741*^9}, {3.547747370928504*^9, 
   3.5477473764665136`*^9}, {3.5478910054295244`*^9, 
   3.5478910073195267`*^9}, {3.5478911595627413`*^9, 
   3.5478912228418303`*^9}, {3.5478915242422543`*^9, 
   3.5478915425742807`*^9}, {3.547893112610493*^9, 3.547893118050501*^9}, 
   3.5479370009871845`*^9, 3.5479790954992743`*^9, {3.547984795549308*^9, 
   3.547984801024917*^9}, {3.5479870157732058`*^9, 3.547987017489208*^9}, {
   3.5479870725885053`*^9, 3.5479870845849266`*^9}, {3.547990132987343*^9, 
   3.547990145748165*^9}, {3.6113488357896614`*^9, 3.6113488625061893`*^9}, 
   3.611352243083547*^9, {3.611352276367451*^9, 3.611352395482264*^9}, {
   3.611479000013215*^9, 3.6114791152138042`*^9}, {3.611479993317029*^9, 
   3.6114799936220465`*^9}, {3.611480275446166*^9, 3.6114802864487953`*^9}, 
   3.611481174328579*^9, 3.611482870912618*^9, 3.6116205196423445`*^9, {
   3.645805612079257*^9, 3.645805622726866*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Below", " ", "you", " ", "can", " ", "export", " ", "your", " ", 
     "ellipsoid", " ", "to", " ", "a", " ", "graphics", " ", "file"}], ",", 
    " ", "although", ",", " ", 
    RowBox[{
    "it", " ", "is", " ", "generally", " ", "easier", " ", "to", " ", 
     "simpliy", " ", "click", " ", "on", " ", "the", " ", "image", " ", "and",
      " ", "copy", " ", "and", " ", "paste", " ", "it", " ", "into", " ", 
     "another", " ", "program", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"e", ".", "g", "."}], ",", " ", 
        RowBox[{
        "Adobe", " ", "Illustrator", " ", "or", " ", "Adobe", " ", 
         "Photoshop"}]}], ")"}], ".", "  ", "With"}], " ", "some", " ", 
     "Mathematica", " ", "graphics"}], ",", " ", 
    RowBox[{
    "pasting", " ", "the", " ", "image", " ", "into", " ", "Adobe", " ", 
     "Illustrator", " ", 
     RowBox[{"(", 
      RowBox[{"or", " ", "similar", " ", "programs"}], ")"}], " ", "gives", 
     " ", "you", " ", "the", " ", "ability", " ", "to", " ", "continue", " ", 
     "to", " ", "manipulate", " ", "the", " ", "image", " ", "as", " ", "a", 
     " ", "vector", " ", "diagram", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"e", ".", "g", "."}], ",", " ", 
       RowBox[{
       "you", " ", "can", " ", "change", " ", "the", " ", "stroke", " ", 
        "weight", " ", "for", " ", "individual", " ", "lines"}], ",", " ", 
       RowBox[{"change", " ", "colors", " ", "of", " ", "points"}], ",", " ", 
       "lines", ",", " ", "text", ",", " ", 
       RowBox[{"etc", "."}]}], ")"}], " ", "while", " ", "other", " ", 
     "graphics", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"for", " ", "instance"}], ",", " ", 
       RowBox[{
        RowBox[{"the", " ", "three"}], "-", 
        RowBox[{"dimensional", " ", "ellipsoid", " ", "graphic"}]}]}], ")"}], 
     " ", "will", " ", "get", " ", "pasted", " ", "into", " ", "Illustrator", 
     " ", "as", " ", "a", " ", "rastor", " ", "image", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"i", ".", "e", "."}], ",", " ", 
        RowBox[{"like", " ", "a", " ", "static", " ", "photograph"}]}], ")"}],
       ".", " ", "If"}], " ", "you", " ", "are", " ", "using", " ", "a", " ", 
     "Windows", " ", "operating", " ", "system"}], ",", " ", 
    RowBox[{
    "your", " ", "file", " ", "will", " ", "appear", " ", "in", " ", "your", 
     " ", "\"\<My Documents\>\"", " ", "folder", " ", "unless", " ", "you", 
     " ", "have", " ", "specified", " ", "a", " ", "different", " ", 
     RowBox[{"path", ".", " ", "To"}], " ", "determine", " ", "your", " ", 
     "the", " ", "current", " ", "working", " ", "directory", " ", "type", 
     " ", "\"\<Directory[]\>\"", " ", "into", " ", "an", " ", "empty", " ", 
     "cell", " ", "and", " ", "evaluate", " ", "that", " ", 
     RowBox[{"cell", ".", "  ", "You"}], " ", "can", " ", "also", " ", 
     "change", " ", "the", " ", "directory", " ", "with", " ", "the", " ", 
     RowBox[{"SetDirectory", "[", "]"}], " ", 
     RowBox[{"function", "."}]}]}], " ", "*)"}], "\n", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<EllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.jpg\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ElleWOplanes"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<EllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.tif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ElleWOplanes"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<EllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.gif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ElleWOplanes"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"the", " ", "*", 
      RowBox[{".", "eps"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"and", " ", "sometimes", " ", "the", " ", "*", 
         RowBox[{".", "wmf"}]}], ",", " ", 
        RowBox[{
         RowBox[{
         "however", " ", "not", " ", "with", " ", "the", " ", "three"}], "-", 
         RowBox[{
         "dimensional", " ", "images", " ", "like", " ", "the", " ", 
          "ellipsoids"}]}]}], ")"}], " ", "file", " ", "format", " ", "saves",
       " ", "the", " ", "image", " ", "as", " ", "a", " ", "vector", " ", 
      RowBox[{"image", ".", "  ", "As"}], " ", "mentioned", " ", "above"}], 
     ",", " ", 
     RowBox[{
      RowBox[{
      "this", " ", "has", " ", "the", " ", "advantage", " ", "of", " ", 
       "being", " ", "able", " ", "to", " ", "manipulate", " ", "individual", 
       " ", "components", " ", "of", " ", "the", " ", "image", " ", "using", 
       " ", "programs", " ", "like", " ", "Adobe", " ", "Illustrator"}], ";", 
      " ", "however"}], ",", " ", 
     RowBox[{"you", " ", "may", " ", "loose", " ", "some", " ", 
      RowBox[{"resolution", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<EllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.pdf\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ElleWOplanes"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<EllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.eps\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ElleWOplanes"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4967750049414854`*^9, 3.496775058535248*^9}, {
   3.4967752804922247`*^9, 3.496775442930035*^9}, {3.4967754946418276`*^9, 
   3.4967757176159024`*^9}, {3.496775759380167*^9, 3.4967757603632207`*^9}, {
   3.496928988470044*^9, 3.496928989289091*^9}, {3.4969291953258753`*^9, 
   3.496929208481628*^9}, {3.496939064591365*^9, 3.4969390915569077`*^9}, 
   3.4969514021846385`*^9, 3.4969515764426055`*^9, 3.496951783440445*^9, {
   3.496951852793412*^9, 3.4969518530864286`*^9}, 3.5032390337527504`*^9, {
   3.503239666154953*^9, 3.503239676201764*^9}, {3.5032397204827304`*^9, 
   3.50323973224828*^9}, {3.5032397814198403`*^9, 3.5032398065446796`*^9}, {
   3.503239880231708*^9, 3.5032399989340734`*^9}, {3.5032401029802823`*^9, 
   3.5032401114177284`*^9}, {3.503240167339246*^9, 3.503240177886053*^9}, {
   3.5032404392750053`*^9, 3.503240602711459*^9}, {3.503240661039211*^9, 
   3.50324067366413*^9}, {3.5032407095857754`*^9, 3.5032407156326113`*^9}, 
   3.547980071371978*^9, {3.611058618320553*^9, 3.611058653854585*^9}, 
   3.6116210167967806`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Here", " ", "you", " ", "can", " ", "choose", " ", "your", " ", "own", 
    " ", "viewing", " ", "perspective", " ", 
    RowBox[{"(", 
     RowBox[{
     "simply", " ", "change", " ", "the", " ", "vector", " ", "components", 
      " ", "of", " ", "ViewingDir", " ", "and", " ", "control", " ", "the", 
      " ", "distance", " ", "by", " ", "changing", " ", "Scaling"}], ")"}], 
    " ", "and", " ", "the", " ", "axes", " ", "labels", " ", 
    RowBox[{"(", 
     RowBox[{
     "add", " ", "them", " ", "between", " ", "the", " ", "quotation", " ", 
      "markes", " ", "below"}], ")"}]}], "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Scaling", "=", "6"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ViewingDir", "=", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"NewViewingDirection", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"ElleWOplanes", ",", 
      RowBox[{"ViewPoint", "\[Rule]", 
       RowBox[{"Scaling", "*", 
        RowBox[{"ViewingDir", "/", 
         RowBox[{"Norm", "[", "ViewingDir", "]"}]}]}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\< \>\"", ",", "\"\< \>\"", ",", "\"\< \>\""}], "}"}]}]}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.5034189833267164`*^9, 3.50341898856069*^9}, {
   3.5034221493804197`*^9, 3.5034222093445644`*^9}, {3.5034222505757723`*^9, 
   3.50342228218272*^9}, {3.5034223841436386`*^9, 3.503422388268322*^9}, {
   3.5034225328353434`*^9, 3.5034225420533853`*^9}, {3.503422617750696*^9, 
   3.5034226236877403`*^9}, {3.5034226845111933`*^9, 3.503422685886088*^9}, {
   3.503422751209196*^9, 3.503422785956527*^9}, 3.521982197745466*^9, 
   3.5219822600000267`*^9, {3.5219823914395447`*^9, 3.521982416148958*^9}, {
   3.5219824757303658`*^9, 3.521982484664877*^9}, {3.5219825309385233`*^9, 
   3.5219825984223833`*^9}, {3.521982678270951*^9, 3.521982738785412*^9}, {
   3.5219832129395323`*^9, 3.52198323930704*^9}, {3.5219832805654*^9, 
   3.521983293749154*^9}, {3.5220105681580615`*^9, 3.5220105730408697`*^9}, {
   3.5220108050444775`*^9, 3.52201080669808*^9}, {3.522010860970576*^9, 
   3.5220108629517794`*^9}, {3.522010895228236*^9, 3.52201095452394*^9}, 
   3.522010989967202*^9, {3.5220176743137426`*^9, 3.5220177585538907`*^9}, 
   3.611058717858246*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "You", " ", "can", " ", "export", " ", "your", " ", "ellipsoid", " ", 
    "with", " ", "the", " ", "new", " ", "viewing", " ", "perspective"}], " ",
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<NewViewingDirection-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.jpg\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "NewViewingDirection"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<NewViewingDirection-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.tif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "NewViewingDirection"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<NewViewingDirection-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.gif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "NewViewingDirection"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<NewViewingDirection-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.pdf\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "NewViewingDirection"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<NewViewingDirection-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.eps\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "NewViewingDirection"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.50342279587764*^9, 3.5034229804415894`*^9}, {
   3.5034230411400523`*^9, 3.5034230641695337`*^9}, {3.611058733769156*^9, 
   3.6110587533282747`*^9}, {3.6110601414276695`*^9, 3.6110601924465876`*^9}, 
   3.611621018024851*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "You", " ", "can", " ", "export", " ", "images", " ", "of", " ", "the", 
    " ", "ellipsoid", " ", "with", " ", "the", " ", "planes"}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PlanesEllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.jpg\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "EllipsoidPlanes"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PlanesEllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.tif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "EllipsoidPlanes"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PlanesEllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.gif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "EllipsoidPlanes"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PlanesEllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.pdf\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "EllipsoidPlanes"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PlanesEllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.eps\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "EllipsoidPlanes"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.496794845706218*^9, 3.4967948791517715`*^9}, {
   3.4967949150929475`*^9, 3.4967949784868755`*^9}, {3.4967953256210346`*^9, 
   3.4967953358730087`*^9}, {3.496929286066066*^9, 3.496929335985921*^9}, {
   3.5032398476694164`*^9, 3.50323984790379*^9}, {3.5032400373088274`*^9, 
   3.5032400403869333`*^9}, {3.61106025402511*^9, 3.6110603174327364`*^9}, {
   3.611060407502888*^9, 3.6110604114411135`*^9}, 3.611621019437931*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "You", " ", "can", " ", "export", " ", "images", " ", "of", " ", "the", 
    " ", "Hsu", " ", "Diagram"}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<HsuDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.jpg\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FullHsu"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<HsuDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.tif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FullHsu"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<HsuDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.gif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FullHsu"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<HsuDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.pdf\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FullHsu"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<HsuDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.eps\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FullHsu"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4967969767813673`*^9, 3.4967970137177925`*^9}, {
   3.49679705410182*^9, 3.496797061766221*^9}, {3.4969391590187664`*^9, 
   3.496939162700977*^9}, {3.503239849935027*^9, 3.5032398501694*^9}, {
   3.5032400440431595`*^9, 3.503240047996259*^9}, {3.5179614283598213`*^9, 
   3.5179614287408433`*^9}, {3.6110605230574975`*^9, 3.6110605685530996`*^9}, 
   3.611621021734063*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "You", " ", "can", " ", "export", " ", "images", " ", "of", " ", "the", 
    " ", "Flinn", " ", "Diagram"}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<FlinnDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.jpg\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FlinnDiagram"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<FlinnDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.tif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FlinnDiagram"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<FlinnDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.gif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FlinnDiagram"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<FlinnDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.pdf\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FlinnDiagram"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<FlinnDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.eps\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FlinnDiagram"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4967969767813673`*^9, 3.4967970137177925`*^9}, {
   3.49679705410182*^9, 3.4967970890676317`*^9}, {3.49693916747325*^9, 
   3.496939170961449*^9}, {3.5032398523568864`*^9, 3.50323985256001*^9}, {
   3.5032400544337177`*^9, 3.5032400581524444`*^9}, {3.611060630890665*^9, 
   3.611060686467844*^9}, 3.6116210236871743`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "You", " ", "can", " ", "export", " ", "images", " ", "of", " ", "the", 
    " ", "Equal", " ", "Area", " ", "Plot", " ", "of", " ", "the", " ", 
    "Long", " ", "Axes"}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<LongAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.jpg\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "LongAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<LongAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.tif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "LongAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<LongAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.gif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "LongAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<LongAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.pdf\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "LongAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<LongAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.eps\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "LongAxesPlot"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4967969767813673`*^9, 3.4967970137177925`*^9}, {
   3.49679705410182*^9, 3.4967970890676317`*^9}, {3.4967972014151607`*^9, 
   3.4967972338596478`*^9}, {3.4969391764617643`*^9, 
   3.4969391804199905`*^9}, {3.5032398544193735`*^9, 
   3.5032398546381216`*^9}, {3.503240061714922*^9, 3.5032400641524057`*^9}, {
   3.611060758704976*^9, 3.611060820036484*^9}, 3.611621025625285*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "You", " ", "can", " ", "export", " ", "images", " ", "of", " ", "the", 
    " ", "Equal", " ", "Area", " ", "Plot", " ", "of", " ", "the", " ", 
    "Intermediate", " ", "Axes"}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<IntermediateAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.jpg\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "IntermediateAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<IntermediateAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.tif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "IntermediateAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<IntermediateAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.gif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "IntermediateAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<IntermediateAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.pdf\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "IntermediateAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<IntermediateAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.eps\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "IntermediateAxesPlot"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4967969767813673`*^9, 3.4967970137177925`*^9}, {
   3.49679705410182*^9, 3.4967970890676317`*^9}, {3.4967972014151607`*^9, 
   3.496797308313342*^9}, {3.496939185766296*^9, 3.496939188930477*^9}, {
   3.5032398570912313`*^9, 3.5032398573412294`*^9}, {3.503240066918013*^9, 
   3.5032400695273714`*^9}, {3.6110609400273466`*^9, 3.611060998266678*^9}, 
   3.6116210275853977`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "You", " ", "can", " ", "export", " ", "images", " ", "of", " ", "the", 
    " ", "Equal", " ", "Area", " ", "Plot", " ", "of", " ", "the", " ", 
    "Short", " ", "Axes"}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<ShortAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.jpg\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ShortAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<ShortAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.tif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ShortAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<ShortAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.gif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ShortAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<ShortAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.pdf\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ShortAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<ShortAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.eps\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ShortAxesPlot"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4967969767813673`*^9, 3.4967970137177925`*^9}, {
   3.49679705410182*^9, 3.4967970890676317`*^9}, {3.4967972014151607`*^9, 
   3.4967972338596478`*^9}, {3.4967972650569096`*^9, 3.496797321384058*^9}, {
   3.496939193738752*^9, 3.49693919824701*^9}, {3.5032398592162175`*^9, 
   3.503239859434966*^9}, {3.5032400734492216`*^9, 3.5032400771991973`*^9}, {
   3.6110610584891224`*^9, 3.6110611032636833`*^9}, 3.6116210296175137`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "You", " ", "can", " ", "export", " ", "images", " ", "of", " ", "the", 
    " ", "Equal", " ", "Area", " ", "Plot", " ", "of", " ", "the", " ", 
    "Principal", " ", "Axes"}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PrincipalAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.jpg\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "PrinAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PrincipalAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.tif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "PrinAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PrincipalAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.gif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "PrinAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PrincipalAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.pdf\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "PrinAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PrincipalAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.eps\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "PrinAxesPlot"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5179505980923653`*^9, 3.5179506022306023`*^9}, {
   3.517950652984505*^9, 3.5179506923597574`*^9}, {3.611061141467869*^9, 
   3.611061200692256*^9}, {3.6116205213214407`*^9, 3.6116205265087376`*^9}, 
   3.6116210314126167`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "You", " ", "can", " ", "also", " ", "export", " ", "the", " ", "strain", 
    " ", "data", " ", "to", " ", "various", " ", "types", " ", "of", " ", 
    "files"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"RectErrorArea", "*", "ErrorShapePercent"}], "<", 
       "IrregularErrorArea"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"AlphaOn", "==", "0"}], ",", 
         RowBox[{
          RowBox[{"ExportDataTable", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
              "\"\<Long Axis Length\>\"", ",", 
               "\"\<Intermediate Axis Length\>\"", ",", 
               "\"\<Short Axis Length\>\"", ",", "\"\<\[Epsilon]s\>\"", ",", 
               "\"\<Flinn's k\>\"", ",", "\"\<Lode's Ratio\>\"", ",", " ", 
               "\"\<Long Axis Trend\>\"", ",", "\"\<Long Axis Plunge\>\"", 
               ",", " ", "\"\<Intermediate Axis Trend\>\"", ",", 
               "\"\<Intermediate Axis Plunge\>\"", ",", " ", 
               "\"\<Short Axis Trend\>\"", ",", "\"\<Short Axis Plunge\>\"", 
               ",", "\"\<Mean Error\>\"", ",", 
               "\"\<Confidence Level (Percentage)\>\"", ",", 
               "\"\<(+)\[Epsilon]s\>\"", ",", "\"\<(-)\[Epsilon]s\>\"", ",", 
               "\"\<(+)k\>\"", ",", "\"\<(-)k\>\"", ",", "\"\<(+)\[Nu]\>\"", 
               ",", "\"\<(-)\[Nu]\>\"", ",", "\"\<(+)Rxy\>\"", ",", 
               "\"\<(-)Rxy\>\"", ",", "\"\<(+)Ryz\>\"", ",", "\"\<(-)Ryz\>\"",
                ",", "\"\<Confidence Level (Percentage)\>\"", ",", 
               "\"\<Long Axis Error Angle\>\"", ",", 
               "\"\<Intermediate Axis Error Angle\>\"", ",", 
               "\"\<Short Axis Error Angle\>\""}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
              "NormLong", ",", "1.0", ",", "NormShort", ",", "\[Epsilon]s", 
               ",", "K", ",", "\[Nu]", ",", "FitTrendLong", ",", 
               "FitPlungeLong", ",", "FitTrendInterm", ",", "FitPlungeInterm",
                ",", "FitTrendShort", ",", "FitPlungeShort", ",", 
               "MeanDiffError", ",", 
               RowBox[{"Round", "[", 
                RowBox[{"100", "*", "desiredpercentage"}], "]"}], ",", 
               RowBox[{"\[Epsilon]smax", "-", "\[Epsilon]s"}], ",", 
               RowBox[{"\[Epsilon]s", "-", "\[Epsilon]smin"}], ",", 
               RowBox[{"Abs", "[", 
                RowBox[{"Kmax", "-", "K"}], "]"}], ",", 
               RowBox[{"Abs", "[", 
                RowBox[{"K", "-", "Kmin"}], "]"}], ",", 
               RowBox[{"Abs", "[", 
                RowBox[{"\[Nu]max", "-", "\[Nu]"}], "]"}], ",", 
               RowBox[{"Abs", "[", 
                RowBox[{"\[Nu]", "-", "\[Nu]min"}], "]"}], ",", "PosRxy", ",",
                "NegRxy", ",", "PosRyz", ",", "NegRyz", ",", 
               RowBox[{"Round", "[", 
                RowBox[{"100", "*", "desiredpercentage"}], "]"}], ",", 
               "LongCIAngle", ",", "IntermCIAngle", ",", "ShortCIAngle"}], 
              "}"}]}], "}"}]}], ";"}], ",", 
         RowBox[{
          RowBox[{"ExportDataTable", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
              "\"\<Long Axis Length\>\"", ",", 
               "\"\<Intermediate Axis Length\>\"", ",", 
               "\"\<Short Axis Length\>\"", ",", "\"\<\[Epsilon]s\>\"", ",", 
               "\"\<Flinn's k\>\"", ",", "\"\<Lode's Ratio\>\"", ",", " ", 
               "\"\<Long Axis Trend\>\"", ",", "\"\<Long Axis Plunge\>\"", 
               ",", " ", "\"\<Intermediate Axis Trend\>\"", ",", 
               "\"\<Intermediate Axis Plunge\>\"", ",", " ", 
               "\"\<Short Axis Trend\>\"", ",", "\"\<Short Axis Plunge\>\"", 
               ",", "\"\<Mean Error\>\"", ",", 
               "\"\<Confidence Level (Percentage)\>\"", ",", 
               "\"\<(+)\[Epsilon]s\>\"", ",", "\"\<(-)\[Epsilon]s\>\"", ",", 
               "\"\<(+)k\>\"", ",", "\"\<(-)k\>\"", ",", "\"\<(+)\[Nu]\>\"", 
               ",", "\"\<(-)\[Nu]\>\"", ",", "\"\<(+)Rxy\>\"", ",", 
               "\"\<(-)Rxy\>\"", ",", "\"\<(+)Ryz\>\"", ",", "\"\<(-)Ryz\>\"",
                ",", "\"\<\[Alpha] Confidence Level\>\"", ",", 
               "\"\<Long Axis \[Alpha]\>\"", ",", 
               "\"\<Intermediate Axis \[Alpha]\>\"", ",", 
               "\"\<Short Axis \[Alpha]\>\""}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
              "NormLong", ",", "1.0", ",", "NormShort", ",", "\[Epsilon]s", 
               ",", "K", ",", "\[Nu]", ",", "FitTrendLong", ",", 
               "FitPlungeLong", ",", "FitTrendInterm", ",", "FitPlungeInterm",
                ",", "FitTrendShort", ",", "FitPlungeShort", ",", 
               "MeanDiffError", ",", 
               RowBox[{"Round", "[", 
                RowBox[{"100", "*", "desiredpercentage"}], "]"}], ",", 
               RowBox[{"\[Epsilon]smax", "-", "\[Epsilon]s"}], ",", 
               RowBox[{"\[Epsilon]s", "-", "\[Epsilon]smin"}], ",", 
               RowBox[{"Abs", "[", 
                RowBox[{"Kmax", "-", "K"}], "]"}], ",", 
               RowBox[{"Abs", "[", 
                RowBox[{"K", "-", "Kmin"}], "]"}], ",", 
               RowBox[{"Abs", "[", 
                RowBox[{"\[Nu]max", "-", "\[Nu]"}], "]"}], ",", 
               RowBox[{"Abs", "[", 
                RowBox[{"\[Nu]", "-", "\[Nu]min"}], "]"}], ",", "PosRxy", ",",
                "NegRxy", ",", "PosRyz", ",", "NegRyz", ",", 
               RowBox[{"Round", "[", 
                RowBox[{"100", "*", "alphapercent"}], "]"}], ",", "LongAlpha",
                ",", "IntermAlpha", ",", "ShortAlpha"}], "}"}]}], "}"}]}], 
          ";"}]}], "]"}], ";"}], ",", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"AlphaOn", "==", "0"}], ",", 
         RowBox[{
          RowBox[{"ExportDataTable", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
              "\"\<Long Axis Length\>\"", ",", 
               "\"\<Intermediate Axis Length\>\"", ",", 
               "\"\<Short Axis Length\>\"", ",", "\"\<\[Epsilon]s\>\"", ",", 
               "\"\<Flinn's k\>\"", ",", "\"\<Lode's Ratio\>\"", ",", " ", 
               "\"\<Long Axis Trend\>\"", ",", "\"\<Long Axis Plunge\>\"", 
               ",", " ", "\"\<Intermediate Axis Trend\>\"", ",", 
               "\"\<Intermediate Axis Plunge\>\"", ",", " ", 
               "\"\<Short Axis Trend\>\"", ",", "\"\<Short Axis Plunge\>\"", 
               ",", "\"\<Mean Error\>\"", ",", 
               "\"\<Confidence Level (Percentage)\>\"", ",", 
               "\"\<(+)\[Epsilon]s\>\"", ",", "\"\<(-)\[Epsilon]s\>\"", ",", 
               "\"\<(+)k\>\"", ",", "\"\<(-)k\>\"", ",", "\"\<(+)\[Nu]\>\"", 
               ",", "\"\<(-)\[Nu]\>\"", ",", 
               "\"\<Confidence Level (Percentage)\>\"", ",", 
               "\"\<Long Axis Error Angle\>\"", ",", 
               "\"\<Intermediate Axis Error Angle\>\"", ",", 
               "\"\<Short Axis Error Angle\>\""}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
              "NormLong", ",", "1.0", ",", "NormShort", ",", "\[Epsilon]s", 
               ",", "K", ",", "\[Nu]", ",", "FitTrendLong", ",", 
               "FitPlungeLong", ",", "FitTrendInterm", ",", "FitPlungeInterm",
                ",", "FitTrendShort", ",", "FitPlungeShort", ",", 
               "MeanDiffError", ",", 
               RowBox[{"Round", "[", 
                RowBox[{"100", "*", "desiredpercentage"}], "]"}], ",", 
               RowBox[{"\[Epsilon]smax", "-", "\[Epsilon]s"}], ",", 
               RowBox[{"\[Epsilon]s", "-", "\[Epsilon]smin"}], ",", 
               RowBox[{"Abs", "[", 
                RowBox[{"Kmax", "-", "K"}], "]"}], ",", 
               RowBox[{"Abs", "[", 
                RowBox[{"K", "-", "Kmin"}], "]"}], ",", 
               RowBox[{"Abs", "[", 
                RowBox[{"\[Nu]max", "-", "\[Nu]"}], "]"}], ",", 
               RowBox[{"Abs", "[", 
                RowBox[{"\[Nu]", "-", "\[Nu]min"}], "]"}], ",", 
               RowBox[{"Round", "[", 
                RowBox[{"100", "*", "desiredpercentage"}], "]"}], ",", 
               "LongCIAngle", ",", "IntermCIAngle", ",", "ShortCIAngle"}], 
              "}"}]}], "}"}]}], ";"}], ",", 
         RowBox[{
          RowBox[{"ExportDataTable", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
              "\"\<Long Axis Length\>\"", ",", 
               "\"\<Intermediate Axis Length\>\"", ",", 
               "\"\<Short Axis Length\>\"", ",", "\"\<\[Epsilon]s\>\"", ",", 
               "\"\<Flinn's k\>\"", ",", "\"\<Lode's Ratio\>\"", ",", " ", 
               "\"\<Long Axis Trend\>\"", ",", "\"\<Long Axis Plunge\>\"", 
               ",", " ", "\"\<Intermediate Axis Trend\>\"", ",", 
               "\"\<Intermediate Axis Plunge\>\"", ",", " ", 
               "\"\<Short Axis Trend\>\"", ",", "\"\<Short Axis Plunge\>\"", 
               ",", "\"\<Mean Error\>\"", ",", 
               "\"\<Confidence Level (Percentage)\>\"", ",", 
               "\"\<(+)\[Epsilon]s\>\"", ",", "\"\<(-)\[Epsilon]s\>\"", ",", 
               "\"\<(+)k\>\"", ",", "\"\<(-)k\>\"", ",", "\"\<(+)\[Nu]\>\"", 
               ",", "\"\<(-)\[Nu]\>\"", ",", 
               "\"\<\[Alpha] Confidence Level\>\"", ",", 
               "\"\<Long Axis \[Alpha]\>\"", ",", 
               "\"\<Intermediate Axis \[Alpha]\>\"", ",", 
               "\"\<Short Axis \[Alpha]\>\""}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
              "NormLong", ",", "1.0", ",", "NormShort", ",", "\[Epsilon]s", 
               ",", "K", ",", "\[Nu]", ",", "FitTrendLong", ",", 
               "FitPlungeLong", ",", "FitTrendInterm", ",", "FitPlungeInterm",
                ",", "FitTrendShort", ",", "FitPlungeShort", ",", 
               "MeanDiffError", ",", 
               RowBox[{"Round", "[", 
                RowBox[{"100", "*", "desiredpercentage"}], "]"}], ",", 
               RowBox[{"\[Epsilon]smax", "-", "\[Epsilon]s"}], ",", 
               RowBox[{"\[Epsilon]s", "-", "\[Epsilon]smin"}], ",", 
               RowBox[{"Abs", "[", 
                RowBox[{"Kmax", "-", "K"}], "]"}], ",", 
               RowBox[{"Abs", "[", 
                RowBox[{"K", "-", "Kmin"}], "]"}], ",", 
               RowBox[{"Abs", "[", 
                RowBox[{"\[Nu]max", "-", "\[Nu]"}], "]"}], ",", 
               RowBox[{"Abs", "[", 
                RowBox[{"\[Nu]", "-", "\[Nu]min"}], "]"}], ",", 
               RowBox[{"Round", "[", 
                RowBox[{"100", "*", "alphapercent"}], "]"}], ",", "LongAlpha",
                ",", "IntermAlpha", ",", "ShortAlpha"}], "}"}]}], "}"}]}], 
          ";"}]}], "]"}], ";"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<DataTable-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.xls\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ExportDataTable"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<DataTable-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.txt\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ExportDataTable"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<DataTable-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.dat\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ExportDataTable"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.518188056808186*^9, 3.518188094310652*^9}, {
   3.518188628166637*^9, 3.5181886441775527`*^9}, {3.5181914847640247`*^9, 
   3.518191503855117*^9}, {3.518191547841633*^9, 3.51819158888498*^9}, {
   3.518191882317764*^9, 3.518191905100067*^9}, {3.5181920611679935`*^9, 
   3.5181920625840745`*^9}, {3.5181929876769867`*^9, 3.518192988939059*^9}, 
   3.6110615556975613`*^9, {3.6114813453143587`*^9, 3.611481349334589*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "If", " ", "you", " ", "are", " ", "using", " ", "the", " ", "irregular", 
     " ", "polygon", " ", "error", " ", "region"}], ",", " ", 
    RowBox[{
     RowBox[{
     "then", " ", "you", " ", "can", " ", "export", " ", "the", " ", 
      "coordinate", " ", "of", " ", "that", " ", "irregular", " ", "polygon", 
      " ", "in", " ", "Flinn"}], "-", 
     RowBox[{"space", " ", "with", " ", "the", " ", "script", " ", 
      RowBox[{"below", ".", "  ", "The"}], " ", "data", " ", "from", " ", 
      "the", " ", "file", " ", "that", " ", "is", " ", "exported"}]}], ",", 
    " ", "\"\<FlinnDataTable.xls\>\"", ",", " ", 
    RowBox[{
    "can", " ", "be", " ", "plotted", " ", "using", " ", "the", " ", 
     "program", " ", 
     RowBox[{"\"\<Flinn Plot with Error Regions\>\"", ".", "  ", "Using"}], 
     " ", "this", " ", "program"}], ",", " ", 
    RowBox[{
    "several", " ", "sets", " ", "of", " ", "strain", " ", "data", " ", "and",
      " ", "their", " ", "associated", " ", "error", " ", "regions", " ", 
     "can", " ", "be", " ", "combined", " ", "into", " ", "one", " ", "file", 
     " ", "and", " ", "then", " ", "plotted", " ", "on", " ", "the", " ", 
     "same", " ", "Flinn", " ", 
     RowBox[{"Diagram", "."}]}]}], "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"FlinnExportTable", "[", "0", "]"}], "=", "\"\<\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"FlinnExportTable", "[", "1", "]"}], "=", "NormLong"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"FlinnExportTable", "[", "2", "]"}], "=", "1.0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"FlinnExportTable", "[", "3", "]"}], "=", "NormShort"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"FlinnExportTable", "[", "4", "]"}], "=", "islandnumb"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tablect", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tabletot", "=", "5"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"tablect", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"tablect2", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"tablect2", "\[LessEqual]", 
          RowBox[{
           RowBox[{"DimPerimeterList", "[", "tablect", "]"}], "+", "1"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"tablect2", "==", 
             RowBox[{
              RowBox[{"DimPerimeterList", "[", "tablect", "]"}], "+", "1"}]}],
             ",", 
            RowBox[{
             RowBox[{
              RowBox[{"FlinnExportTable", "[", "tabletot", "]"}], "=", 
              RowBox[{"-", "999"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"tabletot", "=", 
              RowBox[{"tabletot", "+", "1"}]}], ";"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"FlinnExportTable", "[", "tabletot", "]"}], "=", 
              RowBox[{"NewPerimxFlinnpt", "[", 
               RowBox[{"tablect", ",", "tablect2"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"FlinnExportTable", "[", 
               RowBox[{"tabletot", "+", "1"}], "]"}], "=", 
              RowBox[{"NewPerimyFlinnpt", "[", 
               RowBox[{"tablect", ",", "tablect2"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"tabletot", "=", 
              RowBox[{"tabletot", "+", "2"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"tablect2", "=", 
           RowBox[{"tablect2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"tablect", "=", 
        RowBox[{"tablect", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FlinnTabbyExport", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"FlinnExportTable", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", 
         RowBox[{"tabletot", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FlinnExportDataTable", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<Sample\>\"", ",", "\"\<Long Axis Length\>\"", ",", 
         "\"\<Intermediate Axis Length\>\"", ",", "\"\<Short Axis Length\>\"",
          ",", "\"\<islandnumb\>\"", ",", "\"\<Perimeter Coords\>\""}], " ", 
        "}"}], ",", "FlinnTabbyExport"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<FlinnDataTable-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.xls\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FlinnExportDataTable"}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.54679798966546*^9, 3.5467980259255342`*^9}, {
   3.546798142167183*^9, 3.546798167967658*^9}, {3.546869061886698*^9, 
   3.5468690794507027`*^9}, {3.546871344519057*^9, 3.546871424751646*^9}, {
   3.5468729466890216`*^9, 3.546872958431038*^9}, {3.5468730333011436`*^9, 
   3.546873033631144*^9}, {3.546873067425192*^9, 3.546873140336294*^9}, 
   3.547027038714113*^9, {3.547045259075488*^9, 3.547045265081499*^9}, {
   3.547045333316019*^9, 3.547045432469793*^9}, {3.5470455639000235`*^9, 
   3.5470455836652584`*^9}, 3.5470456137109113`*^9, {3.54704585203253*^9, 
   3.5470458734669676`*^9}, {3.547046273108469*^9, 3.5470463524034085`*^9}, 
   3.547054148935236*^9, {3.5472290741848183`*^9, 3.5472290778664255`*^9}, {
   3.5476740360974236`*^9, 3.547674077642482*^9}, {3.547674292322784*^9, 
   3.5476746317082615`*^9}, {3.5476747061973667`*^9, 3.547674710057372*^9}, {
   3.547674814050518*^9, 3.547674827412537*^9}, 3.611062598726219*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "If", " ", "you", " ", "are", " ", "using", " ", "the", " ", "irregular", 
     " ", "polygon", " ", "error", " ", "region"}], ",", " ", 
    RowBox[{
     RowBox[{
     "then", " ", "you", " ", "can", " ", "export", " ", "the", " ", 
      "coordinate", " ", "of", " ", "that", " ", "irregular", " ", "polygon", 
      " ", "in", " ", "Hsu"}], "-", 
     RowBox[{"space", " ", "with", " ", "the", " ", "script", " ", 
      RowBox[{"below", ".", "  ", "The"}], " ", "data", " ", "from", " ", 
      "the", " ", "file", " ", "that", " ", "is", " ", "exported"}]}], ",", 
    " ", "\"\<HsuDataTable.xls\>\"", ",", " ", 
    RowBox[{
    "can", " ", "be", " ", "plotted", " ", "using", " ", "the", " ", 
     "program", " ", 
     RowBox[{"\"\<Hsu Plot with Error Regions\>\"", ".", "  ", "Using"}], " ",
      "this", " ", "program"}], ",", " ", 
    RowBox[{
    "several", " ", "sets", " ", "of", " ", "strain", " ", "data", " ", "and",
      " ", "their", " ", "associated", " ", "error", " ", "regions", " ", 
     "can", " ", "be", " ", "combined", " ", "into", " ", "one", " ", "file", 
     " ", "and", " ", "then", " ", "plotted", " ", "on", " ", "the", " ", 
     "same", " ", "Hsu", " ", 
     RowBox[{"Diagram", "."}]}]}], "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"HsuExportTable", "[", "0", "]"}], "=", "\"\<\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"HsuExportTable", "[", "1", "]"}], "=", "NormLong"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"HsuExportTable", "[", "2", "]"}], "=", "1.0"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"HsuExportTable", "[", "3", "]"}], "=", "NormShort"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"HsuExportTable", "[", "4", "]"}], "=", "islandnumb"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"HsuExportTable", "[", "5", "]"}], "=", "EsMax"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tablect", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tabletot", "=", "6"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"tablect", "\[LessEqual]", "islandnumb"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"tablect2", "=", "1"}], ";", "\[IndentingNewLine]", 
       RowBox[{"While", "[", 
        RowBox[{
         RowBox[{"tablect2", "\[LessEqual]", 
          RowBox[{
           RowBox[{"DimPerimeterList", "[", "tablect", "]"}], "+", "1"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"tablect2", "==", 
             RowBox[{
              RowBox[{"DimPerimeterList", "[", "tablect", "]"}], "+", "1"}]}],
             ",", 
            RowBox[{
             RowBox[{
              RowBox[{"HsuExportTable", "[", "tabletot", "]"}], "=", 
              RowBox[{"-", "999"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"tabletot", "=", 
              RowBox[{"tabletot", "+", "1"}]}], ";"}], ",", 
            RowBox[{
             RowBox[{
              RowBox[{"HsuExportTable", "[", "tabletot", "]"}], "=", 
              RowBox[{"NewPerimxHsupt", "[", 
               RowBox[{"tablect", ",", "tablect2"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"HsuExportTable", "[", 
               RowBox[{"tabletot", "+", "1"}], "]"}], "=", 
              RowBox[{"NewPerimyHsupt", "[", 
               RowBox[{"tablect", ",", "tablect2"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"tabletot", "=", 
              RowBox[{"tabletot", "+", "2"}]}], ";"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"tablect2", "=", 
           RowBox[{"tablect2", "+", "1"}]}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"tablect", "=", 
        RowBox[{"tablect", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"HsuTabbyExport", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"HsuExportTable", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", 
         RowBox[{"tabletot", "-", "1"}]}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"HsuExportDataTable", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<Sample\>\"", ",", "\"\<Long Axis Length\>\"", ",", 
         "\"\<Intermediate Axis Length\>\"", ",", "\"\<Short Axis Length\>\"",
          ",", "\"\<islandnumb\>\"", ",", "\"\<\[Epsilon]s-max\>\"", " ", 
         ",", "\"\<Perimeter Coords\>\""}], " ", "}"}], ",", 
       "HsuTabbyExport"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<HsuDataTable-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.xls\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "HsuExportDataTable"}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.54679798966546*^9, 3.5467980259255342`*^9}, {
   3.546798142167183*^9, 3.546798167967658*^9}, {3.546869061886698*^9, 
   3.5468690794507027`*^9}, {3.546871344519057*^9, 3.546871424751646*^9}, {
   3.5468729466890216`*^9, 3.546872958431038*^9}, {3.5468730333011436`*^9, 
   3.546873033631144*^9}, {3.546873067425192*^9, 3.546873140336294*^9}, 
   3.547027038714113*^9, {3.547045259075488*^9, 3.547045265081499*^9}, {
   3.547045333316019*^9, 3.547045432469793*^9}, {3.5470455639000235`*^9, 
   3.5470455836652584`*^9}, 3.5470456137109113`*^9, {3.54704585203253*^9, 
   3.5470458734669676`*^9}, {3.547046273108469*^9, 3.5470463524034085`*^9}, 
   3.547054148935236*^9, {3.5472290741848183`*^9, 3.5472290778664255`*^9}, {
   3.547639135518611*^9, 3.547639244303764*^9}, {3.5476393332868958`*^9, 
   3.5476393366079006`*^9}, {3.547642386151199*^9, 3.5476424542982945`*^9}, 
   3.5476746411392746`*^9, {3.5476746857443376`*^9, 3.547674692215347*^9}, {
   3.547674777365466*^9, 3.547674856665578*^9}, {3.5479800934950094`*^9, 
   3.54798009406501*^9}, 3.611062702560158*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "If", " ", "you", " ", "know", " ", "the", " ", "orientation", " ", "of",
       " ", "the", " ", "regional", " ", "motion", " ", "plane", " ", "and", 
      " ", "want", " ", "to", " ", "know", " ", "how", " ", "much", " ", 
      "out"}], "-", "of", "-", 
     RowBox[{
     "plane", " ", "motion", " ", "your", " ", "strain", " ", "measurement", 
      " ", "represents", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"one", " ", "is", " ", "plane", " ", "strain"}], ",", " ", 
        RowBox[{
        "less", " ", "than", " ", "one", " ", "is", " ", "constrictional", 
         " ", "and", " ", "greater", " ", "than", " ", "one", " ", "is", " ", 
         "flattening"}]}], ")"}]}]}], ",", " ", 
    RowBox[{"evaluate", " ", "this", " ", 
     RowBox[{"cell", ".", " ", "This"}], " ", "method", " ", "assumes", " ", 
     "no", " ", "volume", " ", 
     RowBox[{"loss", "."}]}]}], "  ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"MotionDip", "=", 
     RowBox[{
     "Input", "[", "\"\<Enter the Dip  for the Regional Motion Plane\>\"", 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MotionDipDir", "=", 
     RowBox[{
     "Input", "[", 
      "\"\<Enter the Dip Direction for the Regional Motion Plane\>\"", 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"MotionDipDir", "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{"MotionDipDir", "\[LessEqual]", "90"}]}], ",", 
      RowBox[{
       RowBox[{"\[Theta]", "=", "MotionDipDir"}], ";"}]}], "]"}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"MotionDipDir", ">", "90"}], "&&", 
       RowBox[{"MotionDipDir", "\[LessEqual]", "180"}]}], ",", 
      RowBox[{
       RowBox[{"\[Theta]", "=", 
        RowBox[{"180", "-", "MotionDipDir"}]}], ";"}]}], "]"}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"MotionDipDir", ">", "180"}], "&&", 
       RowBox[{"MotionDipDir", "\[LessEqual]", "270"}]}], ",", 
      RowBox[{
       RowBox[{"\[Theta]", "=", 
        RowBox[{"MotionDipDir", "-", "180"}]}], ";"}]}], "]"}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"MotionDipDir", ">", "270"}], "&&", 
       RowBox[{"MotionDipDir", "\[LessEqual]", "360"}]}], ",", 
      RowBox[{
       RowBox[{"\[Theta]", "=", 
        RowBox[{"360", "-", "MotionDipDir"}]}], ";"}]}], "]"}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Theta]", "\[Equal]", "90"}], "||", 
       RowBox[{"\[Theta]", "\[Equal]", "270"}]}], ",", 
      RowBox[{
       RowBox[{"a", "=", "0"}], ";"}], ",", 
      RowBox[{
       RowBox[{"a", "=", 
        SqrtBox[
         FractionBox["1", 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"Tan", "[", 
             FractionBox[
              RowBox[{"\[Theta]", " ", "\[Pi]"}], "180"], "]"}], "2"]}]]]}], 
       ";"}]}], "]"}], ";", 
    RowBox[{"b", "=", 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox["a", "2"]}]]}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"MotionDip", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"a", "=", "0"}], ";", 
       RowBox[{"b", "=", "0"}], ";", 
       RowBox[{"c", "=", "1"}], ";"}], ",", 
      RowBox[{
       RowBox[{"c", "=", 
        RowBox[{"Tan", "[", 
         RowBox[{
          FractionBox["1", "180"], " ", 
          RowBox[{"(", 
           RowBox[{"90", "-", "MotionDip"}], ")"}], " ", "\[Pi]"}], "]"}]}], 
       ";"}]}], "]"}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"MotionDipDir", "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{"MotionDipDir", "\[LessEqual]", "90"}]}], ",", 
      RowBox[{
       RowBox[{"a", "=", "a"}], ";", 
       RowBox[{"b", "=", 
        RowBox[{"-", "b"}]}], ";"}]}], "]"}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"MotionDipDir", ">", "90"}], "&&", 
       RowBox[{"MotionDipDir", "\[LessEqual]", "180"}]}], ",", 
      RowBox[{
       RowBox[{"a", "=", 
        RowBox[{"-", "a"}]}], ";", 
       RowBox[{"b", "=", 
        RowBox[{"-", "b"}]}], ";"}]}], "]"}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"MotionDipDir", ">", "180"}], "&&", 
       RowBox[{"MotionDipDir", "\[LessEqual]", "270"}]}], ",", 
      RowBox[{
       RowBox[{"a", "=", 
        RowBox[{"-", "a"}]}], ";", 
       RowBox[{"b", "=", "b"}], ";"}]}], "]"}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"MotionDipDir", ">", "270"}], "&&", 
       RowBox[{"MotionDipDir", "\[LessEqual]", "360"}]}], ",", 
      RowBox[{
       RowBox[{"a", "=", "a"}], ";", 
       RowBox[{"b", "=", "b"}], ";"}]}], "]"}], ";", 
    RowBox[{"scale", "=", 
     FractionBox["1", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]]}], ";", 
    RowBox[{"aprime", "=", 
     RowBox[{"scale", " ", "a"}]}], ";", 
    RowBox[{"bprime", "=", 
     RowBox[{"scale", " ", "b"}]}], ";", 
    RowBox[{"cprime", "=", 
     RowBox[{"scale", " ", "c"}]}], ";", 
    RowBox[{"normvect", "=", 
     RowBox[{"N", "[", 
      RowBox[{"{", 
       RowBox[{"aprime", ",", "bprime", ",", "cprime"}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"linit", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"FitLengths", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "*", 
        RowBox[{"FitLengths", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "*", 
        RowBox[{"FitLengths", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"1", "/", "3"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"len", "=", 
     RowBox[{"1", "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Norm", "[", 
        RowBox[{"FitEllipsoid", ".", 
         RowBox[{"Normalize", "[", "normvect", "]"}]}], "]"}], "]"}]}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"OutofPlane", "=", 
     RowBox[{"Log", "[", 
      RowBox[{"len", "/", "linit"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<Your out-of-plane natural strain (\!\(\*SubscriptBox[\(\[Epsilon]\), \
\(OP\)]\)) = \>\"", ",", "OutofPlane"}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.5034256456431365`*^9, 3.50342580613081*^9}, {
  3.503425963774952*^9, 3.5034259791018996`*^9}, {3.503426075110151*^9, 
  3.5034261022330675`*^9}, {3.5034264432381268`*^9, 3.503426453831063*^9}, {
  3.503428500236387*^9, 3.5034286007599163`*^9}, {3.503428683487937*^9, 
  3.503428693393426*^9}, {3.5034289183605223`*^9, 3.5034289200791407`*^9}, {
  3.503429321876405*^9, 3.5034293502960973`*^9}, {3.5034294005578613`*^9, 
  3.5034294279307594`*^9}, {3.5037529301537943`*^9, 3.5037529359503355`*^9}, {
  3.5037775551728115`*^9, 3.503777557344561*^9}, {3.5479801049470253`*^9, 
  3.547980107407029*^9}}]
}, Open  ]]
},
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 63712, 1028, 1512, "Title"],
Cell[64282, 1052, 902608, 22117, 55563, "Input"],
Cell[966893, 23171, 7452, 157, 352, "Input"],
Cell[974348, 23330, 2440, 49, 112, "Input"],
Cell[976791, 23381, 2574, 61, 152, "Input"],
Cell[979368, 23444, 2749, 63, 152, "Input"],
Cell[982120, 23509, 2578, 63, 152, "Input"],
Cell[984701, 23574, 2563, 62, 152, "Input"],
Cell[987267, 23638, 2685, 64, 152, "Input"],
Cell[989955, 23704, 2771, 64, 152, "Input"],
Cell[992729, 23770, 2745, 64, 152, "Input"],
Cell[995477, 23836, 2562, 62, 152, "Input"],
Cell[998042, 23900, 12662, 245, 712, "Input"],
Cell[1010707, 24147, 6254, 143, 552, "Input"],
Cell[1016964, 24292, 6484, 149, 552, "Input"],
Cell[1023451, 24443, 7270, 198, 481, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
