(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    307551,       7446]
NotebookOptionsPosition[    306735,       7420]
NotebookOutlinePosition[    307156,       7436]
CellTagsIndexPosition[    307113,       7433]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Best Fit Ellipsoid-Absolute Lengths-For ImageJ-v3.0\n", "Title",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["by", "Title",
  FontFamily->"Arial",
  FontSize->26,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox[" ", "Title",
  FontSize->26,
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 Cell[BoxData[
  FormBox[
   RowBox[{"Matty", " ", 
    SuperscriptBox["Mookerjee", "*"]}], TraditionalForm]],
  FontFamily->"Arial",
  FontSize->26,
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox[" ",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["\n", "Title",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "*"], TraditionalForm]],
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["Dept. of Geology, Sonoma State University,Rohnert Park, CA 94928\n\
\n          ", "Title",
  FontFamily->"Arial Narrow",
  FontSize->22,
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["This Mathematic notebook ", "Title",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["will determine the best fit ellipsoid for arbitrarily oriented \
sectional ellipses.  Input for this program includes the absolute lengths of \
the principal axes and orientation of the sectional ellipses.  One can either \
specify the mean values or input the raw data (i.e., a file with several/many \
elliptical measurement) and the means will be calculated automatically.  The \
mean ellipses are determined by averaging ellipse shape tensors as described \
by Shimamoto & Ikeda (1976) and Wheeler (1984).  Additionally, one also needs \
to input the dip and dip direction of the plane from which the data were \
collected.  Data can either be input manually during the running of the \
program or it can be read in from an existing file.  This program will read \
both text files (*.txt) and Excel files (*.xls and *.xlsx).   Examine the \
files, \"Sample Strain Data NO Stats-ABS from ImageJ.txt\", \
\[OpenCurlyDoubleQuote]Sample Strain Data NO Stats-ABS from ImageJ.xls\
\[CloseCurlyDoubleQuote], and \"Sample Strain Data NO Stats-ABS from \
ImageJ.xlsx\", to determine the appropriate file structure (it is easiest \
simply to modify these files and save them with different file names).   \n   \
       The sign convention that this program uses is as follows:  1) all \
sectional data need to be viewed from the perspective of looking downward, 2) \
vertical planes need to be viewed looking westward; for vertical planes that \
are striking exactly east-west, the plane needs to be view from the south to \
the north, 3) the orientation angle (",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["f",
  FontFamily->"Symbol",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox[") is measured from the long axis of the ellipse to the strike line \
of the sectional plane, 4) ",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["f",
  FontFamily->"Symbol",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox[" is always positive and is measured counter clockwise from the \
positive horizontal axis.  For example:",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 "\n",
 Cell[BoxData[
  RowBox[{" ", 
   GraphicsBox[{{}, {}, 
     {RGBColor[0, 0, 1], Thickness[Large], LineBox[CompressedData["
1:eJwt2nk0Vd/bAPB73XtUUlIhkqGRSklCGfbRgIRQiEQDZQoRCQlpIGQWytcU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       "]]}},
    Axes->True,
    AxesOrigin->{0, 0},
    ImageSize->{300, 300},
    PlotRange->{{-3.8116399780037673`, 
     3.8116399780037673`}, {-3.8116399780037673`, 3.8116399780037673`}},
    PlotRangeClipping->True,
    PlotRangePadding->{Automatic, Automatic},
    Ticks->False]}]],
  CellChangeTimes->{{3.487174247242574*^9, 3.4871742776123114`*^9}, 
    3.4871743338275266`*^9, {3.487174762772061*^9, 3.4871747985711083`*^9}, {
    3.48717490176101*^9, 3.4871749090874295`*^9}, {3.4871749554500813`*^9, 
    3.48717502361598*^9}, {3.4871862392520313`*^9, 3.487186271423872*^9}, {
    3.487186360744981*^9, 3.4871863936968656`*^9}, 3.487186428625863*^9, {
    3.4871865765023212`*^9, 3.487186577094355*^9}, {3.4871866405469847`*^9, 
    3.4871866966911955`*^9}, {3.487186901263897*^9, 3.4871869297615266`*^9}, {
    3.4871869857947316`*^9, 3.487186995583291*^9}, {3.487187104629528*^9, 
    3.487187110441861*^9}, {3.487187144660818*^9, 3.487187203680194*^9}, 
    3.4871883033280897`*^9, {3.487203071425685*^9, 3.487203090535719*^9}, 
    3.4872045032274*^9, {3.4872463495157666`*^9, 3.4872463693439007`*^9}, {
    3.487246433157551*^9, 3.487246435278672*^9}, {3.4872473815177937`*^9, 
    3.487247450426735*^9}, {3.4872474820085416`*^9, 3.4872477205581856`*^9}, {
    3.487248117408884*^9, 3.4872481184019413`*^9}, {3.487248178762394*^9, 
    3.4872482110042377`*^9}, {3.4872482608720903`*^9, 3.487248319881465*^9}, 
    3.4872483575806217`*^9, {3.487248908602138*^9, 3.487248909463187*^9}, {
    3.487249340737855*^9, 3.4872493588798923`*^9}, {3.4872496780271463`*^9, 
    3.4872497003824253`*^9}, {3.487250023118885*^9, 3.487250027655144*^9}, {
    3.487250575263466*^9, 3.487250676430252*^9}, {3.487251411085272*^9, 
    3.487251471173709*^9}, {3.487251816966487*^9, 3.487251829224188*^9}, {
    3.4872519179082603`*^9, 3.487251966365032*^9}, {3.4872520257294273`*^9, 
    3.487252033389866*^9}, {3.4872523305878644`*^9, 3.487252332862994*^9}, {
    3.4872523688660536`*^9, 3.4872523709751744`*^9}, 3.4872527765613728`*^9, {
    3.4872528923829975`*^9, 3.487252892648012*^9}, {3.487499290280834*^9, 
    3.48749930069143*^9}, {3.48749933355931*^9, 3.487499376693777*^9}, {
    3.4874994538371897`*^9, 3.48749946608889*^9}, {3.487499503736044*^9, 
    3.4874995041570673`*^9}, {3.487507728289461*^9, 3.487507734874838*^9}, {
    3.4875080286316395`*^9, 3.4875080768673983`*^9}, {3.4875082677043138`*^9, 
    3.4875083238205233`*^9}, {3.487508913094228*^9, 3.487508937050598*^9}, {
    3.4875876017805667`*^9, 3.487587603337656*^9}, {3.4875892032991686`*^9, 
    3.4875892051122723`*^9}, {3.487589275342289*^9, 3.4875892781714506`*^9}, {
    3.4875909175242167`*^9, 3.4875909362422867`*^9}, {3.487591048960734*^9, 
    3.4875911435141425`*^9}, 3.487591236332451*^9, {3.487591325170532*^9, 
    3.4875913269496346`*^9}, {3.4875913587614536`*^9, 
    3.4875913744783525`*^9}, {3.4875915221567993`*^9, 3.487591533167429*^9}, {
    3.487591630017969*^9, 3.487591630756011*^9}, {3.4875916701542645`*^9, 
    3.487591717766988*^9}, {3.487591978521902*^9, 3.4875919790189304`*^9}, {
    3.4876119442692347`*^9, 3.487611949521535*^9}, {3.4876123171505623`*^9, 
    3.4876123207197666`*^9}, {3.4876123583329177`*^9, 3.487612362155136*^9}, {
    3.487620968917506*^9, 3.4876209735663147`*^9}, {3.487621086931713*^9, 
    3.4876211069621487`*^9}, {3.4876211776146727`*^9, 3.48762118185788*^9}, {
    3.4876223429523196`*^9, 3.4876224066628313`*^9}, {3.4876226462948523`*^9, 
    3.4876226545940666`*^9}, {3.4879378505605435`*^9, 3.487937852526147*^9}, {
    3.4879389595976915`*^9, 3.4879389806109285`*^9}, 3.487954506800294*^9, 
    3.4879552059462833`*^9, {3.487955354226764*^9, 3.4879553548828015`*^9}, 
    3.4879778865925393`*^9, {3.488026762836731*^9, 3.4880267855730314`*^9}, {
    3.4880286760411596`*^9, 3.488028691873065*^9}, {3.48802875996296*^9, 
    3.4880287779629893`*^9}, {3.488029402590716*^9, 3.488029423166893*^9}, 
    3.4881035588680367`*^9, 3.4881039206262083`*^9, 3.488104120777656*^9, 
    3.488104903078401*^9, {3.4881050616464705`*^9, 3.488105078194417*^9}, {
    3.4881111465675077`*^9, 3.488111160340296*^9}, {3.488112068437236*^9, 
    3.4881120941107044`*^9}, 3.4881151584709883`*^9, {3.488131862127383*^9, 
    3.4881319519195185`*^9}, {3.4881327730814867`*^9, 3.488132802714182*^9}, {
    3.4881871755509825`*^9, 3.488187183630445*^9}, 3.4881889555927954`*^9, {
    3.488189998898469*^9, 3.488190098602172*^9}, {3.4881901543543606`*^9, 
    3.488190173469454*^9}, {3.4881903638923454`*^9, 3.488190380942321*^9}, {
    3.4882137973446627`*^9, 3.4882138365939074`*^9}, {3.4882140471889524`*^9, 
    3.488214056358477*^9}, {3.4882148881910553`*^9, 3.4882148951354523`*^9}, 
    3.4882149283413515`*^9, {3.4882302297011557`*^9, 3.4882302344904294`*^9}, 
    3.488231704599515*^9, {3.4882319839284916`*^9, 3.4882319992813697`*^9}, {
    3.488275876124522*^9, 3.488275881496829*^9}, 3.488276068637533*^9, 
    3.4882765579205184`*^9, 3.488277169769514*^9, 3.48827741201637*^9, {
    3.488277522075665*^9, 3.488277525446858*^9}, 3.488278079202531*^9, {
    3.488278397793753*^9, 3.488278425786354*^9}, {3.488278718245082*^9, 
    3.488278719804171*^9}, {3.488281865350086*^9, 3.488281871320428*^9}, {
    3.4882830136195784`*^9, 3.4882830192511883`*^9}, {3.488283407479191*^9, 
    3.48828342058294*^9}, {3.488285026388787*^9, 3.4882850392645235`*^9}, 
    3.4882907709793587`*^9, {3.488291081025092*^9, 3.4882910896975884`*^9}, {
    3.4882911289018307`*^9, 3.4882911544232903`*^9}, {3.488291200132905*^9, 
    3.4882912002289104`*^9}, {3.4882912461585374`*^9, 
    3.4882912662906885`*^9}, {3.4882912993615804`*^9, 3.488291313319379*^9}, {
    3.488292675314749*^9, 3.4882926928803797`*^9}, {3.488292814825794*^9, 
    3.4882928340762277`*^9}, 3.488293248100955*^9, {3.488293668880494*^9, 
    3.4882943519120936`*^9}, {3.488294386169754*^9, 3.4882944270418253`*^9}, 
    3.488294576739689*^9, {3.4883963963753386`*^9, 3.4883964781840177`*^9}, {
    3.4883965083107405`*^9, 3.488396598437896*^9}, {3.4883970123125677`*^9, 
    3.488397038351057*^9}, {3.4883973207822113`*^9, 3.4883973230023384`*^9}, {
    3.4884010355926867`*^9, 3.4884010418300433`*^9}, {3.4884029584056654`*^9, 
    3.4884029600077567`*^9}, {3.4884030443625813`*^9, 
    3.4884030517140017`*^9}, {3.4884559968958817`*^9, 3.4884560201222105`*^9},
     3.4884561828885202`*^9, {3.4884595324081016`*^9, 3.4884595557644377`*^9},
     3.488488413833895*^9, {3.488488614512373*^9, 3.488488650284419*^9}, 
    3.4884941868160906`*^9, 3.488494307578998*^9, 3.488494915640777*^9, {
    3.4884969399105587`*^9, 3.4884969446568303`*^9}, 3.4884970443505325`*^9, {
    3.488497121122924*^9, 3.4884971234120545`*^9}, {3.488497153530777*^9, 
    3.4884971544248285`*^9}, 3.488497216257365*^9, 3.4884982796191854`*^9, {
    3.4884985827925262`*^9, 3.4884985838495865`*^9}, 3.488548766839347*^9, {
    3.4885546595003877`*^9, 3.48855467351919*^9}, {3.488554768972649*^9, 
    3.488554780388302*^9}, {3.4885548176644344`*^9, 3.488554834780413*^9}, 
    3.4885558246670313`*^9, {3.488555877735067*^9, 3.488555885167492*^9}, {
    3.488555925882821*^9, 3.488555968589263*^9}, {3.488556183800573*^9, 
    3.4885561926470785`*^9}, {3.4885565714927473`*^9, 3.488556578579153*^9}, {
    3.488556819261919*^9, 3.488556860995306*^9}, 3.489757221378025*^9, {
    3.4897714976971006`*^9, 3.489771499584704*^9}, {3.4899235962696867`*^9, 
    3.489923596809717*^9}, {3.4900048505124407`*^9, 3.4900048575248413`*^9}, {
    3.490004927360836*^9, 3.490004927640852*^9}, {3.4900054204690404`*^9, 
    3.49000542064305*^9}, {3.4900273743567305`*^9, 3.490027413935995*^9}, 
    3.4900274660839777`*^9, {3.4900314898301225`*^9, 3.4900314904871597`*^9}, 
    3.490031551025623*^9, {3.4900342535741997`*^9, 3.4900342782086086`*^9}, {
    3.490036273490732*^9, 3.4900362852984076`*^9}, {3.4900363603587008`*^9, 
    3.490036371115316*^9}, 3.490037162197563*^9, 3.4900403448696017`*^9, 
    3.490048845135789*^9, 3.4904418396813517`*^9, {3.4904419441003237`*^9, 
    3.490441947441515*^9}, {3.490441986359741*^9, 3.4904420592999134`*^9}, 
    3.490444327068622*^9, {3.4904444014798784`*^9, 3.4904444022399216`*^9}, 
    3.4904474676582537`*^9, 3.49044858339207*^9, 3.490450905146867*^9, 
    3.490451714886181*^9, 3.490452510791704*^9, 3.490453288249172*^9, 
    3.490464459496053*^9, {3.4904681593526726`*^9, 3.4904681643289576`*^9}, {
    3.4904682052062955`*^9, 3.4904682058513327`*^9}, 3.490531867888402*^9, {
    3.4905333015014*^9, 3.4905333019644265`*^9}, 3.4907062892196035`*^9, {
    3.490708250619789*^9, 3.4907082541179895`*^9}, {3.490712025183682*^9, 
    3.4907120313920374`*^9}, {3.4907128353390207`*^9, 3.490712841327363*^9}, 
    3.490714884718238*^9, 3.4907291944635754`*^9, 3.490729713173244*^9, {
    3.490730085218524*^9, 3.490730101265442*^9}, {3.4907306694449396`*^9, 
    3.4907306727751303`*^9}, {3.490731048785637*^9, 3.49073105373092*^9}, {
    3.4907317737701035`*^9, 3.4907318297893076`*^9}, {3.49073192354667*^9, 
    3.490731949549157*^9}, 3.490732404969206*^9, {3.490732482961667*^9, 
    3.490732520929838*^9}, {3.490732560906125*^9, 3.490732566699456*^9}, {
    3.4907951817937293`*^9, 3.4907952097603292`*^9}, 3.49079688138494*^9, 
    3.4909578135058956`*^9, {3.490966426065824*^9, 3.4909664589038815`*^9}, 
    3.4909679863493643`*^9, {3.4909682970395103`*^9, 
    3.4909683252911596`*^9}, {3.490972673956398*^9, 3.4909726987292414`*^9}, 
    3.4909728202534547`*^9, {3.490972862435929*^9, 3.4909728817019625`*^9}, {
    3.490972913073618*^9, 3.4909729566132946`*^9}, {3.490973518869482*^9, 
    3.4909735657475643`*^9}, {3.4909736125476465`*^9, 3.490973619021658*^9}, {
    3.490973703355406*^9, 3.4909737369578648`*^9}, {3.490973801963179*^9, 
    3.4909738048959846`*^9}, 3.490974014136751*^9, 3.4911489290724*^9, 
    3.491152414014719*^9, {3.4911532777726364`*^9, 3.491153287179453*^9}, {
    3.4911533826048203`*^9, 3.4911533843676233`*^9}, 3.4911608269218388`*^9, 
    3.4911610198473773`*^9, {3.4912215420326176`*^9, 3.4912215503786325`*^9}, 
    3.4912215809234858`*^9, {3.491221615103146*^9, 3.4912217052401047`*^9}, 
    3.4912220487527075`*^9, {3.4912290845968103`*^9, 
    3.4912290884968166`*^9}, {3.4912385323231597`*^9, 3.491238550410194*^9}, 
    3.491238719776881*^9, {3.4912389233205233`*^9, 3.4912389754925075`*^9}, 
    3.491241094984701*^9, 3.4912414098657107`*^9, {3.491385847243327*^9, 
    3.4913859619878902`*^9}, 3.4913859937217054`*^9, {3.491386060978552*^9, 
    3.4913860866870227`*^9}, 3.491386146561447*^9, {3.491386424457342*^9, 
    3.4913864460755787`*^9}, {3.4913864766593275`*^9, 3.49138647687934*^9}, 
    3.491397677026628*^9, 3.4913977115026884`*^9, 3.4913978076456575`*^9, 
    3.4913980532212887`*^9, {3.491398197490342*^9, 3.491398204603955*^9}, {
    3.491398273540476*^9, 3.4913983694494443`*^9}, {3.4913984869332504`*^9, 
    3.491398496948468*^9}, 3.4914136297351246`*^9, 3.4914140468859844`*^9, {
    3.491416748060483*^9, 3.4914167482264924`*^9}, 3.4914168077348957`*^9, {
    3.4916705003527727`*^9, 3.491670503035977*^9}, {3.491670536529236*^9, 
    3.4916706071469603`*^9}, {3.4916706472234306`*^9, 
    3.4916706812470903`*^9}, {3.4916708342053595`*^9, 3.491670835266161*^9}, {
    3.4916709879504294`*^9, 3.491670997248046*^9}, 3.4916710720657773`*^9, {
    3.4917362307280855`*^9, 3.491736236375295*^9}, {3.491736287652585*^9, 
    3.49173648371373*^9}, {3.4917372333262467`*^9, 3.4917372347458496`*^9}, 
    3.4917372742763186`*^9, {3.491757814102442*^9, 3.491757843992094*^9}, 
    3.491761526294041*^9}],
 StyleBox[" ",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain"],
 StyleBox["\[Phi] = 120\[Degree].",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 StyleBox["\n  ",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain"],
 Cell[BoxData[
  GraphicsBox[{{}, {}, 
    {RGBColor[0, 0, 1], Thickness[Large], LineBox[CompressedData["
1:eJwt2nk0lN//AHBmxsyEZI1shbKrkCXiXrsspVCEFpVkK5IWabWUItkSKtFi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      "]]}},
   Axes->True,
   AxesOrigin->{0, 0},
   ImageSize->{300, 300},
   PlotRange->{{-3.8116399780037673`, 
    3.8116399780037673`}, {-3.8116399780037673`, 3.8116399780037673`}},
   PlotRangeClipping->True,
   PlotRangePadding->{Automatic, Automatic},
   Ticks->False]],
  CellChangeTimes->{{3.487174247242574*^9, 3.4871742776123114`*^9}, 
    3.4871743338275266`*^9, {3.487174762772061*^9, 3.4871747985711083`*^9}, {
    3.48717490176101*^9, 3.4871749090874295`*^9}, {3.4871749554500813`*^9, 
    3.48717502361598*^9}, {3.4871862392520313`*^9, 3.487186271423872*^9}, {
    3.487186360744981*^9, 3.4871863936968656`*^9}, 3.487186428625863*^9, {
    3.4871865765023212`*^9, 3.487186577094355*^9}, {3.4871866405469847`*^9, 
    3.4871866966911955`*^9}, {3.487186901263897*^9, 3.4871869297615266`*^9}, {
    3.4871869857947316`*^9, 3.487186995583291*^9}, {3.487187104629528*^9, 
    3.487187110441861*^9}, {3.487187144660818*^9, 3.487187203680194*^9}, 
    3.4871883033280897`*^9, {3.487203071425685*^9, 3.487203090535719*^9}, 
    3.4872045032274*^9, {3.4872463495157666`*^9, 3.4872463693439007`*^9}, {
    3.487246433157551*^9, 3.487246435278672*^9}, {3.4872473815177937`*^9, 
    3.487247450426735*^9}, {3.4872474820085416`*^9, 3.4872477205581856`*^9}, {
    3.487248117408884*^9, 3.4872481184019413`*^9}, {3.487248178762394*^9, 
    3.4872482110042377`*^9}, {3.4872482608720903`*^9, 3.487248319881465*^9}, 
    3.4872483575806217`*^9, {3.487248908602138*^9, 3.487248909463187*^9}, {
    3.487249340737855*^9, 3.4872493588798923`*^9}, {3.4872496780271463`*^9, 
    3.4872497003824253`*^9}, {3.487250023118885*^9, 3.487250027655144*^9}, {
    3.487250575263466*^9, 3.487250676430252*^9}, {3.487251411085272*^9, 
    3.487251471173709*^9}, {3.487251816966487*^9, 3.487251829224188*^9}, {
    3.4872519179082603`*^9, 3.487251966365032*^9}, {3.4872520257294273`*^9, 
    3.487252033389866*^9}, {3.4872523305878644`*^9, 3.487252332862994*^9}, {
    3.4872523688660536`*^9, 3.4872523709751744`*^9}, 3.4872527765613728`*^9, {
    3.4872528923829975`*^9, 3.487252892648012*^9}, {3.487499290280834*^9, 
    3.48749930069143*^9}, {3.48749933355931*^9, 3.487499376693777*^9}, {
    3.4874994538371897`*^9, 3.48749946608889*^9}, {3.487499503736044*^9, 
    3.4874995041570673`*^9}, {3.487507728289461*^9, 3.487507734874838*^9}, {
    3.4875080286316395`*^9, 3.4875080768673983`*^9}, {3.4875082677043138`*^9, 
    3.4875083238205233`*^9}, {3.487508913094228*^9, 3.487508937050598*^9}, {
    3.4875876017805667`*^9, 3.487587603337656*^9}, {3.4875892032991686`*^9, 
    3.4875892051122723`*^9}, {3.487589275342289*^9, 3.4875892781714506`*^9}, {
    3.4875909175242167`*^9, 3.4875909362422867`*^9}, {3.487591048960734*^9, 
    3.4875911435141425`*^9}, 3.487591236332451*^9, {3.487591325170532*^9, 
    3.4875913269496346`*^9}, {3.4875913587614536`*^9, 
    3.4875913744783525`*^9}, {3.4875915221567993`*^9, 3.487591533167429*^9}, {
    3.487591630017969*^9, 3.487591630756011*^9}, {3.4875916701542645`*^9, 
    3.487591717766988*^9}, {3.487591978521902*^9, 3.4875919790189304`*^9}, {
    3.4876119442692347`*^9, 3.487611949521535*^9}, {3.4876123171505623`*^9, 
    3.4876123207197666`*^9}, {3.4876123583329177`*^9, 3.487612362155136*^9}, {
    3.487620968917506*^9, 3.4876209735663147`*^9}, {3.487621086931713*^9, 
    3.4876211069621487`*^9}, {3.4876211776146727`*^9, 3.48762118185788*^9}, {
    3.4876223429523196`*^9, 3.4876224066628313`*^9}, {3.4876226462948523`*^9, 
    3.4876226545940666`*^9}, {3.4879378505605435`*^9, 3.487937852526147*^9}, {
    3.4879389595976915`*^9, 3.4879389806109285`*^9}, 3.487954506800294*^9, 
    3.4879552059462833`*^9, {3.487955354226764*^9, 3.4879553548828015`*^9}, 
    3.4879778865925393`*^9, {3.488026762836731*^9, 3.4880267855730314`*^9}, {
    3.4880286760411596`*^9, 3.488028691873065*^9}, {3.48802875996296*^9, 
    3.4880287779629893`*^9}, {3.488029402590716*^9, 3.488029423166893*^9}, 
    3.4881035588680367`*^9, 3.4881039206262083`*^9, 3.488104120777656*^9, 
    3.488104903078401*^9, {3.4881050616464705`*^9, 3.488105078194417*^9}, {
    3.4881111465675077`*^9, 3.488111160340296*^9}, {3.488112068437236*^9, 
    3.4881120941107044`*^9}, 3.4881151584709883`*^9, {3.488131862127383*^9, 
    3.4881319519195185`*^9}, {3.4881327730814867`*^9, 3.488132802714182*^9}, {
    3.4881871755509825`*^9, 3.488187183630445*^9}, 3.4881889555927954`*^9, {
    3.488189998898469*^9, 3.488190098602172*^9}, {3.4881901543543606`*^9, 
    3.488190173469454*^9}, {3.4881903638923454`*^9, 3.488190380942321*^9}, {
    3.4882137973446627`*^9, 3.4882138365939074`*^9}, {3.4882140471889524`*^9, 
    3.488214056358477*^9}, {3.4882148881910553`*^9, 3.4882148951354523`*^9}, 
    3.4882149283413515`*^9, {3.4882302297011557`*^9, 3.4882302344904294`*^9}, 
    3.488231704599515*^9, {3.4882319839284916`*^9, 3.4882319992813697`*^9}, {
    3.488275876124522*^9, 3.488275881496829*^9}, 3.488276068637533*^9, 
    3.4882765579205184`*^9, 3.488277169769514*^9, 3.48827741201637*^9, {
    3.488277522075665*^9, 3.488277525446858*^9}, 3.488278079202531*^9, {
    3.488278397793753*^9, 3.488278425786354*^9}, {3.488278718245082*^9, 
    3.488278719804171*^9}, {3.488281865350086*^9, 3.488281871320428*^9}, {
    3.4882830136195784`*^9, 3.4882830192511883`*^9}, {3.488283407479191*^9, 
    3.48828342058294*^9}, {3.488285026388787*^9, 3.4882850392645235`*^9}, 
    3.4882907709793587`*^9, {3.488291081025092*^9, 3.4882910896975884`*^9}, {
    3.4882911289018307`*^9, 3.4882911544232903`*^9}, {3.488291200132905*^9, 
    3.4882912002289104`*^9}, {3.4882912461585374`*^9, 
    3.4882912662906885`*^9}, {3.4882912993615804`*^9, 3.488291313319379*^9}, {
    3.488292675314749*^9, 3.4882926928803797`*^9}, {3.488292814825794*^9, 
    3.4882928340762277`*^9}, 3.488293248100955*^9, {3.488293668880494*^9, 
    3.4882943519120936`*^9}, {3.488294386169754*^9, 3.4882944270418253`*^9}, 
    3.488294576739689*^9, {3.4883963963753386`*^9, 3.4883964781840177`*^9}, {
    3.4883965083107405`*^9, 3.488396598437896*^9}, {3.4883970123125677`*^9, 
    3.488397038351057*^9}, {3.4883973207822113`*^9, 3.4883973230023384`*^9}, {
    3.4884010355926867`*^9, 3.4884010418300433`*^9}, {3.4884029584056654`*^9, 
    3.4884029600077567`*^9}, {3.4884030443625813`*^9, 
    3.4884030517140017`*^9}, {3.4884559968958817`*^9, 3.4884560201222105`*^9},
     3.4884561828885202`*^9, {3.4884595324081016`*^9, 3.4884595557644377`*^9},
     3.488488413833895*^9, {3.488488614512373*^9, 3.488488650284419*^9}, 
    3.4884941868160906`*^9, 3.488494307578998*^9, 3.488494915640777*^9, {
    3.4884969399105587`*^9, 3.4884969446568303`*^9}, 3.4884970443505325`*^9, {
    3.488497121122924*^9, 3.4884971234120545`*^9}, {3.488497153530777*^9, 
    3.4884971544248285`*^9}, 3.488497216257365*^9, 3.4884982796191854`*^9, {
    3.4884985827925262`*^9, 3.4884985838495865`*^9}, 3.488548766839347*^9, {
    3.4885546595003877`*^9, 3.48855467351919*^9}, {3.488554768972649*^9, 
    3.488554780388302*^9}, {3.4885548176644344`*^9, 3.488554834780413*^9}, 
    3.4885558246670313`*^9, {3.488555877735067*^9, 3.488555885167492*^9}, {
    3.488555925882821*^9, 3.488555968589263*^9}, {3.488556183800573*^9, 
    3.4885561926470785`*^9}, {3.4885565714927473`*^9, 3.488556578579153*^9}, {
    3.488556819261919*^9, 3.488556860995306*^9}, 3.489757221378025*^9, {
    3.4897714976971006`*^9, 3.489771499584704*^9}, {3.4899235962696867`*^9, 
    3.489923596809717*^9}, {3.4900048505124407`*^9, 3.4900048575248413`*^9}, {
    3.490004927360836*^9, 3.490004927640852*^9}, {3.4900054204690404`*^9, 
    3.49000542064305*^9}, {3.4900273743567305`*^9, 3.490027413935995*^9}, 
    3.4900274660839777`*^9, {3.4900314898301225`*^9, 3.4900314904871597`*^9}, 
    3.490031551025623*^9, {3.4900342535741997`*^9, 3.4900342782086086`*^9}, {
    3.490036273490732*^9, 3.4900362852984076`*^9}, {3.4900363603587008`*^9, 
    3.490036371115316*^9}, 3.490037162197563*^9, 3.4900403448696017`*^9, 
    3.490048845135789*^9, 3.4904418396813517`*^9, {3.4904419441003237`*^9, 
    3.490441947441515*^9}, {3.490441986359741*^9, 3.4904420592999134`*^9}, 
    3.490444327068622*^9, {3.4904444014798784`*^9, 3.4904444022399216`*^9}, 
    3.4904474676582537`*^9, 3.49044858339207*^9, 3.490450905146867*^9, 
    3.490451714886181*^9, 3.490452510791704*^9, 3.490453288249172*^9, 
    3.490464459496053*^9, {3.4904681593526726`*^9, 3.4904681643289576`*^9}, {
    3.4904682052062955`*^9, 3.4904682058513327`*^9}, 3.490531867888402*^9, {
    3.4905333015014*^9, 3.4905333019644265`*^9}, 3.4907062892196035`*^9, {
    3.490708250619789*^9, 3.4907082541179895`*^9}, {3.490712025183682*^9, 
    3.4907120313920374`*^9}, {3.4907128353390207`*^9, 3.490712841327363*^9}, 
    3.490714884718238*^9, 3.4907291944635754`*^9, 3.490729713173244*^9, {
    3.490730085218524*^9, 3.490730101265442*^9}, {3.4907306694449396`*^9, 
    3.4907306727751303`*^9}, {3.490731048785637*^9, 3.49073105373092*^9}, {
    3.4907317737701035`*^9, 3.4907318297893076`*^9}, {3.49073192354667*^9, 
    3.490731949549157*^9}, 3.490732404969206*^9, {3.490732482961667*^9, 
    3.490732520929838*^9}, {3.490732560906125*^9, 3.490732566699456*^9}, {
    3.4907951817937293`*^9, 3.4907952097603292`*^9}, 3.49079688138494*^9, 
    3.4909578135058956`*^9, {3.490966426065824*^9, 3.4909664589038815`*^9}, 
    3.4909679863493643`*^9, {3.4909682970395103`*^9, 
    3.4909683252911596`*^9}, {3.490972673956398*^9, 3.4909726987292414`*^9}, 
    3.4909728202534547`*^9, {3.490972862435929*^9, 3.4909728817019625`*^9}, {
    3.490972913073618*^9, 3.4909729566132946`*^9}, {3.490973518869482*^9, 
    3.4909735657475643`*^9}, {3.4909736125476465`*^9, 3.490973619021658*^9}, {
    3.490973703355406*^9, 3.4909737369578648`*^9}, {3.490973801963179*^9, 
    3.4909738048959846`*^9}, 3.490974014136751*^9, 3.4911489290724*^9, 
    3.491152414014719*^9, {3.4911532777726364`*^9, 3.491153287179453*^9}, {
    3.4911533826048203`*^9, 3.4911533843676233`*^9}, 3.4911608269218388`*^9, 
    3.4911610198473773`*^9, {3.4912215420326176`*^9, 3.4912215503786325`*^9}, 
    3.4912215809234858`*^9, {3.491221615103146*^9, 3.4912217052401047`*^9}, 
    3.4912220487527075`*^9, {3.4912290845968103`*^9, 
    3.4912290884968166`*^9}, {3.4912385323231597`*^9, 3.491238550410194*^9}, 
    3.491238719776881*^9, {3.4912389233205233`*^9, 3.4912389754925075`*^9}, 
    3.491241094984701*^9, 3.4912414098657107`*^9, {3.491385847243327*^9, 
    3.4913859619878902`*^9}, 3.4913859937217054`*^9, {3.491386060978552*^9, 
    3.4913860866870227`*^9}, 3.491386146561447*^9, {3.491386424457342*^9, 
    3.4913864460755787`*^9}, {3.4913864766593275`*^9, 3.49138647687934*^9}, 
    3.491397677026628*^9, 3.4913977115026884`*^9, 3.4913978076456575`*^9, 
    3.4913980532212887`*^9, {3.491398197490342*^9, 3.491398204603955*^9}, {
    3.491398273540476*^9, 3.4913983694494443`*^9}, {3.4913984869332504`*^9, 
    3.491398496948468*^9}, 3.4914136297351246`*^9, 3.4914140468859844`*^9, {
    3.491416748060483*^9, 3.4914167482264924`*^9}, 3.4914168077348957`*^9, {
    3.4916705003527727`*^9, 3.491670503035977*^9}, {3.491670536529236*^9, 
    3.4916706071469603`*^9}, {3.4916706472234306`*^9, 
    3.4916706812470903`*^9}, {3.4916708342053595`*^9, 3.491670835266161*^9}, {
    3.4916709879504294`*^9, 3.491670997248046*^9}, 3.4916710720657773`*^9, {
    3.4917362307280855`*^9, 3.491736236375295*^9}, {3.491736287652585*^9, 
    3.49173648371373*^9}, {3.4917372333262467`*^9, 3.4917372347458496`*^9}, 
    3.4917372742763186`*^9, {3.491757814102442*^9, 3.491757843992094*^9}, 
    3.491761526294041*^9}],
 StyleBox[" ",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain"],
 StyleBox["\[Phi] = 60\[Degree].",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->GrayLevel[0]],
 "\n",
 StyleBox["\n", "Subtitle",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain"],
 StyleBox["and 5) for perfectly horizontal planes, \[Phi] is measured from \
the east-west line such that the NE quadrant is positive and the SE quadrant \
is negative.", "Subtitle",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["\n", "Subtitle",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain"],
 "\n",
 StyleBox["     \tYou can read the \[OpenCurlyDoubleQuote]readme.txt\
\[CloseCurlyDoubleQuote] file for more information about this program. To \
start the program (as with all Mathematica notebooks), place the cursor \
anywhere in the cell below and either press \[OpenCurlyDoubleQuote]Shift + \
Enter\[CloseCurlyDoubleQuote] or simply press the \
\[OpenCurlyDoubleQuote]Enter\[CloseCurlyDoubleQuote] key adjacent to the \
number pad.\n     \n          This notebook includes some code for plotting \
equal area and equal angel projections that was modified from code written by \
Joshua R. Davis. \n          \n           \[OpenCurlyDoubleQuote]Geological \
Programs for ",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["Mathematica\[CloseCurlyDoubleQuote]",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox[" is licensed under the MIT Licence, Copyright (C) 2010--2014 Matty \
Mookerjee.",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->RGBColor[0.8, 0.043137254901960784`, 0.00784313725490196]],
 StyleBox["\n        ",
  FontFamily->"Times New Roman",
  FontSize->18,
  FontWeight->"Plain"]
}], "Title",
 CellChangeTimes->{
  3.4917614716499157`*^9, {3.4917615574568233`*^9, 3.4917615853424187`*^9}, {
   3.4917616314800577`*^9, 3.4917617411333294`*^9}, {3.4917617914002047`*^9, 
   3.491761819106789*^9}, {3.4917618524476957`*^9, 3.4917619213336363`*^9}, {
   3.4917620172371216`*^9, 3.491762028839785*^9}, {3.4917621011239195`*^9, 
   3.4917622244359727`*^9}, {3.491762641874849*^9, 3.491762662914052*^9}, {
   3.4917627301618986`*^9, 3.4917627370082903`*^9}, {3.491762842899347*^9, 
   3.491762940447926*^9}, {3.4917630387615495`*^9, 3.4917630447968946`*^9}, {
   3.4917630789628487`*^9, 3.491763276090124*^9}, {3.4917633460441246`*^9, 
   3.4917633932208233`*^9}, {3.4917634758815513`*^9, 3.491763569314895*^9}, {
   3.4917636143754725`*^9, 3.491763621594886*^9}, {3.491763696945195*^9, 
   3.4917638106997013`*^9}, {3.496273066387349*^9, 3.4962730700685596`*^9}, 
   3.4965751470772*^9, {3.4965897584788036`*^9, 3.4965898182322216`*^9}, {
   3.496589859949608*^9, 3.4965899082923727`*^9}, {3.4965899703479223`*^9, 
   3.496590039466875*^9}, {3.496590116442278*^9, 3.496590204748329*^9}, {
   3.4966078234209867`*^9, 3.4966078319614754`*^9}, {3.496607962894964*^9, 
   3.496607990430539*^9}, 3.496608321495475*^9, {3.4966085919609447`*^9, 
   3.4966086007164454`*^9}, {3.496608681365058*^9, 3.496608695300855*^9}, {
   3.4966087359201784`*^9, 3.496608862116397*^9}, {3.496608903985791*^9, 
   3.4966089553447285`*^9}, {3.4966090112649274`*^9, 3.496609125722474*^9}, {
   3.49660919820362*^9, 3.496609200408746*^9}, {3.496609328095049*^9, 
   3.496609341975843*^9}, {3.496609398300064*^9, 3.4966093992441187`*^9}, 
   3.496609435008164*^9, 3.496609482951906*^9, {3.496609568459797*^9, 
   3.4966095701598945`*^9}, 3.4966096162915325`*^9, {3.4968307194487405`*^9, 
   3.4968307820042915`*^9}, {3.4968325326709795`*^9, 3.496832539280351*^9}, {
   3.4968326815674334`*^9, 3.4968327197956204`*^9}, {3.496832749995345*^9, 
   3.496832777318908*^9}, {3.4968328130169497`*^9, 3.4968328230395217`*^9}, {
   3.4968328978147683`*^9, 3.496832935579914*^9}, 3.4968329666366825`*^9, {
   3.4968330077840357`*^9, 3.4968330328574605`*^9}, {3.4968330663233747`*^9, 
   3.4968333775300426`*^9}, {3.496938603911016*^9, 3.4969386055211077`*^9}, {
   3.4969386786712923`*^9, 3.4969386836955795`*^9}, {3.496939311156468*^9, 
   3.496939314469658*^9}, {3.496939346905513*^9, 3.4969393474845457`*^9}, {
   3.496939427847142*^9, 3.4969394284751787`*^9}, {3.4969394867675123`*^9, 
   3.496939488839631*^9}, {3.496939537498414*^9, 3.4969395926565685`*^9}, {
   3.496939815612321*^9, 3.496939816277359*^9}, {3.4969398839832315`*^9, 
   3.4969399557973394`*^9}, 3.4969400297825713`*^9, {3.496940087655881*^9, 
   3.4969401154374704`*^9}, {3.4969440150081162`*^9, 3.496944015218128*^9}, {
   3.4969622197252674`*^9, 3.4969622389243083`*^9}, {3.497133450312991*^9, 
   3.4971334821448116`*^9}, {3.497133530978605*^9, 3.4971335328977146`*^9}, {
   3.4971349163158417`*^9, 3.497134959195294*^9}, 3.4971350063889933`*^9, {
   3.497135053921712*^9, 3.4971351565745835`*^9}, {3.4971351883714027`*^9, 
   3.4971352004910955`*^9}, {3.4971352427895145`*^9, 
   3.4971352452806573`*^9}, {3.497135472832672*^9, 3.4971354911547203`*^9}, {
   3.4971355388814507`*^9, 3.4971355394224815`*^9}, {3.4971356013900256`*^9, 
   3.4971356231022673`*^9}, {3.50377854306903*^9, 3.50377855556831*^9}, {
   3.5037787530256863`*^9, 3.5037787593534465`*^9}, {3.503779473765419*^9, 
   3.503779477358962*^9}, {3.5037797825913796`*^9, 3.5037797952000284`*^9}, 
   3.5042655611991186`*^9, {3.504265675901679*^9, 3.5042656886374073`*^9}, {
   3.504270853482152*^9, 3.5042708589314637`*^9}, {3.5176705503127556`*^9, 
   3.5176705504687557`*^9}, 3.5179591222719207`*^9, {3.5193920185919447`*^9, 
   3.5193920270524282`*^9}, {3.519518056199721*^9, 3.519518090756697*^9}, 
   3.522014768434239*^9, {3.5477190375469685`*^9, 3.5477190407269735`*^9}, {
   3.5479357439343667`*^9, 3.5479357843184233`*^9}, 3.547980359552384*^9, 
   3.547980436474492*^9, 3.547987881521325*^9, 3.6114999213508472`*^9, {
   3.6114999521386085`*^9, 3.6115000047916203`*^9}, {3.6458058347279916`*^9, 
   3.6458058347279916`*^9}},
 TextAlignment->Left],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "\"\<Precise\>\"", " ", "is", " ", "the", " ", "working", " ", "precision",
     " ", "used", " ", "by", " ", "Mathematica", " ", "in", " ", "its", " ", 
    "FindMinimum", " ", 
    RowBox[{"function", ".", "  ", "To"}], " ", "use", " ", "the", " ", 
    "default", " ", "value", " ", "of", " ", "working", " ", "precision", " ", 
    RowBox[{"(", "recommended", ")"}], " ", "keep", " ", "\"\<Precise\>\"", 
    " ", "equal", " ", "to", " ", 
    RowBox[{"zero", "."}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Precise", "=", "0"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "\"\<Flinncontinterval\>\"", " ", "is", " ", "the", " ", "octahedral", " ",
     "shear", " ", "strain", " ", "contour", " ", "interval", " ", "for", " ",
     "the", " ", "Flinn", " ", "diagram"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Flinncontinterval", "=", ".25"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "\"\<Flinncolor\>\"", " ", "is", " ", "the", " ", "color", " ", "of", " ", 
    "the", " ", "point", " ", "for", " ", "the", " ", "Flinn", " ", 
    "diagram"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Flinncolor", "=", 
    RowBox[{"CMYKColor", "[", 
     RowBox[{"0", ",", "1", ",", "1", ",", ".25"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "\"\<FlinnPtSize\>\"", " ", "is", " ", "the", " ", "size", " ", "of", " ", 
    "the", " ", "point", " ", "for", " ", "the", " ", "Flinn", " ", 
    "diagram"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FlinnPtSize", "=", "0.02"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "\"\<continterval\>\"", " ", "is", " ", "the", " ", "octahedral", " ", 
    "shear", " ", "strain", " ", "contour", " ", "interval", " ", "for", " ", 
    "the", " ", "Hsu", " ", "diagram"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"continterval", "=", "0.1"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "\"\<PtSize\>\"", " ", "is", " ", "the", " ", "size", " ", "of", " ", 
    "the", " ", "point", " ", "for", " ", "the", " ", "Hsu", " ", "diagram"}],
    " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PtSize", "=", "0.02"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "\"\<color\>\"", " ", "is", " ", "the", " ", "color", " ", "of", " ", 
    "the", " ", "point", " ", "for", " ", "the", " ", "Hsu", " ", "diagram"}],
    " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"color", "=", 
    RowBox[{"CMYKColor", "[", 
     RowBox[{"0", ",", "1", ",", "1", ",", ".25"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "\"\<kcont[x]\>\"", " ", "specifies", " ", "the", " ", "values", " ", 
     "for", " ", "the", " ", "Flinn", " ", "k", " ", 
     RowBox[{"contours", ".", "  ", "You"}], " ", "can", " ", "add", " ", 
     "additional", " ", "contours", " ", "by", " ", "typing", " ", "in", " ", 
     "addtional", " ", "values"}], ",", " ", 
    RowBox[{"e", ".", "g", "."}], ",", " ", 
    RowBox[{"\"\<kcont[9]=1000;\>\"", "."}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"kcont", "[", "1", "]"}], "=", "10"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"kcont", "[", "2", "]"}], "=", "5"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"kcont", "[", "3", "]"}], "=", "2"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"kcont", "[", "4", "]"}], "=", "1"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"kcont", "[", "5", "]"}], "=", "0.75"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"kcont", "[", "6", "]"}], "=", "0.5"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"kcont", "[", "7", "]"}], "=", "0.25"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"kcont", "[", "8", "]"}], "=", "0.1"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "obspkg"}], "]"}], 
  "MessageName"], "\[IndentingNewLine]", 
 RowBox[{"Off", "[", 
  RowBox[{"Power", "::", "infy"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Off", "[", 
  StyleBox[
   RowBox[{"Solve", "::", "ratnz"}], "MessageName"], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FileorManual", "=", 
    RowBox[{
    "Input", "[", 
     "\"\<Do you want to enter your data manually (m) or do you want to \
import a file (f)?  Enter 'm' or 'f' accordingly.\>\"", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"FileorManual", "\[Equal]", "f"}], ",", 
     RowBox[{"FOM", "=", "1"}]}], "]"}], ";", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"FileorManual", "\[Equal]", "m"}], ",", 
     RowBox[{"FOM", "=", "0"}]}], "]"}], ";", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"FOM", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"FN", "=", 
       RowBox[{
       "Input", "[", 
        "\"\<Enter the name of the data file to be opened. Enclose the entire \
file name (include the file extension) in quotations marks.\>\"", "]"}]}], 
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"FF", "=", 
       RowBox[{"FileFormat", "[", "FN", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"FF", "\[Equal]", "\"\<XLS\>\""}], "||", 
         RowBox[{"FF", "==", "\"\<XLSX\>\""}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"things", "=", 
          RowBox[{"Import", "[", "FN", "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"numbplanes", "=", 
          RowBox[{"Round", "[", 
           RowBox[{"things", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "1", ",", "3"}], "]"}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Tot", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "things", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"count", "=", "1"}], ";", "\[IndentingNewLine]", 
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"count", "\[LessEqual]", "Tot"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"things", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "count", ",", "1"}], "]"}], "]"}], 
               "\[Equal]", "\"\<\>\""}], ",", 
              RowBox[{
               RowBox[{"Break", "[", "]"}], ";"}]}], "]"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"count", "=", 
             RowBox[{"count", "+", "1"}]}], ";"}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Tot", "=", 
          RowBox[{"count", "-", "1"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"sectposition", "[", "1", "]"}], "=", "1"}], ";", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"ct", "<", "numbplanes"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"sectposition", "[", 
              RowBox[{"ct", "+", "1"}], "]"}], "=", 
             RowBox[{
              RowBox[{"Position", "[", 
               RowBox[{"things", ",", 
                RowBox[{"\"\<Section #\>\"", "<>", 
                 RowBox[{"ToString", "[", 
                  RowBox[{"ct", "+", "1"}], "]"}]}]}], "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"ct", "=", 
             RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"Dip", "[", "ct", "]"}], "=", 
             RowBox[{"things", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", 
                RowBox[{
                 RowBox[{"sectposition", "[", "ct", "]"}], "+", "2"}], ",", 
                "1"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"DipDir", "[", "ct", "]"}], "=", 
             RowBox[{"things", "[", 
              RowBox[{"[", 
               RowBox[{"1", ",", 
                RowBox[{
                 RowBox[{"sectposition", "[", "ct", "]"}], "+", "2"}], ",", 
                "2"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"ct", "=", 
             RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"numbdata", "[", "ct", "]"}], "=", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"ct", "<", "numbplanes"}], ",", 
               RowBox[{
                RowBox[{"sectposition", "[", 
                 RowBox[{"ct", "+", "1"}], "]"}], "-", 
                RowBox[{"sectposition", "[", "ct", "]"}], "-", "4"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"Tot", "-", 
                RowBox[{"sectposition", "[", "ct", "]"}], "-", "3"}]}], 
              "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"ct", "=", 
             RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"ct2", "=", "1"}], ";", "\[IndentingNewLine]", 
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{"ct2", "\[LessEqual]", 
               RowBox[{"numbdata", "[", "ct", "]"}]}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"Major", "[", 
                 RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                RowBox[{"things", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", 
                   RowBox[{
                    RowBox[{"sectposition", "[", "ct", "]"}], "+", "3", "+", 
                    "ct2"}], ",", "1"}], "]"}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"Minor", "[", 
                 RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                RowBox[{"things", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", 
                   RowBox[{
                    RowBox[{"sectposition", "[", "ct", "]"}], "+", "3", "+", 
                    "ct2"}], ",", "2"}], "]"}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"Rf", "[", 
                 RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                FractionBox[
                 RowBox[{"Major", "[", 
                  RowBox[{"ct", ",", "ct2"}], "]"}], 
                 RowBox[{"Minor", "[", 
                  RowBox[{"ct", ",", "ct2"}], "]"}]]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"TempPhiAngle", "[", 
                 RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                RowBox[{"things", "[", 
                 RowBox[{"[", 
                  RowBox[{"1", ",", 
                   RowBox[{
                    RowBox[{"sectposition", "[", "ct", "]"}], "+", "3", "+", 
                    "ct2"}], ",", "3"}], "]"}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"PhiAngle", "[", 
                 RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"TempPhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], ">", "90"}], ",", 
                  RowBox[{
                   RowBox[{"TempPhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], "-", "180"}], ",", 
                  RowBox[{"TempPhiAngle", "[", 
                   RowBox[{"ct", ",", "ct2"}], "]"}]}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"ct2", "=", 
                RowBox[{"ct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"ct", "=", 
             RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}]}], "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"FF", "\[Equal]", "\"\<Text\>\""}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"things", "=", 
          RowBox[{"OpenRead", "[", "FN", "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"Skip", "[", 
          RowBox[{"things", ",", "Word", ",", "3"}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"numbplanes", "=", 
          RowBox[{"Read", "[", 
           RowBox[{"things", ",", "Number"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Tabby2", "=", 
          RowBox[{"ReadList", "[", 
           RowBox[{"FN", ",", "Word"}], "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"Tot", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "Tabby2", "]"}], "\[LeftDoubleBracket]",
            "1", "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"sectposition", "[", "1", "]"}], "=", "4"}], ";", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"ct", "<", "numbplanes"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"sectposition", "[", 
              RowBox[{"ct", "+", "1"}], "]"}], "=", 
             RowBox[{
              RowBox[{
               RowBox[{"Position", "[", 
                RowBox[{"Tabby2", ",", 
                 RowBox[{"\"\<#\>\"", "<>", 
                  RowBox[{"ToString", "[", 
                   RowBox[{"ct", "+", "1"}], "]"}]}]}], "]"}], 
               "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
              "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"ct", "=", 
             RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", 
         RowBox[{
          RowBox[{"sectposition", "[", 
           RowBox[{"ct", "+", "1"}], "]"}], "=", 
          RowBox[{"Tot", "+", "2"}]}], ";", "\[IndentingNewLine]", 
         "\[IndentingNewLine]", 
         RowBox[{"ct", "=", "1"}], ";", 
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"stuff", "=", 
             RowBox[{"OpenRead", "[", "FN", "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"Skip", "[", 
             RowBox[{"stuff", ",", "Word", ",", 
              RowBox[{
               RowBox[{"sectposition", "[", "ct", "]"}], "+", "3"}]}], "]"}], 
            ";", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Dip", "[", "ct", "]"}], "=", 
             RowBox[{"Read", "[", 
              RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"DipDir", "[", "ct", "]"}], "=", 
             RowBox[{"Read", "[", 
              RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"ct", "=", 
             RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"numbsub", "[", "0", "]"}], "=", "16"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"numbdata", "[", "0", "]"}], "=", "0"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"numbdata", "[", "ct", "]"}], "=", 
             RowBox[{
              FractionBox["1", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"sectposition", "[", 
                 RowBox[{"ct", "+", "1"}], "]"}], "-", 
                RowBox[{"numbsub", "[", 
                 RowBox[{"ct", "-", "1"}], "]"}], "-", 
                RowBox[{"3", " ", 
                 RowBox[{"numbdata", "[", 
                  RowBox[{"ct", "-", "1"}], "]"}]}]}], ")"}]}]}], ";", 
            RowBox[{
             RowBox[{"numbsub", "[", "ct", "]"}], "=", 
             RowBox[{
              RowBox[{"sectposition", "[", 
               RowBox[{"ct", "+", "1"}], "]"}], "+", "12", "-", 
              RowBox[{"3", " ", 
               RowBox[{"numbdata", "[", "ct", "]"}]}]}]}], ";", 
            RowBox[{"ct", "=", 
             RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"ct", "=", "1"}], ";", 
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"stuff", "=", 
             RowBox[{"OpenRead", "[", "FN", "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"Skip", "[", 
             RowBox[{"stuff", ",", "Word", ",", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"ct", "\[Equal]", "1"}], ",", "14", ",", 
                RowBox[{
                 RowBox[{"sectposition", "[", "ct", "]"}], "+", "10"}]}], 
               "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
            RowBox[{"ct2", "=", "1"}], ";", "\[IndentingNewLine]", 
            RowBox[{"While", "[", 
             RowBox[{
              RowBox[{"ct2", "\[LessEqual]", 
               RowBox[{"numbdata", "[", "ct", "]"}]}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"Major", "[", 
                 RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                RowBox[{"Read", "[", 
                 RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"Minor", "[", 
                 RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                RowBox[{"Read", "[", 
                 RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"Rf", "[", 
                 RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                FractionBox[
                 RowBox[{"Major", "[", 
                  RowBox[{"ct", ",", "ct2"}], "]"}], 
                 RowBox[{"Minor", "[", 
                  RowBox[{"ct", ",", "ct2"}], "]"}]]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"TempPhiAngle", "[", 
                 RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                RowBox[{"Read", "[", 
                 RowBox[{"stuff", ",", "Number"}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"PhiAngle", "[", 
                 RowBox[{"ct", ",", "ct2"}], "]"}], "=", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"TempPhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], ">", "90"}], ",", 
                  RowBox[{
                   RowBox[{"TempPhiAngle", "[", 
                    RowBox[{"ct", ",", "ct2"}], "]"}], "-", "180"}], ",", 
                  RowBox[{"TempPhiAngle", "[", 
                   RowBox[{"ct", ",", "ct2"}], "]"}]}], "]"}]}], ";", 
               "\[IndentingNewLine]", 
               RowBox[{"ct2", "=", 
                RowBox[{"ct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"ct", "=", 
             RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}]}], "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"ct1", "=", "1"}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"ct1", "\[LessEqual]", "numbplanes"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"ct2", "=", "1"}], ";", "\[IndentingNewLine]", 
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"ct2", "\[LessEqual]", 
            RowBox[{"numbdata", "[", "ct1", "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"phi", "=", 
             RowBox[{
              FractionBox["1", "180"], " ", 
              RowBox[{"PhiAngle", "[", 
               RowBox[{"ct1", ",", "ct2"}], "]"}], " ", "\[Pi]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"Elle1", "=", 
             RowBox[{"1", "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Major", "[", 
                 RowBox[{"ct1", ",", "ct2"}], "]"}], "^", "2"}], ")"}]}]}], 
            ";", "\[IndentingNewLine]", 
            RowBox[{"Elle2", "=", 
             RowBox[{"1", "/", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Minor", "[", 
                 RowBox[{"ct1", ",", "ct2"}], "]"}], "^", "2"}], ")"}]}]}], 
            ";", "\[IndentingNewLine]", 
            RowBox[{"PrinMat", "=", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"Elle1", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "Elle2"}], "}"}]}], "}"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"RotMat", "=", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Cos", "[", "phi", "]"}], ",", 
                 RowBox[{"Sin", "[", "phi", "]"}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"Sin", "[", "phi", "]"}]}], ",", 
                 RowBox[{"Cos", "[", "phi", "]"}]}], "}"}]}], "}"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"EllipMat", "[", 
              RowBox[{"ct1", ",", "ct2"}], "]"}], "=", 
             RowBox[{
              RowBox[{"Transpose", "[", "RotMat", "]"}], ".", "PrinMat", ".", 
              "RotMat"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"ct2", "=", 
             RowBox[{"ct2", "+", "1"}]}], ";"}]}], "]"}], ";", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"AvgMat", "[", "ct1", "]"}], "=", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              FractionBox[
               RowBox[{
                UnderoverscriptBox["\[Sum]", 
                 RowBox[{"x", "=", "1"}], 
                 RowBox[{"numbdata", "[", "ct1", "]"}]], 
                RowBox[{
                 RowBox[{"EllipMat", "[", 
                  RowBox[{"ct1", ",", "x"}], "]"}], "\[LeftDoubleBracket]", 
                 RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], 
               RowBox[{"numbdata", "[", "ct1", "]"}]], ",", 
              FractionBox[
               RowBox[{
                UnderoverscriptBox["\[Sum]", 
                 RowBox[{"x", "=", "1"}], 
                 RowBox[{"numbdata", "[", "ct1", "]"}]], 
                RowBox[{
                 RowBox[{"EllipMat", "[", 
                  RowBox[{"ct1", ",", "x"}], "]"}], "\[LeftDoubleBracket]", 
                 RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], 
               RowBox[{"numbdata", "[", "ct1", "]"}]]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              FractionBox[
               RowBox[{
                UnderoverscriptBox["\[Sum]", 
                 RowBox[{"x", "=", "1"}], 
                 RowBox[{"numbdata", "[", "ct1", "]"}]], 
                RowBox[{
                 RowBox[{"EllipMat", "[", 
                  RowBox[{"ct1", ",", "x"}], "]"}], "\[LeftDoubleBracket]", 
                 RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], 
               RowBox[{"numbdata", "[", "ct1", "]"}]], ",", 
              FractionBox[
               RowBox[{
                UnderoverscriptBox["\[Sum]", 
                 RowBox[{"x", "=", "1"}], 
                 RowBox[{"numbdata", "[", "ct1", "]"}]], 
                RowBox[{
                 RowBox[{"EllipMat", "[", 
                  RowBox[{"ct1", ",", "x"}], "]"}], "\[LeftDoubleBracket]", 
                 RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], 
               RowBox[{"numbdata", "[", "ct1", "]"}]]}], "}"}]}], "}"}]}], 
         ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"Eigval", "=", 
          RowBox[{"1", "/", 
           RowBox[{"Sqrt", "[", 
            RowBox[{"Eigenvalues", "[", 
             RowBox[{"AvgMat", "[", "ct1", "]"}], "]"}], "]"}]}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Eigvect", "=", 
          RowBox[{"Eigenvectors", "[", 
           RowBox[{"AvgMat", "[", "ct1", "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"T", "=", 
          RowBox[{"Eigensystem", "[", 
           RowBox[{"AvgMat", "[", "ct1", "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Tevl", "=", 
          RowBox[{"Sort", "[", 
           RowBox[{"Eigval", ",", "Greater"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
            "Tevl", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "\[Equal]", 
            RowBox[{
            "Eigval", "\[LeftDoubleBracket]", "1", 
             "\[RightDoubleBracket]"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"Tevect", "=", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"T", "\[LeftDoubleBracket]", 
               RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
              RowBox[{"T", "\[LeftDoubleBracket]", 
               RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], "}"}]}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"Tevect", "=", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"T", "\[LeftDoubleBracket]", 
               RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
              RowBox[{"T", "\[LeftDoubleBracket]", 
               RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], 
             "}"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Tevect", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "\[Equal]", 
            "0"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"\[CapitalTheta]", "=", 
             FractionBox["\[Pi]", "2"]}], ";"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"\[CapitalTheta]", "=", 
             RowBox[{"ArcTan", "[", 
              FractionBox[
               RowBox[{"Tevect", "\[LeftDoubleBracket]", 
                RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], 
               RowBox[{"Tevect", "\[LeftDoubleBracket]", 
                RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]], "]"}]}], 
            ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"\[CapitalPi]", "[", "ct1", "]"}], "=", 
          FractionBox[
           RowBox[{
           "Tevl", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
           RowBox[{
           "Tevl", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"\[CapitalPsi]", "[", "ct1", "]"}], "=", 
          "\[CapitalTheta]"}], ";", "\[IndentingNewLine]", 
         RowBox[{"ct1", "=", 
          RowBox[{"ct1", "+", "1"}]}], ";"}]}], "]"}], ";"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"numbplanes", "=", 
       RowBox[{
       "Input", "[", 
        "\"\<Enter the number of planes from which you have elliptical \
data.\>\"", "]"}]}], ";", 
      RowBox[{"ct", "=", "1"}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"Dip", "[", "ct", "]"}], "=", 
          RowBox[{"Input", "[", 
           RowBox[{"\"\<\>\"", " ", 
            RowBox[{"N", "[", "ct", "]"}], " ", 
            "\"\<Enter the Dip of plane.\>\""}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"DipDir", "[", "ct", "]"}], "=", 
          RowBox[{"Input", "[", 
           RowBox[{"\"\<\>\"", " ", 
            RowBox[{"N", "[", "ct", "]"}], " ", 
            "\"\<Enter the Dip Direction of plane.\>\""}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Major", "[", "ct", "]"}], "=", 
          RowBox[{"Input", "[", 
           RowBox[{"\"\<\>\"", " ", 
            RowBox[{"N", "[", "ct", "]"}], " ", 
            "\"\<Enter the Length of the Long Axis.\>\""}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Minor", "[", "ct", "]"}], "=", 
          RowBox[{"Input", "[", 
           RowBox[{"\"\<\>\"", " ", 
            RowBox[{"N", "[", "ct", "]"}], " ", 
            "\"\<Enter the Length of the Short Axis.\>\""}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"\[CapitalPi]", "[", "ct", "]"}], "=", 
          RowBox[{
           RowBox[{"Major", "[", "ct", "]"}], "/", 
           RowBox[{"Minor", "[", "ct", "]"}]}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"TempFee", "[", "ct", "]"}], "=", 
          RowBox[{"Input", "[", 
           RowBox[{"\"\<\>\"", " ", 
            RowBox[{"N", "[", "ct", "]"}], " ", 
            "\"\<Enter the Angular Orientation, (\[Phi]).\>\""}], "]"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Fee", "[", "ct", "]"}], "=", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"TempFee", "[", "ct", "]"}], ">", "90"}], ",", 
            RowBox[{
             RowBox[{"TempFee", "[", "ct", "]"}], "-", "180"}], ",", 
            RowBox[{"TempFee", "[", "ct", "]"}]}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"\[CapitalPsi]", "[", "ct", "]"}], "=", 
          RowBox[{
           FractionBox["1", "180"], " ", 
           RowBox[{"Fee", "[", "ct", "]"}], " ", "\[Pi]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Elle1", "=", 
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Major", "[", "ct", "]"}], "^", "2"}], ")"}]}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Elle2", "=", 
          RowBox[{"1", "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Minor", "[", "ct", "]"}], "^", "2"}], ")"}]}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"PrinMat", "=", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"Elle1", ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "Elle2"}], "}"}]}], "}"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"RotMat", "=", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"\[CapitalPsi]", "[", "ct", "]"}], "]"}], ",", 
              RowBox[{"Sin", "[", 
               RowBox[{"\[CapitalPsi]", "[", "ct", "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"Sin", "[", 
                RowBox[{"\[CapitalPsi]", "[", "ct", "]"}], "]"}]}], ",", 
              RowBox[{"Cos", "[", 
               RowBox[{"\[CapitalPsi]", "[", "ct", "]"}], "]"}]}], "}"}]}], 
           "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"AvgMat", "[", "ct", "]"}], "=", 
          RowBox[{
           RowBox[{"Transpose", "[", "RotMat", "]"}], ".", "PrinMat", ".", 
           "RotMat"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"ct", "=", 
          RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"GeneralEllipsoid", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Lambda]1", ",", "\[Gamma]3", ",", "\[Gamma]2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]3", ",", "\[Lambda]2", ",", "\[Gamma]1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Gamma]2", ",", "\[Gamma]1", ",", "\[Lambda]3"}], "}"}]}], 
     "}"}]}], ";"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"dummy", "=", "1"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"ErrorIndex", "[", "0", "]"}], "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"While", "[", 
    RowBox[{
     RowBox[{"dummy", "\[LessEqual]", "numbplanes"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"OriginalDipDir", "[", "dummy", "]"}], "=", 
       RowBox[{"DipDir", "[", "dummy", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"DipDir", "[", "dummy", "]"}], "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Dip", "[", "dummy", "]"}], "\[Equal]", "90"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"DipDir", "[", "dummy", "]"}], "\[Equal]", "0"}], ",", 
           "180", ",", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"DipDir", "[", "dummy", "]"}], ">", "180"}], ",", 
             RowBox[{
              RowBox[{"DipDir", "[", "dummy", "]"}], "-", "180"}], ",", 
             RowBox[{"DipDir", "[", "dummy", "]"}]}], "]"}]}], "]"}], ",", 
         RowBox[{"DipDir", "[", "dummy", "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"f", "=", 
       RowBox[{
        RowBox[{"DipDir", "[", "dummy", "]"}], "-", "90"}]}], ";", 
      RowBox[{"j", "=", 
       RowBox[{"90", "-", 
        RowBox[{"Dip", "[", "dummy", "]"}]}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Dip", "[", "dummy", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{"f", "=", "90"}]}], "]"}], ";", 
      RowBox[{"\[Mu]", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}], ",", 
           RowBox[{"Sin", "[", 
            FractionBox[
             RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}], ",", "0"}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Sin", "[", 
             FractionBox[
              RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}]}], ",", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}], ",", "0"}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
      RowBox[{"H", "=", 
       RowBox[{
        RowBox[{"Transpose", "[", "\[Mu]", "]"}], ".", "GeneralEllipsoid", 
        ".", "\[Mu]"}]}], ";", 
      RowBox[{"\[Eta]", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}], ",", 
           RowBox[{"Sin", "[", 
            FractionBox[
             RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"-", 
            RowBox[{"Sin", "[", 
             FractionBox[
              RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}]}], ",", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}]}], "}"}]}], "}"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"Q", "=", 
       RowBox[{
        RowBox[{"Transpose", "[", "\[Eta]", "]"}], ".", "H", ".", 
        "\[Eta]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"TempMatEll", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Q", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Q", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Q", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Q", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], "}"}]}], 
        "}"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"SectionEllipse", "[", "dummy", "]"}], "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"TempMatEll", "\[LeftDoubleBracket]", 
            RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], "}"}]}], 
        "}"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"EllipMat", "[", "dummy", "]"}], "=", 
       RowBox[{"AvgMat", "[", "dummy", "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ErrorIndex", "[", "dummy", "]"}], "=", 
       RowBox[{
        RowBox[{"ErrorIndex", "[", 
         RowBox[{"dummy", "-", "1"}], "]"}], "+", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"EllipMat", "[", "dummy", "]"}], "\[LeftDoubleBracket]", 
              RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "-", 
             RowBox[{
              RowBox[{"SectionEllipse", "[", "dummy", "]"}], 
              "\[LeftDoubleBracket]", 
              RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ")"}], 
           "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"EllipMat", "[", "dummy", "]"}], "\[LeftDoubleBracket]", 
              RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
             RowBox[{
              RowBox[{"SectionEllipse", "[", "dummy", "]"}], 
              "\[LeftDoubleBracket]", 
              RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], ")"}], 
           "2"], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"EllipMat", "[", "dummy", "]"}], "\[LeftDoubleBracket]", 
              RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
             RowBox[{
              RowBox[{"SectionEllipse", "[", "dummy", "]"}], 
              "\[LeftDoubleBracket]", 
              RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], ")"}], 
           "2"]}], ")"}]}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"MD", "[", "dummy", "]"}], "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Abs", "[", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"EllipMat", "[", "dummy", "]"}], "\[LeftDoubleBracket]", 
              RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "-", 
             RowBox[{
              RowBox[{"SectionEllipse", "[", "dummy", "]"}], 
              "\[LeftDoubleBracket]", 
              RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ")"}], 
           "]"}], "+", 
          RowBox[{"Abs", "[", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"EllipMat", "[", "dummy", "]"}], "\[LeftDoubleBracket]", 
              RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
             RowBox[{
              RowBox[{"SectionEllipse", "[", "dummy", "]"}], 
              "\[LeftDoubleBracket]", 
              RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}], ")"}], 
           "]"}], "+", 
          RowBox[{"Abs", "[", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"EllipMat", "[", "dummy", "]"}], "\[LeftDoubleBracket]", 
              RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], "-", 
             RowBox[{
              RowBox[{"SectionEllipse", "[", "dummy", "]"}], 
              "\[LeftDoubleBracket]", 
              RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], ")"}], 
           "]"}]}], ")"}], "/", "3"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"dummy", "=", 
       RowBox[{"dummy", "+", "1"}]}], ";"}]}], "]"}], ";"}], "\n"}], "\n", 
 RowBox[{"Off", "[", 
  RowBox[{"FindMinimum", "::", "precw"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mycons", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "-", "\[Lambda]1", "-", "\[Lambda]3"}], ")"}], 
       "\[LessEqual]", "0"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"\[Gamma]1", "^", "2"}]}], "-", 
         RowBox[{"\[Gamma]2", "^", "2"}], "-", 
         RowBox[{"\[Gamma]3", "^", "2"}], "+", "\[Lambda]1", "+", 
         "\[Lambda]3", "+", 
         RowBox[{"\[Lambda]1", " ", "\[Lambda]3"}]}], ")"}], 
       "\[GreaterEqual]", "0"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Gamma]2", "^", "2"}], "-", 
        RowBox[{"2", " ", "\[Gamma]1", " ", "\[Gamma]2", " ", "\[Gamma]3"}], 
        "+", 
        RowBox[{
         RowBox[{"\[Gamma]1", "^", "2"}], " ", "\[Lambda]1"}], "+", 
        RowBox[{
         RowBox[{"\[Gamma]3", "^", "2"}], " ", "\[Lambda]3"}], "-", 
        RowBox[{"\[Lambda]1", " ", "\[Lambda]3"}]}], "\[LessEqual]", "0"}]}], 
     "}"}]}], ";"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e", ",", "g"}], "]"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"stepsize", "=", ".1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Lamda1max", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Lamda3max", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"init\[Lambda]1", "=", ".01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"counter", "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"While", "[", 
   RowBox[{
    RowBox[{"init\[Lambda]1", "\[LessEqual]", "Lamda1max"}], ",", "\n", 
    RowBox[{
     RowBox[{"init\[Lambda]3", "=", ".01"}], ";", "\n", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"init\[Lambda]3", "\[LessEqual]", "Lamda3max"}], ",", "\n", 
       RowBox[{
        RowBox[{"Quiet", "[", 
         RowBox[{
          RowBox[{"FindMinimum", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], ",", "mycons"}],
              "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Lambda]2", ",", "1"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
            RowBox[{"Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}]}], 
           "]"}], ";", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "$MessageList", "]"}], "\[Equal]", "0"}], 
            ",", 
            RowBox[{"Break", "[", "]"}]}], "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"init\[Lambda]3", "=", 
         RowBox[{"init\[Lambda]3", "+", "stepsize"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"counter", "=", 
         RowBox[{"counter", "+", "1"}]}], ";"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Quiet", "[", 
      RowBox[{
       RowBox[{"FindMinimum", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], ",", "mycons"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Lambda]2", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
         RowBox[{"Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}]}], "]"}],
        ";", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Length", "[", "$MessageList", "]"}], "\[Equal]", "0"}], 
         ",", 
         RowBox[{"Break", "[", "]"}]}], "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"init\[Lambda]1", "=", 
      RowBox[{"init\[Lambda]1", "+", "stepsize"}]}], ";"}]}], "]"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"reducedprecision", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"Precise", "\[Equal]", "0"}], ",", "\n", 
     RowBox[{
      RowBox[{"absolute", "=", 
       RowBox[{"FindMinimum", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], ",", "mycons"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Lambda]2", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
         RowBox[{"Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}]}], 
        "]"}]}], ";"}], ",", 
     RowBox[{
      RowBox[{"Quiet", "[", 
       RowBox[{
        RowBox[{"FindMinimum", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], ",", "mycons"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Lambda]2", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
          RowBox[{"Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}], ",", 
          RowBox[{"WorkingPrecision", "\[Rule]", "Precise"}]}], "]"}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", "$MessageList", "]"}], "\[Equal]", "0"}], 
          ",", 
          RowBox[{
           RowBox[{"absolute", "=", 
            RowBox[{"FindMinimum", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], ",", 
                "mycons"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Lambda]2", ",", "1"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
              RowBox[{"Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}], 
              ",", 
              RowBox[{"WorkingPrecision", "\[Rule]", "Precise"}]}], "]"}]}], 
           ";"}], ",", 
          RowBox[{
           RowBox[{"reducedprecision", "=", "1"}], ";", 
           RowBox[{
            RowBox[{"{", "absolute", "}"}], "=", 
            RowBox[{"FindMinimum", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], ",", 
                "mycons"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Lambda]2", ",", "1"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
              RowBox[{"Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}]}], 
             "]"}]}], ";"}]}], "]"}], ";"}], "]"}], ";"}]}], "]"}], ";"}], 
  "\n", "\n"}], "\n", 
 RowBox[{
  RowBox[{"\[Lambda]1", "=", 
   RowBox[{"absolute", "[", 
    RowBox[{"[", 
     RowBox[{"2", ",", "1", ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]2", "=", 
   RowBox[{"absolute", "[", 
    RowBox[{"[", 
     RowBox[{"2", ",", "2", ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Lambda]3", "=", 
   RowBox[{"absolute", "[", 
    RowBox[{"[", 
     RowBox[{"2", ",", "3", ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Gamma]1", "=", 
   RowBox[{"absolute", "[", 
    RowBox[{"[", 
     RowBox[{"2", ",", "4", ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Gamma]2", "=", 
   RowBox[{"absolute", "[", 
    RowBox[{"[", 
     RowBox[{"2", ",", "5", ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Gamma]3", "=", 
   RowBox[{"absolute", "[", 
    RowBox[{"[", 
     RowBox[{"2", ",", "6", ",", "2"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Gerror", "=", 
    FractionBox[
     RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], "numbplanes"]}], ";"}], 
  "\n"}], "\n", 
 RowBox[{
  RowBox[{"FitEllipsoid", "=", 
   RowBox[{"N", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Lambda]1", ",", "\[Gamma]3", ",", "\[Gamma]2"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"\[Gamma]3", ",", "\[Lambda]2", ",", "\[Gamma]1"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"\[Gamma]2", ",", "\[Gamma]1", ",", "\[Lambda]3"}], "}"}]}], 
      "}"}], ",", "6"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"S", "=", 
   RowBox[{"Eigensystem", "[", "FitEllipsoid", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"M", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"Eigenvectors", "[", "FitEllipsoid", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"L", "=", 
   RowBox[{"Eigenvalues", "[", "FitEllipsoid", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Sort", "[", 
    RowBox[{
     RowBox[{"Abs", "[", "L", "]"}], ",", "Greater"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rat", "=", 
    RowBox[{
     SqrtBox[
      RowBox[{"test", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]],
      "/", 
     SqrtBox[
      RowBox[{
      "test", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]]}]}], 
   ";"}], "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"rat", ">", "10"}], ",", 
     RowBox[{
      RowBox[{"Quiet", "[", 
       RowBox[{
        RowBox[{"FindMinimum", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], ",", "mycons"}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Lambda]2", ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
          RowBox[{"Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}], ",", 
          RowBox[{"WorkingPrecision", "\[Rule]", "40"}]}], "]"}], ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", "$MessageList", "]"}], "\[Equal]", "0"}], 
          ",", 
          RowBox[{
           RowBox[{"absolute", "=", 
            RowBox[{"FindMinimum", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], ",", 
                "mycons"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Lambda]2", ",", "1"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
              RowBox[{"Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}], 
              ",", 
              RowBox[{"WorkingPrecision", "\[Rule]", "40"}]}], "]"}]}], ";"}],
           ",", 
          RowBox[{
           RowBox[{"absolute", "=", 
            RowBox[{"FindMinimum", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], ",", 
                "mycons"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Lambda]1", ",", "init\[Lambda]1"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Lambda]2", ",", "1"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Lambda]3", ",", "init\[Lambda]3"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Gamma]1", ",", "0.0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Gamma]2", ",", "0.0"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Gamma]3", ",", "0.0"}], "}"}], ",", 
              RowBox[{"Gradient", "\[Rule]", "\"\<FiniteDifference\>\""}]}], 
             "]"}]}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"\[Lambda]1", "=", 
         RowBox[{"absolute", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "1", ",", "2"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Lambda]2", "=", 
         RowBox[{"absolute", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "2", ",", "2"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Lambda]3", "=", 
         RowBox[{"absolute", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "3", ",", "2"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Gamma]1", "=", 
         RowBox[{"absolute", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "4", ",", "2"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Gamma]2", "=", 
         RowBox[{"absolute", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "5", ",", "2"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Gamma]3", "=", 
         RowBox[{"absolute", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "6", ",", "2"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"absolute", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "=", 
         FractionBox[
          RowBox[{"ErrorIndex", "[", "numbplanes", "]"}], "numbplanes"]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"FitEllipsoid", "=", 
         RowBox[{"N", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"\[Lambda]1", ",", "\[Gamma]3", ",", "\[Gamma]2"}], 
              "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Gamma]3", ",", "\[Lambda]2", ",", "\[Gamma]1"}], 
              "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Gamma]2", ",", "\[Gamma]1", ",", "\[Lambda]3"}], 
              "}"}]}], "}"}], ",", "6"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"S", "=", 
         RowBox[{"Eigensystem", "[", "FitEllipsoid", "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"M", "=", 
         RowBox[{"Transpose", "[", 
          RowBox[{"Eigenvectors", "[", "FitEllipsoid", "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"L", "=", 
         RowBox[{"Eigenvalues", "[", "FitEllipsoid", "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"test", "=", 
         RowBox[{"Sort", "[", 
          RowBox[{
           RowBox[{"Abs", "[", "L", "]"}], ",", "Greater"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"rat", "=", 
         RowBox[{
          SqrtBox[
           RowBox[{
           "test", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]], 
          "/", 
          SqrtBox[
           RowBox[{
           "test", "\[LeftDoubleBracket]", "3", 
            "\[RightDoubleBracket]"}]]}]}], ";"}], "]"}], ";"}]}], "]"}], 
   ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MeanDiffError", "=", 
    RowBox[{"Mean", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"MD", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "1", ",", "numbplanes"}], "}"}]}], "]"}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Problem", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"L", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "<", "0"}], "||", 
     RowBox[{
      RowBox[{"L", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "<", "0"}], "||", 
     RowBox[{
      RowBox[{"L", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "<", "0"}], "||", 
     RowBox[{"rat", ">", "1000"}]}], ",", 
    RowBox[{
     RowBox[{"Problem", "=", "1"}], ";"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"L", "=", 
   RowBox[{"Sort", "[", 
    RowBox[{
     RowBox[{"Abs", "[", "L", "]"}], ",", "Greater"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Lval", "=", 
    RowBox[{"N", "[", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", 
        SqrtBox[
         RowBox[{
         "L", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]]], ",", 
       FractionBox["1", 
        SqrtBox[
         RowBox[{
         "L", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]]], ",", 
       FractionBox["1", 
        SqrtBox[
         RowBox[{
         "L", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]]]}], 
      "}"}], "]"}]}], ";"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Min", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"S", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
        RowBox[{"S", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
        RowBox[{"S", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], "]"}], "\[Equal]", 
     RowBox[{"S", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"Longnumb", "=", "1"}], ";"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Min", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"S", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
        RowBox[{"S", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
        RowBox[{"S", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], "]"}], "\[Equal]", 
     RowBox[{"S", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"Longnumb", "=", "2"}], ";"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Min", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"S", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"S", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
         RowBox[{"S", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], "]"}], "\[Equal]", 
      RowBox[{"S", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Longnumb", "=", "3"}], ";"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Max", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"S", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
        RowBox[{"S", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
        RowBox[{"S", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], "]"}], "\[Equal]", 
     RowBox[{"S", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"Shortnumb", "=", "1"}], ";"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Max", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"S", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
        RowBox[{"S", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
        RowBox[{"S", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], "]"}], "\[Equal]", 
     RowBox[{"S", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ",", 
    RowBox[{
     RowBox[{"Shortnumb", "=", "2"}], ";"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Max", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"S", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
         RowBox[{"S", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
         RowBox[{"S", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "3"}], "]"}], "]"}]}], "}"}], "]"}], "\[Equal]", 
      RowBox[{"S", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "3"}], "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"Shortnumb", "=", "3"}], ";"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Intermnumb", "=", 
    RowBox[{"6", "-", "Longnumb", "-", "Shortnumb"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ShortAxis", "=", 
   RowBox[{
    RowBox[{"S", "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "Shortnumb"}], "]"}], "]"}], "/", 
    RowBox[{"Norm", "[", 
     RowBox[{"S", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "Shortnumb"}], "]"}], "]"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"IntermAxis", "=", 
   RowBox[{
    RowBox[{"S", "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "Intermnumb"}], "]"}], "]"}], "/", 
    RowBox[{"Norm", "[", 
     RowBox[{"S", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "Intermnumb"}], "]"}], "]"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"LongAxis", "=", 
    RowBox[{
     RowBox[{"S", "[", 
      RowBox[{"[", 
       RowBox[{"2", ",", "Longnumb"}], "]"}], "]"}], "/", 
     RowBox[{"Norm", "[", 
      RowBox[{"S", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "Longnumb"}], "]"}], "]"}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Ellipsoids", "=", 
    RowBox[{"ParametricPlot3D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
          "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
          " ", 
          RowBox[{
          "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], " ", 
          RowBox[{"Cos", "[", "t", "]"}], " ", 
          RowBox[{"Cos", "[", "u", "]"}]}], "+", 
         RowBox[{
          RowBox[{
          "IntermAxis", "\[LeftDoubleBracket]", "1", 
           "\[RightDoubleBracket]"}], " ", 
          RowBox[{
          "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], " ", 
          RowBox[{"Sin", "[", "t", "]"}], " ", 
          RowBox[{"Cos", "[", "u", "]"}]}], "+", 
         RowBox[{
          RowBox[{
          "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
           " ", 
          RowBox[{
          "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], " ", 
          RowBox[{"Sin", "[", "u", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
          "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
          " ", 
          RowBox[{
          "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], " ", 
          RowBox[{"Cos", "[", "t", "]"}], " ", 
          RowBox[{"Cos", "[", "u", "]"}]}], "+", 
         RowBox[{
          RowBox[{
          "IntermAxis", "\[LeftDoubleBracket]", "2", 
           "\[RightDoubleBracket]"}], " ", 
          RowBox[{
          "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], " ", 
          RowBox[{"Sin", "[", "t", "]"}], " ", 
          RowBox[{"Cos", "[", "u", "]"}]}], "+", 
         RowBox[{
          RowBox[{
          "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
           " ", 
          RowBox[{
          "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], " ", 
          RowBox[{"Sin", "[", "u", "]"}]}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
          "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
          " ", 
          RowBox[{
          "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], " ", 
          RowBox[{"Cos", "[", "t", "]"}], " ", 
          RowBox[{"Cos", "[", "u", "]"}]}], "+", 
         RowBox[{
          RowBox[{
          "IntermAxis", "\[LeftDoubleBracket]", "3", 
           "\[RightDoubleBracket]"}], " ", 
          RowBox[{
          "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], " ", 
          RowBox[{"Sin", "[", "t", "]"}], " ", 
          RowBox[{"Cos", "[", "u", "]"}]}], "+", 
         RowBox[{
          RowBox[{
          "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}],
           " ", 
          RowBox[{
          "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], " ", 
          RowBox[{"Sin", "[", "u", "]"}]}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", 
        RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"u", ",", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}], ",", 
        FractionBox["\[Pi]", "2"]}], "}"}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"400", ",", "400"}], "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"m1", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"Cylinder", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1.2"}], " ", 
         RowBox[{
         "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], " ", 
         "LongAxis"}], ",", 
        RowBox[{"1.2", " ", 
         RowBox[{
         "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], " ", 
         "LongAxis"}]}], "}"}], ",", 
      RowBox[{".075", "*", 
       RowBox[{"Lval", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}]}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"m2", "=", 
   RowBox[{"Graphics3D", "[", 
    RowBox[{"Cylinder", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "1.2"}], " ", 
         RowBox[{
         "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], " ", 
         "IntermAxis"}], ",", 
        RowBox[{"1.2", " ", 
         RowBox[{
         "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], " ", 
         "IntermAxis"}]}], "}"}], ",", 
      RowBox[{".075", "*", 
       RowBox[{"Lval", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}]}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"m3", "=", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"Cylinder", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "1.2"}], " ", 
          RowBox[{
          "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], " ",
           "ShortAxis"}], ",", 
         RowBox[{"1.2", " ", 
          RowBox[{
          "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], " ",
           "ShortAxis"}]}], "}"}], ",", 
       RowBox[{".075", "*", 
        RowBox[{"Lval", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}]}], "]"}], "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vectors", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"m1", ",", "m2", ",", "m3"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Vellipsoid", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"Ellipsoids", ",", "vectors", ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"400", ",", "400"}], "}"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"dummy", "=", "1"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"While", "[", 
    RowBox[{
     RowBox[{"dummy", "\[LessEqual]", "numbplanes"}], ",", 
     RowBox[{
      RowBox[{"f", "=", 
       RowBox[{
        RowBox[{"DipDir", "[", "dummy", "]"}], "-", "90"}]}], ";", 
      RowBox[{"j", "=", 
       RowBox[{"90", "-", 
        RowBox[{"Dip", "[", "dummy", "]"}]}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Dip", "[", "dummy", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{"f", "=", "90"}]}], "]"}], ";", 
      RowBox[{"\[Mu]", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}], ",", 
           RowBox[{"Sin", "[", 
            FractionBox[
             RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}], ",", "0"}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Sin", "[", 
             FractionBox[
              RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}]}], ",", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"f", " ", "\[Pi]"}], "180"], "]"}], ",", "0"}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
      RowBox[{"H", "=", 
       RowBox[{
        RowBox[{"Transpose", "[", "\[Mu]", "]"}], ".", "FitEllipsoid", ".", 
        "\[Mu]"}]}], ";", 
      RowBox[{"\[Eta]", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}], ",", 
           RowBox[{"Sin", "[", 
            FractionBox[
             RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"-", 
            RowBox[{"Sin", "[", 
             FractionBox[
              RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}]}], ",", 
           RowBox[{"Cos", "[", 
            FractionBox[
             RowBox[{"j", " ", "\[Pi]"}], "180"], "]"}]}], "}"}]}], "}"}]}], 
      ";", 
      RowBox[{"Q", "=", 
       RowBox[{
        RowBox[{"Transpose", "[", "\[Eta]", "]"}], ".", "H", ".", 
        "\[Eta]"}]}], ";", 
      RowBox[{"Ellipse", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Q", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Q", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Q", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Q", "\[LeftDoubleBracket]", 
            RowBox[{"3", ",", "3"}], "\[RightDoubleBracket]"}]}], "}"}]}], 
        "}"}]}], ";", 
      RowBox[{"Se", "=", 
       RowBox[{"Eigensystem", "[", "Ellipse", "]"}]}], ";", 
      RowBox[{"Me", "=", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Eigenvectors", "[", "Ellipse", "]"}], "]"}]}], ";", 
      RowBox[{
       RowBox[{"Le", "[", "dummy", "]"}], "=", 
       RowBox[{"Eigenvalues", "[", "Ellipse", "]"}]}], ";", 
      RowBox[{
       RowBox[{"Le", "[", "dummy", "]"}], "=", 
       RowBox[{"Sort", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Le", "[", "dummy", "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "//", "N"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Le", "[", "dummy", "]"}], "[", 
             RowBox[{"[", "2", "]"}], "]"}], "//", "N"}]}], "}"}], ",", 
         "Greater"}], "]"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Le", "[", "dummy", "]"}], "\[NotEqual]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Se", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{"Se", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], "}"}]}], 
        ",", 
        RowBox[{
         RowBox[{"Me", "=", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Me", "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
              RowBox[{"Me", "\[LeftDoubleBracket]", 
               RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Me", "\[LeftDoubleBracket]", 
               RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
              RowBox[{"Me", "\[LeftDoubleBracket]", 
               RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}], "}"}]}], 
           "}"}]}], ";"}]}], "]"}], ";", 
      RowBox[{
       RowBox[{"Le", "[", "dummy", "]"}], "=", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", 
          SqrtBox[
           RowBox[{
            RowBox[{"Le", "[", "dummy", "]"}], "\[LeftDoubleBracket]", "2", 
            "\[RightDoubleBracket]"}]]], ",", 
         FractionBox["1", 
          SqrtBox[
           RowBox[{
            RowBox[{"Le", "[", "dummy", "]"}], "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}]]]}], "}"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Me", "\[LeftDoubleBracket]", 
          RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], "\[Equal]", 
         "0"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"AngularOrientation", "[", "dummy", "]"}], "=", 
          FractionBox["\[Pi]", "2"]}], ";"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"AngularOrientation", "[", "dummy", "]"}], "=", 
          RowBox[{"ArcTan", "[", 
           FractionBox[
            RowBox[{"Me", "\[LeftDoubleBracket]", 
             RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], 
            RowBox[{"Me", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]], "]"}]}], 
         ";"}]}], "]"}], ";", 
      RowBox[{
       RowBox[{"FitAxialRatio", "[", "dummy", "]"}], "=", 
       FractionBox[
        RowBox[{
         RowBox[{"Le", "[", "dummy", "]"}], "\[LeftDoubleBracket]", "1", 
         "\[RightDoubleBracket]"}], 
        RowBox[{
         RowBox[{"Le", "[", "dummy", "]"}], "\[LeftDoubleBracket]", "2", 
         "\[RightDoubleBracket]"}]]}], ";", 
      RowBox[{"dummy", "=", 
       RowBox[{"dummy", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"num", "=", "1"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"While", "[", 
    RowBox[{
     RowBox[{"num", "\[LessEqual]", "numbplanes"}], ",", 
     RowBox[{
      RowBox[{"r", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"AreaFit", "[", "num", "]"}], " ", 
             RowBox[{"\[CapitalPi]", "[", "num", "]"}]}], "\[Pi]"]], ">", 
          RowBox[{
           RowBox[{"Le", "[", "num", "]"}], "\[LeftDoubleBracket]", "1", 
           "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{
          SqrtBox[
           FractionBox[
            RowBox[{
             RowBox[{"AreaFit", "[", "num", "]"}], " ", 
             RowBox[{"\[CapitalPi]", "[", "num", "]"}]}], "\[Pi]"]], "*", 
          "1.1"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Le", "[", "num", "]"}], "\[LeftDoubleBracket]", "1", 
           "\[RightDoubleBracket]"}], " ", "1.1"}]}], "]"}]}], ";", 
      RowBox[{
       RowBox[{"AreaFit", "[", "num", "]"}], "=", 
       RowBox[{"\[Pi]", " ", 
        RowBox[{
         RowBox[{"Le", "[", "num", "]"}], "\[LeftDoubleBracket]", "1", 
         "\[RightDoubleBracket]"}], " ", 
        RowBox[{
         RowBox[{"Le", "[", "num", "]"}], "\[LeftDoubleBracket]", "2", 
         "\[RightDoubleBracket]"}]}]}], ";", 
      RowBox[{
       RowBox[{"Initgraph", "[", "num", "]"}], "=", 
       RowBox[{"ParametricPlot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             SqrtBox[
              FractionBox[
               RowBox[{
                RowBox[{"AreaFit", "[", "num", "]"}], " ", 
                RowBox[{"\[CapitalPi]", "[", "num", "]"}]}], "\[Pi]"]], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[CapitalPsi]", "[", "num", "]"}], "]"}], " ", 
             RowBox[{"Sin", "[", "t", "]"}]}], "-", 
            RowBox[{
             SqrtBox[
              FractionBox[
               RowBox[{"AreaFit", "[", "num", "]"}], 
               RowBox[{
                RowBox[{"\[CapitalPi]", "[", "num", "]"}], " ", "\[Pi]"}]]], 
             " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[CapitalPsi]", "[", "num", "]"}], "]"}], " ", 
             RowBox[{"Cos", "[", "t", "]"}]}]}], ",", 
           RowBox[{
            RowBox[{
             SqrtBox[
              FractionBox[
               RowBox[{
                RowBox[{"AreaFit", "[", "num", "]"}], " ", 
                RowBox[{"\[CapitalPi]", "[", "num", "]"}]}], "\[Pi]"]], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[CapitalPsi]", "[", "num", "]"}], "]"}], " ", 
             RowBox[{"Sin", "[", "t", "]"}]}], "+", 
            RowBox[{
             SqrtBox[
              FractionBox[
               RowBox[{"AreaFit", "[", "num", "]"}], 
               RowBox[{
                RowBox[{"\[CapitalPi]", "[", "num", "]"}], " ", "\[Pi]"}]]], 
             " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[CapitalPsi]", "[", "num", "]"}], "]"}], " ", 
             RowBox[{"Cos", "[", "t", "]"}]}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", 
           RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
         RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "r"}], ",", "r"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "r"}], ",", "r"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"300", ",", "300"}], "}"}]}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Thick", ",", "Blue"}], "}"}]}], ",", 
         RowBox[{
         "PlotLabel", "\[Rule]", "\"\<initial input data (input)\>\""}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Fitgraph", "[", "num", "]"}], "=", 
       RowBox[{"ParametricPlot", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Le", "[", "num", "]"}], "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"AngularOrientation", "[", "num", "]"}], "]"}], " ", 
             RowBox[{"Sin", "[", "t", "]"}]}], "-", 
            RowBox[{
             RowBox[{
              RowBox[{"Le", "[", "num", "]"}], "\[LeftDoubleBracket]", "2", 
              "\[RightDoubleBracket]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"AngularOrientation", "[", "num", "]"}], "]"}], " ", 
             RowBox[{"Cos", "[", "t", "]"}]}]}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Le", "[", "num", "]"}], "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"AngularOrientation", "[", "num", "]"}], "]"}], " ", 
             RowBox[{"Sin", "[", "t", "]"}]}], "+", 
            RowBox[{
             RowBox[{
              RowBox[{"Le", "[", "num", "]"}], "\[LeftDoubleBracket]", "2", 
              "\[RightDoubleBracket]"}], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"AngularOrientation", "[", "num", "]"}], "]"}], " ", 
             RowBox[{"Cos", "[", "t", "]"}]}]}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", 
           RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
         RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "r"}], ",", "r"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "r"}], ",", "r"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Thick", ",", "Red"}], "}"}]}], ",", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"300", ",", "300"}], "}"}]}], ",", 
         RowBox[{
         "PlotLabel", "\[Rule]", 
          "\"\<Section through best fit ellipsoid (fit)\>\""}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"sections", "[", "num", "]"}], "=", 
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Initgraph", "[", "num", "]"}], ",", 
         RowBox[{"Fitgraph", "[", "num", "]"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<Red = fit.  Blue = input.  Dip:DipDir = \>\"", ",", 
             RowBox[{"N", "[", 
              RowBox[{"Dip", "[", "num", "]"}], "]"}], ",", "\"\<:\>\"", ",", 
             RowBox[{"N", "[", 
              RowBox[{"OriginalDipDir", "[", "num", "]"}], "]"}]}], "}"}], 
           "]"}]}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "r"}], ",", "r"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "r"}], ",", "r"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"300", ",", "300"}], "}"}]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"num", "=", 
       RowBox[{"num", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"ct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"While", "[", 
    RowBox[{
     RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{"sections", "[", "ct", "]"}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<Initial Axial Ratio (Blue) = \>\"", ",", 
        RowBox[{"N", "[", 
         RowBox[{"\[CapitalPi]", "[", "ct", "]"}], "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<Final Fit Axial Ratio (Red) = \>\"", ",", 
        RowBox[{"N", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"Le", "[", "ct", "]"}], "\[LeftDoubleBracket]", "1", 
           "\[RightDoubleBracket]"}], 
          RowBox[{
           RowBox[{"Le", "[", "ct", "]"}], "\[LeftDoubleBracket]", "2", 
           "\[RightDoubleBracket]"}]], "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<Initial Angle (Blue) = \>\"", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"N", "[", 
            FractionBox[
             RowBox[{
              RowBox[{"\[CapitalPsi]", "[", "ct", "]"}], " ", "180"}], 
             "\[Pi]"], "]"}], "\[GreaterEqual]", "0"}], ",", 
          RowBox[{"N", "[", 
           FractionBox[
            RowBox[{
             RowBox[{"\[CapitalPsi]", "[", "ct", "]"}], " ", "180"}], 
            "\[Pi]"], "]"}], ",", 
          RowBox[{"180", "+", 
           RowBox[{"N", "[", 
            FractionBox[
             RowBox[{
              RowBox[{"\[CapitalPsi]", "[", "ct", "]"}], " ", "180"}], 
             "\[Pi]"], "]"}]}]}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<Final Fit Angle (Red)= \>\"", ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"N", "[", 
            FractionBox[
             RowBox[{
              RowBox[{"AngularOrientation", "[", "ct", "]"}], " ", "180"}], 
             "\[Pi]"], "]"}], "\[GreaterEqual]", "0"}], ",", 
          RowBox[{"N", "[", 
           FractionBox[
            RowBox[{
             RowBox[{"AngularOrientation", "[", "ct", "]"}], " ", "180"}], 
            "\[Pi]"], "]"}], ",", 
          RowBox[{"180", "+", 
           RowBox[{"N", "[", 
            FractionBox[
             RowBox[{
              RowBox[{"AngularOrientation", "[", "ct", "]"}], " ", "180"}], 
             "\[Pi]"], "]"}]}]}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"ct", "=", 
       RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{"Clear", "[", 
  RowBox[{"a", ",", "b", ",", "c"}], "]"}], "\n", 
 RowBox[{
  RowBox[{"dummy3", "=", "1"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"While", "[", 
    RowBox[{
     RowBox[{"dummy3", "\[LessEqual]", "numbplanes"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"DipDir", "[", "dummy3", "]"}], "\[GreaterEqual]", "0"}], "&&", 
         RowBox[{
          RowBox[{"DipDir", "[", "dummy3", "]"}], "\[LessEqual]", "90"}]}], 
        ",", 
        RowBox[{
         RowBox[{"\[Theta]", "=", 
          RowBox[{"DipDir", "[", "dummy3", "]"}]}], ";"}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"DipDir", "[", "dummy3", "]"}], ">", "90"}], "&&", 
         RowBox[{
          RowBox[{"DipDir", "[", "dummy3", "]"}], "\[LessEqual]", "180"}]}], 
        ",", 
        RowBox[{
         RowBox[{"\[Theta]", "=", 
          RowBox[{"180", "-", 
           RowBox[{"DipDir", "[", "dummy3", "]"}]}]}], ";"}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"DipDir", "[", "dummy3", "]"}], ">", "180"}], "&&", 
         RowBox[{
          RowBox[{"DipDir", "[", "dummy3", "]"}], "\[LessEqual]", "270"}]}], 
        ",", 
        RowBox[{
         RowBox[{"\[Theta]", "=", 
          RowBox[{
           RowBox[{"DipDir", "[", "dummy3", "]"}], "-", "180"}]}], ";"}]}], 
       "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"DipDir", "[", "dummy3", "]"}], ">", "270"}], "&&", 
         RowBox[{
          RowBox[{"DipDir", "[", "dummy3", "]"}], "\[LessEqual]", "360"}]}], 
        ",", 
        RowBox[{
         RowBox[{"\[Theta]", "=", 
          RowBox[{"360", "-", 
           RowBox[{"DipDir", "[", "dummy3", "]"}]}]}], ";"}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Theta]", "\[Equal]", "90"}], "||", 
         RowBox[{"\[Theta]", "\[Equal]", "270"}]}], ",", 
        RowBox[{
         RowBox[{"a", "=", "0"}], ";"}], ",", 
        RowBox[{
         RowBox[{"a", "=", 
          SqrtBox[
           FractionBox["1", 
            RowBox[{"1", "+", 
             SuperscriptBox[
              RowBox[{"Tan", "[", 
               FractionBox[
                RowBox[{"\[Theta]", " ", "\[Pi]"}], "180"], "]"}], "2"]}]]]}],
          ";"}]}], "]"}], ";", 
      RowBox[{"b", "=", 
       SqrtBox[
        RowBox[{"1", "-", 
         SuperscriptBox["a", "2"]}]]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Dip", "[", "dummy3", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"a", "=", "0"}], ";", 
         RowBox[{"b", "=", "0"}], ";", 
         RowBox[{"c", "=", "1"}], ";"}], ",", 
        RowBox[{
         RowBox[{"c", "=", 
          RowBox[{"Tan", "[", 
           RowBox[{
            FractionBox["1", "180"], " ", 
            RowBox[{"(", 
             RowBox[{"90", "-", 
              RowBox[{"Dip", "[", "dummy3", "]"}]}], ")"}], " ", "\[Pi]"}], 
           "]"}]}], ";"}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"DipDir", "[", "dummy3", "]"}], "\[GreaterEqual]", "0"}], "&&", 
         RowBox[{
          RowBox[{"DipDir", "[", "dummy3", "]"}], "\[LessEqual]", "90"}]}], 
        ",", 
        RowBox[{
         RowBox[{"a", "=", "a"}], ";", 
         RowBox[{"b", "=", 
          RowBox[{"-", "b"}]}], ";"}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"DipDir", "[", "dummy3", "]"}], ">", "90"}], "&&", 
         RowBox[{
          RowBox[{"DipDir", "[", "dummy3", "]"}], "\[LessEqual]", "180"}]}], 
        ",", 
        RowBox[{
         RowBox[{"a", "=", 
          RowBox[{"-", "a"}]}], ";", 
         RowBox[{"b", "=", 
          RowBox[{"-", "b"}]}], ";"}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"DipDir", "[", "dummy3", "]"}], ">", "180"}], "&&", 
         RowBox[{
          RowBox[{"DipDir", "[", "dummy3", "]"}], "\[LessEqual]", "270"}]}], 
        ",", 
        RowBox[{
         RowBox[{"a", "=", 
          RowBox[{"-", "a"}]}], ";", 
         RowBox[{"b", "=", "b"}], ";"}]}], "]"}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"DipDir", "[", "dummy3", "]"}], ">", "270"}], "&&", 
         RowBox[{
          RowBox[{"DipDir", "[", "dummy3", "]"}], "\[LessEqual]", "360"}]}], 
        ",", 
        RowBox[{
         RowBox[{"a", "=", "a"}], ";", 
         RowBox[{"b", "=", "b"}], ";"}]}], "]"}], ";", 
      RowBox[{"scale", "=", 
       FractionBox["1", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["a", "2"], "+", 
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["c", "2"]}]]]}], ";", 
      RowBox[{"aprime", "=", 
       RowBox[{"scale", " ", "a"}]}], ";", 
      RowBox[{"bprime", "=", 
       RowBox[{"scale", " ", "b"}]}], ";", 
      RowBox[{"cprime", "=", 
       RowBox[{"scale", " ", "c"}]}], ";", 
      RowBox[{
       RowBox[{"normvect", "[", "dummy3", "]"}], "=", 
       RowBox[{"N", "[", 
        RowBox[{"{", 
         RowBox[{"aprime", ",", "bprime", ",", "cprime"}], "}"}], "]"}]}], 
      ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"normvect", "[", "dummy3", "]"}], "\[LeftDoubleBracket]", 
          "3", "\[RightDoubleBracket]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"DipDir", "[", "dummy3", "]"}], "\[Equal]", "90"}], "||", 
            RowBox[{
             RowBox[{"DipDir", "[", "dummy3", "]"}], "\[Equal]", "270"}]}], 
           ",", 
           RowBox[{
            RowBox[{
             RowBox[{"const1", "[", "dummy3", "]"}], "=", "1"}], ";", 
            RowBox[{
             RowBox[{"const2", "[", "dummy3", "]"}], "=", "0"}], ";"}], ",", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"DipDir", "[", "dummy3", "]"}], ">", "45"}], "&&", 
                 RowBox[{
                  RowBox[{"DipDir", "[", "dummy3", "]"}], "<", "135"}]}], 
                ")"}], "||", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"DipDir", "[", "dummy3", "]"}], "<", "315"}], "&&", 
                 RowBox[{
                  RowBox[{"DipDir", "[", "dummy3", "]"}], ">", "225"}]}], 
                ")"}]}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"const1", "[", "dummy3", "]"}], "=", 
                RowBox[{"Tan", "[", 
                 RowBox[{
                  FractionBox["1", "180"], " ", 
                  RowBox[{"DipDir", "[", "dummy3", "]"}], " ", "\[Pi]"}], 
                 "]"}]}], ";", 
               RowBox[{
                RowBox[{"const2", "[", "dummy3", "]"}], "=", "1"}], ";"}], 
              ",", 
              RowBox[{
               RowBox[{
                RowBox[{"const1", "[", "dummy3", "]"}], "=", 
                RowBox[{"Tan", "[", 
                 RowBox[{
                  FractionBox["1", "180"], " ", 
                  RowBox[{"DipDir", "[", "dummy3", "]"}], " ", "\[Pi]"}], 
                 "]"}]}], ";", 
               RowBox[{
                RowBox[{"const2", "[", "dummy3", "]"}], "=", "1"}], ";"}]}], 
             "]"}], ";"}]}], "]"}], ";", 
         RowBox[{
          RowBox[{"PlaneSect", "[", "dummy3", "]"}], "=", 
          RowBox[{"ParametricPlot3D", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{"const1", "[", "dummy3", "]"}], " ", "x"}], ",", 
              RowBox[{
               RowBox[{"const2", "[", "dummy3", "]"}], " ", "x"}], ",", "z"}],
              "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                "Lval", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}]}], " ", "1.1"}], ",", 
              RowBox[{
               RowBox[{
               "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
                " ", "1.1"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"z", ",", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                "Lval", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}]}], " ", "1.1"}], ",", 
              RowBox[{
               RowBox[{
               "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
                " ", "1.1"}]}], "}"}], ",", 
            RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}], ";"}],
         ",", 
        RowBox[{
         RowBox[{
          RowBox[{"PlaneSect", "[", "dummy3", "]"}], "=", 
          RowBox[{"Plot3D", "[", 
           RowBox[{
            FractionBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "x"}], " ", 
               RowBox[{
                RowBox[{"normvect", "[", "dummy3", "]"}], 
                "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], "-", 
              RowBox[{"y", " ", 
               RowBox[{
                RowBox[{"normvect", "[", "dummy3", "]"}], 
                "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}]}], 
             RowBox[{
              RowBox[{"normvect", "[", "dummy3", "]"}], 
              "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                "Lval", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}]}], " ", "1.1"}], ",", 
              RowBox[{
               RowBox[{
               "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
                " ", "1.1"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"y", ",", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{
                "Lval", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}]}], " ", "1.1"}], ",", 
              RowBox[{
               RowBox[{
               "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
                " ", "1.1"}]}], "}"}], ",", 
            RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}], 
         ";"}]}], "]"}], ";", 
      RowBox[{"dummy3", "=", 
       RowBox[{"dummy3", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{"AxesInit", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ct", "=", "1"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"While", "[", 
    RowBox[{
     RowBox[{"ct", "\[LessEqual]", "numbplanes"}], ",", 
     RowBox[{
      RowBox[{"RotPhi", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"AngularOrientation", "[", "ct", "]"}], "]"}], ",", 
           RowBox[{"Sin", "[", 
            RowBox[{"AngularOrientation", "[", "ct", "]"}], "]"}], ",", "0"}],
           "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Sin", "[", 
             RowBox[{"AngularOrientation", "[", "ct", "]"}], "]"}]}], ",", 
           RowBox[{"Cos", "[", 
            RowBox[{"AngularOrientation", "[", "ct", "]"}], "]"}], ",", "0"}],
           "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
      RowBox[{"first", "=", 
       RowBox[{"AxesInit", ".", "RotPhi"}]}], ";", 
      RowBox[{"RotDip", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"Cos", "[", 
            RowBox[{
             FractionBox["1", "180"], " ", 
             RowBox[{"Dip", "[", "ct", "]"}], " ", "\[Pi]"}], "]"}], ",", 
           RowBox[{"Sin", "[", 
            RowBox[{
             FractionBox["1", "180"], " ", 
             RowBox[{"Dip", "[", "ct", "]"}], " ", "\[Pi]"}], "]"}]}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"-", 
            RowBox[{"Sin", "[", 
             RowBox[{
              FractionBox["1", "180"], " ", 
              RowBox[{"Dip", "[", "ct", "]"}], " ", "\[Pi]"}], "]"}]}], ",", 
           RowBox[{"Cos", "[", 
            RowBox[{
             FractionBox["1", "180"], " ", 
             RowBox[{"Dip", "[", "ct", "]"}], " ", "\[Pi]"}], "]"}]}], 
          "}"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"second", "=", 
       RowBox[{"first", ".", "RotDip"}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Dip", "[", "ct", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"DD", "=", "0"}], ";"}], ",", 
        RowBox[{
         RowBox[{"DD", "=", 
          RowBox[{"DipDir", "[", "ct", "]"}]}], ";"}]}], "]"}], ";", 
      RowBox[{"RotDipDir", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{
             FractionBox["1", "180"], " ", 
             RowBox[{"(", 
              RowBox[{"90", "-", "DD"}], ")"}], " ", "\[Pi]"}], "]"}], ",", 
           RowBox[{"Sin", "[", 
            RowBox[{
             FractionBox["1", "180"], " ", 
             RowBox[{"(", 
              RowBox[{"90", "-", "DD"}], ")"}], " ", "\[Pi]"}], "]"}], ",", 
           "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Sin", "[", 
             RowBox[{
              FractionBox["1", "180"], " ", 
              RowBox[{"(", 
               RowBox[{"90", "-", "DD"}], ")"}], " ", "\[Pi]"}], "]"}]}], ",", 
           RowBox[{"Cos", "[", 
            RowBox[{
             FractionBox["1", "180"], " ", 
             RowBox[{"(", 
              RowBox[{"90", "-", "DD"}], ")"}], " ", "\[Pi]"}], "]"}], ",", 
           "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"third", "=", 
       RowBox[{"second", ".", "RotDipDir"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"x", "[", "t_", "]"}], "=", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Le", "[", "ct", "]"}], "\[LeftDoubleBracket]", "1", 
          "\[RightDoubleBracket]"}], " ", 
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"third", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"Le", "[", "ct", "]"}], "\[LeftDoubleBracket]", "2", 
          "\[RightDoubleBracket]"}], " ", 
         RowBox[{"Sin", "[", "t", "]"}], " ", 
         RowBox[{"third", "\[LeftDoubleBracket]", 
          RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}]}]}]}], ";", 
      RowBox[{
       RowBox[{"y", "[", "t_", "]"}], "=", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Le", "[", "ct", "]"}], "\[LeftDoubleBracket]", "1", 
          "\[RightDoubleBracket]"}], " ", 
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"third", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"Le", "[", "ct", "]"}], "\[LeftDoubleBracket]", "2", 
          "\[RightDoubleBracket]"}], " ", 
         RowBox[{"Sin", "[", "t", "]"}], " ", 
         RowBox[{"third", "\[LeftDoubleBracket]", 
          RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}]}]}]}], ";", 
      RowBox[{
       RowBox[{"z", "[", "t_", "]"}], "=", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Le", "[", "ct", "]"}], "\[LeftDoubleBracket]", "1", 
          "\[RightDoubleBracket]"}], " ", 
         RowBox[{"Cos", "[", "t", "]"}], " ", 
         RowBox[{"third", "\[LeftDoubleBracket]", 
          RowBox[{"1", ",", "3"}], "\[RightDoubleBracket]"}]}], "+", 
        RowBox[{
         RowBox[{
          RowBox[{"Le", "[", "ct", "]"}], "\[LeftDoubleBracket]", "2", 
          "\[RightDoubleBracket]"}], " ", 
         RowBox[{"Sin", "[", "t", "]"}], " ", 
         RowBox[{"third", "\[LeftDoubleBracket]", 
          RowBox[{"2", ",", "3"}], "\[RightDoubleBracket]"}]}]}]}], ";", 
      RowBox[{
       RowBox[{"PlaneEllipse", "[", "ct", "]"}], "=", 
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"x", "[", "t", "]"}], ",", 
           RowBox[{"y", "[", "t", "]"}], ",", 
           RowBox[{"z", "[", "t", "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "0", ",", 
           RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Red", ",", "Thick"}], "}"}]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ct", "=", 
       RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TempPlaneSection", "=", 
   RowBox[{"PlaneSect", "[", "1", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"While", "[", 
    RowBox[{
     RowBox[{"ct", "<", "numbplanes"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"TempPlaneSection", "=", 
       RowBox[{"Show", "[", 
        RowBox[{"TempPlaneSection", ",", 
         RowBox[{"PlaneSect", "[", 
          RowBox[{"ct", "+", "1"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ct", "=", 
       RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"qt", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TempPlaneEllipse", "=", 
   RowBox[{"PlaneEllipse", "[", "1", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"While", "[", 
    RowBox[{
     RowBox[{"qt", "<", "numbplanes"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"TempPlaneEllipse", "=", 
       RowBox[{"Show", "[", 
        RowBox[{"TempPlaneEllipse", ",", 
         RowBox[{"PlaneEllipse", "[", 
          RowBox[{"qt", "+", "1"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"qt", "=", 
       RowBox[{"qt", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EllipsoidPlanes", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
    "TempPlaneSection", ",", "Vellipsoid", ",", "TempPlaneEllipse", ",", 
     RowBox[{"BoxRatios", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<North \[UpArrow] \>\"", ",", "\"\<East \[Rule] \>\"", ",", 
        "\"\<Up \[UpArrow] \>\""}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{
            "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
           " ", "1.1"}], ",", 
          RowBox[{
           RowBox[{
           "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
           " ", "1.1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{
            "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
           " ", "1.1"}], ",", 
          RowBox[{
           RowBox[{
           "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
           " ", "1.1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{
            "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
           " ", "1.1"}], ",", 
          RowBox[{
           RowBox[{
           "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
           " ", "1.1"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "0", ",", "3"}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", "False"}]}], "]"}]}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"K", "=", 
   FractionBox[
    RowBox[{
     FractionBox[
      RowBox[{"Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      RowBox[{"Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]],
      "-", "1"}], 
    RowBox[{
     FractionBox[
      RowBox[{"Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      RowBox[{"Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]],
      "-", "1"}]]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[Nu]", "=", 
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"Log", "[", 
       RowBox[{"Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
        "]"}]}], "-", 
     RowBox[{"Log", "[", 
      RowBox[{"Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "]"}], "-", 
     RowBox[{"Log", "[", 
      RowBox[{"Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "]"}]}], 
    RowBox[{
     RowBox[{"Log", "[", 
      RowBox[{"Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "]"}], "-", 
     RowBox[{"Log", "[", 
      RowBox[{"Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "]"}]}]]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"lnot", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      " ", 
      RowBox[{"Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      " ", 
      RowBox[{
      "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], ")"}], 
    RowBox[{"1", "/", "3"}]]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Epsilon]s", "=", 
    RowBox[{
     FractionBox["1", "3"], " ", 
     SqrtBox["3"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{
             "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
             "lnot"], "]"}], "-", 
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{
             "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
             "lnot"], "]"}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{
             "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
             "lnot"], "]"}], "-", 
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{
             "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
             "lnot"], "]"}]}], ")"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{
             "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
             "lnot"], "]"}], "-", 
           RowBox[{"Log", "[", 
            FractionBox[
             RowBox[{
             "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
             "lnot"], "]"}]}], ")"}], "2"]}], ")"}], ".5"]}]}], ";"}], "\n", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ct", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Kcount", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"While", "[", 
   RowBox[{
    RowBox[{"Kcount", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"Kcount", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"kcont", "[", "ct", "]"}], "\[Element]", "Reals"}], ",", 
          RowBox[{"Break", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Kcount", "=", "0"}], ";"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"ct", "=", 
      RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NumbKConts", "=", 
   RowBox[{"ct", "-", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"contour", "[", "d_", "]"}], ":=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Tooltip", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "-", "1"}], ")"}], "*", 
         RowBox[{"kcont", "[", "d", "]"}]}], "+", "1"}], ",", 
       RowBox[{"\"\<k = \>\"", " ", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{"N", "[", 
          RowBox[{"kcont", "[", "d", "]"}], "]"}], "]"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "1", ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"kcont", "[", "d", "]"}], "\[LessEqual]", "1"}], ",", 
         RowBox[{"(", 
          RowBox[{"plotmax", "*", "1.1"}], ")"}], ",", 
         RowBox[{"1", "+", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"plotmax", "*", "1.1"}], ")"}], "-", "1"}], ")"}], "/", 
            RowBox[{"kcont", "[", "d", "]"}]}], ")"}]}]}], "]"}]}], "}"}], 
     ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Hue", "[", ".57", "]"}], ",", "Thin"}], "}"}]}]}], "]"}]}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lnaught", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Lval", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "*", 
      RowBox[{"Lval", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "*", 
      RowBox[{"Lval", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"1", "/", "3"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"e1", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Lval", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "-", "lnaught"}], ")"}], "/", 
    "lnaught"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"e2", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Lval", "[", 
       RowBox[{"[", "2", "]"}], "]"}], "-", "lnaught"}], ")"}], "/", 
    "lnaught"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"e3", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Lval", "[", 
       RowBox[{"[", "3", "]"}], "]"}], "-", "lnaught"}], ")"}], "/", 
    "lnaught"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"khorzval", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "e2"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", "e3"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kvertval", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "e1"}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"1", "+", "e2"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Lval", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "/", 
       RowBox[{"Lval", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], ")"}], "\[Equal]", "1"}], ",", 
    RowBox[{"K", "=", "\"\<\[Infinity]\>\""}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"kpt", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"Graphics", "[", 
     RowBox[{"Tooltip", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"PointSize", "[", "FlinnPtSize", "]"}], ",", "Flinncolor", 
         ",", 
         RowBox[{"Point", "[", 
          RowBox[{"{", 
           RowBox[{"khorzval", ",", "kvertval"}], "}"}], "]"}]}], "}"}], ",", 
       RowBox[{"DisplayForm", "[", 
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<k = \>\"", "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{"N", "[", "K", "]"}], "]"}]}], 
           RowBox[{"\"\<,  \[Epsilon]s = \>\"", "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{"N", "[", "\[Epsilon]s", "]"}], "]"}]}]}], "}"}], "]"}], 
        "]"}]}], "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MaxVal", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"{", 
     RowBox[{"khorzval", ",", "kvertval"}], "}"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"plotmax", "=", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Round", "[", "MaxVal", "]"}], ">", "MaxVal"}], ",", 
      RowBox[{"Round", "[", "MaxVal", "]"}], ",", 
      RowBox[{
       RowBox[{"Round", "[", "MaxVal", "]"}], "+", "1"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "\"\<plotmax\>\"", " ", "determines", " ", "the", " ", "maximum", " ", 
    "range", " ", "of", " ", "the", " ", "Flinn", " ", 
    RowBox[{"plot", ".", "  ", "You"}], " ", "can", " ", "overwrite", " ", 
    "this", " ", "value", " ", "by", " ", "deleting", " ", "the", " ", 
    "comment", " ", "marks", " ", "from", " ", "the", " ", "next", " ", 
    RowBox[{"line", "."}]}], "  ", "*)"}], "\n", 
  RowBox[{"(*", " ", 
   RowBox[{"plotmax", "=", "4"}], " ", "*)"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tempEpiSMax", "=", 
   RowBox[{
    SqrtBox[
     FractionBox["2", "3"]], " ", 
    RowBox[{"\[Sqrt]", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Log", "[", 
         FractionBox["1", "plotmax"], "]"}], "2"], "-", 
       RowBox[{
        RowBox[{"Log", "[", 
         FractionBox["1", "plotmax"], "]"}], " ", 
        RowBox[{"Log", "[", "plotmax", "]"}]}], "+", 
       SuperscriptBox[
        RowBox[{"Log", "[", "plotmax", "]"}], "2"]}], ")"}]}]}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"\[Epsilon]scontmax", "=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Round", "[", 
       RowBox[{"tempEpiSMax", ",", "Flinncontinterval"}], "]"}], 
      "\[GreaterEqual]", "tempEpiSMax"}], ",", 
     RowBox[{
      RowBox[{"Round", "[", 
       RowBox[{"tempEpiSMax", ",", "Flinncontinterval"}], "]"}], "-", 
      "Flinncontinterval"}], ",", 
     RowBox[{"Round", "[", 
      RowBox[{"tempEpiSMax", ",", "Flinncontinterval"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numb\[Epsilon]scontours", "=", 
   RowBox[{"\[Epsilon]scontmax", "/", "Flinncontinterval"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ct", "=", "1"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"While", "[", 
    RowBox[{
     RowBox[{"ct", "\[LessEqual]", "numb\[Epsilon]scontours"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Epsilon]scont", "[", "ct", "]"}], "=", 
       RowBox[{"ct", "*", 
        RowBox[{"(", 
         RowBox[{"\[Epsilon]scontmax", "/", "numb\[Epsilon]scontours"}], 
         ")"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ct", "=", 
       RowBox[{"ct", "+", "1"}]}], ";"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Epsilon]splot", "[", "d_", "]"}], ":=", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"Tooltip", "[", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Log", "[", 
             FractionBox["1", "b"], "]"}], "+", 
            RowBox[{
             SqrtBox["3"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox[
                 RowBox[{"\[Epsilon]scont", "[", "d", "]"}], "2"]}], "-", 
               SuperscriptBox[
                RowBox[{"Log", "[", 
                 FractionBox["1", "b"], "]"}], "2"]}]]}]}], ")"}]}]], ",", 
        RowBox[{"\"\<\[Epsilon]s = \>\"", "<>", 
         RowBox[{"ToString", "[", 
          RowBox[{"N", "[", 
           RowBox[{"\[Epsilon]scont", "[", "d", "]"}], "]"}], "]"}]}]}], 
       "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"b", ",", "1", ",", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          SqrtBox[
           FractionBox["3", "2"]], "  ", 
          RowBox[{"\[Epsilon]scont", "[", "d", "]"}]}]]}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"GrayLevel", "[", ".5", "]"}], ",", 
         RowBox[{"Thickness", "[", ".001", "]"}], ",", 
         RowBox[{"Dashing", "[", 
          RowBox[{"{", 
           RowBox[{".015", ",", ".01"}], "}"}], "]"}]}], "}"}]}]}], "]"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{"FlinnDiagram", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"contour", "[", "x", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "1", ",", "NumbKConts"}], "}"}]}], "]"}], ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"\[Epsilon]splot", "[", "x", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "1", ",", "numb\[Epsilon]scontours"}], "}"}]}], 
     "]"}], ",", "kpt", ",", 
    RowBox[{"Axes", "\[Rule]", "True"}], ",", 
    RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "plotmax"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "plotmax"}], "}"}]}], "}"}]}], ",", 
    RowBox[{"AxesStyle", "\[Rule]", "Thick"}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", 
     RowBox[{"Style", "[", 
      RowBox[{"\"\<Flinn Diagram\>\"", ",", "32", ",", "Blue", ",", "Bold"}], 
      "]"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<\!\(\*SubscriptBox[\(\[Epsilon]\), \(s\)]\) contour interval: \>\"", 
   ",", 
   RowBox[{"N", "[", "Flinncontinterval", "]"}]}], "]"}], "\n", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Flinn's k-value contours: \>\"", ",", 
    RowBox[{"TableForm", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"N", "[", 
         RowBox[{"kcont", "[", "x", "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "1", ",", "NumbKConts"}], "}"}]}], "]"}], ",", 
      RowBox[{"TableDirections", "\[Rule]", "Row"}]}], "]"}]}], "]"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"EsMax", "=", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Round", "[", 
        RowBox[{"\[Epsilon]s", ",", "continterval"}], "]"}], "<", 
       "\[Epsilon]s"}], ",", 
      RowBox[{
       RowBox[{"Round", "[", 
        RowBox[{"\[Epsilon]s", ",", "continterval"}], "]"}], "+", 
       "continterval"}], ",", 
      RowBox[{"Round", "[", 
       RowBox[{"\[Epsilon]s", ",", "continterval"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "\"\<EsMax\>\"", " ", "determines", " ", "the", " ", "maximum", " ", 
    "Octehedral", " ", "Shear", " ", "Strain", " ", "for", " ", "the", " ", 
    "Hsu", " ", 
    RowBox[{"plot", ".", "  ", "You"}], " ", "can", " ", "overwrite", " ", 
    "this", " ", "value", " ", "by", " ", "deleting", " ", "the", " ", 
    "comment", " ", "marks", " ", "from", " ", "the", " ", "next", " ", 
    RowBox[{"line", "."}]}], "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"EsMax", "=", "1.25"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"contnumb", "=", 
   RowBox[{"EsMax", "/", "continterval"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Esprime", "=", 
   RowBox[{"\[Epsilon]s", "/", "EsMax"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Hsu\[Theta]", "=", 
   RowBox[{"90", "-", 
    RowBox[{"30", "*", "\[Nu]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xHsupt", "=", 
   RowBox[{"Esprime", "*", 
    RowBox[{"Cos", "[", 
     RowBox[{"Hsu\[Theta]", "*", 
      RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yHsupt", "=", 
   RowBox[{"Esprime", "*", 
    RowBox[{"Sin", "[", 
     RowBox[{"Hsu\[Theta]", "*", 
      RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Stuff", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"Graphics", "[", 
     RowBox[{"Tooltip", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"PointSize", "[", "PtSize", "]"}], ",", "color", ",", 
         RowBox[{"Point", "[", 
          RowBox[{"{", 
           RowBox[{"xHsupt", ",", "yHsupt"}], "}"}], "]"}]}], "}"}], ",", 
       RowBox[{"DisplayForm", "[", 
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\< \[Nu] = \>\"", "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{"N", "[", "\[Nu]", "]"}], "]"}]}], ",", 
           RowBox[{"\"\<, \[Epsilon]s = \>\"", "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{"N", "[", "\[Epsilon]s", "]"}], "]"}]}]}], "}"}], "]"}], 
        "]"}]}], "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"jazz", "=", "1"}], ";"}], "\n", 
 RowBox[{"While", "[", 
  RowBox[{
   RowBox[{"jazz", "\[LessEqual]", "contnumb"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Arc", "[", "jazz", "]"}], "=", 
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"Tooltip", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"jazz", "/", "contnumb"}], ")"}], 
            RowBox[{"Cos", "[", 
             RowBox[{"t", "*", 
              RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"jazz", "/", "contnumb"}], ")"}], 
            RowBox[{"Sin", "[", 
             RowBox[{"t", "*", 
              RowBox[{"Pi", "/", "180"}]}], "]"}]}]}], "}"}], ",", 
         RowBox[{"\"\<\[Epsilon]s = \>\"", "<>", 
          RowBox[{"ToString", "[", 
           RowBox[{"N", "[", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"EsMax", "/", "contnumb"}], ")"}], "*", "jazz"}], 
             ")"}], "]"}], "]"}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "60", ",", "120"}], "}"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
       RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"jazz", "=", 
     RowBox[{"jazz", "+", "1"}]}], ";"}]}], "]"}], "\n", 
 RowBox[{
  RowBox[{"Arcs", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Arc", "[", "jazz", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"jazz", ",", "contnumb"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"FinalArc", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Tooltip", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"t", "*", 
           RowBox[{"Pi", "/", "180"}]}], "]"}], ",", 
         RowBox[{"Sin", "[", 
          RowBox[{"t", "*", 
           RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}], ",", 
       RowBox[{"\"\<\[Epsilon]s = \>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{"N", "[", 
          RowBox[{"(", 
           RowBox[{"(", "EsMax", ")"}], ")"}], "]"}], "]"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "60", ",", "120"}], "}"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"Ticks", "\[Rule]", "None"}], ",", 
     RowBox[{"Axes", "\[Rule]", "None"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Thick", ",", "Black"}], "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Radii1", ":=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Tooltip", "[", 
     RowBox[{
      RowBox[{"x", "*", 
       RowBox[{"Tan", "[", 
        RowBox[{"60", "*", 
         RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", "\"\<\[Nu] = 1.0\>\""}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", 
      RowBox[{"Cos", "[", 
       RowBox[{"60", "*", 
        RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "None"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", "Black"}], "}"}]}]}], "]"}]}], "\n", 
 RowBox[{"Radii2", ":=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Tooltip", "[", 
     RowBox[{
      RowBox[{"x", "*", 
       RowBox[{"Tan", "[", 
        RowBox[{"67.5", "*", 
         RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", "\"\<\[Nu] = 0.75\>\""}],
      "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", 
      RowBox[{"Cos", "[", 
       RowBox[{"67.5", "*", 
        RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]}], "\n", 
 RowBox[{"Radii3", ":=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Tooltip", "[", 
     RowBox[{
      RowBox[{"x", "*", 
       RowBox[{"Tan", "[", 
        RowBox[{"75", "*", 
         RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", "\"\<\[Nu] = 0.5\>\""}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", 
      RowBox[{"Cos", "[", 
       RowBox[{"75", "*", 
        RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]}], "\n", 
 RowBox[{"Radii4", ":=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Tooltip", "[", 
     RowBox[{
      RowBox[{"x", "*", 
       RowBox[{"Tan", "[", 
        RowBox[{"82.5", "*", 
         RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", "\"\<\[Nu] = 0.25\>\""}],
      "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", 
      RowBox[{"Cos", "[", 
       RowBox[{"82.5", "*", 
        RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]}], "\n", 
 RowBox[{"Radii5", ":=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Tooltip", "[", 
     RowBox[{
      RowBox[{"x", "*", 
       RowBox[{"Tan", "[", 
        RowBox[{"97.5", "*", 
         RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", 
      "\"\<\[Nu] = -0.25\>\""}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", 
      RowBox[{"Cos", "[", 
       RowBox[{"97.5", "*", 
        RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]}], "\n", 
 RowBox[{"Radii6", ":=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Tooltip", "[", 
     RowBox[{
      RowBox[{"x", "*", 
       RowBox[{"Tan", "[", 
        RowBox[{"105", "*", 
         RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", "\"\<\[Nu] = -0.5\>\""}],
      "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", 
      RowBox[{"Cos", "[", 
       RowBox[{"105", "*", 
        RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]}], "\n", 
 RowBox[{"Radii7", ":=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Tooltip", "[", 
     RowBox[{
      RowBox[{"x", "*", 
       RowBox[{"Tan", "[", 
        RowBox[{"112.5", "*", 
         RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", 
      "\"\<\[Nu] = -0.75\>\""}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", 
      RowBox[{"Cos", "[", 
       RowBox[{"112.5", "*", 
        RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "None"}]}], "]"}]}], "\n", 
 RowBox[{"Radii8", ":=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Tooltip", "[", 
     RowBox[{
      RowBox[{"x", "*", 
       RowBox[{"Tan", "[", 
        RowBox[{"120", "*", 
         RowBox[{"Pi", "/", "180"}]}], "]"}]}], ",", "\"\<\[Nu] = -1.0\>\""}],
      "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", 
      RowBox[{"Cos", "[", 
       RowBox[{"120", "*", 
        RowBox[{"Pi", "/", "180"}]}], "]"}]}], "}"}], ",", 
    RowBox[{"Axes", "\[Rule]", "None"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Thick", ",", "Black"}], "}"}]}]}], "]"}]}], "\n", 
 RowBox[{"vert", ":=", 
  RowBox[{"Show", "[", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Thick", ",", 
      RowBox[{"Tooltip", "[", 
       RowBox[{
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "1"}], "}"}]}], "}"}], "]"}], ",", 
        "\"\<\[Nu] = 0\>\""}], "]"}]}], "}"}], "]"}], "]"}]}], "\n", 
 RowBox[{"HsuPlot", ":=", 
  RowBox[{"Show", "[", 
   RowBox[{
   "Arcs", ",", "FinalArc", ",", "Radii1", ",", "Radii2", ",", "Radii3", ",", 
    "Radii4", ",", "Radii5", ",", "Radii6", ",", "Radii7", ",", "Radii8", ",",
     "vert"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"FullHsu", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"HsuPlot", ",", "Stuff", ",", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(\[Epsilon]\), \(s\)]\) \[Rule]\>\"", " ", 
          ",", 
          RowBox[{"FontSize", "\[Rule]", "30"}], ",", "Bold"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.3", ",", "0.4"}], "}"}], ",", "Automatic", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"30", "\[Degree]"}], "]"}], ",", 
          RowBox[{"Cos", "[", 
           RowBox[{"30", "\[Degree]"}], "]"}]}], "}"}]}], "]"}], "}"}], "]"}],
     ",", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<\[LeftArrow] \!\(\*SubscriptBox[\(\[Epsilon]\), \(s\)]\)\>\"", 
          " ", ",", 
          RowBox[{"FontSize", "\[Rule]", "30"}], ",", "Bold"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.3"}], ",", "0.4"}], "}"}], ",", "Automatic", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"30", "\[Degree]"}], "]"}], ",", 
          RowBox[{"-", 
           RowBox[{"Cos", "[", 
            RowBox[{"30", "\[Degree]"}], "]"}]}]}], "}"}]}], "]"}], "}"}], 
     "]"}], ",", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<\[Nu] = -1\>\"", " ", ",", 
          RowBox[{"FontSize", "\[Rule]", "24"}], ",", "Bold"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", ".51"}], ",", "0.91"}], "}"}], ",", "Automatic", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"30", "\[Degree]"}], "]"}], ",", 
          RowBox[{"Sin", "[", 
           RowBox[{"30", "\[Degree]"}], "]"}]}], "}"}]}], "]"}], "}"}], "]"}],
     ",", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<\[Nu] = 0\>\"", " ", ",", 
          RowBox[{"FontSize", "\[Rule]", "24"}], ",", "Bold"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0.0", ",", "1.04"}], "}"}]}], "]"}], "}"}], "]"}], ",", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<\[Nu] = 1\>\"", " ", ",", 
          RowBox[{"FontSize", "\[Rule]", "24"}], ",", "Bold"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{".525", ",", "0.9"}], "}"}], ",", "Automatic", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"30", "\[Degree]"}], "]"}], ",", 
          RowBox[{"-", 
           RowBox[{"Sin", "[", 
            RowBox[{"30", "\[Degree]"}], "]"}]}]}], "}"}]}], "]"}], "}"}], 
     "]"}], ",", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Hsu Diagram\>\"", ",", 
          RowBox[{"FontSize", "\[Rule]", "24"}], ",", "Blue", ",", "Bold"}], 
         "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "1.125"}], "}"}]}], "]"}], "}"}], "]"}], ",", 
    "Stuff", ",", 
    RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
    RowBox[{"PlotRange", "->", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", ".6"}], ",", ".6"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1.15"}], "}"}]}], "}"}]}]}], "]"}]}], "\n", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<Plot Range for strain is 0 to \>\"", ",", 
   RowBox[{"N", "[", "EsMax", "]"}]}], "]"}], "\n", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<Strain contour interval is \>\"", ",", 
   RowBox[{"N", "[", "continterval", "]"}]}], "]"}], "\n", 
 RowBox[{"Print", "[", "\"\<Plot Range for Lode's Ratio is -1 to 1\>\"", 
  "]"}], "\n", 
 RowBox[{
  RowBox[{"Print", "[", "\"\<Lode's Ratio contour interal is 0.25\>\"", "]"}],
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[Equal]", "0"}]}], ",", 
    RowBox[{
     RowBox[{"LPlunge", "=", "90"}], ";"}], ",", 
    RowBox[{
     RowBox[{"LPlunge", "=", 
      FractionBox[
       RowBox[{
        RowBox[{"ArcTan", "[", 
         FractionBox[
          RowBox[{"Abs", "[", 
           RowBox[{
           "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}],
            "]"}], 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{
             "LongAxis", "\[LeftDoubleBracket]", "2", 
              "\[RightDoubleBracket]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
             "LongAxis", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], "2"]}]]], "]"}], " ", "180"}], 
       "\[Pi]"]}], ";"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
     "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
     "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{"Tl", "=", "90"}], ";"}], ",", 
    RowBox[{
     RowBox[{"Tl", "=", 
      RowBox[{"Abs", "[", 
       FractionBox[
        RowBox[{
         RowBox[{"ArcTan", "[", 
          FractionBox[
           RowBox[{
           "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
           RowBox[{
           "LongAxis", "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}]], "]"}], " ", "180"}], "\[Pi]"], 
       "]"}]}], ";"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ">",
       "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}]}], ",", 
    RowBox[{"LTrend", "=", 
     RowBox[{"180", "-", "Tl"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "<",
       "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}]}], ",", 
    RowBox[{"LTrend", "=", "Tl"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "<",
       "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "<",
       "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}]}], ",", 
    RowBox[{"LTrend", "=", 
     RowBox[{"360", "-", "Tl"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ">",
       "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "<",
       "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}]}], ",", 
    RowBox[{"LTrend", "=", 
     RowBox[{"180", "+", "Tl"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ">",
       "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], "<",
       "0"}]}], ",", 
    RowBox[{"LTrend", "=", 
     RowBox[{"360", "-", "Tl"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "<",
       "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], "<",
       "0"}]}], ",", 
    RowBox[{"LTrend", "=", 
     RowBox[{"180", "+", "Tl"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "<",
       "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "<",
       "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], "<",
       "0"}]}], ",", 
    RowBox[{"LTrend", "=", 
     RowBox[{"180", "-", "Tl"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ">",
       "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "<",
       "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], "<",
       "0"}]}], ",", 
    RowBox[{"LTrend", "=", "Tl"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[LessEqual]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "\[LessEqual]", "0"}]}], ",", 
    RowBox[{"LTrend", "=", "90"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}]}], ",", 
    RowBox[{"LTrend", "=", "90"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "<",
       "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], ">",
       "0"}]}], ",", 
    RowBox[{"LTrend", "=", "270"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ">",
       "0"}], "&&", 
     RowBox[{
      RowBox[{
      "LongAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], "<",
       "0"}]}], ",", 
    RowBox[{"LTrend", "=", "270"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
       "LongAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       "\[Equal]", "0"}], "&&", 
      RowBox[{
       RowBox[{
       "LongAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
       "\[Equal]", "0"}]}], ",", 
     RowBox[{
      RowBox[{"LPlunge", "=", "90"}], ";", 
      RowBox[{"LTrend", "=", "NA"}]}]}], "]"}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[Equal]", "0"}]}], ",", 
    RowBox[{
     RowBox[{"IPlunge", "=", "90"}], ";"}], ",", 
    RowBox[{
     RowBox[{"IPlunge", "=", 
      FractionBox[
       RowBox[{
        RowBox[{"ArcTan", "[", 
         FractionBox[
          RowBox[{"Abs", "[", 
           RowBox[{
           "IntermAxis", "\[LeftDoubleBracket]", "3", 
            "\[RightDoubleBracket]"}], "]"}], 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{
             "IntermAxis", "\[LeftDoubleBracket]", "2", 
              "\[RightDoubleBracket]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
             "IntermAxis", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], "2"]}]]], "]"}], " ", "180"}], 
       "\[Pi]"]}], ";"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
     "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
     "\[Equal]", "0"}], ",", 
    RowBox[{"\[CapitalTau]i", "=", "90"}], ",", 
    RowBox[{
     RowBox[{"\[CapitalTau]i", "=", 
      RowBox[{"Abs", "[", 
       FractionBox[
        RowBox[{
         RowBox[{"ArcTan", "[", 
          FractionBox[
           RowBox[{
           "IntermAxis", "\[LeftDoubleBracket]", "2", 
            "\[RightDoubleBracket]"}], 
           RowBox[{
           "IntermAxis", "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}]], "]"}], " ", "180"}], "\[Pi]"], 
       "]"}]}], ";"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      ">", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}]}], ",", 
    RowBox[{"ITrend", "=", 
     RowBox[{"180", "-", "\[CapitalTau]i"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "<", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}]}], ",", 
    RowBox[{"ITrend", "=", "\[CapitalTau]i"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "<", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "<", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}]}], ",", 
    RowBox[{"ITrend", "=", 
     RowBox[{"360", "-", "\[CapitalTau]i"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      ">", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "<", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}]}], ",", 
    RowBox[{"ITrend", "=", 
     RowBox[{"180", "+", "\[CapitalTau]i"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      ">", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "<", "0"}]}], ",", 
    RowBox[{"ITrend", "=", 
     RowBox[{"360", "-", "\[CapitalTau]i"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "<", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "<", "0"}]}], ",", 
    RowBox[{"ITrend", "=", 
     RowBox[{"180", "+", "\[CapitalTau]i"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "<", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "<", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "<", "0"}]}], ",", 
    RowBox[{"ITrend", "=", 
     RowBox[{"180", "-", "\[CapitalTau]i"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      ">", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "<", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "<", "0"}]}], ",", 
    RowBox[{"ITrend", "=", "\[CapitalTau]i"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[LessEqual]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "\[LessEqual]", "0"}]}], ",", 
    RowBox[{"ITrend", "=", "90"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}]}], ",", 
    RowBox[{"ITrend", "=", "90"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "<", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      ">", "0"}]}], ",", 
    RowBox[{"ITrend", "=", "270"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      ">", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "IntermAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "<", "0"}]}], ",", 
    RowBox[{"ITrend", "=", "270"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
       "IntermAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       "\[Equal]", "0"}], "&&", 
      RowBox[{
       RowBox[{
       "IntermAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
       "\[Equal]", "0"}]}], ",", 
     RowBox[{
      RowBox[{"IPlunge", "=", "90"}], ";", 
      RowBox[{"ITrend", "=", "NA"}]}]}], "]"}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[Equal]", "0"}]}], ",", 
    RowBox[{
     RowBox[{"SPlunge", "=", "90"}], ";"}], ",", 
    RowBox[{
     RowBox[{"SPlunge", "=", 
      FractionBox[
       RowBox[{
        RowBox[{"ArcTan", "[", 
         FractionBox[
          RowBox[{"Abs", "[", 
           RowBox[{
           "ShortAxis", "\[LeftDoubleBracket]", "3", 
            "\[RightDoubleBracket]"}], "]"}], 
          SqrtBox[
           RowBox[{
            SuperscriptBox[
             RowBox[{
             "ShortAxis", "\[LeftDoubleBracket]", "2", 
              "\[RightDoubleBracket]"}], "2"], "+", 
            SuperscriptBox[
             RowBox[{
             "ShortAxis", "\[LeftDoubleBracket]", "1", 
              "\[RightDoubleBracket]"}], "2"]}]]], "]"}], " ", "180"}], 
       "\[Pi]"]}], ";"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
     "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
     "\[Equal]", "0"}], ",", 
    RowBox[{"\[CapitalTau]s", "=", "90"}], ",", 
    RowBox[{
     RowBox[{"\[CapitalTau]s", "=", 
      RowBox[{"Abs", "[", 
       FractionBox[
        RowBox[{
         RowBox[{"ArcTan", "[", 
          FractionBox[
           RowBox[{
           "ShortAxis", "\[LeftDoubleBracket]", "2", 
            "\[RightDoubleBracket]"}], 
           RowBox[{
           "ShortAxis", "\[LeftDoubleBracket]", "1", 
            "\[RightDoubleBracket]"}]], "]"}], " ", "180"}], "\[Pi]"], 
       "]"}]}], ";"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      ">", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}]}], ",", 
    RowBox[{"STrend", "=", 
     RowBox[{"180", "-", "\[CapitalTau]s"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "<", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}]}], ",", 
    RowBox[{"STrend", "=", "\[CapitalTau]s"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "<", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "<", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}]}], ",", 
    RowBox[{"STrend", "=", 
     RowBox[{"360", "-", "\[CapitalTau]s"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      ">", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "<", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}]}], ",", 
    RowBox[{"STrend", "=", 
     RowBox[{"180", "+", "\[CapitalTau]s"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      ">", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "<", "0"}]}], ",", 
    RowBox[{"STrend", "=", 
     RowBox[{"360", "-", "\[CapitalTau]s"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "<", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "<", "0"}]}], ",", 
    RowBox[{"STrend", "=", 
     RowBox[{"180", "+", "\[CapitalTau]s"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "<", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "<", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "<", "0"}]}], ",", 
    RowBox[{"STrend", "=", 
     RowBox[{"180", "-", "\[CapitalTau]s"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      ">", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "<", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "<", "0"}]}], ",", 
    RowBox[{"STrend", "=", "\[CapitalTau]s"}]}], "]"}], ";", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[LessEqual]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "\[LessEqual]", "0"}]}], ",", 
    RowBox[{"STrend", "=", "90"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "\[GreaterEqual]", "0"}]}], ",", 
    RowBox[{"STrend", "=", "90"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      "<", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      ">", "0"}]}], ",", 
    RowBox[{"STrend", "=", "270"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
      ">", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "ShortAxis", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
      "<", "0"}]}], ",", 
    RowBox[{"STrend", "=", "270"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
       "ShortAxis", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       "\[Equal]", "0"}], "&&", 
      RowBox[{
       RowBox[{
       "ShortAxis", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
       "\[Equal]", "0"}]}], ",", 
     RowBox[{
      RowBox[{"SPlunge", "=", "90"}], ";", 
      RowBox[{"STrend", "=", "NA"}]}]}], "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FitSizePercent", "=", "3"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sphericalFromTrendPlungeDeg", "[", 
    RowBox[{"{", 
     RowBox[{"trendDeg_", ",", " ", "plungeDeg_"}], "}"}], "]"}], " ", ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"1.0", ",", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"plungeDeg", "+", "90.0"}], ")"}], " ", "Degree"}], ",", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"90.0", "-", "trendDeg"}], ")"}], " ", "Degree"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cartesianFromSpherical", "[", 
    RowBox[{"{", 
     RowBox[{"rho_", ",", " ", "phi_", ",", " ", "theta_"}], "}"}], "]"}], 
   " ", ":=", " ", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"rho", " ", "*", " ", 
      RowBox[{"Sin", "[", "phi", "]"}], " ", "*", " ", 
      RowBox[{"Cos", "[", "theta", "]"}]}], ",", " ", 
     RowBox[{"rho", " ", "*", " ", 
      RowBox[{"Sin", "[", "phi", "]"}], " ", "*", " ", 
      RowBox[{"Sin", "[", "theta", "]"}]}], ",", " ", 
     RowBox[{"rho", " ", "*", " ", 
      RowBox[{"Cos", "[", "phi", "]"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cartesianFromTrendPlungeDeg", "[", "x_", "]"}], " ", ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"cartesianFromSpherical", "[", 
    RowBox[{"sphericalFromTrendPlungeDeg", "[", "x", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lowerHemisphere", "[", 
    RowBox[{"{", 
     RowBox[{"x_", ",", " ", "y_", ",", " ", "z_"}], "}"}], "]"}], " ", ":=", 
   " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", " ", "y", ",", " ", "z"}], "}"}], " ", "/", " ", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"z", " ", "<=", " ", "0"}], ",", " ", 
      RowBox[{"Norm", "[", 
       RowBox[{"{", 
        RowBox[{"x", ",", " ", "y", ",", " ", "z"}], "}"}], "]"}], ",", " ", 
      RowBox[{"-", 
       RowBox[{"Norm", "[", 
        RowBox[{"{", 
         RowBox[{"x", ",", " ", "y", ",", " ", "z"}], "}"}], "]"}]}]}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"equalAreaProjection", "[", 
    RowBox[{"{", 
     RowBox[{"x_", ",", " ", "y_", ",", " ", "z_"}], "}"}], "]"}], " ", ":=", 
   " ", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "scaling", "}"}], ",", " ", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"x", "^", "2"}], " ", "+", " ", 
         RowBox[{"y", "^", "2"}]}], " ", "\[Equal]", " ", "0"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", "0"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"scaling", " ", "=", " ", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{"1", " ", "+", " ", "z"}], ")"}]}], ")"}], " ", "/", 
           " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"x", "^", "2"}], " ", "+", " ", 
             RowBox[{"y", "^", "2"}]}], ")"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"scaling", " ", "*", " ", "x"}], ",", " ", 
          RowBox[{"scaling", " ", "*", " ", "y"}]}], "}"}]}]}], "]"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fringePrimitive", "[", 
    RowBox[{"plotRadius_", ",", " ", "padding_"}], "]"}], " ", ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"Thick", ",", 
     RowBox[{"Circle", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.", ",", "0."}], "}"}], ",", "plotRadius"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Line", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"plotRadius", " ", "*", " ", 
             RowBox[{"Cos", "[", "angle", "]"}]}], ",", " ", 
            RowBox[{"plotRadius", " ", "*", 
             RowBox[{"Sin", "[", "angle", "]"}]}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"plotRadius", " ", "+", " ", "padding"}], ")"}], " ", 
             "*", " ", 
             RowBox[{"Cos", "[", "angle", "]"}]}], ",", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"plotRadius", " ", "+", " ", "padding"}], ")"}], " ", 
             "*", " ", 
             RowBox[{"Sin", "[", "angle", "]"}]}]}], "}"}]}], "}"}], "]"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"angle", ",", " ", "0", ",", " ", 
         RowBox[{"2", " ", "Pi"}], ",", " ", 
         RowBox[{"Pi", " ", "/", " ", "2"}]}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Text", "[", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<000\>\"", ",", "Large", ",", "Bold"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"plotRadius", " ", "+", " ", 
          RowBox[{"2", " ", "*", " ", 
           RowBox[{"(", 
            RowBox[{"padding", "*", "1.4"}], ")"}]}]}]}], "}"}]}], "]"}], ",",
      "\[IndentingNewLine]", 
     RowBox[{"Text", "[", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<090\>\"", ",", "Large", ",", "Bold"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"plotRadius", " ", "+", " ", 
          RowBox[{"2", " ", "*", " ", 
           RowBox[{"(", 
            RowBox[{"padding", "*", "1.7"}], ")"}]}]}], ",", "0"}], "}"}]}], 
      "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Text", "[", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<180\>\"", ",", "Large", ",", "Bold"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"plotRadius", " ", "+", " ", 
            RowBox[{"2", " ", "*", " ", 
             RowBox[{"(", 
              RowBox[{"padding", "*", "1.4"}], ")"}]}]}], ")"}]}]}], "}"}]}], 
      "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Text", "[", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<270\>\"", ",", "Large", ",", "Bold"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"plotRadius", " ", "+", " ", 
            RowBox[{"2", " ", "*", " ", 
             RowBox[{"(", 
              RowBox[{"padding", "*", "1.7"}], ")"}]}]}], ")"}]}], ",", "0"}],
         "}"}]}], "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"equalAreaPlot", "[", 
    RowBox[{"diskList_", ",", "pointRadius_", ",", "coloring_"}], "]"}], " ", 
   ":=", " ", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"fringePrimitive", "[", 
        RowBox[{
         RowBox[{"Sqrt", "[", "2", "]"}], ",", " ", "0.1"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{"Function", "[", 
          RowBox[{"vector", ",", 
           RowBox[{"{", 
            RowBox[{"coloring", ",", 
             RowBox[{"Disk", "[", 
              RowBox[{
               RowBox[{"equalAreaProjection", "[", 
                RowBox[{"lowerHemisphere", "[", "vector", "]"}], "]"}], ",", 
               " ", "pointRadius"}], "]"}]}], "}"}]}], "]"}], ",", " ", 
         "diskList"}], "]"}]}], "]"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"curvePrimitive", "[", "pointList_", "]"}], " ", ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Line", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"pointList", "[", 
         RowBox[{"[", "i", "]"}], "]"}], ",", " ", 
        RowBox[{"pointList", "[", 
         RowBox[{"[", 
          RowBox[{"i", " ", "+", " ", "1"}], "]"}], "]"}]}], "}"}], "]"}], 
     ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{
        RowBox[{"Length", "[", "pointList", "]"}], " ", "-", " ", "1"}]}], 
      "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lowerHemisphereGrid", "[", 
    RowBox[{"gridSkip_", ",", " ", "sampleSkip_"}], "]"}], " ", ":=", " ", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "curves", ",", " ", "curve", ",", " ", "phi", ",", " ", "theta"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"curves", " ", "=", " ", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"phi", " ", "=", " ", "gridSkip"}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"phi", " ", "<", " ", "Pi"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"curve", " ", "=", " ", 
          RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"theta", " ", "=", " ", "0"}], ";", "\[IndentingNewLine]", 
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"theta", " ", "\[LessEqual]", " ", "Pi"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"curve", " ", "=", " ", 
             RowBox[{"Append", "[", 
              RowBox[{"curve", ",", " ", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Sin", "[", "phi", "]"}], " ", 
                  RowBox[{"Cos", "[", "theta", "]"}]}], ",", " ", 
                 RowBox[{"Cos", "[", "phi", "]"}], ",", " ", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"Sin", "[", "phi", "]"}]}], " ", 
                  RowBox[{"Sin", "[", "theta", "]"}]}]}], "}"}]}], "]"}]}], 
            ";", "\[IndentingNewLine]", 
            RowBox[{"theta", " ", "=", " ", 
             RowBox[{"theta", " ", "+", " ", "sampleSkip"}]}]}]}], "]"}], ";",
          "\[IndentingNewLine]", 
         RowBox[{"curves", " ", "=", " ", 
          RowBox[{"Append", "[", 
           RowBox[{"curves", ",", " ", "curve"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"phi", " ", "=", " ", 
          RowBox[{"phi", " ", "+", " ", "gridSkip"}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"theta", " ", "=", " ", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"theta", " ", "\[LessEqual]", " ", "Pi"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"curve", " ", "=", " ", 
          RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"phi", " ", "=", " ", "0"}], ";", "\[IndentingNewLine]", 
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{"phi", " ", "\[LessEqual]", " ", "Pi"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"curve", " ", "=", " ", 
             RowBox[{"Append", "[", 
              RowBox[{"curve", ",", " ", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Sin", "[", "phi", "]"}], " ", 
                  RowBox[{"Cos", "[", "theta", "]"}]}], ",", " ", 
                 RowBox[{"Cos", "[", "phi", "]"}], ",", " ", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"Sin", "[", "phi", "]"}]}], " ", 
                  RowBox[{"Sin", "[", "theta", "]"}]}]}], "}"}]}], "]"}]}], 
            ";", "\[IndentingNewLine]", 
            RowBox[{"phi", " ", "=", " ", 
             RowBox[{"phi", " ", "+", " ", "sampleSkip"}]}]}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"curves", " ", "=", " ", 
          RowBox[{"Append", "[", 
           RowBox[{"curves", ",", " ", "curve"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"theta", " ", "=", " ", 
          RowBox[{"theta", " ", "+", " ", "gridSkip"}]}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", "curves"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"schmidtNet", "[", 
     RowBox[{"gridSkip_", ",", " ", "sampleSkip_"}], "]"}], " ", ":=", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"Graphics", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"GrayLevel", "[", ".7", "]"}], ",", "Thin", ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{"Function", "[", 
           RowBox[{"curve", ",", " ", 
            RowBox[{"curvePrimitive", "[", 
             RowBox[{"Map", "[", 
              RowBox[{"equalAreaProjection", ",", "curve"}], "]"}], "]"}]}], 
           "]"}], ",", " ", 
          RowBox[{"lowerHemisphereGrid", "[", 
           RowBox[{"gridSkip", ",", " ", "sampleSkip"}], "]"}]}], "]"}]}], 
       "}"}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Needs", "[", "\"\<PlotLegends`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"LegendPosition", "::", "\"\<shdw\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Off", "[", 
    RowBox[{"ShowLegend", "::", "\"\<shdw\>\""}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IntermPtLabel", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"Graphics", "[", 
     RowBox[{"Tooltip", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Blue", ",", 
         RowBox[{"PointSize", "[", ".025", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"equalAreaProjection", "[", 
           RowBox[{"lowerHemisphere", "[", 
            RowBox[{"IntermAxis", ".", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], "]"}], 
           "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"DisplayForm", "[", 
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<(\>\"", "<>", 
           RowBox[{"ToString", "[", 
            RowBox[{"N", "[", "ITrend", "]"}], "]"}], "<>", 
           RowBox[{"ToString", "[", "\"\<,\>\"", "]"}], "<>", 
           RowBox[{"ToString", "[", 
            RowBox[{"N", "[", "IPlunge", "]"}], "]"}], "<>", 
           RowBox[{"ToString", "[", "\"\<)\>\"", "]"}]}], "}"}], "]"}], 
        "]"}]}], "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"LongPtLabel", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"Graphics", "[", 
     RowBox[{"Tooltip", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Red", ",", 
         RowBox[{"PointSize", "[", ".025", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"equalAreaProjection", "[", 
           RowBox[{"lowerHemisphere", "[", 
            RowBox[{"LongAxis", ".", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], "]"}], 
           "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"DisplayForm", "[", 
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<(\>\"", "<>", 
           RowBox[{"ToString", "[", 
            RowBox[{"N", "[", "LTrend", "]"}], "]"}], "<>", 
           RowBox[{"ToString", "[", "\"\<,\>\"", "]"}], "<>", 
           RowBox[{"ToString", "[", 
            RowBox[{"N", "[", "LPlunge", "]"}], "]"}], "<>", 
           RowBox[{"ToString", "[", "\"\<)\>\"", "]"}]}], "}"}], "]"}], 
        "]"}]}], "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"ShortPtLabel", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"Graphics", "[", 
      RowBox[{"Tooltip", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"CMYKColor", "[", 
           RowBox[{".95", ",", ".3", ",", "1", ",", ".2"}], "]"}], ",", 
          RowBox[{"PointSize", "[", ".025", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"equalAreaProjection", "[", 
            RowBox[{"lowerHemisphere", "[", 
             RowBox[{"ShortAxis", ".", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "1"}], ",", "0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], "]"}], 
            "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"DisplayForm", "[", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<(\>\"", "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{"N", "[", "STrend", "]"}], "]"}], "<>", 
            RowBox[{"ToString", "[", "\"\<,\>\"", "]"}], "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{"N", "[", "SPlunge", "]"}], "]"}], "<>", 
            RowBox[{"ToString", "[", "\"\<)\>\"", "]"}]}], "}"}], "]"}], 
         "]"}]}], "]"}], "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sumptsize", "=", "0.015"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SumShortFit", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"equalAreaPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"cartesianFromTrendPlungeDeg", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"STrend", "\[Equal]", "\"\<NA\>\""}], ",", "000", ",", 
            "STrend"}], "]"}], ",", "SPlunge"}], "}"}], "]"}], "}"}], ",", 
      " ", 
      RowBox[{"FitSizePercent", "*", "sumptsize"}], ",", 
      RowBox[{"CMYKColor", "[", 
       RowBox[{".95", ",", ".3", ",", "1", ",", ".2"}], "]"}]}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SumIntermFit", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"equalAreaPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"cartesianFromTrendPlungeDeg", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"ITrend", "\[Equal]", "\"\<NA\>\""}], ",", "000", ",", 
            "ITrend"}], "]"}], ",", "IPlunge"}], "}"}], "]"}], "}"}], ",", 
      " ", 
      RowBox[{"FitSizePercent", "*", "sumptsize"}], ",", "Blue"}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SumLongFit", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"equalAreaPlot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"cartesianFromTrendPlungeDeg", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"LTrend", "\[Equal]", "\"\<NA\>\""}], ",", "000", ",", 
            "LTrend"}], "]"}], ",", "LPlunge"}], "}"}], "]"}], "}"}], ",", 
      " ", 
      RowBox[{"FitSizePercent", "*", "sumptsize"}], ",", "Red"}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AxesPlot", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"schmidtNet", "[", 
      RowBox[{
       RowBox[{"10", " ", "Degree"}], ",", " ", 
       RowBox[{"5", " ", "Degree"}]}], "]"}], ",", "SumLongFit", ",", 
     "SumShortFit", ",", "SumIntermFit", ",", "LongPtLabel", ",", 
     "IntermPtLabel", ",", "ShortPtLabel", ",", 
     RowBox[{"PlotLabel", "\[Rule]", 
      RowBox[{"Style", "[", 
       RowBox[{
       "\"\<Principal Axes Orientations\>\"", ",", "24", ",", "Blue", ",", 
        "Bold"}], "]"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"PrinAxesPlot", "=", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"ShowLegend", "[", 
      RowBox[{"AxesPlot", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Red", ",", 
                RowBox[{"Disk", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", ".1"}], "]"}]}], 
               "}"}], "]"}], ",", 
             RowBox[{"Text", "[", 
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Long Axis\>\"", ",", 
                RowBox[{"FontSize", "\[Rule]", "18"}]}], "]"}], "]"}]}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{"Blue", ",", 
                RowBox[{"Disk", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", ".1"}], "]"}]}], 
               "}"}], "]"}], ",", 
             RowBox[{"Text", "[", 
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Intermediate Axis\>\"", ",", 
                RowBox[{"FontSize", "\[Rule]", "18"}]}], "]"}], "]"}]}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Graphics", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"CMYKColor", "[", 
                 RowBox[{".95", ",", ".3", ",", "1", ",", ".2"}], "]"}], ",", 
                RowBox[{"Disk", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}], ",", ".1"}], "]"}]}], 
               "}"}], "]"}], ",", 
             RowBox[{"Text", "[", 
              RowBox[{"Style", "[", 
               RowBox[{"\"\<Short Axis\>\"", ",", 
                RowBox[{"FontSize", "\[Rule]", "18"}]}], "]"}], "]"}]}], 
            "}"}]}], "}"}], ",", 
         RowBox[{"LegendPosition", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"0.85", ",", 
            RowBox[{"-", "0.95"}]}], "}"}]}]}], "}"}]}], "]"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "850"}]}], "]"}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ElleWOplanes", "=", 
   RowBox[{"Show", "[", 
    RowBox[{"Vellipsoid", ",", 
     RowBox[{"BoxRatios", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<\[UpArrow] North \>\"", ",", "\"\<East \[Rule] \>\"", ",", 
        "\"\<Up \[UpArrow] \>\""}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Lval", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "*", "1.1"}], ",", 
          RowBox[{
           RowBox[{"Lval", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "*", "1.1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Lval", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "*", "1.1"}], ",", 
          RowBox[{
           RowBox[{"Lval", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "*", "1.1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Lval", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "*", "1.1"}], ",", 
          RowBox[{
           RowBox[{"Lval", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "*", "1.1"}]}], "}"}]}], "}"}]}], 
     ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "3"}], ",", "0", ",", "3"}], "}"}]}], ",", 
     RowBox[{"Ticks", "\[Rule]", "False"}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<K = \>\"", ",", 
    RowBox[{"N", "[", "K", "]"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Lode's Ratio, \[Nu] = \>\"", ",", 
    RowBox[{"N", "[", "\[Nu]", "]"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Octahedral Shear Strain, \[Epsilon]s = \>\"", ",", 
    RowBox[{"N", "[", "\[Epsilon]s", "]"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Length of the Long axis = \>\"", ",", 
    RowBox[{"Lval", "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", "\"\<(units)\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Length of the Intermediate axis = \>\"", ",", 
    RowBox[{"Lval", "[", 
     RowBox[{"[", "2", "]"}], "]"}], ",", "\"\<(units)\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Length of the Short axis = \>\"", ",", 
    RowBox[{"Lval", "[", 
     RowBox[{"[", "3", "]"}], "]"}], ",", "\"\<(units)\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Volume of the Ellipsoid = \>\"", ",", 
    RowBox[{"Pi", "*", 
     RowBox[{"Lval", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "*", 
     RowBox[{"Lval", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "*", 
     RowBox[{"Lval", "[", 
      RowBox[{"[", "3", "]"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{"4", "/", "3"}], ")"}]}], ",", 
    "\"\<(\!\(\*SuperscriptBox[\(units\), \(3\)]\))\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The Trend:Plunge of the Long Axis = \>\"", ",", 
    RowBox[{"N", "[", "LTrend", "]"}], ",", "\"\<\[Degree]:\>\"", ",", 
    RowBox[{"N", "[", "LPlunge", "]"}], ",", "\"\<\[Degree]\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The Trend:Plunge of the Intermediate Axis = \>\"", ",", 
    RowBox[{"N", "[", "ITrend", "]"}], ",", "\"\<\[Degree]:\>\"", ",", 
    RowBox[{"N", "[", "IPlunge", "]"}], ",", "\"\<\[Degree]\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The Trend:Plunge of the Short Axis = \>\"", ",", 
    RowBox[{"N", "[", "STrend", "]"}], ",", "\"\<\[Degree]:\>\"", ",", 
    RowBox[{"N", "[", "SPlunge", "]"}], ",", "\"\<\[Degree]\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<Mean Error (zero is a perfect fit) = \>\"", ",", "MeanDiffError"}], 
    "]"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"Problem", "\[Equal]", "1"}], ",", 
    RowBox[{
    "Print", "[", "\"\<More data is needed to constrain the solution.\>\"", 
     "]"}]}], "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"Problem", "\[Equal]", "1"}], ",", 
    RowBox[{"EmitSound", "[", 
     RowBox[{"Sound", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"SoundNote", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"DeleteCases", "[", 
            RowBox[{
             RowBox[{"3", " ", 
              RowBox[{"Range", "[", "21", "]"}], 
              RowBox[{"Reverse", "[", "#", "]"}]}], ",", "0"}], "]"}], "-", 
           "24"}], ",", ".1"}], "]"}], "&"}], "/@", 
       RowBox[{"Transpose", "[", 
        RowBox[{"CellularAutomaton", "[", 
         RowBox[{"90", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "1", "}"}], ",", "0"}], "}"}], ",", "20"}], "]"}], 
        "]"}]}], "]"}], "]"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"reducedprecision", "\[Equal]", "1"}], ",", 
     RowBox[{
     "Print", "[", 
      "\"\<The working precision was reduced in order to make the function \
converge\>\"", "]"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.487174247242574*^9, 3.4871742776123114`*^9}, 
   3.4871743338275266`*^9, {3.487174762772061*^9, 3.4871747985711083`*^9}, {
   3.48717490176101*^9, 3.4871749090874295`*^9}, {3.4871749554500813`*^9, 
   3.48717502361598*^9}, {3.4871862392520313`*^9, 3.487186271423872*^9}, {
   3.487186360744981*^9, 3.4871863936968656`*^9}, 3.487186428625863*^9, {
   3.4871865765023212`*^9, 3.487186577094355*^9}, {3.4871866405469847`*^9, 
   3.4871866966911955`*^9}, {3.487186901263897*^9, 3.4871869297615266`*^9}, {
   3.4871869857947316`*^9, 3.487186995583291*^9}, {3.487187104629528*^9, 
   3.487187110441861*^9}, {3.487187144660818*^9, 3.487187203680194*^9}, 
   3.4871883033280897`*^9, {3.487203071425685*^9, 3.487203090535719*^9}, 
   3.4872045032274*^9, {3.4872463495157666`*^9, 3.4872463693439007`*^9}, {
   3.487246433157551*^9, 3.487246435278672*^9}, {3.4872473815177937`*^9, 
   3.487247450426735*^9}, {3.4872474820085416`*^9, 3.4872477205581856`*^9}, {
   3.487248117408884*^9, 3.4872481184019413`*^9}, {3.487248178762394*^9, 
   3.4872482110042377`*^9}, {3.4872482608720903`*^9, 3.487248319881465*^9}, 
   3.4872483575806217`*^9, {3.487248908602138*^9, 3.487248909463187*^9}, {
   3.487249340737855*^9, 3.4872493588798923`*^9}, {3.4872496780271463`*^9, 
   3.4872497003824253`*^9}, {3.487250023118885*^9, 3.487250027655144*^9}, {
   3.487250575263466*^9, 3.487250676430252*^9}, {3.487251411085272*^9, 
   3.487251471173709*^9}, {3.487251816966487*^9, 3.487251829224188*^9}, {
   3.4872519179082603`*^9, 3.487251966365032*^9}, {3.4872520257294273`*^9, 
   3.487252033389866*^9}, {3.4872523305878644`*^9, 3.487252332862994*^9}, {
   3.4872523688660536`*^9, 3.4872523709751744`*^9}, 3.4872527765613728`*^9, {
   3.4872528923829975`*^9, 3.487252892648012*^9}, {3.487499290280834*^9, 
   3.48749930069143*^9}, {3.48749933355931*^9, 3.487499376693777*^9}, {
   3.4874994538371897`*^9, 3.48749946608889*^9}, {3.487499503736044*^9, 
   3.4874995041570673`*^9}, {3.487507728289461*^9, 3.487507734874838*^9}, {
   3.4875080286316395`*^9, 3.4875080768673983`*^9}, {3.4875082677043138`*^9, 
   3.4875083238205233`*^9}, {3.487508913094228*^9, 3.487508937050598*^9}, {
   3.4875876017805667`*^9, 3.487587603337656*^9}, {3.4875892032991686`*^9, 
   3.4875892051122723`*^9}, {3.487589275342289*^9, 3.4875892781714506`*^9}, {
   3.4875909175242167`*^9, 3.4875909362422867`*^9}, {3.487591048960734*^9, 
   3.4875911435141425`*^9}, 3.487591236332451*^9, {3.487591325170532*^9, 
   3.4875913269496346`*^9}, {3.4875913587614536`*^9, 
   3.4875913744783525`*^9}, {3.4875915221567993`*^9, 3.487591533167429*^9}, {
   3.487591630017969*^9, 3.487591630756011*^9}, {3.4875916701542645`*^9, 
   3.487591717766988*^9}, {3.487591978521902*^9, 3.4875919790189304`*^9}, {
   3.4876119442692347`*^9, 3.487611949521535*^9}, {3.4876123171505623`*^9, 
   3.4876123207197666`*^9}, {3.4876123583329177`*^9, 3.487612362155136*^9}, {
   3.487620968917506*^9, 3.4876209735663147`*^9}, {3.487621086931713*^9, 
   3.4876211069621487`*^9}, {3.4876211776146727`*^9, 3.48762118185788*^9}, {
   3.4876223429523196`*^9, 3.4876224066628313`*^9}, {3.4876226462948523`*^9, 
   3.4876226545940666`*^9}, {3.4879378505605435`*^9, 3.487937852526147*^9}, {
   3.4879389595976915`*^9, 3.4879389806109285`*^9}, 3.487954506800294*^9, 
   3.4879552059462833`*^9, {3.487955354226764*^9, 3.4879553548828015`*^9}, 
   3.4879778865925393`*^9, {3.488026762836731*^9, 3.4880267855730314`*^9}, {
   3.4880286760411596`*^9, 3.488028691873065*^9}, {3.48802875996296*^9, 
   3.4880287779629893`*^9}, {3.488029402590716*^9, 3.488029423166893*^9}, 
   3.4881035588680367`*^9, 3.4881039206262083`*^9, 3.488104120777656*^9, 
   3.488104903078401*^9, {3.4881050616464705`*^9, 3.488105078194417*^9}, {
   3.4881111465675077`*^9, 3.488111160340296*^9}, {3.488112068437236*^9, 
   3.4881120941107044`*^9}, 3.4881151584709883`*^9, {3.488131862127383*^9, 
   3.4881319519195185`*^9}, {3.4881327730814867`*^9, 3.488132802714182*^9}, {
   3.4881871755509825`*^9, 3.488187183630445*^9}, 3.4881889555927954`*^9, {
   3.488189998898469*^9, 3.488190098602172*^9}, {3.4881901543543606`*^9, 
   3.488190173469454*^9}, {3.4881903638923454`*^9, 3.488190380942321*^9}, {
   3.4882137973446627`*^9, 3.4882138365939074`*^9}, {3.4882140471889524`*^9, 
   3.488214056358477*^9}, {3.4882148881910553`*^9, 3.4882148951354523`*^9}, 
   3.4882149283413515`*^9, {3.4882302297011557`*^9, 3.4882302344904294`*^9}, 
   3.488231704599515*^9, {3.4882319839284916`*^9, 3.4882319992813697`*^9}, {
   3.488275876124522*^9, 3.488275881496829*^9}, 3.488276068637533*^9, 
   3.4882765579205184`*^9, 3.488277169769514*^9, 3.48827741201637*^9, {
   3.488277522075665*^9, 3.488277525446858*^9}, 3.488278079202531*^9, {
   3.488278397793753*^9, 3.488278425786354*^9}, {3.488278718245082*^9, 
   3.488278719804171*^9}, {3.488281865350086*^9, 3.488281871320428*^9}, {
   3.4882830136195784`*^9, 3.4882830192511883`*^9}, {3.488283407479191*^9, 
   3.48828342058294*^9}, {3.488285026388787*^9, 3.4882850392645235`*^9}, 
   3.4882907709793587`*^9, {3.488291081025092*^9, 3.4882910896975884`*^9}, {
   3.4882911289018307`*^9, 3.4882911544232903`*^9}, {3.488291200132905*^9, 
   3.4882912002289104`*^9}, {3.4882912461585374`*^9, 
   3.4882912662906885`*^9}, {3.4882912993615804`*^9, 3.488291313319379*^9}, {
   3.488292675314749*^9, 3.4882926928803797`*^9}, {3.488292814825794*^9, 
   3.4882928340762277`*^9}, 3.488293248100955*^9, {3.488293668880494*^9, 
   3.4882943519120936`*^9}, {3.488294386169754*^9, 3.4882944270418253`*^9}, 
   3.488294576739689*^9, {3.4883963963753386`*^9, 3.4883964781840177`*^9}, {
   3.4883965083107405`*^9, 3.488396598437896*^9}, {3.4883970123125677`*^9, 
   3.488397038351057*^9}, {3.4883973207822113`*^9, 3.4883973230023384`*^9}, {
   3.4884010355926867`*^9, 3.4884010418300433`*^9}, {3.4884029584056654`*^9, 
   3.4884029600077567`*^9}, {3.4884030443625813`*^9, 
   3.4884030517140017`*^9}, {3.4884559968958817`*^9, 3.4884560201222105`*^9}, 
   3.4884561828885202`*^9, {3.4884595324081016`*^9, 3.4884595557644377`*^9}, 
   3.488488413833895*^9, {3.488488614512373*^9, 3.488488650284419*^9}, 
   3.4884941868160906`*^9, 3.488494307578998*^9, 3.488494915640777*^9, {
   3.4884969399105587`*^9, 3.4884969446568303`*^9}, 3.4884970443505325`*^9, {
   3.488497121122924*^9, 3.4884971234120545`*^9}, {3.488497153530777*^9, 
   3.4884971544248285`*^9}, 3.488497216257365*^9, 3.4884982796191854`*^9, {
   3.4884985827925262`*^9, 3.4884985838495865`*^9}, 3.488548766839347*^9, {
   3.4885546595003877`*^9, 3.48855467351919*^9}, {3.488554768972649*^9, 
   3.488554780388302*^9}, {3.4885548176644344`*^9, 3.488554834780413*^9}, 
   3.4885558246670313`*^9, {3.488555877735067*^9, 3.488555885167492*^9}, {
   3.488555925882821*^9, 3.488555968589263*^9}, {3.488556183800573*^9, 
   3.4885561926470785`*^9}, {3.4885565714927473`*^9, 3.488556578579153*^9}, {
   3.488556819261919*^9, 3.488556860995306*^9}, 3.489757221378025*^9, {
   3.4897714976971006`*^9, 3.489771499584704*^9}, {3.4899235962696867`*^9, 
   3.489923596809717*^9}, {3.4900048505124407`*^9, 3.4900048575248413`*^9}, {
   3.490004927360836*^9, 3.490004927640852*^9}, {3.4900054204690404`*^9, 
   3.49000542064305*^9}, {3.4900273743567305`*^9, 3.490027413935995*^9}, 
   3.4900274660839777`*^9, {3.4900314898301225`*^9, 3.4900314904871597`*^9}, 
   3.490031551025623*^9, {3.4900342535741997`*^9, 3.4900342782086086`*^9}, {
   3.490036273490732*^9, 3.4900362852984076`*^9}, {3.4900363603587008`*^9, 
   3.490036371115316*^9}, 3.490037162197563*^9, 3.4900403448696017`*^9, 
   3.490048845135789*^9, 3.4904418396813517`*^9, {3.4904419441003237`*^9, 
   3.490441947441515*^9}, {3.490441986359741*^9, 3.4904420592999134`*^9}, 
   3.490444327068622*^9, {3.4904444014798784`*^9, 3.4904444022399216`*^9}, 
   3.4904474676582537`*^9, 3.49044858339207*^9, 3.490450905146867*^9, 
   3.490451714886181*^9, 3.490452510791704*^9, 3.490453288249172*^9, 
   3.490464459496053*^9, {3.4904681593526726`*^9, 3.4904681643289576`*^9}, {
   3.4904682052062955`*^9, 3.4904682058513327`*^9}, 3.490531867888402*^9, {
   3.4905333015014*^9, 3.4905333019644265`*^9}, 3.4907062892196035`*^9, {
   3.490708250619789*^9, 3.4907082541179895`*^9}, {3.490712025183682*^9, 
   3.4907120313920374`*^9}, {3.4907128353390207`*^9, 3.490712841327363*^9}, 
   3.490714884718238*^9, 3.4907291944635754`*^9, 3.490729713173244*^9, {
   3.490730085218524*^9, 3.490730101265442*^9}, {3.4907306694449396`*^9, 
   3.4907306727751303`*^9}, {3.490731048785637*^9, 3.49073105373092*^9}, {
   3.4907317737701035`*^9, 3.4907318297893076`*^9}, {3.49073192354667*^9, 
   3.490731949549157*^9}, 3.490732404969206*^9, {3.490732482961667*^9, 
   3.490732520929838*^9}, {3.490732560906125*^9, 3.490732566699456*^9}, {
   3.4907951817937293`*^9, 3.4907952097603292`*^9}, 3.49079688138494*^9, 
   3.4909578135058956`*^9, {3.490966426065824*^9, 3.4909664589038815`*^9}, 
   3.4909679863493643`*^9, {3.4909682970395103`*^9, 3.4909683252911596`*^9}, {
   3.490972673956398*^9, 3.4909726987292414`*^9}, 3.4909728202534547`*^9, {
   3.490972862435929*^9, 3.4909728817019625`*^9}, {3.490972913073618*^9, 
   3.4909729566132946`*^9}, {3.490973518869482*^9, 3.4909735657475643`*^9}, {
   3.4909736125476465`*^9, 3.490973619021658*^9}, {3.490973703355406*^9, 
   3.4909737369578648`*^9}, {3.490973801963179*^9, 3.4909738048959846`*^9}, 
   3.490974014136751*^9, 3.4911489290724*^9, 3.491152414014719*^9, {
   3.4911532777726364`*^9, 3.491153287179453*^9}, {3.4911533826048203`*^9, 
   3.4911533843676233`*^9}, 3.4911608269218388`*^9, 3.4911610198473773`*^9, {
   3.4912215420326176`*^9, 3.4912215503786325`*^9}, 3.4912215809234858`*^9, {
   3.491221615103146*^9, 3.4912217052401047`*^9}, 3.4912220487527075`*^9, {
   3.4912290845968103`*^9, 3.4912290884968166`*^9}, {3.4912385323231597`*^9, 
   3.491238550410194*^9}, 3.491238719776881*^9, {3.4912389233205233`*^9, 
   3.4912389754925075`*^9}, 3.491241094984701*^9, 3.4912414098657107`*^9, {
   3.491385847243327*^9, 3.4913859619878902`*^9}, 3.4913859937217054`*^9, {
   3.491386060978552*^9, 3.4913860866870227`*^9}, 3.491386146561447*^9, {
   3.491386424457342*^9, 3.4913864460755787`*^9}, {3.4913864766593275`*^9, 
   3.49138647687934*^9}, 3.491397677026628*^9, 3.4913977115026884`*^9, 
   3.4913978076456575`*^9, 3.4913980532212887`*^9, {3.491398197490342*^9, 
   3.491398204603955*^9}, {3.491398273540476*^9, 3.4913983694494443`*^9}, {
   3.4913984869332504`*^9, 3.491398496948468*^9}, 3.4914136297351246`*^9, 
   3.4914140468859844`*^9, {3.491416748060483*^9, 3.4914167482264924`*^9}, 
   3.4914168077348957`*^9, {3.4916705003527727`*^9, 3.491670503035977*^9}, {
   3.491670536529236*^9, 3.4916706071469603`*^9}, {3.4916706472234306`*^9, 
   3.4916706812470903`*^9}, {3.4916708342053595`*^9, 3.491670835266161*^9}, {
   3.4916709879504294`*^9, 3.491670997248046*^9}, 3.4916710720657773`*^9, {
   3.4917362307280855`*^9, 3.491736236375295*^9}, {3.491736287652585*^9, 
   3.49173648371373*^9}, {3.4917372333262467`*^9, 3.4917372347458496`*^9}, 
   3.4917372742763186`*^9, 3.4918499908880067`*^9, {3.49194008792935*^9, 
   3.4919400883505507`*^9}, {3.4919402282671967`*^9, 
   3.4919402295931993`*^9}, {3.4968251903923903`*^9, 3.496825223213194*^9}, {
   3.4968254530659294`*^9, 3.4968255575707097`*^9}, 3.4968261056500845`*^9, {
   3.4968265429314823`*^9, 3.4968265481427803`*^9}, 3.496826601390794*^9, {
   3.4968266512696466`*^9, 3.496826654096808*^9}, {3.496826782880129*^9, 
   3.496826824518507*^9}, {3.496828531730624*^9, 3.496828533445722*^9}, {
   3.496828605156804*^9, 3.496828605533826*^9}, {3.496828661187009*^9, 
   3.4968286692754717`*^9}, 3.496828730113943*^9, {3.4968288101334667`*^9, 
   3.4968288838726473`*^9}, {3.496828923024887*^9, 3.4968289823032417`*^9}, {
   3.4968300729289045`*^9, 3.496830095038164*^9}, 3.4969079758841925`*^9, 
   3.496940472866914*^9, 3.4994671877282686`*^9, {3.5033168957512093`*^9, 
   3.503316932454099*^9}, {3.503317042906517*^9, 3.5033171029998827`*^9}, {
   3.5033171562495418`*^9, 3.5033171655151076`*^9}, {3.503317245608345*^9, 
   3.5033173250453367`*^9}, {3.503317359826364*^9, 3.5033173689981804`*^9}, {
   3.50331739954486*^9, 3.5033174389196076`*^9}, {3.503318218867741*^9, 
   3.503318259961228*^9}, {3.50332303538379*^9, 3.5033230402275095`*^9}, 
   3.5033231502893047`*^9, {3.503323211710787*^9, 3.5033232559136286`*^9}, {
   3.503323409022024*^9, 3.5033234092563972`*^9}, 3.503323744035505*^9, {
   3.503323781316516*^9, 3.503323781910262*^9}, 3.503323820535015*^9, {
   3.503325373915698*^9, 3.5033254489152184`*^9}, {3.503325833319008*^9, 
   3.503325891287387*^9}, {3.5033277428067875`*^9, 3.503327844587386*^9}, {
   3.5033289913925467`*^9, 3.503328992564414*^9}, 3.50333016269755*^9, {
   3.5033301980879483`*^9, 3.5033302456188946`*^9}, {3.503330419914654*^9, 
   3.5033304238365035`*^9}, {3.5037795013732033`*^9, 3.5037795733534327`*^9}, 
   3.503779622397482*^9, {3.503861037609375*^9, 3.503861044*^9}, {
   3.5051374775339622`*^9, 3.5051374937058873`*^9}, {3.5052448093854065`*^9, 
   3.505244832941448*^9}, {3.517929933542421*^9, 3.517929937988675*^9}, {
   3.517958773042946*^9, 3.5179587732069554`*^9}, {3.517958838164671*^9, 
   3.517958846669157*^9}, {3.5192967941633267`*^9, 3.5192968145534935`*^9}, {
   3.519296860148101*^9, 3.519296883109414*^9}, 3.519392039044114*^9, {
   3.519392665959972*^9, 3.519392678099666*^9}, {3.5220134604343414`*^9, 
   3.5220134740063653`*^9}, {3.522013513349634*^9, 3.522013523723653*^9}, 
   3.5220268000753126`*^9, 3.54771905272899*^9, {3.547893400148898*^9, 
   3.547893418119923*^9}, {3.5479846952723317`*^9, 3.5479847010911417`*^9}, {
   3.547987891396143*^9, 3.547987900178958*^9}, {3.547990314790062*^9, 
   3.5479903208896723`*^9}, 3.6115001532671127`*^9, 3.6115004688831644`*^9, {
   3.611500513580721*^9, 3.6115005803585405`*^9}, {3.6115011802578526`*^9, 
   3.611501181726937*^9}, 3.611620810887003*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Below", " ", "you", " ", "can", " ", "export", " ", "your", " ", 
     "ellipsoid", " ", "to", " ", "a", " ", "graphics", " ", "file"}], ",", 
    " ", "although", ",", " ", 
    RowBox[{
    "it", " ", "is", " ", "generally", " ", "easier", " ", "to", " ", 
     "simpliy", " ", "click", " ", "on", " ", "the", " ", "image", " ", "and",
      " ", "copy", " ", "and", " ", "paste", " ", "it", " ", "into", " ", 
     "another", " ", "program", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"e", ".", "g", "."}], ",", " ", 
        RowBox[{
        "Adobe", " ", "Illustrator", " ", "or", " ", "Adobe", " ", 
         "Photoshop"}]}], ")"}], ".", "  ", "With"}], " ", "some", " ", 
     "Mathematica", " ", "graphics"}], ",", " ", 
    RowBox[{
    "pasting", " ", "the", " ", "image", " ", "into", " ", "Adobe", " ", 
     "Illustrator", " ", 
     RowBox[{"(", 
      RowBox[{"or", " ", "similar", " ", "programs"}], ")"}], " ", "gives", 
     " ", "you", " ", "the", " ", "ability", " ", "to", " ", "continue", " ", 
     "to", " ", "manipulate", " ", "the", " ", "image", " ", "as", " ", "a", 
     " ", "vector", " ", "diagram", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"e", ".", "g", "."}], ",", " ", 
       RowBox[{
       "you", " ", "can", " ", "change", " ", "the", " ", "stroke", " ", 
        "weight", " ", "for", " ", "individual", " ", "lines"}], ",", " ", 
       RowBox[{"change", " ", "colors", " ", "of", " ", "points"}], ",", " ", 
       "lines", ",", " ", "text", ",", " ", 
       RowBox[{"etc", "."}]}], ")"}], " ", "while", " ", "other", " ", 
     "graphics", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"for", " ", "instance"}], ",", " ", 
       RowBox[{
        RowBox[{"the", " ", "three"}], "-", 
        RowBox[{"dimensional", " ", "ellipsoid", " ", "graphic"}]}]}], ")"}], 
     " ", "will", " ", "get", " ", "pasted", " ", "into", " ", "Illustrator", 
     " ", "as", " ", "a", " ", "rastor", " ", "image", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"i", ".", "e", "."}], ",", " ", 
        RowBox[{"like", " ", "a", " ", "static", " ", "photograph"}]}], ")"}],
       ".", " ", "If"}], " ", "you", " ", "are", " ", "using", " ", "a", " ", 
     "Windows", " ", "operating", " ", "system"}], ",", " ", 
    RowBox[{
    "your", " ", "file", " ", "will", " ", "appear", " ", "in", " ", "your", 
     " ", "\"\<My Documents\>\"", " ", "folder", " ", "unless", " ", "you", 
     " ", "have", " ", "specified", " ", "a", " ", "different", " ", 
     RowBox[{"path", ".", " ", "To"}], " ", "determine", " ", "your", " ", 
     "the", " ", "current", " ", "working", " ", "directory", " ", "type", 
     " ", "\"\<Directory[]\>\"", " ", "into", " ", "an", " ", "empty", " ", 
     "cell", " ", "and", " ", "evaluate", " ", "that", " ", 
     RowBox[{"cell", ".", "  ", "You"}], " ", "can", " ", "also", " ", 
     "change", " ", "the", " ", "directory", " ", "with", " ", "the", " ", 
     RowBox[{"SetDirectory", "[", "]"}], " ", 
     RowBox[{"function", "."}]}]}], " ", "*)"}], "\n", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<EllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.jpg\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ElleWOplanes"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<EllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.tif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ElleWOplanes"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<EllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.gif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ElleWOplanes"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"the", " ", "*", 
      RowBox[{".", "eps"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"and", " ", "sometimes", " ", "the", " ", "*", 
         RowBox[{".", "wmf"}]}], ",", " ", 
        RowBox[{
         RowBox[{
         "however", " ", "not", " ", "with", " ", "the", " ", "three"}], "-", 
         RowBox[{
         "dimensional", " ", "images", " ", "like", " ", "the", " ", 
          "ellipsoids"}]}]}], ")"}], " ", "file", " ", "format", " ", "saves",
       " ", "the", " ", "image", " ", "as", " ", "a", " ", "vector", " ", 
      RowBox[{"image", ".", "  ", "As"}], " ", "mentioned", " ", "above"}], 
     ",", " ", 
     RowBox[{
      RowBox[{
      "this", " ", "has", " ", "the", " ", "advantage", " ", "of", " ", 
       "being", " ", "able", " ", "to", " ", "manipulate", " ", "individual", 
       " ", "components", " ", "of", " ", "the", " ", "image", " ", "using", 
       " ", "programs", " ", "like", " ", "Adobe", " ", "Illustrator"}], ";", 
      " ", "however"}], ",", " ", 
     RowBox[{"you", " ", "may", " ", "loose", " ", "some", " ", 
      RowBox[{"resolution", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<EllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.pdf\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ElleWOplanes"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<EllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.eps\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ElleWOplanes"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4967750049414854`*^9, 3.496775058535248*^9}, {
   3.4967752804922247`*^9, 3.496775442930035*^9}, {3.4967754946418276`*^9, 
   3.4967757176159024`*^9}, {3.496775759380167*^9, 3.4967757603632207`*^9}, {
   3.496928988470044*^9, 3.496928989289091*^9}, {3.4969291953258753`*^9, 
   3.496929208481628*^9}, {3.496939064591365*^9, 3.4969390915569077`*^9}, 
   3.4969514021846385`*^9, 3.4969515764426055`*^9, 3.496951783440445*^9, {
   3.496951852793412*^9, 3.4969518530864286`*^9}, 3.5032390337527504`*^9, {
   3.503239666154953*^9, 3.503239676201764*^9}, {3.5032397204827304`*^9, 
   3.50323973224828*^9}, {3.5032397814198403`*^9, 3.5032398065446796`*^9}, {
   3.503239880231708*^9, 3.5032399989340734`*^9}, {3.5032401029802823`*^9, 
   3.5032401114177284`*^9}, {3.503240167339246*^9, 3.503240177886053*^9}, {
   3.5032404392750053`*^9, 3.503240602711459*^9}, {3.503240661039211*^9, 
   3.50324067366413*^9}, {3.5032407095857754`*^9, 3.5032407156326113`*^9}, 
   3.547980071371978*^9, {3.611058618320553*^9, 3.611058653854585*^9}, 
   3.611621234028205*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Here", " ", "you", " ", "can", " ", "choose", " ", "your", " ", "own", 
    " ", "viewing", " ", "perspective", " ", 
    RowBox[{"(", 
     RowBox[{
     "simply", " ", "change", " ", "the", " ", "vector", " ", "components", 
      " ", "of", " ", "ViewingDir", " ", "and", " ", "control", " ", "the", 
      " ", "distance", " ", "by", " ", "changing", " ", "Scaling"}], ")"}], 
    " ", "and", " ", "the", " ", "axes", " ", "labels", " ", 
    RowBox[{"(", 
     RowBox[{
     "add", " ", "them", " ", "between", " ", "the", " ", "quotation", " ", 
      "markes", " ", "below"}], ")"}]}], "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Scaling", "=", "6"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ViewingDir", "=", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"NewViewingDirection", "=", 
    RowBox[{"Show", "[", 
     RowBox[{"ElleWOplanes", ",", 
      RowBox[{"ViewPoint", "\[Rule]", 
       RowBox[{"Scaling", "*", 
        RowBox[{"ViewingDir", "/", 
         RowBox[{"Norm", "[", "ViewingDir", "]"}]}]}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\< \>\"", ",", "\"\< \>\"", ",", "\"\< \>\""}], "}"}]}]}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.5034189833267164`*^9, 3.50341898856069*^9}, {
   3.5034221493804197`*^9, 3.5034222093445644`*^9}, {3.5034222505757723`*^9, 
   3.50342228218272*^9}, {3.5034223841436386`*^9, 3.503422388268322*^9}, {
   3.5034225328353434`*^9, 3.5034225420533853`*^9}, {3.503422617750696*^9, 
   3.5034226236877403`*^9}, {3.5034226845111933`*^9, 3.503422685886088*^9}, {
   3.503422751209196*^9, 3.503422785956527*^9}, 3.521982197745466*^9, 
   3.5219822600000267`*^9, {3.5219823914395447`*^9, 3.521982416148958*^9}, {
   3.5219824757303658`*^9, 3.521982484664877*^9}, {3.5219825309385233`*^9, 
   3.5219825984223833`*^9}, {3.521982678270951*^9, 3.521982738785412*^9}, {
   3.5219832129395323`*^9, 3.52198323930704*^9}, {3.5219832805654*^9, 
   3.521983293749154*^9}, {3.5220105681580615`*^9, 3.5220105730408697`*^9}, {
   3.5220108050444775`*^9, 3.52201080669808*^9}, {3.522010860970576*^9, 
   3.5220108629517794`*^9}, {3.522010895228236*^9, 3.52201095452394*^9}, 
   3.522010989967202*^9, {3.5220176743137426`*^9, 3.5220177585538907`*^9}, 
   3.611058717858246*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "You", " ", "can", " ", "export", " ", "your", " ", "ellipsoid", " ", 
    "with", " ", "the", " ", "new", " ", "viewing", " ", "perspective"}], " ",
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<NewViewingDirection-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.jpg\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "NewViewingDirection"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<NewViewingDirection-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.tif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "NewViewingDirection"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<NewViewingDirection-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.gif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "NewViewingDirection"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<NewViewingDirection-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.pdf\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "NewViewingDirection"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<NewViewingDirection-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.eps\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "NewViewingDirection"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.50342279587764*^9, 3.5034229804415894`*^9}, {
   3.5034230411400523`*^9, 3.5034230641695337`*^9}, {3.611058733769156*^9, 
   3.6110587533282747`*^9}, {3.6110601414276695`*^9, 3.6110601924465876`*^9}, 
   3.611621235600295*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "You", " ", "can", " ", "export", " ", "images", " ", "of", " ", "the", 
    " ", "ellipsoid", " ", "with", " ", "the", " ", "planes"}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PlanesEllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.jpg\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "EllipsoidPlanes"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PlanesEllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.tif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "EllipsoidPlanes"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PlanesEllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.gif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "EllipsoidPlanes"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PlanesEllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.pdf\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "EllipsoidPlanes"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PlanesEllipsoidImage-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.eps\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "EllipsoidPlanes"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.496794845706218*^9, 3.4967948791517715`*^9}, {
   3.4967949150929475`*^9, 3.4967949784868755`*^9}, {3.4967953256210346`*^9, 
   3.4967953358730087`*^9}, {3.496929286066066*^9, 3.496929335985921*^9}, {
   3.5032398476694164`*^9, 3.50323984790379*^9}, {3.5032400373088274`*^9, 
   3.5032400403869333`*^9}, {3.61106025402511*^9, 3.6110603174327364`*^9}, {
   3.611060407502888*^9, 3.6110604114411135`*^9}, 3.6116212373113933`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "You", " ", "can", " ", "export", " ", "images", " ", "of", " ", "the", 
    " ", "Hsu", " ", "Diagram"}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<HsuDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.jpg\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FullHsu"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<HsuDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.tif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FullHsu"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<HsuDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.gif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FullHsu"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<HsuDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.pdf\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FullHsu"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<HsuDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.eps\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FullHsu"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4967969767813673`*^9, 3.4967970137177925`*^9}, {
   3.49679705410182*^9, 3.496797061766221*^9}, {3.4969391590187664`*^9, 
   3.496939162700977*^9}, {3.503239849935027*^9, 3.5032398501694*^9}, {
   3.5032400440431595`*^9, 3.503240047996259*^9}, {3.5179614283598213`*^9, 
   3.5179614287408433`*^9}, {3.6110605230574975`*^9, 3.6110605685530996`*^9}, 
   3.6116212387254744`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "You", " ", "can", " ", "export", " ", "images", " ", "of", " ", "the", 
    " ", "Flinn", " ", "Diagram"}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<FlinnDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.jpg\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FlinnDiagram"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<FlinnDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.tif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FlinnDiagram"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<FlinnDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.gif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FlinnDiagram"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<FlinnDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.pdf\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FlinnDiagram"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<FlinnDiagram-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.eps\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "FlinnDiagram"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4967969767813673`*^9, 3.4967970137177925`*^9}, {
   3.49679705410182*^9, 3.4967970890676317`*^9}, {3.49693916747325*^9, 
   3.496939170961449*^9}, {3.5032398523568864`*^9, 3.50323985256001*^9}, {
   3.5032400544337177`*^9, 3.5032400581524444`*^9}, {3.611060630890665*^9, 
   3.611060686467844*^9}, 3.611621240350567*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "You", " ", "can", " ", "export", " ", "images", " ", "of", " ", "the", 
    " ", "Equal", " ", "Area", " ", "Plot", " ", "of", " ", "the", " ", 
    "Principal", " ", "Axes"}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PrincipalAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.jpg\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "PrinAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PrincipalAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.tif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "PrinAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PrincipalAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.gif\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "PrinAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PrincipalAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.pdf\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "PrinAxesPlot"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<PrincipalAxesPlot-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.eps\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "PrinAxesPlot"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5179505980923653`*^9, 3.5179506022306023`*^9}, {
   3.517950652984505*^9, 3.5179506923597574`*^9}, {3.611061141467869*^9, 
   3.611061200692256*^9}, {3.6116208120140676`*^9, 3.6116208166863346`*^9}, 
   3.611621241851653*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "You", " ", "can", " ", "also", " ", "export", " ", "the", " ", "strain", 
    " ", "data", " ", "to", " ", "various", " ", "types", " ", "of", " ", 
    "files"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ExportDataTable", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<Long Axis Length\>\"", ",", "\"\<Intermediate Axis Length\>\"", 
         ",", "\"\<Short Axis Length\>\"", ",", "\"\<\[Epsilon]s\>\"", ",", 
         "\"\<Flinn's k\>\"", ",", "\"\<Lode's Ratio\>\"", ",", " ", 
         "\"\<Long Axis Trend\>\"", ",", "\"\<Long Axis Plunge\>\"", ",", 
         " ", "\"\<Intermediate Axis Trend\>\"", ",", 
         "\"\<Intermediate Axis Plunge\>\"", ",", " ", 
         "\"\<Short Axis Trend\>\"", ",", "\"\<Short Axis Plunge\>\"", ",", 
         "\"\<Mean Error\>\""}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{
          "Lval", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
          RowBox[{
          "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
         ",", "1.0", ",", 
         FractionBox[
          RowBox[{
          "Lval", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
          RowBox[{
          "Lval", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]], 
         ",", "\[Epsilon]s", ",", "K", ",", "\[Nu]", ",", "LTrend", ",", 
         "LPlunge", ",", "ITrend", ",", "IPlunge", ",", "STrend", ",", 
         "SPlunge", ",", "MeanDiffError"}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<DataTable-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.xls\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ExportDataTable"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<DataTable-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.txt\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ExportDataTable"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{"\"\<DataTable-\>\"", "<>", 
        RowBox[{"ToString", "[", 
         RowBox[{
          RowBox[{"FileBaseName", "[", "FN", "]"}], "<>", 
          RowBox[{"ToString", "[", "\"\<.dat\>\"", "]"}]}], "]"}]}], "}"}], 
      "]"}], ",", "ExportDataTable"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.518188056808186*^9, 3.518188094310652*^9}, {
   3.518188628166637*^9, 3.5181886441775527`*^9}, {3.5181914847640247`*^9, 
   3.518191503855117*^9}, {3.518191547841633*^9, 3.51819158888498*^9}, {
   3.518191882317764*^9, 3.518191905100067*^9}, {3.5181920611679935`*^9, 
   3.5181920625840745`*^9}, {3.5181929876769867`*^9, 3.518192988939059*^9}, 
   3.61148466055698*^9, {3.611499195500331*^9, 3.611499203992817*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "  ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "If", " ", "you", " ", "know", " ", "the", " ", "orientation", " ", "of",
       " ", "the", " ", "regional", " ", "motion", " ", "plane", " ", "and", 
      " ", "want", " ", "to", " ", "know", " ", "how", " ", "much", " ", 
      "out"}], "-", "of", "-", 
     RowBox[{
     "plane", " ", "motion", " ", "your", " ", "strain", " ", "measurement", 
      " ", "represents", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"one", " ", "is", " ", "plane", " ", "strain"}], ",", " ", 
        RowBox[{
        "less", " ", "than", " ", "one", " ", "is", " ", "constrictional", 
         " ", "and", " ", "greater", " ", "than", " ", "one", " ", "is", " ", 
         "flattening"}]}], ")"}]}]}], ",", " ", 
    RowBox[{"evaluate", " ", "this", " ", 
     RowBox[{"cell", ".", " ", "This"}], " ", "method", " ", "assumes", " ", 
     "no", " ", "volume", " ", 
     RowBox[{"loss", "."}]}]}], "  ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"MotionDip", "=", 
     RowBox[{
     "Input", "[", "\"\<Enter the Dip  for the Regional Motion Plane\>\"", 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MotionDipDir", "=", 
     RowBox[{
     "Input", "[", 
      "\"\<Enter the Dip Direction for the Regional Motion Plane\>\"", 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"MotionDipDir", "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{"MotionDipDir", "\[LessEqual]", "90"}]}], ",", 
      RowBox[{
       RowBox[{"\[Theta]", "=", "MotionDipDir"}], ";"}]}], "]"}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"MotionDipDir", ">", "90"}], "&&", 
       RowBox[{"MotionDipDir", "\[LessEqual]", "180"}]}], ",", 
      RowBox[{
       RowBox[{"\[Theta]", "=", 
        RowBox[{"180", "-", "MotionDipDir"}]}], ";"}]}], "]"}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"MotionDipDir", ">", "180"}], "&&", 
       RowBox[{"MotionDipDir", "\[LessEqual]", "270"}]}], ",", 
      RowBox[{
       RowBox[{"\[Theta]", "=", 
        RowBox[{"MotionDipDir", "-", "180"}]}], ";"}]}], "]"}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"MotionDipDir", ">", "270"}], "&&", 
       RowBox[{"MotionDipDir", "\[LessEqual]", "360"}]}], ",", 
      RowBox[{
       RowBox[{"\[Theta]", "=", 
        RowBox[{"360", "-", "MotionDipDir"}]}], ";"}]}], "]"}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Theta]", "\[Equal]", "90"}], "||", 
       RowBox[{"\[Theta]", "\[Equal]", "270"}]}], ",", 
      RowBox[{
       RowBox[{"a", "=", "0"}], ";"}], ",", 
      RowBox[{
       RowBox[{"a", "=", 
        SqrtBox[
         FractionBox["1", 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{"Tan", "[", 
             FractionBox[
              RowBox[{"\[Theta]", " ", "\[Pi]"}], "180"], "]"}], "2"]}]]]}], 
       ";"}]}], "]"}], ";", 
    RowBox[{"b", "=", 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox["a", "2"]}]]}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"MotionDip", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"a", "=", "0"}], ";", 
       RowBox[{"b", "=", "0"}], ";", 
       RowBox[{"c", "=", "1"}], ";"}], ",", 
      RowBox[{
       RowBox[{"c", "=", 
        RowBox[{"Tan", "[", 
         RowBox[{
          FractionBox["1", "180"], " ", 
          RowBox[{"(", 
           RowBox[{"90", "-", "MotionDip"}], ")"}], " ", "\[Pi]"}], "]"}]}], 
       ";"}]}], "]"}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"MotionDipDir", "\[GreaterEqual]", "0"}], "&&", 
       RowBox[{"MotionDipDir", "\[LessEqual]", "90"}]}], ",", 
      RowBox[{
       RowBox[{"a", "=", "a"}], ";", 
       RowBox[{"b", "=", 
        RowBox[{"-", "b"}]}], ";"}]}], "]"}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"MotionDipDir", ">", "90"}], "&&", 
       RowBox[{"MotionDipDir", "\[LessEqual]", "180"}]}], ",", 
      RowBox[{
       RowBox[{"a", "=", 
        RowBox[{"-", "a"}]}], ";", 
       RowBox[{"b", "=", 
        RowBox[{"-", "b"}]}], ";"}]}], "]"}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"MotionDipDir", ">", "180"}], "&&", 
       RowBox[{"MotionDipDir", "\[LessEqual]", "270"}]}], ",", 
      RowBox[{
       RowBox[{"a", "=", 
        RowBox[{"-", "a"}]}], ";", 
       RowBox[{"b", "=", "b"}], ";"}]}], "]"}], ";", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"MotionDipDir", ">", "270"}], "&&", 
       RowBox[{"MotionDipDir", "\[LessEqual]", "360"}]}], ",", 
      RowBox[{
       RowBox[{"a", "=", "a"}], ";", 
       RowBox[{"b", "=", "b"}], ";"}]}], "]"}], ";", 
    RowBox[{"scale", "=", 
     FractionBox["1", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}]]]}], ";", 
    RowBox[{"aprime", "=", 
     RowBox[{"scale", " ", "a"}]}], ";", 
    RowBox[{"bprime", "=", 
     RowBox[{"scale", " ", "b"}]}], ";", 
    RowBox[{"cprime", "=", 
     RowBox[{"scale", " ", "c"}]}], ";", 
    RowBox[{"normvect", "=", 
     RowBox[{"N", "[", 
      RowBox[{"{", 
       RowBox[{"aprime", ",", "bprime", ",", "cprime"}], "}"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"linit", "=", 
     RowBox[{"linit", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Lval", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "*", 
         RowBox[{"Lval", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "*", 
         RowBox[{"Lval", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "3"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"len", "=", 
     RowBox[{"1", "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Norm", "[", 
        RowBox[{"FitEllipsoid", ".", 
         RowBox[{"Normalize", "[", "normvect", "]"}]}], "]"}], "]"}]}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"OutofPlane", "=", 
     RowBox[{"Log", "[", 
      RowBox[{"len", "/", "linit"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<Your out-of-plane natural strain (\!\(\*SubscriptBox[\(\[Epsilon]\), \
\(OP\)]\)) = \>\"", ",", "OutofPlane"}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.5034256456431365`*^9, 3.50342580613081*^9}, {
   3.503425963774952*^9, 3.5034259791018996`*^9}, {3.503426075110151*^9, 
   3.5034261022330675`*^9}, {3.5034264432381268`*^9, 3.503426453831063*^9}, {
   3.503428500236387*^9, 3.5034286007599163`*^9}, {3.503428683487937*^9, 
   3.503428693393426*^9}, {3.5034289183605223`*^9, 3.5034289200791407`*^9}, {
   3.503429321876405*^9, 3.5034293502960973`*^9}, {3.5034294005578613`*^9, 
   3.5034294279307594`*^9}, {3.5037529301537943`*^9, 
   3.5037529359503355`*^9}, {3.5037775551728115`*^9, 3.503777557344561*^9}, {
   3.5479801049470253`*^9, 3.547980107407029*^9}, 3.611499235409614*^9}]
}, Open  ]]
},
WindowSize->{1024, 626},
WindowMargins->{{0, Automatic}, {Automatic, 3}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 62266, 1002, 1570, "Title"],
Cell[62836, 1026, 210340, 5583, 15048, "Input"],
Cell[273179, 6611, 7450, 157, 412, "Input"],
Cell[280632, 6770, 2440, 49, 152, "Input"],
Cell[283075, 6821, 2574, 61, 252, "Input"],
Cell[285652, 6884, 2751, 63, 172, "Input"],
Cell[288406, 6949, 2580, 63, 152, "Input"],
Cell[290989, 7014, 2561, 62, 152, "Input"],
Cell[293553, 7078, 2560, 62, 172, "Input"],
Cell[296116, 7142, 3277, 74, 218, "Input"],
Cell[299396, 7218, 7323, 199, 559, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
